local util = require("util")

-- STORAGE =========================================================

local created_items = function()
  return
  {
    ["power-armor-mk2"] = "1",
    ["submachine-gun"] = "1",
    ["combat-shotgun"] = "1",
    ["flamethrower"] = "1",
    ["uranium-rounds-magazine"] = "200",
    ["piercing-shotgun-shell"] = "200",
    ["flamethrower-ammo"] = "100",
    ["construction-robot"] = "100",
    ["infinity-pipe"] = "50",
    ["infinity-chest"] = "50",
    ["heat-interface"] = "50",
    ["electric-energy-interface"] = "50",
    ["loader"] = "50",
    ["fast-loader"] = "50",
    ["express-loader"] = "50"
  }
end

-- EVENTS ======================================================

--  on_player ===============================
local on_player_created = function(event)
  local player = game.players[event.player_index]

  player.color={r=0.118,g=0.565,b=1.000,a=.9}
  player.teleport({0,0}, game.surfaces["Sandbox"])

  util.insert_safe(player, storage.created_items)

  local p_armor = player.get_inventory(5)[1].grid
  p_armor.put({name = "fission-reactor-equipment"})
  p_armor.put({name = "fission-reactor-equipment"})
  p_armor.put({name = "fission-reactor-equipment"})
  p_armor.put({name = "fission-reactor-equipment"})
  p_armor.put({name = "exoskeleton-equipment"})
  p_armor.put({name = "exoskeleton-equipment"})
  p_armor.put({name = "personal-roboport-mk2-equipment"})
  p_armor.put({name = "personal-roboport-mk2-equipment"})
  p_armor.put({name = "personal-roboport-mk2-equipment"})
  p_armor.put({name = "personal-roboport-mk2-equipment"})
  p_armor.put({name = "battery-mk2-equipment"})
  p_armor.put({name = "battery-mk2-equipment"})

  player.force.research_all_technologies()
  for k, v in pairs(player.force.recipes) do
    player.force.recipes[v.name].enabled = true
  end

  player.cheat_mode = true
  player.surface.always_day = true
  player.force.technologies['worker-robots-speed-6'].level = 100
  --player.force.character_build_distance_bonus = 10000
  --player.force.character_reach_distance_bonus = 10000

  player.print({"msg-intro"})
  player.surface.print({"map-working"})
end --on_player_created

local on_player_respawned = function(event)
  local player = game.players[event.player_index]
  player.teleport({0,0}, game.surfaces["Sandbox"])
  player.cheat_mode = true
  for k, v in pairs(player.force.recipes) do
    player.force.recipes[v.name].enabled = true
  end
  player.print({"msg-death"})
end --on_player_respawned


--  on_chunk_generated ===============================
local on_chunk_generated = function(event)
  local force = game.forces.player
  
  -- make sandbox
  if event.surface.name == "Sandbox" then
    ClearAreaSquare2(event.surface.name,event.area.left_top.x,event.area.left_top.y,event.area.right_bottom.x,event.area.right_bottom.y);
    weed_tile(event.surface,event.area.left_top.x,event.area.left_top.y,event.area.right_bottom.x,event.area.right_bottom.y);
    DrawLndSquare(event.surface.name,"sand-3",event.area.left_top.x,event.area.left_top.y,32,32);
    -- draw logo
    if event.area.left_top.x == 192 and event.area.left_top.y == 128 then
        DrawFactorioGear(event.surface.name,0,0)
        local radius = 300
        force.chart(event.surface,{{x = -radius , y = -radius }, {x = radius , y = radius }})
        event.surface.print({"map-ready"})
    end
    -- draw resources
    if event.area.left_top.y >= 192 then -- past resource line
        for i=1,#storage.resourcecoords do
          left = storage.resourcecoords[i]
          if event.area.left_top.x == left then
            someresource = storage.resourcelist[i]
            if someresource == "trees" then
              DrawTreesSquare(event.surface.name,event.area.left_top.x,event.area.left_top.y,32,32,2)
            elseif TableHasItem(storage.ores,someresource) == true then
              DrawOreSquare(event.surface.name,someresource,4000000,event.area.left_top.x,event.area.left_top.y,32,32)
            elseif TableHasItem(storage.liquids,someresource) == true then
              DrawLiquidSquare(event.surface.name,someresource,15000*10*4,event.area.left_top.x+1,event.area.left_top.y+1,8,8)
            elseif TableHasItem(storage.lands,someresource) == true then
              if someresource == "deepwater-green" or someresource == "water-green" or someresource == "deepwater" or someresource == "water" then
              DrawLndSquare(event.surface.name,"grass-1",event.area.left_top.x,event.area.left_top.y,10,34)
              end
              DrawLndSquare(event.surface.name,someresource,event.area.left_top.x+2,event.area.left_top.y+2,6,30)
            end
          end -- matching left
        end -- for
    end -- line
  end -- sandbox

end --on_chunk_generated





-- setup ==============================================
local ovsandbox = {}

ovsandbox.events =
{
  [defines.events.on_player_created] = on_player_created,
  [defines.events.on_chunk_generated] = on_chunk_generated,
  [defines.events.on_player_respawned] = on_player_respawned
}

-- config changed ==============================================

ovsandbox.on_configuration_changed = function(event)
  storage.created_items = storage.created_items or created_items()
end

-- INIT ==============================================

ovsandbox.on_init = function()
  storage.created_items = created_items()

  local nauvis = game.surfaces["nauvis"]
  local force = game.forces.player

  -- trees,newores,newliquids,copper,iron,stone,oil,uranium-ore,coal,water
  storage.ores = {"copper-ore","iron-ore","stone","coal","uranium-ore"}
  storage.liquids = {"crude-oil"}
  storage.lands = {"water-green","water","deepwater","deepwater-green"}
  storage.resourcecoords = {}
  storage.resourcelist = {"copper-ore","iron-ore","stone","crude-oil","coal","uranium-ore","water"}

  local SandboxAutoplace = {}
  -- add unknown resources
  -- for k, item in pairs(game.entity_prototypes) do
  for k, item in pairs(prototypes.entity) do
      if item.type == "resource" then
        SandboxAutoplace[item.name] = { frequency = "none", size = "none", richness = "none" }
        if item.resource_category == "basic-solid" then
          if TableHasItem(storage.ores,item.name) == false then
            table.insert(storage.ores,item.name)
            table.insert(storage.resourcelist,1,item.name)
          end
        else
          if TableHasItem(storage.liquids,item.name) == false then
            table.insert(storage.liquids,item.name)
            table.insert(storage.resourcelist,1,item.name)
          end
        end
      end
  end
  -- add trees to the start
  table.insert(storage.resourcelist,1,"trees")

  -- chuncks are 32 wide
  -- resourcestart = ((math.floor(#storage.resourcelist /2) * 64)-32) * -1
  resourcestart = ((math.floor(#storage.resourcelist /2) * 64)) * -1
  for i=0,#storage.resourcelist-1 do
    table.insert(storage.resourcecoords,resourcestart + (i*64))
  end

  SandboxAutoplace["enemy-base"] = nauvis.map_gen_settings.autoplace_controls["enemy-base"]

  local map_gen =
  {
    terrain_segmentation = "normal",
    water = "none",
    autoplace_controls = SandboxAutoplace,
    seed = nauvis and nauvis.map_gen_settings.seed or math.round(math.random() * const.max_uint),
    shift = nauvis and nauvis.map_gen_settings.shift or nil,
    width = nauvis and nauvis.map_gen_settings.width or 0,
    height = nauvis and nauvis.map_gen_settings.height or 0,
    starting_area = "very-big",
    peaceful_mode = nauvis and nauvis.map_gen_settings.peaceful_mode or 0
  }   
  game.create_surface( "Sandbox", map_gen )

  --reveal map and generate chunks for drawing
  local radius = 200
  force.chart(game.surfaces["Sandbox"],{{x = -radius , y = -radius }, {x = radius , y = radius }})

end -- init

-- FUNCTIONS =============================================================

function weed_tile(surface,tx,ty,bx,by)
    local tile = { {tx,ty},{bx,by} }
    surface.destroy_decoratives(tile)
end

function TableConcat(t1,t2)
    for i=1,#t2 do
        t1[#t1+1] = t2[i]
    end
    return t1
end -- TableConcat, add t2 to the end of t1

function TableHasItem(tab, val)
  for index, value in ipairs (tab) do
    if value == val then
      return true
    end
  end
  return false
end -- TableHasItem

function DrawTreesSquare(surface,x,y,width,height,spaceing)
  listtrees = {
    "dead-tree-desert",
    "tree-01",
    "tree-02",
    "tree-02-red",
    "tree-03",
    "tree-04",
    "tree-05"
  }
  px = 0
  while( px < width ) do
    py = 0
    while( py < height ) do
      game.surfaces[surface].create_entity{name = listtrees[math.random(#listtrees)], position={x + px, y + py}}
      py = py + spaceing
    end
    px = px + spaceing
  end
end -- DrawTreesSquare

function DrawOreSquare(surface,type,richness,x,y,width,length)
  for vl=0,length-1 do
      for vw=0,width-1 do
          game.surfaces[surface].create_entity{name=type,amount=richness,position={x+vw, y+vl}}
      end
  end
end -- DrawOreSquare

function DrawLiquidSquare(surface,type,richness,x,y,width,height)
  local spaceing = 4;
  for wellx=0,(width-1) do
    for welly=0,(height-1) do
      game.surfaces[surface].create_entity{name=type, position={x+(wellx*spaceing),y+(welly*spaceing)}, amount=richness};
    end
  end
end -- DrawLiquidSquare

function DrawLndCircle(surface,type,radius,x,y)
  local tiles={};
  for gx=-radius ,radius do 
      for gy=-radius ,radius do
          spotx = x+gx; spoty = y+gy;
          distance = math.sqrt((x - spotx) * (x - spotx) + (y - spoty) * (y - spoty));
          if distance <= radius then table.insert(tiles,{name=type,position={spotx,spoty}}) end
      end 
  end
  game.surfaces[surface].set_tiles(tiles);
end -- DrawLndCircle

function DrawLndRing(surface,type,x,y,radius,width) 
-- inner width
local tiles={};
for gx=-radius ,radius  do 
    for gy=-radius ,radius  do
        spotx = x+gx; spoty = y+gy;
        distance = math.sqrt((x - spotx) * (x - spotx) + (y - spoty) * (y - spoty));
        if distance <= radius and distance >= (radius - width) then table.insert(tiles,{name=type,position={spotx,spoty}}) end
    end 
end
game.surfaces[surface].set_tiles(tiles);
end -- DrawLndRing

function DrawLndSquare(surface,type,x,y,width,height)
  local tiles={};
  for gx=x ,x+width-1 do 
      for gy=y ,y+height-1 do
        table.insert(tiles,{name=type,position={gx,gy}})
      end 
  end
  game.surfaces[surface].set_tiles(tiles);
end -- DrawLndSquare

function DrawLndSquareRadius(surface,type,x,y,radius)
  local tiles={};
  for gx= x-radius , x+radius do 
      for gy= y-radius , y+radius do
        table.insert(tiles,{name=type,position={gx,gy}})
      end 
  end
  game.surfaces[surface].set_tiles(tiles);
end -- DrawLndSquareRadius

function DrawLndBox(surface,type,x,y,radius,width) 
-- inner width
local tiles={};
for gx=-radius ,radius  do 
    for gy=-radius ,radius  do
        spotx = x+gx; spoty = y+gy;
        if 
            (spotx >= (x-radius) and spotx <= (x-radius + width) or spotx <= (x+radius) and spotx >= (x+radius - width) )
            or
            (spoty >= (y-radius) and spoty <= (y-radius + width) or spoty <= (y+radius) and spoty >= (y+radius - width) )
        then table.insert(tiles,{name=type, position={spotx,spoty}}) end
    end 
end
game.surfaces[surface].set_tiles(tiles);
end -- DrawLndBox

function weed_tile(surface,tx,ty,bx,by)
    local tile = { {tx,ty},{bx,by} }
    surface.destroy_decoratives(tile)
end

function ClearAreaSquare2(surface,tx,ty,bx,by)
--note you cannont clear what has not been charted, 190 radius normally on start
  for _, entity in ipairs( game.surfaces[surface].find_entities{{tx,ty},{bx,by}} ) do 
    if entity.force.name ~= "player" and entity.force.name ~= "enemy" then entity.destroy(); end
  end
end --ClearAreaSquare2

function ClearAreaSquare(surface,tx,ty,bx,by)
--note you cannont clear what has not been charted, 190 radius normally on start
  for _, entity in ipairs( game.surfaces[surface].find_entities{ {tx,ty},{bx,by} } ) do 
    if entity.force.name ~= "player" then entity.destroy(); end
  end
end --ClearAreaSquare

function ClearAreaSquareRadius(surface,x,y,radius)
--note you cannont clear what has not been charted, 190 radius normally on start
  for _, entity in ipairs( game.surfaces[surface].find_entities{ {x-radius,y-radius},{x+radius,y+radius} } ) do 
    if entity.force.name ~= "player" then entity.destroy(); end
  end
end -- ClearAreaSquareRadius

function ClearAreaCircle(surface,x,y,radius)
--note you cannont clear what has not been charted, 190 radius normally on start
  for _, entity in ipairs(game.surfaces[surface].find_entities{{x-radius,y-radius },{x+radius,y+radius }}) do 
      if entity.force.name ~= "player" then
          local distance = math.sqrt((x - entity.position.x) * (x - entity.position.x) + (y - entity.position.y) * (y - entity.position.y));
          if distance <= radius then entity.destroy() end 
      end
  end
end --ClearAreaCircle

function DrawFactorioGear(surface,posx,posy)
  tiles = {};
  xoffset = -200;
  yoffset = -200;
  
listdirt1 = {299,58,307,340,308,340,309,340,310,340,307,341,308,341,309,341,307,342,308,342,309,342,307,343,308,343,309,343}
listdirt2 = {242,55,310,70,183,96,135,157,326,161,306,339,307,339,308,339,309,339,310,339,311,339,306,340,311,340,310,341,308,344,309,344}
listdirt3 = {215,18,225,25,225,26,224,29,225,31,226,46,126,48,165,51,229,51,230,51,231,53,236,53,237,54,235,55,239,55,234,56,236,56,237,56,238,56,239,56,243,56,214,57,235,57,237,57,239,57,246,57,229,58,233,58,236,58,240,58,244,58,247,58,296,58,232,59,236,59,241,59,245,59,233,60,234,60,238,60,233,61,234,61,305,64,262,65,141,66,305,66,225,67,226,67,307,68,310,69,311,72,310,73,225,74,136,75,189,75,103,76,106,77,194,77,304,79,145,80,303,80,248,81,109,82,310,82,140,88,232,88,239,92,252,92,236,95,122,96,201,96,243,96,143,98,236,99,169,101,170,101,163,108,147,110,132,112,189,113,138,116,282,116,152,118,139,120,145,120,153,120,139,123,136,125,302,125,136,128,144,128,274,128,302,128,137,130,139,131,255,135,139,136,288,137,248,139,101,141,136,141,250,145,289,145,137,148,130,150,119,151,332,151,138,152,335,152,336,152,338,152,339,152,335,153,151,154,326,154,96,155,328,156,122,158,134,159,326,159,327,160,120,161,308,161,75,164,92,165,71,166,82,166,113,166,61,167,62,167,73,167,121,168,94,169,101,171,255,171,325,171,131,172,98,173,94,174,89,175,93,175,325,175,325,176,136,181,103,190,282,192,287,192,130,194,108,200,267,200,279,201,216,203,110,204,126,205,109,207,122,214,194,214,194,215,113,216,153,220,169,220,176,220,181,221,114,223,119,224,162,227,100,229,121,229,275,231,123,232,101,233,282,234,122,235,254,235,274,235,130,237,132,239,83,240,286,241,111,242,263,243,283,246,115,249,266,249,270,249,271,249,270,250,214,251,220,252,219,253,269,253,280,254,260,256,265,258,270,261,192,263,181,264,206,265,271,266,175,268,272,268,272,269,273,270,175,289,252,317,200,318,202,318,303,318,61,323,61,326,347,327,150,329,153,329,162,329,164,329,170,329,173,329,270,329,286,330,353,330,110,331,223,332,110,333,333,333,110,334,110,335,332,335,223,336,122,337,162,337,158,339,315,339,321,340,158,342,158,343,307,344,61,345,213,346,158,347,199,353,200,354,233,354,340,355,124,356,341,356,342,361,343,361}
listdirt4 = {196,16,197,16,203,16,204,16,205,16,206,16,210,17,224,19,226,26,225,27,225,28,225,29,226,29,224,30,226,30,226,31,223,32,224,32,225,32,226,32,223,33,224,33,226,33,224,34,226,34,195,35,214,35,225,35,223,36,225,36,226,36,199,37,216,37,223,37,224,37,226,37,196,38,223,38,224,38,225,38,226,38,222,39,223,39,226,39,222,40,225,40,226,40,195,41,222,41,205,43,222,43,223,43,226,43,205,44,223,44,225,44,226,44,194,45,222,45,223,45,224,45,226,45,227,45,198,46,224,46,225,46,227,46,223,47,224,47,225,47,226,47,228,47,192,48,193,48,224,48,225,48,226,48,228,48,127,49,171,49,192,49,222,49,228,49,168,50,192,50,193,50,222,50,225,50,228,50,229,50,130,51,198,51,210,51,211,51,225,51,227,51,228,51,232,51,131,52,191,52,199,52,224,52,228,52,229,52,230,52,231,52,232,52,233,52,132,53,158,53,192,53,197,53,208,53,214,53,228,53,229,53,230,53,232,53,237,53,133,54,189,54,191,54,226,54,227,54,228,54,229,54,231,54,232,54,233,54,234,54,295,54,135,55,200,55,201,55,211,55,217,55,224,55,225,55,226,55,230,55,237,55,240,55,151,56,197,56,198,56,217,56,224,56,232,56,233,56,235,56,241,56,242,56,244,56,190,57,191,57,192,57,206,57,212,57,222,57,223,57,228,57,229,57,238,57,241,57,242,57,243,57,139,58,145,58,199,58,211,58,212,58,213,58,223,58,226,58,228,58,235,58,238,58,241,58,242,58,243,58,246,58,248,58,249,58,141,59,143,59,208,59,213,59,224,59,225,59,226,59,230,59,235,59,285,59,293,59,297,59,300,59,126,60,186,60,188,60,196,60,199,60,204,60,205,60,208,60,213,60,216,60,218,60,219,60,223,60,226,60,229,60,232,60,236,60,237,60,292,60,293,60,179,61,180,61,188,61,189,61,191,61,192,61,193,61,197,61,198,61,199,61,204,61,206,61,207,61,208,61,209,61,210,61,212,61,213,61,214,61,215,61,216,61,219,61,222,61,225,61,229,61,232,61,251,61,255,61,291,61,300,61,188,62,189,62,190,62,191,62,192,62,193,62,199,62,203,62,204,62,206,62,210,62,211,62,212,62,213,62,214,62,215,62,216,62,217,62,218,62,219,62,220,62,222,62,280,62,299,62,301,62,121,63,130,63,190,63,204,63,211,63,214,63,215,63,216,63,217,63,219,63,220,63,221,63,222,63,226,63,259,63,278,63,172,64,202,64,204,64,210,64,213,64,216,64,220,64,221,64,222,64,223,64,224,64,225,64,226,64,230,64,231,64,294,64,296,64,125,65,126,65,137,65,138,65,172,65,182,65,195,65,196,65,202,65,222,65,223,65,224,65,225,65,226,65,227,65,230,65,234,65,291,65,303,65,305,65,306,65,116,66,140,66,171,66,186,66,187,66,188,66,189,66,195,66,199,66,202,66,208,66,209,66,222,66,226,66,227,66,228,66,297,66,306,66,134,67,135,67,136,67,140,67,141,67,166,67,189,67,190,67,192,67,199,67,210,67,211,67,214,67,220,67,222,67,223,67,227,67,228,67,229,67,230,67,236,67,266,67,298,67,301,67,304,67,136,68,163,68,190,68,210,68,211,68,219,68,220,68,221,68,222,68,223,68,226,68,227,68,228,68,230,68,234,68,292,68,299,68,300,68,301,68,143,69,190,69,191,69,207,69,208,69,217,69,218,69,219,69,221,69,222,69,225,69,228,69,232,69,234,69,235,69,292,69,305,69,97,70,143,70,210,70,221,70,225,70,226,70,233,70,235,70,236,70,291,70,292,70,295,70,307,70,308,70,97,71,98,71,99,71,121,71,141,71,146,71,151,71,152,71,165,71,166,71,171,71,224,71,229,71,231,71,236,71,293,71,302,71,308,71,311,71,99,72,100,72,151,72,164,72,165,72,166,72,192,72,193,72,199,72,220,72,232,72,233,72,235,72,236,72,297,72,298,72,304,72,99,73,101,73,192,73,238,73,240,73,241,73,242,73,243,73,249,73,278,73,279,73,286,73,290,73,296,73,312,73,99,74,100,74,101,74,102,74,133,74,134,74,136,74,137,74,143,74,154,74,226,74,230,74,231,74,241,74,244,74,275,74,277,74,294,74,295,74,296,74,310,74,311,74,313,74,100,75,102,75,103,75,121,75,128,75,134,75,135,75,139,75,154,75,180,75,190,75,211,75,228,75,229,75,239,75,240,75,244,75,251,75,293,75,296,75,304,75,305,75,309,75,310,75,313,75,101,76,102,76,104,76,106,76,116,76,124,76,127,76,135,76,189,76,197,76,199,76,200,76,236,76,243,76,245,76,247,76,255,76,299,76,307,76,310,76,314,76,101,77,102,77,103,77,134,77,146,77,148,77,184,77,189,77,197,77,234,77,235,77,238,77,239,77,243,77,247,77,248,77,271,77,285,77,302,77,308,77,313,77,102,78,103,78,104,78,105,78,215,78,226,78,235,78,240,78,242,78,243,78,249,78,251,78,265,78,271,78,282,78,299,78,302,78,305,78,308,78,311,78,312,78,313,78,314,78,316,78,102,79,103,79,104,79,105,79,106,79,107,79,130,79,241,79,245,79,246,79,249,79,250,79,251,79,252,79,254,79,255,79,260,79,267,79,268,79,277,79,308,79,311,79,312,79,103,80,104,80,105,80,106,80,107,80,111,80,129,80,130,80,174,80,202,80,225,80,246,80,250,80,254,80,257,80,261,80,277,80,300,80,311,80,312,80,313,80,103,81,106,81,108,81,129,81,130,81,143,81,144,81,145,81,147,81,148,81,153,81,161,81,188,81,202,81,220,81,230,81,231,81,232,81,240,81,255,81,256,81,257,81,276,81,280,81,281,81,305,81,306,81,307,81,309,81,310,81,312,81,313,81,314,81,104,82,105,82,106,82,125,82,126,82,145,82,149,82,150,82,153,82,168,82,174,82,188,82,239,82,245,82,247,82,248,82,249,82,253,82,262,82,263,82,272,82,305,82,309,82,312,82,105,83,106,83,107,83,108,83,109,83,110,83,120,83,142,83,143,83,149,83,164,83,176,83,196,83,218,83,253,83,257,83,258,83,259,83,260,83,261,83,262,83,263,83,264,83,268,83,271,83,305,83,308,83,310,83,311,83,105,84,106,84,107,84,108,84,109,84,111,84,130,84,131,84,148,84,169,84,261,84,262,84,263,84,264,84,265,84,275,84,276,84,304,84,305,84,308,84,309,84,107,85,108,85,109,85,114,85,118,85,119,85,120,85,124,85,138,85,143,85,147,85,247,85,253,85,260,85,261,85,262,85,263,85,264,85,265,85,266,85,267,85,276,85,283,85,286,85,308,85,108,86,109,86,117,86,118,86,122,86,126,86,143,86,175,86,184,86,244,86,248,86,259,86,260,86,261,86,262,86,263,86,264,86,266,86,267,86,268,86,269,86,270,86,271,86,272,86,284,86,285,86,306,86,111,87,114,87,118,87,122,87,142,87,149,87,166,87,179,87,182,87,251,87,257,87,259,87,262,87,263,87,264,87,266,87,267,87,269,87,270,87,272,87,275,87,285,87,286,87,114,88,123,88,141,88,162,88,171,88,172,88,210,88,237,88,244,88,245,88,253,88,254,88,256,88,257,88,258,88,262,88,263,88,267,88,269,88,270,88,271,88,272,88,281,88,107,89,115,89,123,89,126,89,140,89,141,89,241,89,242,89,251,89,252,89,258,89,259,89,266,89,267,89,268,89,269,89,270,89,107,90,113,90,114,90,121,90,135,90,136,90,140,90,141,90,186,90,230,90,234,90,245,90,250,90,255,90,258,90,260,90,265,90,266,90,267,90,268,90,269,90,270,90,271,90,272,90,273,90,274,90,280,90,281,90,302,90,107,91,108,91,115,91,119,91,120,91,135,91,140,91,141,91,156,91,168,91,187,91,197,91,233,91,243,91,244,91,249,91,253,91,254,91,258,91,264,91,265,91,268,91,269,91,270,91,271,91,272,91,273,91,274,91,275,91,276,91,284,91,301,91,112,92,121,92,140,92,141,92,154,92,175,92,185,92,187,92,192,92,233,92,246,92,253,92,261,92,262,92,267,92,268,92,269,92,270,92,271,92,272,92,273,92,276,92,277,92,109,93,110,93,111,93,112,93,116,93,131,93,142,93,155,93,213,93,230,93,240,93,243,93,251,93,261,93,266,93,269,93,270,93,271,93,272,93,273,93,274,93,275,93,299,93,113,94,118,94,166,94,167,94,168,94,177,94,202,94,205,94,214,94,245,94,257,94,260,94,262,94,265,94,266,94,267,94,268,94,269,94,270,94,271,94,272,94,274,94,275,94,298,94,116,95,117,95,120,95,122,95,132,95,133,95,169,95,170,95,181,95,184,95,203,95,205,95,215,95,233,95,237,95,256,95,257,95,258,95,259,95,260,95,266,95,268,95,270,95,271,95,272,95,273,95,274,95,282,95,297,95,132,96,200,96,203,96,204,96,208,96,209,96,222,96,231,96,232,96,237,96,241,96,242,96,259,96,265,96,270,96,273,96,274,96,277,96,281,96,282,96,296,96,165,97,176,97,177,97,181,97,182,97,184,97,188,97,192,97,201,97,206,97,207,97,208,97,214,97,231,97,242,97,243,97,244,97,256,97,264,97,265,97,269,97,272,97,273,97,274,97,275,97,276,97,277,97,294,97,163,98,170,98,182,98,184,98,187,98,188,98,191,98,196,98,197,98,198,98,199,98,205,98,237,98,238,98,239,98,256,98,257,98,269,98,273,98,275,98,276,98,277,98,278,98,279,98,132,99,146,99,170,99,171,99,172,99,173,99,174,99,182,99,191,99,192,99,194,99,195,99,196,99,199,99,200,99,205,99,206,99,218,99,234,99,240,99,241,99,270,99,275,99,276,99,277,99,278,99,279,99,284,99,289,99,123,100,124,100,132,100,174,100,175,100,176,100,180,100,188,100,196,100,199,100,200,100,204,100,205,100,206,100,207,100,215,100,234,100,235,100,265,100,272,100,276,100,277,100,278,100,279,100,280,100,283,100,292,100,143,101,161,101,162,101,176,101,177,101,179,101,181,101,198,101,199,101,200,101,203,101,207,101,214,101,215,101,228,101,258,101,265,101,266,101,276,101,277,101,278,101,281,101,283,101,122,102,126,102,159,102,160,102,161,102,162,102,169,102,170,102,175,102,179,102,180,102,181,102,190,102,192,102,199,102,200,102,202,102,203,102,206,102,207,102,211,102,216,102,217,102,219,102,225,102,227,102,236,102,257,102,268,102,269,102,271,102,276,102,277,102,278,102,281,102,283,102,286,102,291,102,122,103,125,103,144,103,154,103,158,103,159,103,165,103,174,103,186,103,187,103,188,103,190,103,191,103,193,103,198,103,199,103,203,103,207,103,215,103,217,103,224,103,225,103,231,103,232,103,233,103,236,103,250,103,271,103,274,103,276,103,277,103,278,103,279,103,280,103,281,103,282,103,283,103,284,103,290,103,114,104,121,104,122,104,139,104,157,104,158,104,159,104,170,104,171,104,175,104,185,104,190,104,193,104,201,104,202,104,204,104,207,104,208,104,211,104,212,104,215,104,216,104,225,104,229,104,231,104,271,104,274,104,277,104,279,104,280,104,281,104,282,104,284,104,121,105,157,105,158,105,159,105,163,105,164,105,173,105,176,105,178,105,181,105,182,105,184,105,185,105,188,105,192,105,207,105,221,105,222,105,224,105,268,105,274,105,278,105,279,105,280,105,281,105,282,105,284,105,288,105,121,106,152,106,158,106,159,106,173,106,177,106,178,106,179,106,180,106,181,106,192,106,206,106,215,106,216,106,217,106,218,106,237,106,242,106,245,106,273,106,274,106,275,106,278,106,279,106,280,106,281,106,282,106,283,106,284,106,120,107,152,107,167,107,172,107,173,107,175,107,178,107,179,107,180,107,183,107,185,107,188,107,193,107,210,107,211,107,213,107,214,107,219,107,220,107,221,107,226,107,232,107,238,107,271,107,273,107,274,107,281,107,284,107,285,107,286,107,120,108,157,108,160,108,166,108,168,108,174,108,177,108,178,108,179,108,182,108,185,108,186,108,188,108,191,108,200,108,202,108,203,108,204,108,205,108,206,108,209,108,212,108,213,108,218,108,219,108,221,108,222,108,223,108,232,108,238,108,262,108,263,108,272,108,273,108,278,108,283,108,284,108,285,108,122,109,153,109,162,109,163,109,164,109,165,109,166,109,172,109,173,109,174,109,176,109,177,109,178,109,182,109,186,109,189,109,190,109,191,109,194,109,198,109,199,109,201,109,209,109,212,109,214,109,215,109,216,109,217,109,218,109,219,109,220,109,221,109,225,109,227,109,228,109,229,109,233,109,235,109,250,109,271,109,272,109,280,109,281,109,282,109,283,109,284,109,157,110,162,110,168,110,172,110,176,110,186,110,187,110,191,110,193,110,194,110,195,110,196,110,198,110,200,110,201,110,204,110,209,110,211,110,212,110,214,110,215,110,216,110,217,110,219,110,222,110,224,110,225,110,226,110,227,110,228,110,229,110,234,110,240,110,241,110,271,110,272,110,284,110,137,111,148,111,157,111,166,111,167,111,173,111,175,111,185,111,186,111,189,111,191,111,194,111,198,111,199,111,200,111,201,111,202,111,204,111,208,111,209,111,210,111,211,111,214,111,215,111,216,111,219,111,223,111,228,111,229,111,239,111,240,111,241,111,271,111,275,111,277,111,280,111,281,111,282,111,284,111,285,111,154,112,158,112,159,112,160,112,161,112,165,112,166,112,167,112,168,112,171,112,175,112,176,112,179,112,180,112,181,112,182,112,188,112,189,112,192,112,193,112,194,112,196,112,197,112,201,112,202,112,203,112,204,112,206,112,207,112,208,112,209,112,212,112,213,112,214,112,215,112,217,112,218,112,219,112,221,112,222,112,223,112,225,112,228,112,229,112,234,112,235,112,239,112,240,112,261,112,271,112,272,112,280,112,282,112,284,112,285,112,301,112,131,113,132,113,153,113,154,113,155,113,160,113,163,113,164,113,166,113,169,113,174,113,176,113,181,113,183,113,187,113,188,113,191,113,205,113,208,113,210,113,211,113,212,113,214,113,217,113,220,113,222,113,223,113,227,113,228,113,229,113,230,113,231,113,233,113,253,113,260,113,273,113,276,113,279,113,282,113,283,113,285,113,112,114,152,114,153,114,162,114,166,114,168,114,169,114,173,114,177,114,184,114,185,114,210,114,212,114,213,114,215,114,216,114,217,114,218,114,221,114,222,114,223,114,226,114,227,114,228,114,232,114,234,114,239,114,251,114,275,114,278,114,281,114,282,114,283,114,116,115,127,115,145,115,161,115,162,115,166,115,167,115,172,115,173,115,176,115,184,115,185,115,211,115,212,115,213,115,214,115,215,115,216,115,217,115,218,115,219,115,222,115,223,115,225,115,226,115,227,115,232,115,233,115,239,115,277,115,286,115,132,116,139,116,140,116,141,116,145,116,153,116,154,116,158,116,161,116,167,116,171,116,214,116,215,116,216,116,217,116,218,116,219,116,220,116,221,116,222,116,223,116,224,116,225,116,226,116,227,116,228,116,232,116,233,116,234,116,243,116,251,116,284,116,285,116,286,116,138,117,154,117,158,117,160,117,161,117,168,117,169,117,171,117,217,117,219,117,222,117,224,117,225,117,228,117,229,117,230,117,231,117,232,117,235,117,236,117,243,117,244,117,251,117,262,117,279,117,284,117,285,117,298,117,301,117,302,117,113,118,114,118,145,118,146,118,148,118,153,118,158,118,159,118,160,118,161,118,165,118,168,118,221,118,222,118,223,118,224,118,225,118,227,118,228,118,229,118,231,118,232,118,235,118,240,118,244,118,245,118,273,118,275,118,279,118,281,118,285,118,296,118,301,118,302,118,107,119,152,119,156,119,157,119,168,119,223,119,225,119,226,119,227,119,228,119,231,119,232,119,233,119,235,119,236,119,237,119,243,119,244,119,248,119,249,119,273,119,284,119,286,119,291,119,297,119,150,120,151,120,154,120,155,120,156,120,157,120,168,120,169,120,228,120,229,120,231,120,232,120,233,120,234,120,235,120,236,120,238,120,249,120,254,120,276,120,277,120,285,120,286,120,288,120,296,120,298,120,302,120,303,120,304,120,107,121,111,121,112,121,134,121,145,121,150,121,152,121,154,121,155,121,156,121,157,121,165,121,228,121,229,121,230,121,231,121,232,121,233,121,234,121,235,121,236,121,237,121,238,121,239,121,287,121,288,121,289,121,296,121,298,121,299,121,300,121,301,121,302,121,303,121,112,122,115,122,116,122,153,122,154,122,155,122,161,122,165,122,229,122,230,122,231,122,232,122,233,122,234,122,236,122,237,122,238,122,239,122,240,122,250,122,251,122,283,122,287,122,299,122,300,122,301,122,303,122,104,123,114,123,115,123,142,123,153,123,154,123,155,123,158,123,230,123,232,123,233,123,234,123,235,123,236,123,237,123,238,123,239,123,240,123,241,123,250,123,251,123,278,123,279,123,287,123,300,123,301,123,104,124,132,124,138,124,148,124,149,124,152,124,153,124,154,124,155,124,167,124,232,124,233,124,234,124,236,124,237,124,238,124,240,124,241,124,242,124,268,124,287,124,299,124,301,124,302,124,124,125,148,125,152,125,153,125,154,125,157,125,162,125,232,125,233,125,234,125,235,125,236,125,237,125,238,125,240,125,241,125,242,125,246,125,248,125,265,125,270,125,289,125,290,125,295,125,297,125,299,125,300,125,303,125,305,125,306,125,136,126,143,126,151,126,153,126,154,126,158,126,232,126,233,126,234,126,235,126,236,126,237,126,238,126,239,126,240,126,241,126,242,126,243,126,244,126,248,126,257,126,265,126,285,126,289,126,290,126,300,126,301,126,302,126,303,126,304,126,305,126,306,126,131,127,137,127,146,127,147,127,149,127,150,127,153,127,158,127,159,127,233,127,236,127,237,127,238,127,239,127,241,127,242,127,243,127,244,127,248,127,249,127,257,127,280,127,285,127,288,127,289,127,290,127,292,127,293,127,296,127,297,127,300,127,301,127,302,127,303,127,304,127,119,128,124,128,134,128,137,128,147,128,148,128,150,128,151,128,152,128,158,128,160,128,239,128,241,128,242,128,244,128,248,128,249,128,257,128,269,128,270,128,283,128,286,128,289,128,290,128,298,128,304,128,305,128,103,129,105,129,128,129,145,129,148,129,149,129,150,129,151,129,152,129,154,129,236,129,237,129,238,129,241,129,242,129,243,129,252,129,262,129,267,129,268,129,290,129,299,129,302,129,304,129,305,129,103,130,112,130,113,130,118,130,138,130,139,130,148,130,150,130,152,130,238,130,243,130,244,130,261,130,274,130,283,130,289,130,290,130,291,130,296,130,297,130,298,130,299,130,300,130,304,130,305,130,306,130,307,130,122,131,137,131,140,131,147,131,149,131,150,131,156,131,158,131,238,131,239,131,242,131,243,131,244,131,245,131,246,131,247,131,255,131,256,131,260,131,261,131,288,131,289,131,290,131,291,131,292,131,293,131,295,131,296,131,298,131,299,131,300,131,301,131,304,131,305,131,306,131,307,131,102,132,122,132,132,132,136,132,145,132,148,132,149,132,150,132,154,132,239,132,241,132,242,132,243,132,244,132,245,132,288,132,289,132,290,132,292,132,296,132,299,132,300,132,301,132,304,132,305,132,307,132,308,132,106,133,111,133,133,133,136,133,146,133,147,133,148,133,149,133,150,133,239,133,240,133,246,133,248,133,252,133,254,133,287,133,289,133,290,133,291,133,301,133,302,133,305,133,309,133,126,134,137,134,143,134,147,134,148,134,149,134,150,134,240,134,241,134,242,134,258,134,264,134,290,134,293,134,295,134,300,134,301,134,302,134,303,134,308,134,309,134,96,135,108,135,124,135,125,135,137,135,138,135,143,135,146,135,148,135,149,135,150,135,151,135,152,135,246,135,248,135,249,135,274,135,290,135,291,135,292,135,293,135,296,135,297,135,299,135,300,135,301,135,302,135,303,135,306,135,308,135,309,135,92,136,93,136,94,136,95,136,97,136,124,136,145,136,146,136,148,136,152,136,241,136,245,136,247,136,248,136,249,136,254,136,268,136,269,136,290,136,291,136,300,136,301,136,302,136,303,136,304,136,307,136,309,136,134,137,139,137,145,137,146,137,147,137,148,137,155,137,241,137,242,137,249,137,255,137,285,137,286,137,291,137,292,137,295,137,296,137,300,137,301,137,302,137,303,137,305,137,307,137,309,137,79,138,116,138,117,138,120,138,122,138,131,138,140,138,145,138,146,138,147,138,244,138,286,138,288,138,291,138,296,138,303,138,304,138,305,138,308,138,80,139,81,139,96,139,97,139,118,139,122,139,129,139,132,139,133,139,136,139,138,139,144,139,145,139,146,139,147,139,149,139,152,139,247,139,251,139,290,139,302,139,303,139,304,139,306,139,307,139,308,139,309,139,85,140,91,140,92,140,96,140,97,140,104,140,105,140,122,140,126,140,131,140,132,140,136,140,139,140,144,140,145,140,146,140,147,140,148,140,149,140,153,140,244,140,248,140,251,140,292,140,293,140,302,140,303,140,304,140,305,140,306,140,307,140,308,140,309,140,86,141,87,141,91,141,92,141,105,141,107,141,122,141,130,141,131,141,132,141,137,141,138,141,143,141,144,141,149,141,153,141,245,141,249,141,250,141,251,141,291,141,292,141,293,141,297,141,298,141,302,141,303,141,304,141,305,141,306,141,308,141,309,141,310,141,86,142,91,142,92,142,96,142,134,142,136,142,138,142,144,142,245,142,263,142,290,142,291,142,292,142,302,142,303,142,304,142,305,142,306,142,308,142,309,142,310,142,104,143,108,143,109,143,133,143,137,143,139,143,143,143,144,143,145,143,153,143,245,143,246,143,257,143,259,143,286,143,294,143,305,143,306,143,74,144,80,144,93,144,94,144,96,144,103,144,128,144,129,144,131,144,132,144,134,144,137,144,142,144,145,144,147,144,148,144,149,144,257,144,259,144,287,144,293,144,294,144,305,144,306,144,80,145,93,145,94,145,104,145,105,145,132,145,133,145,134,145,137,145,139,145,142,145,145,145,147,145,148,145,151,145,245,145,251,145,263,145,264,145,292,145,294,145,302,145,306,145,88,146,89,146,90,146,105,146,116,146,137,146,145,146,148,146,253,146,289,146,294,146,302,146,306,146,307,146,309,146,310,146,88,147,105,147,131,147,140,147,143,147,148,147,293,147,294,147,300,147,301,147,302,147,303,147,306,147,308,147,309,147,75,148,82,148,95,148,136,148,141,148,142,148,148,148,246,148,295,148,298,148,299,148,300,148,304,148,306,148,308,148,309,148,310,148,311,148,312,148,313,148,314,148,315,148,316,148,317,148,320,148,321,148,75,149,84,149,114,149,122,149,123,149,125,149,135,149,136,149,142,149,143,149,149,149,257,149,287,149,289,149,290,149,294,149,298,149,299,149,300,149,304,149,305,149,306,149,307,149,308,149,309,149,310,149,311,149,312,149,313,149,314,149,315,149,316,149,318,149,319,149,320,149,321,149,322,149,74,150,75,150,115,150,127,150,128,150,129,150,133,150,134,150,141,150,147,150,151,150,152,150,246,150,254,150,263,150,289,150,294,150,295,150,299,150,301,150,310,150,311,150,312,150,313,150,314,150,320,150,321,150,324,150,325,150,326,150,327,150,328,150,329,150,331,150,74,151,75,151,81,151,93,151,95,151,100,151,120,151,138,151,139,151,140,151,141,151,142,151,144,151,145,151,146,151,147,151,291,151,293,151,295,151,313,151,314,151,315,151,320,151,321,151,325,151,327,151,328,151,329,151,330,151,335,151,75,152,76,152,77,152,88,152,94,152,95,152,98,152,107,152,108,152,110,152,133,152,139,152,140,152,142,152,293,152,294,152,305,152,315,152,316,152,330,152,332,152,333,152,334,152,337,152,108,153,133,153,135,153,136,153,138,153,142,153,143,153,148,153,151,153,258,153,288,153,294,153,301,153,330,153,333,153,336,153,340,153,91,154,95,154,105,154,123,154,133,154,134,154,135,154,138,154,140,154,142,154,144,154,145,154,150,154,258,154,272,154,291,154,294,154,309,154,310,154,311,154,327,154,328,154,329,154,330,154,331,154,334,154,335,154,336,154,338,154,340,154,77,155,95,155,112,155,123,155,142,155,145,155,259,155,260,155,261,155,285,155,286,155,294,155,295,155,296,155,309,155,311,155,312,155,325,155,326,155,328,155,331,155,332,155,85,156,95,156,99,156,106,156,107,156,125,156,138,156,142,156,249,156,260,156,261,156,292,156,295,156,303,156,304,156,305,156,307,156,330,156,335,156,341,156,81,157,93,157,94,157,138,157,140,157,141,157,142,157,145,157,146,157,261,157,295,157,300,157,304,157,305,157,306,157,307,157,319,157,332,157,335,157,336,157,338,157,81,158,91,158,92,158,123,158,138,158,141,158,142,158,245,158,261,158,269,158,270,158,294,158,295,158,300,158,311,158,318,158,328,158,333,158,335,158,336,158,337,158,342,158,137,159,140,159,142,159,258,159,269,159,295,159,300,159,308,159,314,159,315,159,330,159,333,159,335,159,337,159,339,159,340,159,341,159,76,160,77,160,78,160,80,160,93,160,101,160,118,160,123,160,126,160,130,160,135,160,140,160,141,160,143,160,144,160,147,160,148,160,245,160,246,160,265,160,266,160,267,160,273,160,293,160,295,160,300,160,301,160,308,160,314,160,330,160,331,160,332,160,333,160,334,160,335,160,340,160,80,161,94,161,101,161,102,161,121,161,131,161,133,161,134,161,135,161,137,161,140,161,141,161,142,161,143,161,144,161,149,161,245,161,246,161,255,161,293,161,294,161,295,161,300,161,301,161,306,161,307,161,318,161,330,161,331,161,333,161,334,161,335,161,336,161,341,161,342,161,96,162,130,162,131,162,133,162,137,162,140,162,141,162,142,162,143,162,144,162,149,162,245,162,246,162,264,162,295,162,300,162,301,162,306,162,307,162,325,162,326,162,327,162,328,162,329,162,330,162,331,162,336,162,337,162,338,162,342,162,73,163,74,163,83,163,84,163,104,163,105,163,120,163,129,163,130,163,136,163,137,163,141,163,245,163,246,163,259,163,292,163,294,163,295,163,330,163,331,163,332,163,333,163,336,163,337,163,338,163,340,163,341,163,86,164,87,164,92,164,93,164,103,164,118,164,119,164,130,164,136,164,137,164,245,164,293,164,295,164,327,164,333,164,334,164,336,164,337,164,338,164,339,164,79,165,86,165,90,165,96,165,115,165,126,165,127,165,134,165,139,165,141,165,145,165,148,165,245,165,246,165,302,165,309,165,310,165,326,165,327,165,329,165,330,165,331,165,338,165,75,166,76,166,78,166,79,166,81,166,85,166,90,166,114,166,119,166,124,166,125,166,140,166,141,166,142,166,143,166,149,166,245,166,246,166,262,166,310,166,311,166,326,166,327,166,329,166,330,166,331,166,339,166,341,166,342,166,65,167,74,167,85,167,100,167,104,167,105,167,108,167,114,167,124,167,131,167,244,167,245,167,246,167,260,167,261,167,293,167,294,167,295,167,306,167,311,167,326,167,329,167,331,167,333,167,335,167,336,167,337,167,82,168,83,168,84,168,87,168,89,168,93,168,114,168,115,168,131,168,132,168,141,168,146,168,147,168,244,168,245,168,246,168,260,168,295,168,300,168,303,168,313,168,326,168,330,168,331,168,332,168,333,168,334,168,337,168,338,168,88,169,91,169,92,169,93,169,114,169,134,169,141,169,144,169,150,169,244,169,246,169,257,169,266,169,294,169,300,169,303,169,326,169,95,170,96,170,97,170,100,170,112,170,119,170,120,170,122,170,123,170,127,170,131,170,132,170,134,170,137,170,142,170,151,170,244,170,245,170,257,170,262,170,278,170,294,170,300,170,301,170,308,170,319,170,325,170,338,170,340,170,341,170,114,171,119,171,123,171,124,171,139,171,140,171,142,171,143,171,144,171,145,171,244,171,245,171,256,171,257,171,286,171,294,171,300,171,307,171,338,171,339,171,340,171,98,172,112,172,122,172,125,172,126,172,132,172,138,172,139,172,145,172,146,172,147,172,286,172,293,172,300,172,301,172,307,172,311,172,324,172,97,173,125,173,131,173,142,173,147,173,243,173,293,173,294,173,300,173,301,173,302,173,303,173,307,173,311,173,330,173,331,173,332,173,339,173,100,174,103,174,107,174,112,174,136,174,143,174,144,174,149,174,151,174,152,174,259,174,261,174,291,174,293,174,294,174,300,174,301,174,302,174,303,174,304,174,313,174,332,174,335,174,90,175,91,175,103,175,130,175,131,175,138,175,144,175,256,175,293,175,299,175,300,175,301,175,305,175,328,175,336,175,112,176,121,176,130,176,131,176,137,176,144,176,145,176,287,176,293,176,294,176,299,176,300,176,323,176,324,176,326,176,327,176,333,176,88,177,91,177,100,177,112,177,115,177,127,177,128,177,135,177,136,177,137,177,144,177,153,177,291,177,292,177,293,177,294,177,299,177,324,177,327,177,334,177,337,177,105,178,111,178,126,178,127,178,135,178,141,178,143,178,145,178,146,178,152,178,153,178,292,178,293,178,300,178,304,178,307,178,314,178,324,178,325,178,326,178,109,179,110,179,145,179,146,179,147,179,152,179,153,179,154,179,281,179,282,179,290,179,292,179,293,179,303,179,304,179,319,179,324,179,325,179,329,179,330,179,101,180,108,180,109,180,110,180,120,180,123,180,143,180,144,180,145,180,150,180,153,180,154,180,155,180,258,180,290,180,292,180,293,180,303,180,305,180,325,180,329,180,330,180,332,180,102,181,107,181,108,181,118,181,119,181,129,181,133,181,143,181,144,181,145,181,151,181,152,181,155,181,256,181,257,181,265,181,282,181,288,181,293,181,299,181,303,181,309,181,324,181,326,181,101,182,105,182,114,182,118,182,119,182,128,182,129,182,132,182,133,182,135,182,136,182,137,182,144,182,149,182,150,182,287,182,288,182,299,182,304,182,305,182,306,182,307,182,308,182,326,182,104,183,105,183,117,183,129,183,132,183,143,183,145,183,146,183,148,183,154,183,155,183,253,183,257,183,290,183,292,183,300,183,301,183,302,183,305,183,307,183,309,183,316,183,317,183,323,183,324,183,328,183,103,184,132,184,144,184,146,184,147,184,148,184,289,184,290,184,291,184,298,184,306,184,315,184,320,184,321,184,322,184,328,184,336,184,337,184,102,185,116,185,117,185,123,185,141,185,142,185,143,185,146,185,147,185,151,185,152,185,157,185,253,185,289,185,290,185,291,185,305,185,336,185,338,185,117,186,120,186,127,186,140,186,151,186,153,186,157,186,158,186,288,186,290,186,291,186,117,187,145,187,148,187,152,187,157,187,159,187,160,187,285,187,288,187,290,187,103,188,117,188,132,188,135,188,136,188,146,188,148,188,149,188,150,188,154,188,159,188,160,188,251,188,252,188,285,188,286,188,288,188,289,188,290,188,103,189,140,189,141,189,149,189,150,189,153,189,154,189,158,189,278,189,285,189,287,189,290,189,138,190,139,190,140,190,152,190,153,190,154,190,157,190,159,190,160,190,161,190,252,190,283,190,284,190,289,190,114,191,122,191,150,191,151,191,152,191,153,191,158,191,159,191,243,191,284,191,287,191,104,192,110,192,121,192,122,192,142,192,143,192,150,192,153,192,157,192,158,192,161,192,163,192,283,192,284,192,288,192,115,193,121,193,122,193,131,193,147,193,148,193,151,193,157,193,158,193,162,193,163,193,249,193,250,193,251,193,283,193,114,194,115,194,121,194,122,194,123,194,131,194,152,194,153,194,155,194,157,194,158,194,160,194,161,194,164,194,247,194,251,194,281,194,285,194,106,195,113,195,120,195,121,195,122,195,130,195,156,195,157,195,158,195,159,195,160,195,161,195,164,195,165,195,247,195,284,195,286,195,287,195,106,196,111,196,114,196,121,196,139,196,145,196,147,196,154,196,155,196,156,196,157,196,159,196,163,196,166,196,167,196,237,196,266,196,285,196,286,196,104,197,127,197,137,197,138,197,139,197,146,197,147,197,151,197,156,197,162,197,163,197,164,197,165,197,166,197,168,197,169,197,272,197,273,197,280,197,281,197,285,197,286,197,104,198,119,198,146,198,148,198,151,198,155,198,156,198,159,198,160,198,161,198,162,198,167,198,169,198,170,198,245,198,271,198,280,198,284,198,117,199,132,199,148,199,156,199,158,199,159,199,160,199,161,199,165,199,166,199,167,199,168,199,169,199,170,199,171,199,172,199,271,199,278,199,281,199,282,199,284,199,285,199,109,200,112,200,120,200,131,200,132,200,155,200,157,200,158,200,162,200,163,200,164,200,165,200,167,200,168,200,169,200,170,200,173,200,271,200,274,200,284,200,285,200,109,201,118,201,142,201,158,201,160,201,161,201,162,201,165,201,166,201,167,201,169,201,170,201,171,201,172,201,221,201,273,201,274,201,283,201,284,201,107,202,108,202,116,202,136,202,140,202,145,202,148,202,150,202,152,202,156,202,160,202,161,202,163,202,164,202,165,202,166,202,168,202,169,202,170,202,172,202,174,202,176,202,178,202,218,202,219,202,272,202,277,202,279,202,280,202,282,202,283,202,284,202,109,203,116,203,134,203,135,203,146,203,147,203,148,203,155,203,156,203,160,203,161,203,163,203,164,203,165,203,166,203,168,203,169,203,171,203,172,203,174,203,175,203,176,203,177,203,179,203,180,203,278,203,279,203,280,203,283,203,109,204,111,204,115,204,146,204,147,204,148,204,160,204,163,204,164,204,165,204,166,204,167,204,171,204,172,204,174,204,176,204,177,204,178,204,179,204,181,204,219,204,240,204,283,204,110,205,111,205,115,205,156,205,162,205,164,205,165,205,169,205,171,205,172,205,176,205,177,205,180,205,183,205,184,205,185,205,211,205,240,205,244,205,114,206,115,206,128,206,137,206,156,206,161,206,164,206,165,206,168,206,169,206,170,206,171,206,172,206,173,206,174,206,176,206,177,206,178,206,179,206,180,206,181,206,182,206,183,206,189,206,207,206,215,206,239,206,240,206,242,206,244,206,275,206,277,206,278,206,281,206,282,206,108,207,111,207,123,207,131,207,136,207,143,207,152,207,156,207,167,207,168,207,173,207,174,207,176,207,178,207,182,207,183,207,186,207,187,207,190,207,197,207,198,207,199,207,200,207,201,207,202,207,210,207,238,207,242,207,272,207,275,207,277,207,278,207,280,207,281,207,109,208,110,208,111,208,112,208,130,208,136,208,143,208,149,208,153,208,154,208,156,208,171,208,172,208,173,208,175,208,176,208,177,208,180,208,181,208,182,208,184,208,185,208,186,208,187,208,188,208,190,208,191,208,200,208,208,208,209,208,238,208,110,209,111,209,127,209,130,209,149,209,163,209,168,209,169,209,170,209,171,209,172,209,173,209,175,209,176,209,177,209,178,209,179,209,180,209,181,209,182,209,183,209,186,209,187,209,189,209,190,209,191,209,192,209,193,209,195,209,197,209,198,209,199,209,200,209,201,209,202,209,204,209,208,209,238,209,280,209,110,210,111,210,112,210,113,210,114,210,130,210,149,210,158,210,170,210,171,210,172,210,174,210,175,210,176,210,177,210,178,210,180,210,181,210,182,210,183,210,186,210,187,210,188,210,189,210,191,210,195,210,198,210,199,210,201,210,209,210,229,210,233,210,234,210,238,210,277,210,278,210,279,210,280,210,110,211,111,211,112,211,114,211,135,211,158,211,172,211,174,211,175,211,177,211,178,211,179,211,180,211,181,211,183,211,184,211,186,211,187,211,188,211,189,211,190,211,191,211,192,211,194,211,195,211,199,211,206,211,207,211,211,211,230,211,234,211,278,211,114,212,115,212,119,212,128,212,157,212,159,212,167,212,175,212,176,212,177,212,178,212,179,212,180,212,183,212,185,212,187,212,190,212,191,212,192,212,193,212,194,212,195,212,197,212,213,212,270,212,276,212,277,212,278,212,111,213,114,213,115,213,116,213,123,213,149,213,162,213,163,213,164,213,165,213,166,213,167,213,172,213,176,213,178,213,179,213,182,213,183,213,185,213,186,213,189,213,190,213,191,213,192,213,193,213,194,213,195,213,196,213,197,213,198,213,201,213,213,213,234,213,235,213,270,213,278,213,110,214,113,214,114,214,115,214,124,214,138,214,177,214,182,214,183,214,184,214,185,214,189,214,191,214,192,214,195,214,196,214,197,214,199,214,200,214,201,214,206,214,271,214,278,214,113,215,114,215,115,215,117,215,123,215,124,215,134,215,163,215,164,215,181,215,182,215,183,215,185,215,186,215,187,215,189,215,190,215,191,215,195,215,199,215,200,215,203,215,204,215,205,215,206,215,111,216,112,216,114,216,117,216,120,216,123,216,124,216,147,216,150,216,151,216,169,216,174,216,188,216,189,216,194,216,195,216,201,216,202,216,205,216,209,216,226,216,227,216,230,216,266,216,273,216,274,216,275,216,277,216,113,217,116,217,117,217,118,217,119,217,128,217,168,217,173,217,177,217,192,217,193,217,202,217,204,217,219,217,222,217,226,217,227,217,109,218,112,218,113,218,115,218,116,218,118,218,127,218,146,218,148,218,155,218,169,218,176,218,180,218,181,218,187,218,192,218,204,218,211,218,222,218,227,218,272,218,273,218,276,218,108,219,112,219,116,219,119,219,120,219,123,219,127,219,156,219,170,219,174,219,192,219,193,219,204,219,213,219,225,219,226,219,231,219,272,219,273,219,274,219,275,219,108,220,117,220,118,220,119,220,120,220,127,220,130,220,147,220,156,220,170,220,177,220,178,220,193,220,210,220,231,220,272,220,273,220,274,220,275,220,106,221,107,221,111,221,118,221,119,221,153,221,154,221,155,221,156,221,172,221,176,221,177,221,178,221,207,221,210,221,215,221,230,221,272,221,273,221,274,221,111,222,112,222,113,222,115,222,116,222,119,222,121,222,135,222,160,222,161,222,164,222,175,222,176,222,177,222,181,222,187,222,197,222,198,222,219,222,267,222,273,222,108,223,111,223,113,223,116,223,119,223,122,223,123,223,129,223,132,223,166,223,185,223,186,223,187,223,197,223,224,223,272,223,122,224,124,224,162,224,173,224,185,224,187,224,108,225,115,225,116,225,122,225,124,225,173,225,179,225,187,225,245,225,270,225,101,226,109,226,110,226,113,226,116,226,121,226,125,226,126,226,176,226,180,226,217,226,245,226,264,226,267,226,268,226,269,226,270,226,280,226,104,227,112,227,113,227,120,227,121,227,125,227,127,227,164,227,165,227,174,227,175,227,204,227,260,227,261,227,264,227,268,227,120,228,121,228,122,228,125,228,127,228,128,228,129,228,139,228,143,228,202,228,203,228,214,228,267,228,275,228,279,228,280,228,281,228,114,229,123,229,124,229,125,229,127,229,128,229,130,229,142,229,163,229,260,229,265,229,274,229,282,229,97,230,106,230,110,230,119,230,123,230,124,230,128,230,130,230,143,230,151,230,181,230,182,230,253,230,254,230,255,230,264,230,265,230,266,230,274,230,97,231,106,231,110,231,123,231,126,231,133,231,138,231,174,231,181,231,182,231,189,231,190,231,259,231,262,231,263,231,264,231,265,231,272,231,279,231,280,231,281,231,283,231,100,232,113,232,121,232,126,232,128,232,131,232,132,232,133,232,135,232,168,232,207,232,259,232,260,232,271,232,273,232,278,232,279,232,281,232,111,233,121,233,131,233,133,233,136,233,143,233,151,233,178,233,251,233,259,233,260,233,265,233,272,233,273,233,274,233,275,233,281,233,94,234,100,234,104,234,129,234,130,234,132,234,133,234,134,234,135,234,136,234,141,234,142,234,143,234,153,234,154,234,162,234,168,234,200,234,215,234,242,234,252,234,259,234,260,234,264,234,270,234,271,234,272,234,275,234,284,234,92,235,93,235,94,235,126,235,127,235,129,235,130,235,132,235,133,235,135,235,136,235,142,235,146,235,167,235,203,235,204,235,208,235,241,235,258,235,259,235,271,235,275,235,278,235,279,235,280,235,282,235,90,236,92,236,93,236,96,236,107,236,108,236,118,236,126,236,127,236,128,236,135,236,136,236,142,236,143,236,144,236,150,236,159,236,174,236,175,236,241,236,245,236,253,236,255,236,257,236,259,236,261,236,271,236,272,236,280,236,284,236,285,236,105,237,107,237,108,237,112,237,124,237,125,237,126,237,129,237,132,237,138,237,139,237,140,237,143,237,144,237,150,237,158,237,167,237,173,237,182,237,185,237,189,237,205,237,234,237,245,237,252,237,253,237,254,237,255,237,256,237,257,237,258,237,267,237,283,237,286,237,86,238,88,238,89,238,90,238,96,238,97,238,101,238,112,238,129,238,130,238,131,238,135,238,141,238,143,238,144,238,150,238,176,238,220,238,248,238,249,238,254,238,255,238,256,238,257,238,267,238,268,238,269,238,270,238,286,238,94,239,95,239,101,239,122,239,127,239,128,239,133,239,141,239,142,239,152,239,163,239,246,239,247,239,248,239,254,239,255,239,256,239,257,239,265,239,269,239,270,239,271,239,277,239,278,239,288,239,85,240,94,240,95,240,100,240,131,240,133,240,143,240,152,240,168,240,215,240,238,240,246,240,250,240,251,240,253,240,264,240,265,240,268,240,269,240,270,240,277,240,289,240,84,241,93,241,94,241,95,241,115,241,126,241,131,241,144,241,145,241,146,241,147,241,168,241,173,241,198,241,238,241,250,241,251,241,252,241,253,241,265,241,268,241,269,241,270,241,276,241,84,242,88,242,89,242,90,242,91,242,96,242,102,242,129,242,147,242,150,242,151,242,168,242,173,242,182,242,189,242,192,242,195,242,216,242,244,242,245,242,249,242,250,242,251,242,252,242,260,242,261,242,262,242,263,242,265,242,278,242,281,242,290,242,82,243,87,243,88,243,92,243,103,243,126,243,127,243,128,243,147,243,149,243,150,243,173,243,179,243,194,243,216,243,247,243,248,243,249,243,250,243,251,243,259,243,274,243,281,243,290,243,291,243,92,244,96,244,104,244,106,244,118,244,119,244,125,244,126,244,147,244,148,244,150,244,153,244,162,244,169,244,170,244,171,244,178,244,179,244,208,244,229,244,238,244,239,244,243,244,246,244,247,244,248,244,257,244,260,244,266,244,289,244,290,244,291,244,88,245,89,245,91,245,96,245,125,245,149,245,150,245,151,245,152,245,153,245,162,245,166,245,172,245,229,245,237,245,238,245,239,245,243,245,244,245,259,245,260,245,261,245,262,245,269,245,270,245,288,245,292,245,85,246,86,246,91,246,105,246,111,246,112,246,113,246,121,246,153,246,154,246,155,246,156,246,157,246,158,246,160,246,161,246,162,246,208,246,218,246,236,246,242,246,243,246,259,246,265,246,268,246,271,246,272,246,281,246,288,246,291,246,89,247,91,247,104,247,106,247,111,247,121,247,122,247,123,247,155,247,156,247,157,247,160,247,193,247,216,247,218,247,219,247,223,247,239,247,240,247,255,247,260,247,261,247,263,247,268,247,269,247,271,247,272,247,273,247,290,247,160,248,168,248,173,248,192,248,215,248,217,248,218,248,222,248,226,248,227,248,229,248,236,248,260,248,261,248,262,248,263,248,264,248,265,248,266,248,267,248,268,248,271,248,272,248,277,248,289,248,108,249,119,249,120,249,164,249,180,249,217,249,230,249,231,249,232,249,233,249,234,249,256,249,257,249,258,249,259,249,265,249,268,249,269,249,285,249,288,249,87,250,114,250,118,250,166,250,172,250,185,250,191,250,212,250,230,250,258,250,261,250,262,250,264,250,268,250,269,250,287,250,288,250,110,251,168,251,172,251,185,251,186,251,212,251,213,251,215,251,221,251,222,251,223,251,228,251,229,251,254,251,256,251,257,251,263,251,264,251,266,251,267,251,268,251,276,251,282,251,287,251,90,252,91,252,100,252,111,252,116,252,171,252,178,252,199,252,206,252,212,252,214,252,215,252,221,252,225,252,226,252,227,252,255,252,261,252,262,252,265,252,266,252,276,252,91,253,110,253,113,253,174,253,175,253,182,253,191,253,214,253,215,253,222,253,223,253,267,253,284,253,178,254,179,254,180,254,188,254,190,254,191,254,201,254,206,254,208,254,214,254,218,254,267,254,268,254,269,254,270,254,283,254,181,255,185,255,186,255,187,255,194,255,201,255,205,255,208,255,209,255,211,255,212,255,262,255,267,255,268,255,269,255,282,255,93,256,184,256,185,256,186,256,187,256,188,256,190,256,194,256,198,256,204,256,205,256,206,256,207,256,271,256,281,256,93,257,189,257,191,257,192,257,193,257,194,257,195,257,196,257,197,257,198,257,199,257,200,257,201,257,202,257,203,257,262,257,263,257,264,257,265,257,266,257,277,257,279,257,105,258,262,258,263,258,266,258,272,258,276,258,278,258,276,259,265,260,270,260,276,260,97,261,274,261,275,261,178,262,181,262,182,262,267,262,271,262,274,262,179,263,183,263,184,263,185,263,186,263,188,263,193,263,172,264,180,264,183,264,196,264,197,264,198,264,199,264,201,264,203,264,270,264,271,264,180,265,193,265,207,265,177,266,182,266,184,266,185,266,186,266,187,266,188,266,197,266,206,266,175,267,178,267,185,267,191,267,194,267,196,267,207,267,208,267,178,268,179,268,193,268,199,268,205,268,207,268,271,268,173,269,174,269,178,269,193,269,198,269,199,269,202,269,203,269,208,269,173,270,178,270,179,270,193,270,198,270,199,270,201,270,272,270,173,271,193,271,194,271,195,271,198,271,273,271,173,272,175,272,193,272,196,272,197,272,273,272,274,272,174,273,175,273,197,273,201,273,202,273,203,273,206,273,274,273,275,273,178,274,184,274,196,274,201,274,202,274,196,275,183,276,196,276,206,276,189,277,193,277,206,277,174,278,194,278,203,278,190,279,193,279,174,280,177,280,174,281,205,281,174,282,201,282,205,282,174,283,182,283,197,283,174,284,187,284,181,285,187,285,170,286,178,286,184,286,187,286,189,286,190,286,191,286,192,286,196,286,197,286,198,286,201,286,203,286,204,286,173,288,172,291,172,292,171,293,174,293,173,297,50,317,187,317,51,318,187,318,188,318,231,318,304,318,51,319,137,319,187,319,188,319,304,319,51,320,59,320,60,320,137,320,147,320,187,320,188,320,304,320,351,320,352,320,353,320,354,320,51,321,58,321,59,321,100,321,147,321,187,321,236,321,237,321,277,321,278,321,304,321,356,321,357,321,51,322,58,322,100,322,138,322,147,322,237,322,277,322,304,322,360,322,367,322,51,323,58,323,100,323,138,323,147,323,237,323,277,323,304,323,362,323,365,323,50,324,61,324,138,324,147,324,187,324,237,324,277,324,304,324,362,324,364,324,365,324,138,325,187,325,237,325,277,325,304,325,365,325,366,325,367,325,59,326,187,326,237,326,277,326,304,326,326,326,367,326,368,326,374,326,59,327,61,327,148,327,187,327,196,327,237,327,277,327,304,327,348,327,368,327,369,327,59,328,187,328,196,328,237,328,277,328,304,328,321,328,341,328,342,328,349,328,350,328,351,328,369,328,370,328,371,328,61,329,123,329,124,329,137,329,148,329,151,329,152,329,154,329,155,329,156,329,157,329,158,329,159,329,161,329,167,329,182,329,185,329,186,329,187,329,237,329,260,329,261,329,262,329,263,329,264,329,265,329,266,329,267,329,268,329,269,329,272,329,273,329,274,329,275,329,276,329,304,329,339,329,370,329,62,330,85,330,287,330,289,330,290,330,291,330,292,330,293,330,294,330,295,330,296,330,297,330,299,330,300,330,301,330,302,330,303,330,11,331,122,331,223,331,237,331,260,331,336,331,355,331,371,331,11,332,86,332,123,332,237,332,323,332,335,332,372,332,10,333,11,333,123,333,237,333,260,333,322,333,335,333,372,333,9,334,10,334,11,334,123,334,332,334,334,334,372,334,373,334,9,335,10,335,11,335,30,335,123,335,237,335,260,335,333,335,373,335,8,336,9,336,10,336,11,336,31,336,36,336,37,336,38,336,39,336,40,336,42,336,43,336,123,336,260,336,333,336,373,336,374,336,375,336,8,337,9,337,10,337,11,337,44,337,109,337,177,337,199,337,223,337,260,337,314,337,332,337,333,337,373,337,7,338,8,338,9,338,10,338,11,338,44,338,61,338,123,338,158,338,200,338,212,338,237,338,260,338,304,338,306,338,307,338,308,338,309,338,310,338,311,338,312,338,313,338,333,338,373,338,374,338,381,338,7,339,8,339,9,339,10,339,11,339,44,339,61,339,123,339,211,339,212,339,237,339,260,339,304,339,313,339,333,339,7,340,8,340,9,340,10,340,44,340,122,340,123,340,158,340,212,340,237,340,260,340,304,340,360,340,374,340,7,341,8,341,9,341,10,341,44,341,61,341,123,341,158,341,177,341,212,341,237,341,260,341,304,341,322,341,334,341,372,341,374,341,7,342,8,342,9,342,10,342,11,342,44,342,61,342,123,342,212,342,237,342,260,342,304,342,334,342,372,342,374,342,380,342,8,343,9,343,10,343,44,343,61,343,123,343,177,343,212,343,237,343,304,343,335,343,371,343,8,344,9,344,10,344,61,344,123,344,212,344,237,344,304,344,310,344,336,344,8,345,9,345,10,345,11,345,101,345,123,345,158,345,213,345,214,345,215,345,216,345,217,345,218,345,220,345,221,345,222,345,237,345,304,345,324,345,337,345,338,345,370,345,8,346,9,346,10,346,61,346,86,346,101,346,124,346,125,346,126,346,127,346,135,346,136,346,137,346,237,346,260,346,304,346,339,346,340,346,8,347,9,347,10,347,11,347,58,347,59,347,61,347,157,347,237,347,260,347,304,347,342,347,343,347,8,348,9,348,10,348,11,348,58,348,59,348,61,348,86,348,138,348,157,348,195,348,237,348,260,348,283,348,304,348,345,348,346,348,347,348,348,348,349,348,368,348,8,349,9,349,10,349,58,349,61,349,86,349,138,349,157,349,195,349,196,349,237,349,260,349,283,349,323,349,366,349,367,349,8,350,9,350,10,350,11,350,58,350,86,350,110,350,138,350,157,350,194,350,195,350,196,350,260,350,283,350,304,350,322,350,8,351,9,351,10,351,58,351,86,351,110,351,156,351,157,351,194,351,195,351,196,351,236,351,260,351,283,351,304,351,367,351,369,351,8,352,9,352,10,352,58,352,86,352,100,352,156,352,157,352,195,352,235,352,236,352,283,352,285,352,303,352,321,352,362,352,370,352,8,353,9,353,86,353,99,353,111,353,156,353,157,353,177,353,195,353,233,353,235,353,260,353,283,353,322,353,330,353,334,353,360,353,364,353,8,354,9,354,54,354,86,354,98,354,112,354,138,354,156,354,157,354,177,354,195,354,234,354,260,354,283,354,328,354,356,354,357,354,364,354,8,355,9,355,30,355,86,355,97,355,138,355,156,355,157,355,177,355,233,355,260,355,283,355,351,355,370,355,7,356,8,356,96,356,114,356,133,356,134,356,135,356,136,356,156,356,157,356,202,356,283,356,364,356,368,356,8,357,156,357,157,357,283,357,366,357,156,358,157,358,283,358,350,358,157,359,283,359,350,359,156,360,156,361,344,361,330,364}
listdirt5 = {223,41,316,80,304,87,294,131,294,134,298,142,327,155,326,156,339,156,342,156,331,157,342,157,341,158,339,165,334,178,326,179,337,185,82,241,93,242,85,247,387,335,387,336,306,341,310,342,310,343,55,354}
listdirt6 = {195,16,198,16,200,16,201,16,202,16,207,16,215,17,219,18,229,18,226,23,226,24,226,25,226,27,227,32,227,34,275,34,226,35,227,35,227,36,227,37,227,38,227,39,227,40,228,40,225,41,226,41,227,41,228,41,222,42,223,42,225,42,226,42,227,42,227,43,227,44,228,44,165,45,228,45,124,46,223,46,125,47,177,47,227,47,229,47,174,48,223,48,227,48,229,48,224,49,225,49,226,49,227,49,229,49,224,50,226,50,227,50,223,51,224,51,226,51,225,52,227,52,236,52,237,52,224,53,226,53,227,53,233,53,234,53,238,53,134,54,225,54,230,54,235,54,227,55,231,55,232,55,233,55,238,55,243,55,292,55,305,55,136,56,225,56,228,56,138,57,147,57,213,57,226,57,227,57,230,57,244,57,248,57,288,57,299,57,224,58,234,58,250,58,292,58,292,59,301,59,230,60,257,62,304,62,212,63,224,63,225,63,305,63,212,64,209,65,307,66,308,67,224,68,309,68,307,69,98,72,312,72,100,73,230,73,311,73,313,73,249,76,315,76,104,77,105,77,259,79,317,79,317,80,104,81,105,81,107,81,253,81,107,82,211,82,313,82,104,83,272,83,110,84,310,84,106,85,110,85,259,85,309,85,107,86,110,86,108,87,109,87,110,87,256,87,107,88,108,88,109,88,110,88,111,88,255,88,304,88,305,88,307,88,108,89,109,89,110,89,111,89,264,89,108,90,264,90,113,91,114,91,113,92,114,92,264,92,115,93,114,94,117,94,184,96,219,96,236,96,163,97,183,97,202,97,194,100,227,101,196,102,205,103,192,104,172,105,221,106,224,108,296,108,290,109,292,109,295,109,296,109,299,109,282,110,289,110,290,110,295,110,296,110,297,110,299,110,289,111,293,111,198,112,200,112,286,112,292,112,190,113,196,113,198,113,199,113,289,113,290,113,296,113,297,113,298,113,300,113,301,113,186,114,187,114,189,114,207,114,208,114,286,114,288,114,289,114,290,114,294,114,297,114,298,114,152,115,181,115,283,115,288,115,298,115,301,115,180,116,184,116,213,116,289,116,290,116,294,116,295,116,296,116,298,116,299,116,300,116,301,116,302,116,175,117,180,117,181,117,295,117,296,117,299,117,342,117,289,118,293,118,294,118,295,118,298,118,299,118,289,119,290,119,293,119,294,119,295,119,296,119,303,119,304,119,173,120,174,120,289,120,292,120,293,120,294,120,295,120,297,120,300,120,301,120,305,120,172,121,290,121,292,121,293,121,294,121,295,121,297,121,304,121,291,122,293,122,294,122,295,122,296,122,302,122,304,122,306,122,167,123,168,123,268,123,291,123,294,123,295,123,298,123,299,123,305,123,111,124,168,124,291,124,295,124,297,124,298,124,300,124,142,125,147,125,285,125,287,125,291,125,294,125,298,125,301,125,304,125,142,126,147,126,164,126,165,126,291,126,292,126,293,126,294,126,295,126,296,126,297,126,299,126,307,126,164,127,165,127,294,127,295,127,298,127,305,127,240,128,291,128,293,128,296,128,297,128,299,128,300,128,301,128,303,128,306,128,307,128,104,129,162,129,296,129,297,129,300,129,303,129,242,130,284,130,295,130,303,130,346,130,160,131,161,131,283,131,297,131,308,131,346,131,160,132,161,132,293,132,294,132,298,132,309,132,297,133,298,133,299,133,300,133,303,133,304,133,307,133,308,133,141,134,157,134,158,134,159,134,297,134,298,134,299,134,304,134,305,134,306,134,157,135,258,135,294,135,295,135,298,135,305,135,310,135,294,136,295,136,298,136,299,136,305,136,308,136,310,136,156,137,294,137,298,137,299,137,304,137,306,137,308,137,298,138,299,138,300,138,302,138,306,138,307,138,85,139,299,139,300,139,301,139,155,140,154,141,155,141,295,141,311,141,153,142,295,142,299,142,301,142,307,142,311,142,256,143,302,143,303,143,304,143,308,143,153,144,300,144,301,144,302,144,303,144,304,144,153,145,298,145,303,145,304,145,305,145,307,145,309,145,310,145,311,145,152,146,303,146,304,146,305,146,308,146,311,146,312,146,304,147,305,147,307,147,310,147,312,147,313,147,305,148,307,148,318,148,319,148,91,149,152,149,325,149,326,149,137,150,330,150,332,150,127,151,333,151,334,151,336,151,107,153,134,153,202,153,341,153,202,154,244,154,333,154,373,154,136,155,138,155,150,155,202,155,244,155,330,155,333,155,334,155,337,155,342,155,373,155,96,156,202,156,244,156,327,156,329,156,333,156,334,156,336,156,337,156,373,156,150,157,202,157,244,157,330,157,333,157,334,157,337,157,340,157,373,157,202,158,244,158,331,158,332,158,340,158,373,158,135,159,150,159,202,159,244,159,327,159,329,159,331,159,332,159,336,159,338,159,373,159,133,160,139,160,151,160,152,160,202,160,244,160,329,160,373,160,132,161,202,161,244,161,328,161,329,161,332,161,337,161,373,161,150,162,244,162,332,162,334,162,335,162,340,162,373,162,151,163,152,163,244,163,301,163,326,163,327,163,329,163,334,163,335,163,339,163,342,163,151,164,152,164,244,164,326,164,329,164,332,164,335,164,340,164,133,165,244,165,294,165,328,165,332,165,333,165,334,165,336,165,337,165,340,165,341,165,342,165,86,166,150,166,300,166,328,166,332,166,333,166,335,166,336,166,338,166,63,167,64,167,66,167,72,167,81,167,328,167,330,167,332,167,334,167,338,167,341,167,342,167,259,168,328,168,329,168,335,168,336,168,342,168,151,169,327,169,328,169,330,169,331,169,334,169,335,169,336,169,337,169,338,169,340,169,342,169,99,170,150,170,327,170,334,170,335,170,342,170,151,171,327,171,332,171,334,171,336,171,342,171,326,172,327,172,328,172,332,172,336,172,337,172,339,172,340,172,342,172,372,172,95,173,152,173,327,173,329,173,337,173,338,173,340,173,342,173,372,173,93,174,138,174,327,174,329,174,330,174,331,174,336,174,338,174,339,174,340,174,341,174,342,174,372,174,152,175,153,175,326,175,329,175,330,175,331,175,332,175,333,175,334,175,335,175,337,175,88,176,153,176,328,176,332,176,334,176,335,176,336,176,337,176,86,177,154,177,329,177,333,177,335,177,336,177,338,177,340,177,327,178,329,178,331,178,332,178,335,178,337,178,338,178,340,178,331,179,332,179,334,179,335,179,337,179,338,179,339,179,291,180,326,180,331,180,333,180,335,180,336,180,339,180,154,181,156,181,291,181,305,181,333,181,139,182,155,182,293,182,327,182,333,182,334,182,338,182,144,183,326,183,331,183,332,183,333,183,334,183,336,183,340,183,156,184,157,184,329,184,333,184,338,184,340,184,140,185,158,185,298,185,309,185,331,185,340,185,161,188,161,189,283,191,289,191,164,193,163,194,286,194,167,195,167,197,170,197,286,199,174,200,111,201,272,201,282,201,109,202,153,202,177,202,183,204,160,205,190,206,192,206,205,206,206,206,286,207,184,210,276,211,172,212,234,212,110,213,188,213,181,214,190,214,213,214,283,214,114,217,284,217,187,220,271,221,224,222,116,224,120,225,279,225,280,225,279,226,277,227,280,227,123,228,124,228,263,230,261,232,275,232,284,232,132,233,270,233,276,233,93,234,127,234,167,234,279,234,285,234,95,235,268,235,281,235,285,235,91,236,94,236,95,236,129,236,131,236,267,236,281,236,282,236,283,236,89,237,90,237,91,237,92,237,93,237,95,237,285,237,87,238,92,238,93,238,95,238,199,238,86,239,87,239,89,239,96,239,98,239,289,239,87,240,88,240,89,240,91,240,93,240,97,240,263,240,290,240,81,241,85,241,88,241,90,241,97,241,98,241,132,241,143,241,262,241,82,242,83,242,85,242,86,242,92,242,94,242,95,242,99,242,100,242,264,242,83,243,86,243,89,243,90,243,91,243,95,243,96,243,100,243,101,243,83,244,88,244,89,244,90,244,93,244,94,244,95,244,100,244,101,244,146,244,149,244,256,244,259,244,292,244,293,244,86,245,87,245,90,245,92,245,93,245,94,245,95,245,98,245,100,245,148,245,245,245,293,245,294,245,87,246,88,246,89,246,90,246,92,246,93,246,95,246,99,246,100,246,101,246,151,246,260,246,266,246,269,246,293,246,294,246,295,246,86,247,88,247,90,247,92,247,98,247,99,247,100,247,101,247,102,247,105,247,152,247,293,247,294,247,295,247,296,247,89,248,93,248,95,248,97,248,100,248,101,248,102,248,104,248,180,248,88,249,89,249,92,249,93,249,94,249,96,249,99,249,100,249,101,249,102,249,104,249,106,249,107,249,289,249,88,250,89,250,91,250,95,250,99,250,101,250,102,250,103,250,104,250,105,250,107,250,108,250,229,250,231,250,252,250,298,250,299,250,89,251,91,251,97,251,98,251,99,251,100,251,101,251,102,251,104,251,108,251,117,251,167,251,298,251,89,252,93,252,94,252,95,252,98,252,99,252,101,252,110,252,169,252,170,252,267,252,92,253,93,253,94,253,95,253,96,253,97,253,99,253,101,253,102,253,103,253,104,253,105,253,106,253,109,253,111,253,112,253,206,253,224,253,300,253,91,254,92,254,97,254,100,254,101,254,102,254,106,254,107,254,111,254,93,255,98,255,99,255,213,255,94,256,97,256,96,257,107,257,109,257,96,258,101,258,104,258,107,258,97,259,103,259,97,260,98,260,100,260,101,260,98,261,99,261,105,261,173,261,276,261,99,262,103,262,101,263,172,263,191,263,207,263,268,263,273,263,102,264,189,264,272,264,181,265,198,265,208,265,208,266,270,266,272,267,203,268,179,269,273,269,274,270,207,271,276,274,276,275,194,279,206,280,173,284,205,284,170,287,203,287,170,288,188,288,189,288,175,290,171,292,174,301,147,319,146,320,355,320,356,320,357,320,358,320,359,320,101,321,188,321,238,321,308,321,358,321,366,321,367,321,105,322,188,322,242,322,278,322,283,322,312,322,101,323,109,323,188,323,316,323,317,323,363,323,364,323,51,324,101,324,188,324,51,326,51,327,381,327,382,327,383,327,384,327,385,327,326,328,31,329,46,329,101,329,271,329,350,329,388,329,66,330,67,330,68,330,71,330,73,330,75,330,76,330,77,330,78,330,79,330,83,330,199,330,203,330,206,330,214,330,285,330,288,330,298,330,371,330,389,330,323,331,390,331,10,332,260,332,322,332,86,333,101,333,101,334,260,334,315,334,8,335,41,336,376,336,377,336,81,337,82,337,85,337,158,337,200,337,381,337,387,337,48,338,141,338,305,338,353,338,48,339,101,339,381,339,388,339,11,340,48,340,101,340,312,340,319,340,320,340,11,341,48,341,311,341,48,342,101,342,306,342,7,343,11,343,48,343,101,343,260,343,323,343,374,343,377,343,378,343,379,343,380,343,391,343,392,343,7,344,11,344,50,344,51,344,52,344,53,344,54,344,55,344,56,344,260,344,396,344,7,345,260,345,308,345,309,345,11,346,138,346,283,346,7,347,86,347,283,347,7,348,156,348,284,348,7,349,156,349,194,349,284,349,7,350,101,350,156,350,237,350,389,350,7,351,61,351,237,351,370,351,7,352,260,352,284,352,7,353,10,353,7,354,52,354,53,354,154,354,155,354,386,354,7,355,64,355,301,355,362,355,48,356,137,356,159,356,344,356,7,357,48,357,7,358,8,358,48,358,341,358,7,359,48,359,156,359,341,359,48,360,283,360,48,361,387,361,48,362,48,363,277,364,327,364,328,364,329,364,383,364,46,365,276,365,379,365,380,365,43,366,154,366,155,366,191,366,273,366,315,366,365,366,366,366,374,366,375,366,40,367,151,367,270,367,312,367,340,367,370,367,37,368,83,368,106,368,148,368,186,368,267,368,308,368,34,369,79,369,103,369,183,369,264,369,305,369,363,369,75,370,358,370,352,371,353,371}
listdirt7 = {199,16,209,16,210,16,211,16,212,16,213,16,216,17,217,17,218,17,220,18,222,18,224,18,225,18,226,18,227,18,228,18,225,19,226,19,227,19,228,19,229,19,230,19,231,19,232,19,227,20,228,20,229,20,230,20,231,20,232,20,233,20,234,20,235,20,236,20,237,20,238,20,227,21,228,21,229,21,230,21,231,21,232,21,233,21,234,21,235,21,236,21,237,21,238,21,239,21,240,21,241,21,242,21,243,21,244,21,226,22,227,22,228,22,229,22,230,22,231,22,232,22,233,22,234,22,235,22,236,22,237,22,238,22,239,22,240,22,241,22,242,22,243,22,244,22,245,22,246,22,247,22,248,22,249,22,252,22,227,23,228,23,229,23,230,23,231,23,232,23,233,23,234,23,235,23,236,23,237,23,238,23,239,23,240,23,241,23,242,23,243,23,244,23,245,23,246,23,247,23,248,23,249,23,250,23,251,23,252,23,253,23,254,23,255,23,256,23,257,23,227,24,228,24,229,24,230,24,231,24,232,24,233,24,234,24,235,24,236,24,237,24,238,24,239,24,240,24,241,24,242,24,243,24,244,24,245,24,246,24,247,24,248,24,249,24,250,24,251,24,252,24,253,24,254,24,255,24,256,24,257,24,258,24,259,24,260,24,261,24,262,24,227,25,228,25,229,25,230,25,231,25,232,25,233,25,234,25,235,25,236,25,237,25,238,25,239,25,240,25,241,25,242,25,243,25,244,25,245,25,246,25,247,25,248,25,249,25,250,25,251,25,252,25,253,25,254,25,255,25,256,25,257,25,258,25,259,25,260,25,261,25,262,25,263,25,264,25,265,25,266,25,267,25,228,26,229,26,230,26,231,26,232,26,233,26,234,26,235,26,236,26,237,26,238,26,239,26,240,26,241,26,242,26,243,26,244,26,245,26,246,26,247,26,248,26,249,26,250,26,251,26,252,26,253,26,254,26,255,26,256,26,257,26,258,26,259,26,260,26,261,26,262,26,263,26,264,26,265,26,266,26,267,26,268,26,269,26,270,26,271,26,272,26,228,27,229,27,230,27,231,27,232,27,233,27,234,27,235,27,236,27,237,27,238,27,239,27,240,27,241,27,242,27,243,27,244,27,245,27,246,27,247,27,248,27,249,27,250,27,251,27,252,27,253,27,254,27,255,27,256,27,257,27,258,27,259,27,260,27,261,27,262,27,263,27,264,27,265,27,266,27,267,27,268,27,269,27,270,27,271,27,272,27,273,27,226,28,228,28,229,28,230,28,231,28,232,28,233,28,234,28,235,28,236,28,237,28,238,28,239,28,240,28,241,28,242,28,243,28,244,28,245,28,246,28,247,28,248,28,249,28,250,28,251,28,252,28,253,28,254,28,255,28,256,28,257,28,258,28,259,28,260,28,261,28,262,28,263,28,264,28,265,28,266,28,267,28,268,28,269,28,270,28,271,28,272,28,273,28,274,28,227,29,228,29,229,29,230,29,231,29,232,29,233,29,234,29,235,29,236,29,237,29,238,29,239,29,240,29,241,29,242,29,243,29,244,29,245,29,246,29,247,29,248,29,249,29,250,29,251,29,252,29,253,29,254,29,255,29,256,29,257,29,258,29,259,29,260,29,261,29,262,29,263,29,264,29,265,29,266,29,267,29,268,29,269,29,270,29,271,29,272,29,273,29,274,29,228,30,229,30,230,30,231,30,232,30,233,30,234,30,235,30,236,30,237,30,238,30,239,30,240,30,241,30,242,30,243,30,244,30,245,30,246,30,247,30,248,30,249,30,250,30,251,30,252,30,253,30,254,30,255,30,256,30,257,30,258,30,259,30,260,30,261,30,262,30,263,30,264,30,265,30,266,30,267,30,268,30,269,30,270,30,271,30,272,30,273,30,274,30,228,31,229,31,230,31,231,31,232,31,233,31,234,31,235,31,236,31,237,31,238,31,239,31,240,31,241,31,242,31,243,31,244,31,245,31,246,31,247,31,248,31,249,31,250,31,251,31,252,31,253,31,254,31,255,31,256,31,257,31,258,31,259,31,260,31,261,31,262,31,263,31,264,31,265,31,266,31,267,31,268,31,269,31,270,31,271,31,272,31,273,31,274,31,228,32,229,32,230,32,231,32,232,32,233,32,234,32,235,32,236,32,237,32,238,32,239,32,240,32,241,32,242,32,243,32,244,32,245,32,246,32,247,32,248,32,249,32,250,32,251,32,252,32,253,32,254,32,255,32,256,32,257,32,258,32,259,32,260,32,261,32,262,32,263,32,264,32,265,32,266,32,267,32,268,32,269,32,270,32,271,32,272,32,273,32,274,32,227,33,228,33,229,33,230,33,231,33,232,33,233,33,234,33,235,33,236,33,237,33,238,33,239,33,240,33,241,33,242,33,243,33,244,33,245,33,246,33,247,33,248,33,249,33,250,33,251,33,252,33,253,33,254,33,255,33,256,33,257,33,258,33,259,33,260,33,261,33,262,33,263,33,264,33,265,33,266,33,267,33,268,33,269,33,270,33,271,33,272,33,273,33,274,33,228,34,229,34,230,34,231,34,232,34,233,34,234,34,235,34,236,34,237,34,238,34,239,34,240,34,241,34,242,34,243,34,244,34,245,34,246,34,247,34,248,34,249,34,250,34,251,34,252,34,253,34,254,34,255,34,256,34,257,34,258,34,259,34,260,34,261,34,262,34,263,34,264,34,265,34,266,34,267,34,268,34,269,34,270,34,271,34,272,34,273,34,274,34,229,35,230,35,231,35,232,35,233,35,234,35,235,35,236,35,237,35,238,35,239,35,240,35,241,35,242,35,243,35,244,35,245,35,246,35,247,35,248,35,249,35,250,35,251,35,252,35,253,35,254,35,255,35,256,35,257,35,258,35,259,35,260,35,261,35,262,35,263,35,264,35,265,35,266,35,267,35,268,35,269,35,270,35,271,35,272,35,273,35,274,35,228,36,229,36,230,36,231,36,232,36,233,36,234,36,235,36,236,36,237,36,238,36,239,36,240,36,241,36,242,36,243,36,244,36,245,36,246,36,247,36,248,36,249,36,250,36,251,36,252,36,253,36,254,36,255,36,256,36,257,36,258,36,259,36,260,36,261,36,262,36,263,36,264,36,265,36,266,36,267,36,268,36,269,36,270,36,271,36,272,36,273,36,274,36,275,36,228,37,229,37,230,37,231,37,232,37,233,37,234,37,235,37,236,37,237,37,238,37,239,37,240,37,241,37,242,37,243,37,244,37,245,37,246,37,247,37,248,37,249,37,250,37,251,37,252,37,253,37,254,37,255,37,256,37,257,37,258,37,259,37,260,37,261,37,262,37,263,37,264,37,265,37,266,37,267,37,268,37,269,37,270,37,271,37,272,37,273,37,274,37,275,37,229,38,230,38,231,38,232,38,233,38,234,38,235,38,236,38,237,38,238,38,239,38,240,38,241,38,242,38,243,38,244,38,245,38,246,38,247,38,248,38,249,38,250,38,251,38,252,38,253,38,254,38,255,38,256,38,257,38,258,38,259,38,260,38,261,38,262,38,263,38,264,38,265,38,266,38,267,38,268,38,269,38,270,38,271,38,272,38,273,38,274,38,275,38,228,39,229,39,230,39,231,39,232,39,233,39,234,39,235,39,236,39,237,39,238,39,239,39,240,39,241,39,242,39,243,39,244,39,245,39,246,39,247,39,248,39,249,39,250,39,251,39,252,39,253,39,254,39,255,39,256,39,257,39,258,39,259,39,260,39,261,39,262,39,263,39,264,39,265,39,266,39,267,39,268,39,269,39,270,39,271,39,272,39,273,39,274,39,275,39,229,40,230,40,231,40,232,40,233,40,234,40,235,40,236,40,237,40,238,40,239,40,240,40,241,40,242,40,243,40,244,40,245,40,246,40,247,40,248,40,249,40,250,40,251,40,252,40,253,40,254,40,255,40,256,40,257,40,258,40,259,40,260,40,261,40,262,40,263,40,264,40,265,40,266,40,267,40,268,40,269,40,270,40,271,40,272,40,273,40,274,40,275,40,126,41,127,41,229,41,230,41,231,41,232,41,233,41,234,41,235,41,236,41,237,41,238,41,239,41,240,41,241,41,242,41,243,41,244,41,245,41,246,41,247,41,248,41,249,41,250,41,251,41,252,41,253,41,254,41,255,41,256,41,257,41,258,41,259,41,260,41,261,41,262,41,263,41,264,41,265,41,266,41,267,41,268,41,269,41,270,41,271,41,272,41,273,41,274,41,275,41,125,42,126,42,127,42,128,42,129,42,130,42,131,42,132,42,133,42,134,42,135,42,136,42,228,42,229,42,230,42,231,42,232,42,233,42,234,42,235,42,236,42,237,42,238,42,239,42,240,42,241,42,242,42,243,42,244,42,245,42,246,42,247,42,248,42,249,42,250,42,251,42,252,42,253,42,254,42,255,42,256,42,257,42,258,42,259,42,260,42,261,42,262,42,263,42,264,42,265,42,266,42,267,42,268,42,269,42,270,42,271,42,272,42,273,42,274,42,275,42,123,43,124,43,125,43,126,43,127,43,128,43,129,43,130,43,131,43,132,43,133,43,134,43,135,43,136,43,137,43,138,43,139,43,140,43,141,43,142,43,143,43,144,43,225,43,228,43,229,43,230,43,231,43,232,43,233,43,234,43,235,43,236,43,237,43,238,43,239,43,240,43,241,43,242,43,243,43,244,43,245,43,246,43,247,43,248,43,249,43,250,43,251,43,252,43,253,43,254,43,255,43,256,43,257,43,258,43,259,43,260,43,261,43,262,43,263,43,264,43,265,43,266,43,267,43,268,43,269,43,270,43,271,43,272,43,273,43,274,43,275,43,123,44,124,44,125,44,126,44,127,44,128,44,129,44,130,44,131,44,132,44,133,44,134,44,135,44,136,44,137,44,138,44,139,44,140,44,141,44,142,44,143,44,144,44,145,44,146,44,147,44,148,44,149,44,150,44,151,44,152,44,153,44,154,44,155,44,156,44,157,44,229,44,230,44,231,44,232,44,233,44,234,44,235,44,236,44,237,44,238,44,239,44,240,44,241,44,242,44,243,44,244,44,245,44,246,44,247,44,248,44,249,44,250,44,251,44,252,44,253,44,254,44,255,44,256,44,257,44,258,44,259,44,260,44,261,44,262,44,263,44,264,44,265,44,266,44,267,44,268,44,269,44,270,44,271,44,272,44,273,44,274,44,275,44,123,45,124,45,125,45,126,45,127,45,128,45,129,45,130,45,131,45,132,45,133,45,134,45,135,45,136,45,137,45,138,45,139,45,140,45,141,45,142,45,143,45,144,45,145,45,146,45,147,45,148,45,149,45,150,45,151,45,152,45,153,45,154,45,155,45,156,45,157,45,158,45,159,45,160,45,161,45,162,45,163,45,164,45,229,45,230,45,231,45,232,45,233,45,234,45,235,45,236,45,237,45,238,45,239,45,240,45,241,45,242,45,243,45,244,45,245,45,246,45,247,45,248,45,249,45,250,45,251,45,252,45,253,45,254,45,255,45,256,45,257,45,258,45,259,45,260,45,261,45,262,45,263,45,264,45,265,45,266,45,267,45,268,45,269,45,270,45,271,45,272,45,273,45,274,45,275,45,125,46,126,46,127,46,128,46,129,46,130,46,131,46,132,46,133,46,134,46,135,46,136,46,137,46,138,46,139,46,140,46,141,46,142,46,143,46,144,46,145,46,146,46,147,46,148,46,149,46,150,46,151,46,152,46,153,46,154,46,155,46,156,46,157,46,158,46,159,46,160,46,161,46,162,46,163,46,164,46,165,46,166,46,167,46,168,46,169,46,170,46,171,46,172,46,228,46,229,46,230,46,231,46,232,46,233,46,234,46,235,46,236,46,237,46,238,46,239,46,240,46,241,46,242,46,243,46,244,46,245,46,246,46,247,46,248,46,249,46,250,46,251,46,252,46,253,46,254,46,255,46,256,46,257,46,258,46,259,46,260,46,261,46,262,46,263,46,264,46,265,46,266,46,267,46,268,46,269,46,270,46,271,46,272,46,273,46,274,46,275,46,126,47,127,47,128,47,129,47,130,47,131,47,132,47,133,47,134,47,135,47,136,47,137,47,138,47,139,47,140,47,141,47,142,47,143,47,144,47,145,47,146,47,147,47,148,47,149,47,150,47,151,47,152,47,153,47,154,47,155,47,156,47,157,47,158,47,159,47,160,47,161,47,162,47,163,47,164,47,165,47,166,47,167,47,168,47,169,47,170,47,171,47,172,47,173,47,174,47,175,47,176,47,230,47,231,47,232,47,233,47,234,47,235,47,236,47,237,47,238,47,239,47,240,47,241,47,242,47,243,47,244,47,245,47,246,47,247,47,248,47,249,47,250,47,251,47,252,47,253,47,254,47,255,47,256,47,257,47,258,47,259,47,260,47,261,47,262,47,263,47,264,47,265,47,266,47,267,47,268,47,269,47,270,47,271,47,272,47,273,47,274,47,275,47,127,48,128,48,129,48,130,48,131,48,132,48,133,48,134,48,135,48,136,48,137,48,138,48,139,48,140,48,141,48,142,48,143,48,144,48,145,48,146,48,147,48,148,48,149,48,150,48,151,48,152,48,153,48,154,48,155,48,156,48,157,48,158,48,159,48,160,48,161,48,162,48,163,48,164,48,165,48,166,48,167,48,168,48,169,48,170,48,171,48,172,48,173,48,230,48,231,48,232,48,233,48,234,48,235,48,236,48,237,48,238,48,239,48,240,48,241,48,242,48,243,48,244,48,245,48,246,48,247,48,248,48,249,48,250,48,251,48,252,48,253,48,254,48,255,48,256,48,257,48,258,48,259,48,260,48,261,48,262,48,263,48,264,48,265,48,266,48,267,48,268,48,269,48,270,48,271,48,272,48,273,48,274,48,275,48,128,49,129,49,130,49,131,49,132,49,133,49,134,49,135,49,136,49,137,49,138,49,139,49,140,49,141,49,142,49,143,49,144,49,145,49,146,49,147,49,148,49,149,49,150,49,151,49,152,49,153,49,154,49,155,49,156,49,157,49,158,49,159,49,160,49,161,49,162,49,163,49,164,49,165,49,166,49,167,49,168,49,170,49,232,49,233,49,234,49,235,49,236,49,237,49,238,49,239,49,240,49,241,49,242,49,243,49,244,49,245,49,246,49,247,49,248,49,249,49,250,49,251,49,252,49,253,49,254,49,255,49,256,49,257,49,258,49,259,49,260,49,261,49,262,49,263,49,264,49,265,49,266,49,267,49,268,49,269,49,270,49,271,49,272,49,273,49,274,49,275,49,276,49,129,50,130,50,131,50,132,50,133,50,134,50,135,50,136,50,137,50,138,50,139,50,140,50,141,50,142,50,143,50,144,50,145,50,146,50,147,50,148,50,149,50,150,50,151,50,152,50,153,50,154,50,155,50,156,50,157,50,158,50,159,50,160,50,161,50,162,50,163,50,164,50,165,50,167,50,234,50,235,50,236,50,237,50,238,50,239,50,240,50,241,50,242,50,243,50,244,50,245,50,246,50,247,50,248,50,249,50,250,50,251,50,252,50,253,50,254,50,255,50,256,50,257,50,258,50,259,50,260,50,261,50,262,50,263,50,264,50,265,50,266,50,267,50,268,50,269,50,270,50,271,50,272,50,273,50,274,50,275,50,276,50,131,51,132,51,133,51,134,51,135,51,136,51,137,51,138,51,139,51,140,51,141,51,142,51,143,51,144,51,145,51,146,51,147,51,148,51,149,51,150,51,151,51,152,51,153,51,154,51,155,51,156,51,157,51,158,51,159,51,160,51,161,51,162,51,163,51,231,51,233,51,234,51,235,51,236,51,237,51,238,51,239,51,240,51,241,51,242,51,243,51,244,51,245,51,246,51,247,51,248,51,249,51,250,51,251,51,252,51,253,51,254,51,255,51,256,51,257,51,258,51,259,51,260,51,261,51,262,51,263,51,264,51,265,51,266,51,267,51,268,51,269,51,270,51,271,51,272,51,273,51,274,51,275,51,276,51,132,52,133,52,134,52,135,52,136,52,137,52,138,52,139,52,140,52,141,52,142,52,143,52,144,52,145,52,146,52,147,52,148,52,149,52,150,52,151,52,152,52,153,52,154,52,155,52,156,52,157,52,158,52,159,52,160,52,226,52,238,52,239,52,240,52,241,52,242,52,243,52,244,52,245,52,246,52,247,52,248,52,249,52,250,52,251,52,252,52,253,52,254,52,255,52,256,52,257,52,258,52,259,52,260,52,261,52,262,52,263,52,264,52,265,52,266,52,267,52,268,52,269,52,270,52,271,52,272,52,273,52,274,52,275,52,276,52,133,53,134,53,135,53,136,53,137,53,138,53,139,53,140,53,141,53,142,53,143,53,144,53,145,53,146,53,147,53,148,53,149,53,150,53,151,53,152,53,153,53,154,53,155,53,156,53,157,53,225,53,240,53,241,53,242,53,243,53,244,53,245,53,246,53,247,53,248,53,249,53,250,53,251,53,252,53,253,53,254,53,255,53,256,53,257,53,258,53,259,53,260,53,261,53,262,53,263,53,264,53,265,53,266,53,267,53,268,53,269,53,270,53,271,53,272,53,273,53,274,53,275,53,276,53,277,53,290,53,291,53,135,54,136,54,137,54,138,54,139,54,140,54,141,54,142,54,143,54,144,54,145,54,146,54,147,54,148,54,149,54,150,54,151,54,152,54,153,54,154,54,155,54,224,54,242,54,243,54,244,54,245,54,246,54,247,54,248,54,249,54,250,54,251,54,252,54,253,54,254,54,255,54,256,54,257,54,258,54,259,54,260,54,261,54,262,54,263,54,264,54,265,54,266,54,267,54,268,54,269,54,270,54,271,54,272,54,273,54,274,54,275,54,276,54,277,54,289,54,290,54,291,54,292,54,293,54,297,54,136,55,137,55,138,55,139,55,140,55,141,55,142,55,143,55,144,55,145,55,146,55,147,55,148,55,149,55,150,55,151,55,244,55,245,55,246,55,247,55,248,55,249,55,250,55,251,55,252,55,253,55,254,55,255,55,256,55,257,55,258,55,259,55,260,55,261,55,262,55,263,55,264,55,265,55,266,55,267,55,268,55,269,55,270,55,271,55,272,55,273,55,274,55,275,55,276,55,277,55,278,55,279,55,287,55,288,55,289,55,290,55,297,55,298,55,299,55,300,55,301,55,302,55,303,55,304,55,137,56,138,56,139,56,140,56,141,56,142,56,143,56,144,56,145,56,146,56,147,56,148,56,149,56,150,56,226,56,247,56,248,56,249,56,250,56,251,56,252,56,253,56,254,56,255,56,256,56,257,56,258,56,259,56,260,56,261,56,262,56,263,56,264,56,265,56,266,56,267,56,268,56,269,56,270,56,271,56,272,56,273,56,274,56,275,56,276,56,277,56,278,56,279,56,280,56,286,56,287,56,288,56,289,56,290,56,299,56,300,56,301,56,302,56,303,56,304,56,305,56,306,56,307,56,308,56,309,56,310,56,311,56,139,57,140,57,141,57,142,57,143,57,144,57,145,57,146,57,225,57,249,57,250,57,251,57,252,57,253,57,254,57,255,57,256,57,257,57,258,57,259,57,260,57,261,57,262,57,263,57,264,57,265,57,266,57,267,57,268,57,269,57,270,57,271,57,272,57,273,57,274,57,275,57,276,57,277,57,278,57,279,57,280,57,281,57,282,57,284,57,285,57,286,57,287,57,300,57,301,57,302,57,303,57,304,57,305,57,306,57,307,57,308,57,309,57,310,57,311,57,312,57,313,57,314,57,315,57,316,57,317,57,318,57,319,57,140,58,141,58,142,58,143,58,144,58,225,58,251,58,252,58,253,58,254,58,255,58,256,58,257,58,258,58,259,58,260,58,261,58,262,58,263,58,264,58,265,58,266,58,267,58,268,58,269,58,270,58,271,58,272,58,273,58,274,58,275,58,276,58,277,58,278,58,279,58,280,58,281,58,282,58,283,58,284,58,285,58,286,58,301,58,302,58,303,58,304,58,305,58,306,58,307,58,308,58,309,58,310,58,311,58,312,58,313,58,314,58,315,58,316,58,317,58,318,58,319,58,320,58,321,58,322,58,323,58,324,58,325,58,326,58,252,59,253,59,254,59,255,59,256,59,257,59,258,59,259,59,260,59,261,59,262,59,263,59,264,59,265,59,266,59,267,59,268,59,269,59,270,59,271,59,272,59,273,59,274,59,275,59,276,59,277,59,278,59,279,59,280,59,281,59,282,59,283,59,284,59,302,59,303,59,304,59,305,59,306,59,307,59,308,59,309,59,310,59,311,59,312,59,313,59,314,59,315,59,316,59,317,59,318,59,319,59,320,59,321,59,322,59,323,59,324,59,325,59,326,59,327,59,328,59,329,59,330,59,331,59,332,59,333,59,198,60,254,60,255,60,256,60,257,60,258,60,259,60,260,60,261,60,262,60,263,60,264,60,265,60,266,60,267,60,268,60,269,60,270,60,271,60,272,60,273,60,274,60,275,60,276,60,277,60,278,60,279,60,280,60,281,60,282,60,283,60,302,60,303,60,304,60,305,60,306,60,307,60,308,60,309,60,310,60,311,60,312,60,313,60,314,60,315,60,316,60,317,60,318,60,319,60,320,60,321,60,322,60,323,60,324,60,325,60,326,60,327,60,328,60,329,60,330,60,331,60,332,60,333,60,334,60,257,61,258,61,259,61,260,61,261,61,262,61,263,61,264,61,265,61,266,61,267,61,268,61,269,61,270,61,271,61,272,61,273,61,274,61,275,61,276,61,277,61,278,61,279,61,280,61,282,61,304,61,305,61,306,61,307,61,308,61,309,61,310,61,311,61,312,61,313,61,314,61,315,61,316,61,317,61,318,61,319,61,320,61,321,61,322,61,323,61,324,61,325,61,326,61,327,61,328,61,329,61,330,61,331,61,332,61,333,61,334,61,335,61,207,62,259,62,260,62,261,62,262,62,263,62,264,62,265,62,266,62,267,62,268,62,269,62,270,62,271,62,272,62,273,62,274,62,275,62,276,62,277,62,278,62,279,62,305,62,306,62,307,62,308,62,309,62,310,62,311,62,312,62,313,62,314,62,315,62,316,62,317,62,318,62,319,62,320,62,321,62,322,62,323,62,324,62,325,62,326,62,327,62,328,62,329,62,330,62,331,62,332,62,333,62,334,62,335,62,336,62,260,63,261,63,262,63,263,63,264,63,265,63,266,63,267,63,268,63,269,63,270,63,271,63,272,63,273,63,274,63,275,63,276,63,277,63,306,63,307,63,308,63,309,63,310,63,311,63,312,63,313,63,314,63,315,63,316,63,317,63,318,63,319,63,320,63,321,63,322,63,323,63,324,63,325,63,326,63,327,63,328,63,329,63,330,63,331,63,332,63,333,63,334,63,335,63,336,63,337,63,209,64,261,64,262,64,263,64,264,64,265,64,266,64,267,64,268,64,269,64,270,64,271,64,272,64,273,64,274,64,275,64,306,64,307,64,308,64,309,64,310,64,311,64,312,64,313,64,314,64,315,64,316,64,317,64,318,64,319,64,320,64,321,64,322,64,323,64,324,64,325,64,326,64,327,64,328,64,329,64,330,64,331,64,332,64,333,64,334,64,335,64,336,64,337,64,338,64,264,65,265,65,266,65,267,65,268,65,269,65,270,65,271,65,272,65,273,65,275,65,307,65,308,65,309,65,310,65,311,65,312,65,313,65,314,65,315,65,316,65,317,65,318,65,319,65,320,65,321,65,322,65,323,65,324,65,325,65,326,65,327,65,328,65,329,65,330,65,331,65,332,65,333,65,334,65,335,65,336,65,337,65,338,65,266,66,267,66,268,66,269,66,270,66,271,66,272,66,273,66,309,66,310,66,311,66,312,66,313,66,314,66,315,66,316,66,317,66,318,66,319,66,320,66,321,66,322,66,323,66,324,66,325,66,326,66,327,66,328,66,329,66,330,66,331,66,332,66,333,66,334,66,335,66,336,66,337,66,338,66,339,66,219,67,267,67,268,67,269,67,270,67,309,67,310,67,311,67,312,67,313,67,314,67,315,67,316,67,317,67,318,67,319,67,320,67,321,67,322,67,323,67,324,67,325,67,326,67,327,67,328,67,329,67,330,67,331,67,332,67,333,67,334,67,335,67,336,67,337,67,338,67,339,67,340,67,310,68,311,68,312,68,313,68,314,68,315,68,316,68,317,68,318,68,319,68,320,68,321,68,322,68,323,68,324,68,325,68,326,68,327,68,328,68,329,68,330,68,331,68,332,68,333,68,334,68,335,68,336,68,337,68,338,68,339,68,340,68,341,68,311,69,312,69,313,69,314,69,315,69,316,69,317,69,318,69,319,69,320,69,321,69,322,69,323,69,324,69,325,69,326,69,327,69,328,69,329,69,330,69,331,69,332,69,333,69,334,69,335,69,336,69,337,69,338,69,339,69,340,69,341,69,342,69,312,70,313,70,314,70,315,70,316,70,317,70,318,70,319,70,320,70,321,70,322,70,323,70,324,70,325,70,326,70,327,70,328,70,329,70,330,70,331,70,332,70,333,70,334,70,335,70,336,70,337,70,338,70,339,70,340,70,341,70,342,70,343,70,312,71,313,71,314,71,315,71,316,71,317,71,318,71,319,71,320,71,321,71,322,71,323,71,324,71,325,71,326,71,327,71,328,71,329,71,330,71,331,71,332,71,333,71,334,71,335,71,336,71,337,71,338,71,339,71,340,71,341,71,342,71,343,71,344,71,313,72,314,72,315,72,316,72,317,72,318,72,319,72,320,72,321,72,322,72,323,72,324,72,325,72,326,72,327,72,328,72,329,72,330,72,331,72,332,72,333,72,334,72,335,72,336,72,337,72,338,72,339,72,340,72,341,72,342,72,343,72,344,72,345,72,314,73,315,73,316,73,317,73,318,73,319,73,320,73,321,73,322,73,323,73,324,73,325,73,326,73,327,73,328,73,329,73,330,73,331,73,332,73,333,73,334,73,335,73,336,73,337,73,338,73,339,73,340,73,341,73,342,73,343,73,344,73,345,73,314,74,315,74,316,74,317,74,318,74,319,74,320,74,321,74,322,74,323,74,324,74,325,74,326,74,327,74,328,74,329,74,330,74,331,74,332,74,333,74,334,74,335,74,336,74,337,74,338,74,339,74,340,74,341,74,342,74,343,74,344,74,345,74,346,74,314,75,316,75,317,75,318,75,319,75,320,75,321,75,322,75,323,75,324,75,325,75,326,75,327,75,328,75,329,75,330,75,331,75,332,75,333,75,334,75,335,75,336,75,337,75,338,75,339,75,340,75,341,75,342,75,343,75,344,75,345,75,346,75,347,75,105,76,248,76,316,76,317,76,318,76,319,76,320,76,321,76,322,76,323,76,324,76,325,76,326,76,327,76,328,76,329,76,330,76,331,76,332,76,333,76,334,76,335,76,336,76,337,76,338,76,339,76,340,76,341,76,342,76,343,76,344,76,345,76,346,76,347,76,316,77,317,77,318,77,319,77,320,77,321,77,322,77,323,77,324,77,325,77,326,77,327,77,328,77,329,77,330,77,331,77,332,77,333,77,334,77,335,77,336,77,337,77,338,77,339,77,340,77,341,77,342,77,343,77,344,77,345,77,346,77,347,77,348,77,250,78,317,78,318,78,319,78,320,78,321,78,322,78,323,78,324,78,325,78,326,78,327,78,328,78,329,78,330,78,331,78,332,78,333,78,334,78,335,78,336,78,337,78,338,78,339,78,340,78,341,78,342,78,343,78,344,78,345,78,346,78,347,78,348,78,349,78,258,79,318,79,319,79,320,79,321,79,322,79,323,79,324,79,325,79,326,79,327,79,328,79,329,79,330,79,331,79,332,79,333,79,334,79,335,79,336,79,337,79,338,79,339,79,340,79,341,79,342,79,343,79,344,79,345,79,346,79,347,79,348,79,349,79,318,80,319,80,320,80,321,80,322,80,323,80,324,80,325,80,326,80,327,80,328,80,329,80,330,80,331,80,332,80,333,80,334,80,335,80,336,80,337,80,338,80,339,80,340,80,341,80,342,80,343,80,344,80,345,80,346,80,347,80,348,80,349,80,350,80,254,81,261,81,315,81,318,81,319,81,320,81,321,81,322,81,323,81,324,81,325,81,326,81,327,81,328,81,329,81,330,81,331,81,332,81,333,81,334,81,335,81,336,81,337,81,338,81,339,81,340,81,341,81,342,81,343,81,344,81,345,81,346,81,347,81,348,81,349,81,350,81,108,82,259,82,314,82,316,82,317,82,318,82,319,82,320,82,321,82,322,82,323,82,324,82,325,82,326,82,327,82,328,82,329,82,330,82,331,82,332,82,333,82,334,82,335,82,336,82,337,82,338,82,339,82,340,82,341,82,342,82,343,82,344,82,345,82,346,82,347,82,348,82,349,82,350,82,312,83,313,83,316,83,317,83,318,83,319,83,320,83,321,83,322,83,323,83,324,83,325,83,326,83,327,83,328,83,329,83,330,83,331,83,332,83,333,83,334,83,335,83,336,83,337,83,338,83,339,83,340,83,341,83,342,83,343,83,344,83,345,83,346,83,347,83,348,83,349,83,350,83,311,84,312,84,314,84,315,84,316,84,317,84,318,84,319,84,320,84,321,84,322,84,323,84,324,84,325,84,326,84,327,84,328,84,329,84,330,84,331,84,332,84,333,84,334,84,335,84,336,84,337,84,338,84,339,84,340,84,341,84,342,84,343,84,344,84,345,84,346,84,347,84,348,84,349,84,111,85,310,85,311,85,312,85,313,85,315,85,316,85,317,85,318,85,319,85,320,85,321,85,322,85,323,85,324,85,325,85,326,85,327,85,328,85,329,85,330,85,331,85,332,85,333,85,334,85,335,85,336,85,337,85,338,85,339,85,340,85,341,85,342,85,343,85,344,85,345,85,346,85,347,85,348,85,111,86,307,86,312,86,314,86,315,86,316,86,317,86,318,86,319,86,320,86,321,86,322,86,323,86,324,86,325,86,326,86,327,86,328,86,329,86,330,86,331,86,332,86,333,86,334,86,335,86,336,86,337,86,338,86,339,86,340,86,341,86,342,86,343,86,344,86,345,86,346,86,347,86,107,87,112,87,113,87,261,87,306,87,312,87,313,87,314,87,315,87,316,87,317,87,318,87,319,87,320,87,321,87,322,87,323,87,324,87,325,87,326,87,327,87,328,87,329,87,330,87,331,87,332,87,333,87,334,87,335,87,336,87,337,87,338,87,339,87,340,87,341,87,342,87,343,87,344,87,345,87,346,87,347,87,266,88,306,88,311,88,312,88,313,88,314,88,315,88,316,88,317,88,318,88,319,88,320,88,321,88,322,88,323,88,324,88,325,88,326,88,327,88,328,88,329,88,330,88,331,88,332,88,333,88,334,88,335,88,336,88,337,88,338,88,339,88,340,88,341,88,342,88,343,88,344,88,345,88,346,88,112,89,113,89,114,89,303,89,305,89,310,89,311,89,312,89,313,89,314,89,315,89,316,89,317,89,318,89,319,89,320,89,321,89,322,89,323,89,324,89,325,89,326,89,327,89,328,89,329,89,330,89,331,89,332,89,333,89,334,89,335,89,336,89,337,89,338,89,339,89,340,89,341,89,342,89,343,89,344,89,345,89,109,90,110,90,111,90,112,90,310,90,311,90,312,90,313,90,314,90,315,90,316,90,317,90,318,90,319,90,320,90,321,90,322,90,323,90,324,90,325,90,326,90,327,90,328,90,329,90,330,90,331,90,332,90,333,90,334,90,335,90,336,90,337,90,338,90,339,90,340,90,341,90,342,90,343,90,344,90,109,91,111,91,112,91,302,91,309,91,310,91,311,91,312,91,313,91,314,91,315,91,316,91,317,91,318,91,319,91,320,91,321,91,322,91,323,91,324,91,325,91,326,91,327,91,328,91,329,91,330,91,331,91,332,91,333,91,334,91,335,91,336,91,337,91,338,91,339,91,340,91,341,91,342,91,343,91,344,91,111,92,115,92,263,92,308,92,309,92,310,92,311,92,312,92,313,92,314,92,315,92,316,92,317,92,318,92,319,92,320,92,321,92,322,92,323,92,324,92,325,92,326,92,327,92,328,92,329,92,330,92,331,92,332,92,333,92,334,92,335,92,336,92,337,92,338,92,339,92,340,92,341,92,342,92,343,92,113,93,114,93,307,93,308,93,309,93,310,93,311,93,312,93,313,93,314,93,315,93,316,93,317,93,318,93,319,93,320,93,321,93,322,93,323,93,324,93,325,93,326,93,327,93,328,93,329,93,330,93,331,93,332,93,333,93,334,93,335,93,336,93,337,93,338,93,339,93,340,93,341,93,342,93,115,94,299,94,300,94,303,94,306,94,307,94,308,94,309,94,310,94,311,94,312,94,313,94,314,94,315,94,316,94,317,94,318,94,319,94,320,94,321,94,322,94,323,94,324,94,325,94,326,94,327,94,328,94,329,94,330,94,331,94,332,94,333,94,334,94,335,94,336,94,337,94,338,94,339,94,340,94,341,94,305,95,306,95,307,95,308,95,309,95,310,95,311,95,312,95,313,95,314,95,315,95,316,95,317,95,318,95,319,95,320,95,321,95,322,95,323,95,324,95,325,95,326,95,327,95,328,95,329,95,330,95,331,95,332,95,333,95,334,95,335,95,336,95,337,95,338,95,339,95,340,95,341,95,305,96,306,96,307,96,308,96,309,96,310,96,311,96,312,96,313,96,314,96,315,96,316,96,317,96,318,96,319,96,320,96,321,96,322,96,323,96,324,96,325,96,326,96,327,96,328,96,329,96,330,96,331,96,332,96,333,96,334,96,335,96,336,96,337,96,338,96,339,96,340,96,295,97,304,97,305,97,306,97,307,97,308,97,309,97,310,97,311,97,312,97,313,97,314,97,315,97,316,97,317,97,318,97,319,97,320,97,321,97,322,97,323,97,324,97,325,97,326,97,327,97,328,97,329,97,330,97,331,97,332,97,333,97,334,97,335,97,336,97,337,97,338,97,339,97,304,98,305,98,306,98,307,98,308,98,309,98,310,98,311,98,312,98,313,98,314,98,315,98,316,98,317,98,318,98,319,98,320,98,321,98,322,98,323,98,324,98,325,98,326,98,327,98,328,98,329,98,330,98,331,98,332,98,333,98,334,98,335,98,336,98,337,98,338,98,273,99,294,99,295,99,302,99,303,99,304,99,305,99,306,99,307,99,308,99,309,99,310,99,311,99,312,99,313,99,314,99,315,99,316,99,317,99,318,99,319,99,320,99,321,99,322,99,323,99,324,99,325,99,326,99,327,99,328,99,329,99,330,99,331,99,332,99,333,99,334,99,335,99,336,99,337,99,187,100,274,100,294,100,295,100,302,100,303,100,304,100,305,100,306,100,307,100,308,100,309,100,310,100,311,100,312,100,313,100,314,100,315,100,316,100,317,100,318,100,319,100,320,100,321,100,322,100,323,100,324,100,325,100,326,100,327,100,328,100,329,100,330,100,331,100,332,100,333,100,334,100,335,100,336,100,337,100,275,101,292,101,301,101,302,101,303,101,304,101,305,101,306,101,307,101,308,101,309,101,310,101,311,101,312,101,313,101,314,101,315,101,316,101,317,101,318,101,319,101,320,101,321,101,322,101,323,101,324,101,325,101,326,101,327,101,328,101,329,101,330,101,331,101,332,101,333,101,334,101,335,101,336,101,337,101,300,102,301,102,302,102,303,102,304,102,305,102,306,102,307,102,308,102,309,102,310,102,311,102,312,102,313,102,314,102,315,102,316,102,317,102,318,102,319,102,320,102,321,102,322,102,323,102,324,102,325,102,326,102,327,102,328,102,329,102,330,102,331,102,332,102,333,102,334,102,335,102,336,102,175,103,301,103,302,103,303,103,304,103,305,103,306,103,307,103,308,103,309,103,310,103,311,103,312,103,313,103,314,103,315,103,316,103,317,103,318,103,319,103,320,103,321,103,322,103,323,103,324,103,325,103,326,103,327,103,328,103,329,103,330,103,331,103,332,103,333,103,334,103,335,103,336,103,278,104,301,104,302,104,303,104,304,104,305,104,306,104,307,104,308,104,309,104,310,104,311,104,312,104,313,104,314,104,315,104,316,104,317,104,318,104,319,104,320,104,321,104,322,104,323,104,324,104,325,104,326,104,327,104,328,104,329,104,330,104,331,104,332,104,333,104,334,104,335,104,336,104,297,105,300,105,301,105,302,105,303,105,304,105,305,105,306,105,307,105,308,105,309,105,310,105,311,105,312,105,313,105,314,105,315,105,316,105,317,105,318,105,319,105,320,105,321,105,322,105,323,105,324,105,325,105,326,105,327,105,328,105,329,105,330,105,331,105,332,105,333,105,334,105,335,105,336,105,337,105,295,106,297,106,301,106,302,106,303,106,304,106,305,106,306,106,307,106,308,106,309,106,310,106,311,106,312,106,313,106,314,106,315,106,316,106,317,106,318,106,319,106,320,106,321,106,322,106,323,106,324,106,325,106,326,106,327,106,328,106,329,106,330,106,331,106,332,106,333,106,334,106,335,106,336,106,337,106,291,107,295,107,296,107,297,107,300,107,301,107,302,107,303,107,304,107,305,107,306,107,307,107,308,107,309,107,310,107,311,107,312,107,313,107,314,107,315,107,316,107,317,107,318,107,319,107,320,107,321,107,322,107,323,107,324,107,325,107,326,107,327,107,328,107,329,107,330,107,331,107,332,107,333,107,334,107,335,107,336,107,337,107,290,108,292,108,293,108,294,108,295,108,297,108,298,108,299,108,301,108,302,108,303,108,304,108,305,108,306,108,307,108,308,108,309,108,310,108,311,108,312,108,313,108,314,108,315,108,316,108,317,108,318,108,319,108,320,108,321,108,322,108,323,108,324,108,325,108,326,108,327,108,328,108,329,108,330,108,331,108,332,108,333,108,334,108,335,108,336,108,337,108,289,109,291,109,293,109,294,109,297,109,298,109,300,109,301,109,302,109,303,109,304,109,305,109,306,109,307,109,308,109,309,109,310,109,311,109,312,109,313,109,314,109,315,109,316,109,317,109,318,109,319,109,320,109,321,109,322,109,323,109,324,109,325,109,326,109,327,109,328,109,329,109,330,109,331,109,332,109,333,109,334,109,335,109,336,109,337,109,338,109,169,110,285,110,291,110,292,110,293,110,294,110,298,110,300,110,301,110,302,110,303,110,304,110,305,110,306,110,307,110,308,110,309,110,310,110,311,110,312,110,313,110,314,110,315,110,316,110,317,110,318,110,319,110,320,110,321,110,322,110,323,110,324,110,325,110,326,110,327,110,328,110,329,110,330,110,331,110,332,110,333,110,334,110,335,110,336,110,337,110,338,110,290,111,291,111,292,111,294,111,295,111,296,111,299,111,300,111,301,111,303,111,304,111,305,111,306,111,307,111,308,111,309,111,310,111,311,111,312,111,313,111,314,111,315,111,316,111,317,111,318,111,319,111,320,111,321,111,322,111,323,111,324,111,325,111,326,111,327,111,328,111,329,111,330,111,331,111,332,111,333,111,334,111,335,111,336,111,337,111,338,111,339,111,281,112,289,112,291,112,293,112,294,112,295,112,296,112,298,112,299,112,300,112,302,112,303,112,304,112,305,112,306,112,307,112,308,112,309,112,310,112,311,112,312,112,313,112,314,112,315,112,316,112,317,112,318,112,319,112,320,112,321,112,322,112,323,112,324,112,325,112,326,112,327,112,328,112,329,112,330,112,331,112,332,112,333,112,334,112,335,112,336,112,337,112,338,112,339,112,201,113,291,113,292,113,295,113,299,113,302,113,304,113,305,113,306,113,307,113,308,113,309,113,310,113,311,113,312,113,313,113,314,113,315,113,316,113,317,113,318,113,319,113,320,113,321,113,322,113,323,113,324,113,325,113,326,113,327,113,328,113,329,113,330,113,331,113,332,113,333,113,334,113,335,113,336,113,337,113,338,113,339,113,340,113,193,114,194,114,195,114,196,114,198,114,199,114,200,114,201,114,202,114,285,114,292,114,293,114,295,114,296,114,299,114,300,114,301,114,303,114,304,114,305,114,306,114,307,114,308,114,309,114,310,114,311,114,312,114,313,114,314,114,315,114,316,114,317,114,318,114,319,114,320,114,321,114,322,114,323,114,324,114,325,114,326,114,327,114,328,114,329,114,330,114,331,114,332,114,333,114,334,114,335,114,336,114,337,114,338,114,339,114,340,114,182,115,189,115,191,115,192,115,193,115,194,115,195,115,196,115,197,115,198,115,199,115,200,115,201,115,202,115,203,115,204,115,205,115,207,115,208,115,285,115,287,115,289,115,291,115,293,115,294,115,295,115,296,115,297,115,299,115,300,115,302,115,305,115,306,115,307,115,308,115,309,115,310,115,311,115,312,115,313,115,314,115,315,115,316,115,317,115,318,115,319,115,320,115,321,115,322,115,323,115,324,115,325,115,326,115,327,115,328,115,329,115,330,115,331,115,332,115,333,115,334,115,335,115,336,115,337,115,338,115,339,115,340,115,176,116,183,116,186,116,187,116,188,116,189,116,190,116,191,116,192,116,193,116,194,116,195,116,196,116,197,116,198,116,199,116,200,116,201,116,202,116,203,116,204,116,205,116,206,116,207,116,208,116,209,116,210,116,211,116,212,116,283,116,288,116,291,116,292,116,293,116,297,116,303,116,304,116,305,116,306,116,307,116,308,116,309,116,310,116,311,116,312,116,313,116,314,116,315,116,316,116,317,116,318,116,319,116,320,116,321,116,322,116,323,116,324,116,325,116,326,116,327,116,328,116,329,116,330,116,331,116,332,116,333,116,334,116,335,116,336,116,337,116,338,116,339,116,340,116,341,116,182,117,183,117,184,117,185,117,186,117,187,117,188,117,189,117,190,117,191,117,192,117,193,117,194,117,195,117,196,117,197,117,198,117,199,117,200,117,201,117,202,117,203,117,204,117,205,117,206,117,207,117,208,117,209,117,210,117,211,117,212,117,213,117,214,117,216,117,289,117,290,117,291,117,292,117,293,117,294,117,297,117,300,117,303,117,304,117,306,117,307,117,308,117,309,117,310,117,311,117,312,117,313,117,314,117,315,117,316,117,317,117,318,117,319,117,320,117,321,117,322,117,323,117,324,117,325,117,326,117,327,117,328,117,329,117,330,117,331,117,332,117,333,117,334,117,335,117,336,117,337,117,338,117,339,117,340,117,341,117,179,118,180,118,181,118,182,118,183,118,184,118,185,118,186,118,187,118,188,118,189,118,190,118,191,118,192,118,193,118,194,118,195,118,196,118,197,118,198,118,199,118,200,118,201,118,202,118,203,118,204,118,205,118,206,118,207,118,208,118,209,118,210,118,211,118,212,118,213,118,214,118,215,118,216,118,290,118,291,118,292,118,297,118,304,118,305,118,306,118,307,118,308,118,309,118,310,118,311,118,312,118,313,118,314,118,315,118,316,118,317,118,318,118,319,118,320,118,321,118,322,118,323,118,324,118,325,118,326,118,327,118,328,118,329,118,330,118,331,118,332,118,333,118,334,118,335,118,336,118,337,118,338,118,339,118,340,118,341,118,176,119,177,119,179,119,180,119,181,119,182,119,183,119,184,119,185,119,186,119,187,119,188,119,189,119,190,119,191,119,192,119,193,119,194,119,195,119,196,119,197,119,198,119,199,119,200,119,201,119,202,119,203,119,204,119,205,119,206,119,207,119,208,119,209,119,210,119,211,119,212,119,213,119,214,119,215,119,216,119,287,119,288,119,292,119,298,119,299,119,301,119,305,119,306,119,307,119,308,119,309,119,310,119,311,119,312,119,313,119,314,119,315,119,316,119,317,119,318,119,319,119,320,119,321,119,322,119,323,119,324,119,325,119,326,119,327,119,328,119,329,119,330,119,331,119,332,119,333,119,334,119,335,119,336,119,337,119,338,119,339,119,340,119,341,119,342,119,172,120,175,120,177,120,178,120,179,120,180,120,181,120,182,120,183,120,184,120,185,120,186,120,187,120,188,120,189,120,190,120,191,120,192,120,193,120,194,120,195,120,196,120,197,120,198,120,199,120,200,120,201,120,202,120,203,120,204,120,205,120,206,120,207,120,208,120,209,120,210,120,211,120,212,120,213,120,214,120,215,120,287,120,290,120,299,120,306,120,307,120,308,120,309,120,310,120,311,120,312,120,313,120,314,120,315,120,316,120,317,120,318,120,319,120,320,120,321,120,322,120,323,120,324,120,325,120,326,120,327,120,328,120,329,120,330,120,331,120,332,120,333,120,334,120,335,120,336,120,337,120,338,120,339,120,340,120,341,120,342,120,174,121,175,121,176,121,177,121,178,121,179,121,180,121,181,121,182,121,183,121,184,121,185,121,186,121,187,121,188,121,189,121,190,121,191,121,192,121,193,121,194,121,195,121,196,121,197,121,198,121,199,121,200,121,201,121,202,121,203,121,204,121,205,121,206,121,207,121,208,121,209,121,210,121,211,121,212,121,213,121,214,121,305,121,306,121,307,121,308,121,309,121,310,121,311,121,312,121,313,121,314,121,315,121,316,121,317,121,318,121,319,121,320,121,321,121,322,121,323,121,324,121,325,121,326,121,327,121,328,121,329,121,330,121,331,121,332,121,333,121,334,121,335,121,336,121,337,121,338,121,339,121,340,121,341,121,342,121,171,122,172,122,173,122,174,122,175,122,176,122,177,122,178,122,179,122,180,122,181,122,182,122,183,122,184,122,185,122,186,122,187,122,188,122,189,122,190,122,191,122,192,122,193,122,194,122,195,122,196,122,197,122,198,122,199,122,200,122,201,122,202,122,203,122,204,122,205,122,206,122,207,122,208,122,209,122,210,122,211,122,212,122,213,122,288,122,289,122,297,122,298,122,305,122,307,122,308,122,309,122,310,122,311,122,312,122,313,122,314,122,315,122,316,122,317,122,318,122,319,122,320,122,321,122,322,122,323,122,324,122,325,122,326,122,327,122,328,122,329,122,330,122,331,122,332,122,333,122,334,122,335,122,336,122,337,122,338,122,339,122,340,122,341,122,342,122,343,122,166,123,170,123,171,123,172,123,173,123,174,123,175,123,176,123,177,123,178,123,179,123,180,123,181,123,182,123,183,123,184,123,185,123,186,123,187,123,188,123,189,123,190,123,191,123,192,123,193,123,194,123,195,123,196,123,197,123,198,123,199,123,200,123,201,123,202,123,203,123,204,123,205,123,206,123,207,123,208,123,209,123,210,123,211,123,212,123,292,123,293,123,306,123,307,123,308,123,309,123,310,123,311,123,312,123,313,123,314,123,315,123,316,123,317,123,318,123,319,123,320,123,321,123,322,123,323,123,324,123,325,123,326,123,327,123,328,123,329,123,330,123,331,123,332,123,333,123,334,123,335,123,336,123,337,123,338,123,339,123,340,123,341,123,342,123,343,123,171,124,172,124,173,124,174,124,175,124,176,124,177,124,178,124,179,124,180,124,181,124,182,124,183,124,184,124,185,124,186,124,187,124,188,124,189,124,190,124,191,124,192,124,193,124,194,124,195,124,196,124,197,124,198,124,199,124,200,124,201,124,202,124,203,124,204,124,205,124,206,124,207,124,208,124,209,124,210,124,211,124,293,124,294,124,296,124,303,124,305,124,306,124,307,124,308,124,309,124,310,124,311,124,312,124,313,124,314,124,315,124,316,124,317,124,318,124,319,124,320,124,321,124,322,124,323,124,324,124,325,124,326,124,327,124,328,124,329,124,330,124,331,124,332,124,333,124,334,124,335,124,336,124,337,124,338,124,339,124,340,124,341,124,342,124,343,124,344,124,169,125,170,125,171,125,172,125,173,125,174,125,175,125,176,125,177,125,178,125,179,125,180,125,181,125,182,125,183,125,184,125,185,125,186,125,187,125,188,125,189,125,190,125,191,125,192,125,193,125,194,125,195,125,196,125,197,125,198,125,199,125,200,125,201,125,202,125,203,125,204,125,205,125,206,125,207,125,208,125,209,125,210,125,284,125,292,125,293,125,296,125,307,125,308,125,309,125,310,125,311,125,312,125,313,125,314,125,315,125,316,125,317,125,318,125,319,125,320,125,321,125,322,125,323,125,324,125,325,125,326,125,327,125,328,125,329,125,330,125,331,125,332,125,333,125,334,125,335,125,336,125,337,125,338,125,339,125,340,125,341,125,342,125,343,125,344,125,166,126,168,126,169,126,170,126,171,126,172,126,173,126,174,126,175,126,176,126,177,126,178,126,179,126,180,126,181,126,182,126,183,126,184,126,185,126,186,126,187,126,188,126,189,126,190,126,191,126,192,126,193,126,194,126,195,126,196,126,197,126,198,126,199,126,200,126,201,126,202,126,203,126,204,126,205,126,206,126,207,126,208,126,209,126,210,126,298,126,309,126,310,126,311,126,312,126,313,126,314,126,315,126,316,126,317,126,318,126,319,126,320,126,321,126,322,126,323,126,324,126,325,126,326,126,327,126,328,126,329,126,330,126,331,126,332,126,333,126,334,126,335,126,336,126,337,126,338,126,339,126,340,126,341,126,342,126,343,126,344,126,167,127,168,127,169,127,170,127,171,127,172,127,173,127,174,127,175,127,176,127,177,127,178,127,179,127,180,127,181,127,182,127,183,127,184,127,185,127,186,127,187,127,188,127,189,127,190,127,191,127,192,127,193,127,194,127,195,127,196,127,197,127,198,127,199,127,200,127,201,127,202,127,203,127,204,127,205,127,206,127,207,127,208,127,209,127,291,127,299,127,306,127,307,127,309,127,310,127,311,127,312,127,313,127,314,127,315,127,316,127,317,127,318,127,319,127,320,127,321,127,322,127,323,127,324,127,325,127,326,127,327,127,328,127,329,127,330,127,331,127,332,127,333,127,334,127,335,127,336,127,337,127,338,127,339,127,340,127,341,127,342,127,343,127,344,127,141,128,162,128,164,128,165,128,166,128,167,128,168,128,169,128,170,128,171,128,172,128,173,128,174,128,175,128,176,128,177,128,178,128,179,128,180,128,181,128,182,128,183,128,184,128,185,128,186,128,187,128,188,128,189,128,190,128,191,128,192,128,193,128,194,128,195,128,196,128,197,128,198,128,199,128,200,128,201,128,202,128,203,128,204,128,205,128,206,128,207,128,208,128,209,128,292,128,294,128,309,128,310,128,311,128,312,128,313,128,314,128,315,128,316,128,317,128,318,128,319,128,320,128,321,128,322,128,323,128,324,128,325,128,326,128,327,128,328,128,329,128,330,128,331,128,332,128,333,128,334,128,335,128,336,128,337,128,338,128,339,128,340,128,341,128,342,128,343,128,344,128,165,129,166,129,167,129,168,129,169,129,170,129,171,129,172,129,173,129,174,129,175,129,176,129,177,129,178,129,179,129,180,129,181,129,182,129,183,129,184,129,185,129,186,129,187,129,188,129,189,129,190,129,191,129,192,129,193,129,194,129,195,129,196,129,197,129,198,129,199,129,200,129,201,129,202,129,203,129,204,129,205,129,206,129,207,129,208,129,292,129,295,129,298,129,301,129,307,129,308,129,310,129,311,129,312,129,313,129,314,129,315,129,316,129,317,129,318,129,319,129,320,129,321,129,322,129,323,129,324,129,325,129,326,129,327,129,328,129,329,129,330,129,331,129,332,129,333,129,334,129,335,129,336,129,337,129,338,129,339,129,340,129,341,129,342,129,343,129,344,129,345,129,163,130,164,130,165,130,166,130,167,130,168,130,169,130,170,130,171,130,172,130,173,130,174,130,175,130,176,130,177,130,178,130,179,130,180,130,181,130,182,130,183,130,184,130,185,130,186,130,187,130,188,130,189,130,190,130,191,130,192,130,193,130,194,130,195,130,196,130,197,130,198,130,199,130,200,130,201,130,202,130,203,130,204,130,205,130,206,130,207,130,208,130,292,130,294,130,301,130,302,130,310,130,311,130,312,130,313,130,314,130,315,130,316,130,317,130,318,130,319,130,320,130,321,130,322,130,323,130,324,130,325,130,326,130,327,130,328,130,329,130,330,130,331,130,332,130,333,130,334,130,335,130,336,130,337,130,338,130,339,130,340,130,341,130,342,130,343,130,344,130,345,130,162,131,163,131,164,131,165,131,166,131,167,131,168,131,169,131,170,131,171,131,172,131,173,131,174,131,175,131,176,131,177,131,178,131,179,131,180,131,181,131,182,131,183,131,184,131,185,131,186,131,187,131,188,131,189,131,190,131,191,131,192,131,193,131,194,131,195,131,196,131,197,131,198,131,199,131,200,131,201,131,202,131,203,131,204,131,205,131,206,131,207,131,303,131,309,131,310,131,311,131,312,131,313,131,314,131,315,131,316,131,317,131,318,131,319,131,320,131,321,131,322,131,323,131,324,131,325,131,326,131,327,131,328,131,329,131,330,131,331,131,332,131,333,131,334,131,335,131,336,131,337,131,338,131,339,131,340,131,341,131,342,131,343,131,344,131,345,131,162,132,163,132,164,132,165,132,166,132,167,132,168,132,169,132,170,132,171,132,172,132,173,132,174,132,175,132,176,132,177,132,178,132,179,132,180,132,181,132,182,132,183,132,184,132,185,132,186,132,187,132,188,132,189,132,190,132,191,132,192,132,193,132,194,132,195,132,196,132,197,132,198,132,199,132,200,132,201,132,202,132,203,132,204,132,205,132,206,132,207,132,287,132,295,132,297,132,302,132,303,132,306,132,310,132,311,132,312,132,313,132,314,132,315,132,316,132,317,132,318,132,319,132,320,132,321,132,322,132,323,132,324,132,325,132,326,132,327,132,328,132,329,132,330,132,331,132,332,132,333,132,334,132,335,132,336,132,337,132,338,132,339,132,340,132,341,132,342,132,343,132,344,132,345,132,346,132,161,133,162,133,163,133,164,133,165,133,166,133,167,133,168,133,169,133,170,133,171,133,172,133,173,133,174,133,175,133,176,133,177,133,178,133,179,133,180,133,181,133,182,133,183,133,184,133,185,133,186,133,187,133,188,133,189,133,190,133,191,133,192,133,193,133,194,133,195,133,196,133,197,133,198,133,199,133,200,133,201,133,202,133,203,133,204,133,205,133,206,133,306,133,311,133,312,133,313,133,314,133,315,133,316,133,317,133,318,133,319,133,320,133,321,133,322,133,323,133,324,133,325,133,326,133,327,133,328,133,329,133,330,133,331,133,332,133,333,133,334,133,335,133,336,133,337,133,338,133,339,133,340,133,341,133,342,133,343,133,344,133,345,133,346,133,161,134,162,134,163,134,164,134,165,134,166,134,167,134,168,134,169,134,170,134,171,134,172,134,173,134,174,134,175,134,176,134,177,134,178,134,179,134,180,134,181,134,182,134,183,134,184,134,185,134,186,134,187,134,188,134,189,134,190,134,191,134,192,134,193,134,194,134,195,134,196,134,197,134,198,134,199,134,200,134,201,134,202,134,203,134,204,134,205,134,206,134,307,134,310,134,311,134,312,134,313,134,314,134,315,134,316,134,317,134,318,134,319,134,320,134,321,134,322,134,323,134,324,134,325,134,326,134,327,134,328,134,329,134,330,134,331,134,332,134,333,134,334,134,335,134,336,134,337,134,338,134,339,134,340,134,341,134,342,134,343,134,344,134,345,134,346,134,158,135,159,135,160,135,161,135,162,135,163,135,164,135,165,135,166,135,167,135,168,135,169,135,170,135,171,135,172,135,173,135,174,135,175,135,176,135,177,135,178,135,179,135,180,135,181,135,182,135,183,135,184,135,185,135,186,135,187,135,188,135,189,135,190,135,191,135,192,135,193,135,194,135,195,135,196,135,197,135,198,135,199,135,200,135,201,135,202,135,203,135,204,135,205,135,304,135,307,135,311,135,312,135,313,135,314,135,315,135,316,135,317,135,318,135,319,135,320,135,321,135,322,135,323,135,324,135,325,135,326,135,327,135,328,135,329,135,330,135,331,135,332,135,333,135,334,135,335,135,336,135,337,135,338,135,339,135,340,135,341,135,342,135,343,135,344,135,345,135,346,135,347,135,159,136,160,136,161,136,162,136,163,136,164,136,165,136,166,136,167,136,168,136,169,136,170,136,171,136,172,136,173,136,174,136,175,136,176,136,177,136,178,136,179,136,180,136,181,136,182,136,183,136,184,136,185,136,186,136,187,136,188,136,189,136,190,136,191,136,192,136,193,136,194,136,195,136,196,136,197,136,198,136,199,136,200,136,201,136,202,136,203,136,204,136,205,136,293,136,296,136,297,136,306,136,311,136,312,136,313,136,314,136,315,136,316,136,317,136,318,136,319,136,320,136,321,136,322,136,323,136,324,136,325,136,326,136,327,136,328,136,329,136,330,136,331,136,332,136,333,136,334,136,335,136,336,136,337,136,338,136,339,136,340,136,341,136,342,136,343,136,344,136,345,136,346,136,347,136,158,137,159,137,160,137,161,137,162,137,163,137,164,137,165,137,166,137,167,137,168,137,169,137,170,137,171,137,172,137,173,137,174,137,175,137,176,137,177,137,178,137,179,137,180,137,181,137,182,137,183,137,184,137,185,137,186,137,187,137,188,137,189,137,190,137,191,137,192,137,193,137,194,137,195,137,196,137,197,137,198,137,199,137,200,137,201,137,202,137,203,137,204,137,205,137,297,137,310,137,311,137,312,137,313,137,314,137,315,137,316,137,317,137,318,137,319,137,320,137,321,137,322,137,323,137,324,137,325,137,326,137,327,137,328,137,329,137,330,137,331,137,332,137,333,137,334,137,335,137,336,137,337,137,338,137,339,137,340,137,341,137,342,137,343,137,344,137,345,137,346,137,347,137,141,138,158,138,159,138,160,138,161,138,162,138,163,138,164,138,165,138,166,138,167,138,168,138,169,138,170,138,171,138,172,138,173,138,174,138,175,138,176,138,177,138,178,138,179,138,180,138,181,138,182,138,183,138,184,138,185,138,186,138,187,138,188,138,189,138,190,138,191,138,192,138,193,138,194,138,195,138,196,138,197,138,198,138,199,138,200,138,201,138,202,138,203,138,204,138,293,138,294,138,295,138,301,138,309,138,312,138,313,138,314,138,315,138,316,138,317,138,318,138,319,138,320,138,321,138,322,138,323,138,324,138,325,138,326,138,327,138,328,138,329,138,330,138,331,138,332,138,333,138,334,138,335,138,336,138,337,138,338,138,339,138,340,138,341,138,342,138,343,138,344,138,345,138,346,138,347,138,157,139,158,139,159,139,160,139,161,139,162,139,163,139,164,139,165,139,166,139,167,139,168,139,169,139,170,139,171,139,172,139,173,139,174,139,175,139,176,139,177,139,178,139,179,139,180,139,181,139,182,139,183,139,184,139,185,139,186,139,187,139,188,139,189,139,190,139,191,139,192,139,193,139,194,139,195,139,196,139,197,139,198,139,199,139,200,139,201,139,202,139,203,139,204,139,296,139,298,139,305,139,312,139,313,139,314,139,315,139,316,139,317,139,318,139,319,139,320,139,321,139,322,139,323,139,324,139,325,139,326,139,327,139,328,139,329,139,330,139,331,139,332,139,333,139,334,139,335,139,336,139,337,139,338,139,339,139,340,139,341,139,342,139,343,139,344,139,345,139,346,139,347,139,157,140,158,140,159,140,160,140,161,140,162,140,163,140,164,140,165,140,166,140,167,140,168,140,169,140,170,140,171,140,172,140,173,140,174,140,175,140,176,140,177,140,178,140,179,140,180,140,181,140,182,140,183,140,184,140,185,140,186,140,187,140,188,140,189,140,190,140,191,140,192,140,193,140,194,140,195,140,196,140,197,140,198,140,199,140,200,140,201,140,202,140,203,140,295,140,298,140,299,140,301,140,310,140,311,140,312,140,313,140,314,140,315,140,316,140,317,140,318,140,319,140,320,140,321,140,322,140,323,140,324,140,325,140,326,140,327,140,328,140,329,140,330,140,331,140,332,140,333,140,334,140,335,140,336,140,337,140,338,140,339,140,340,140,341,140,342,140,343,140,344,140,345,140,346,140,347,140,156,141,157,141,158,141,159,141,160,141,161,141,162,141,163,141,164,141,165,141,166,141,167,141,168,141,169,141,170,141,171,141,172,141,173,141,174,141,175,141,176,141,177,141,178,141,179,141,180,141,181,141,182,141,183,141,184,141,185,141,186,141,187,141,188,141,189,141,190,141,191,141,192,141,193,141,194,141,195,141,196,141,197,141,198,141,199,141,200,141,201,141,202,141,203,141,296,141,299,141,300,141,301,141,307,141,312,141,313,141,314,141,315,141,316,141,317,141,318,141,319,141,320,141,321,141,322,141,323,141,324,141,325,141,326,141,327,141,328,141,329,141,330,141,331,141,332,141,333,141,334,141,335,141,336,141,337,141,338,141,339,141,340,141,341,141,342,141,343,141,344,141,345,141,346,141,347,141,348,141,154,142,155,142,156,142,157,142,158,142,159,142,160,142,161,142,162,142,163,142,164,142,165,142,166,142,167,142,168,142,169,142,170,142,171,142,172,142,173,142,174,142,175,142,176,142,177,142,178,142,179,142,180,142,181,142,182,142,183,142,184,142,185,142,186,142,187,142,188,142,189,142,190,142,191,142,192,142,193,142,194,142,195,142,196,142,197,142,198,142,199,142,200,142,201,142,202,142,203,142,293,142,294,142,297,142,300,142,313,142,314,142,315,142,316,142,317,142,318,142,319,142,320,142,321,142,322,142,323,142,324,142,325,142,326,142,327,142,328,142,329,142,330,142,331,142,332,142,333,142,334,142,335,142,336,142,337,142,338,142,339,142,340,142,341,142,342,142,343,142,344,142,345,142,346,142,347,142,348,142,155,143,156,143,157,143,158,143,159,143,160,143,161,143,162,143,163,143,164,143,165,143,166,143,167,143,168,143,169,143,170,143,171,143,172,143,173,143,174,143,175,143,176,143,177,143,178,143,179,143,180,143,181,143,182,143,183,143,184,143,185,143,186,143,187,143,188,143,189,143,190,143,191,143,192,143,193,143,194,143,195,143,196,143,197,143,198,143,199,143,200,143,201,143,202,143,203,143,298,143,299,143,300,143,301,143,307,143,309,143,310,143,311,143,313,143,314,143,315,143,316,143,317,143,318,143,319,143,320,143,321,143,322,143,323,143,324,143,325,143,326,143,327,143,328,143,329,143,330,143,331,143,332,143,333,143,334,143,335,143,336,143,337,143,338,143,339,143,340,143,341,143,342,143,343,143,344,143,345,143,346,143,347,143,348,143,155,144,156,144,157,144,158,144,159,144,160,144,161,144,162,144,163,144,164,144,165,144,166,144,167,144,168,144,169,144,170,144,171,144,172,144,173,144,174,144,175,144,176,144,177,144,178,144,179,144,180,144,181,144,182,144,183,144,184,144,185,144,186,144,187,144,188,144,189,144,190,144,191,144,192,144,193,144,194,144,195,144,196,144,197,144,198,144,199,144,200,144,201,144,202,144,203,144,299,144,307,144,308,144,309,144,310,144,311,144,314,144,315,144,316,144,317,144,318,144,319,144,320,144,321,144,322,144,323,144,324,144,325,144,326,144,327,144,328,144,329,144,330,144,331,144,332,144,333,144,334,144,335,144,336,144,337,144,338,144,339,144,340,144,341,144,342,144,343,144,344,144,345,144,346,144,347,144,348,144,349,144,156,145,157,145,158,145,159,145,160,145,161,145,162,145,163,145,164,145,165,145,166,145,167,145,168,145,169,145,170,145,171,145,172,145,173,145,174,145,175,145,176,145,177,145,178,145,179,145,180,145,181,145,182,145,183,145,184,145,185,145,186,145,187,145,188,145,189,145,190,145,191,145,192,145,193,145,194,145,195,145,196,145,197,145,198,145,199,145,200,145,201,145,202,145,295,145,296,145,299,145,301,145,308,145,312,145,314,145,315,145,316,145,317,145,318,145,319,145,320,145,321,145,322,145,323,145,324,145,325,145,326,145,327,145,328,145,329,145,330,145,331,145,332,145,333,145,334,145,335,145,336,145,337,145,338,145,339,145,340,145,341,145,342,145,343,145,344,145,345,145,346,145,347,145,348,145,349,145,350,145,351,145,352,145,154,146,155,146,156,146,157,146,158,146,159,146,160,146,161,146,162,146,163,146,164,146,165,146,166,146,167,146,168,146,169,146,170,146,171,146,172,146,173,146,174,146,175,146,176,146,177,146,178,146,179,146,180,146,181,146,182,146,183,146,184,146,185,146,186,146,187,146,188,146,189,146,190,146,191,146,192,146,193,146,194,146,195,146,196,146,197,146,198,146,199,146,200,146,201,146,202,146,295,146,300,146,313,146,317,146,319,146,320,146,321,146,322,146,323,146,324,146,325,146,326,146,327,146,328,146,329,146,330,146,331,146,332,146,333,146,334,146,335,146,336,146,337,146,338,146,339,146,340,146,341,146,342,146,343,146,344,146,345,146,346,146,347,146,348,146,349,146,350,146,351,146,352,146,353,146,354,146,355,146,356,146,155,147,156,147,157,147,158,147,159,147,160,147,161,147,162,147,163,147,164,147,165,147,166,147,167,147,168,147,169,147,170,147,171,147,172,147,173,147,174,147,175,147,176,147,177,147,178,147,179,147,180,147,181,147,182,147,183,147,184,147,185,147,186,147,187,147,188,147,189,147,190,147,191,147,192,147,193,147,194,147,195,147,196,147,197,147,198,147,199,147,200,147,201,147,202,147,311,147,314,147,317,147,323,147,324,147,325,147,326,147,327,147,328,147,329,147,330,147,331,147,332,147,333,147,334,147,335,147,336,147,337,147,338,147,339,147,340,147,341,147,342,147,343,147,344,147,345,147,346,147,347,147,348,147,349,147,350,147,351,147,352,147,353,147,354,147,355,147,356,147,357,147,358,147,359,147,360,147,154,148,155,148,156,148,157,148,158,148,159,148,160,148,161,148,162,148,163,148,164,148,165,148,166,148,167,148,168,148,169,148,170,148,171,148,172,148,173,148,174,148,175,148,176,148,177,148,178,148,179,148,180,148,181,148,182,148,183,148,184,148,185,148,186,148,187,148,188,148,189,148,190,148,191,148,192,148,193,148,194,148,195,148,196,148,197,148,198,148,199,148,200,148,201,148,202,148,322,148,326,148,327,148,328,148,329,148,330,148,331,148,332,148,333,148,334,148,335,148,336,148,337,148,338,148,339,148,340,148,341,148,342,148,343,148,344,148,345,148,346,148,347,148,348,148,349,148,350,148,351,148,352,148,353,148,354,148,355,148,356,148,357,148,358,148,359,148,360,148,361,148,362,148,363,148,364,148,141,149,154,149,155,149,156,149,157,149,158,149,159,149,160,149,161,149,162,149,163,149,164,149,165,149,166,149,167,149,168,149,169,149,170,149,171,149,172,149,173,149,174,149,175,149,176,149,177,149,178,149,179,149,180,149,181,149,182,149,183,149,184,149,185,149,186,149,187,149,188,149,189,149,190,149,191,149,192,149,193,149,194,149,195,149,196,149,197,149,198,149,199,149,200,149,201,149,202,149,323,149,324,149,327,149,328,149,329,149,330,149,331,149,332,149,333,149,334,149,335,149,336,149,337,149,338,149,339,149,340,149,341,149,342,149,343,149,344,149,345,149,346,149,347,149,348,149,349,149,350,149,351,149,352,149,353,149,354,149,355,149,356,149,357,149,358,149,359,149,360,149,361,149,362,149,363,149,364,149,365,149,366,149,367,149,154,150,155,150,156,150,157,150,158,150,159,150,160,150,161,150,162,150,163,150,164,150,165,150,166,150,167,150,168,150,169,150,170,150,171,150,172,150,173,150,174,150,175,150,176,150,177,150,178,150,179,150,180,150,181,150,182,150,183,150,184,150,185,150,186,150,187,150,188,150,189,150,190,150,191,150,192,150,193,150,194,150,195,150,196,150,197,150,198,150,199,150,200,150,201,150,202,150,333,150,334,150,335,150,336,150,337,150,338,150,339,150,340,150,341,150,342,150,343,150,344,150,345,150,346,150,347,150,348,150,349,150,350,150,351,150,352,150,353,150,354,150,355,150,356,150,357,150,358,150,359,150,360,150,361,150,362,150,363,150,364,150,365,150,366,150,367,150,368,150,369,150,370,150,154,151,155,151,156,151,157,151,158,151,159,151,160,151,161,151,162,151,163,151,164,151,165,151,166,151,167,151,168,151,169,151,170,151,171,151,172,151,173,151,174,151,175,151,176,151,177,151,178,151,179,151,180,151,181,151,182,151,183,151,184,151,185,151,186,151,187,151,188,151,189,151,190,151,191,151,192,151,193,151,194,151,195,151,196,151,197,151,198,151,199,151,200,151,201,151,202,151,337,151,338,151,339,151,340,151,341,151,342,151,343,151,344,151,345,151,346,151,347,151,348,151,349,151,350,151,351,151,352,151,353,151,354,151,355,151,356,151,357,151,358,151,359,151,360,151,361,151,362,151,363,151,364,151,365,151,366,151,367,151,368,151,369,151,370,151,371,151,372,151,154,152,155,152,156,152,157,152,158,152,159,152,160,152,161,152,162,152,163,152,164,152,165,152,166,152,167,152,168,152,169,152,170,152,171,152,172,152,173,152,174,152,175,152,176,152,177,152,178,152,179,152,180,152,181,152,182,152,183,152,184,152,185,152,186,152,187,152,188,152,189,152,190,152,191,152,192,152,193,152,194,152,195,152,196,152,197,152,198,152,199,152,200,152,201,152,295,152,301,152,340,152,341,152,342,152,343,152,344,152,345,152,346,152,347,152,348,152,349,152,350,152,351,152,352,152,353,152,354,152,355,152,356,152,357,152,358,152,359,152,360,152,361,152,362,152,363,152,364,152,365,152,366,152,367,152,368,152,369,152,370,152,371,152,372,152,150,153,153,153,154,153,155,153,156,153,157,153,158,153,159,153,160,153,161,153,162,153,163,153,164,153,165,153,166,153,167,153,168,153,169,153,170,153,171,153,172,153,173,153,174,153,175,153,176,153,177,153,178,153,179,153,180,153,181,153,182,153,183,153,184,153,185,153,186,153,187,153,188,153,189,153,190,153,191,153,192,153,193,153,194,153,195,153,196,153,197,153,198,153,199,153,200,153,201,153,342,153,343,153,344,153,345,153,346,153,347,153,348,153,349,153,350,153,351,153,352,153,353,153,354,153,355,153,356,153,357,153,358,153,359,153,360,153,361,153,362,153,363,153,364,153,365,153,366,153,367,153,368,153,369,153,370,153,371,153,372,153,153,154,154,154,155,154,156,154,157,154,158,154,159,154,160,154,161,154,162,154,163,154,164,154,165,154,166,154,167,154,168,154,169,154,170,154,171,154,172,154,173,154,174,154,175,154,176,154,177,154,178,154,179,154,180,154,181,154,182,154,183,154,184,154,185,154,186,154,187,154,188,154,189,154,190,154,191,154,192,154,193,154,194,154,195,154,196,154,197,154,198,154,199,154,200,154,201,154,341,154,342,154,343,154,344,154,345,154,346,154,347,154,348,154,349,154,350,154,351,154,352,154,353,154,354,154,355,154,356,154,357,154,358,154,359,154,360,154,361,154,362,154,363,154,364,154,365,154,366,154,367,154,368,154,369,154,370,154,371,154,372,154,153,155,154,155,155,155,156,155,157,155,158,155,159,155,160,155,161,155,162,155,163,155,164,155,165,155,166,155,167,155,168,155,169,155,170,155,171,155,172,155,173,155,174,155,175,155,176,155,177,155,178,155,179,155,180,155,181,155,182,155,183,155,184,155,185,155,186,155,187,155,188,155,189,155,190,155,191,155,192,155,193,155,194,155,195,155,196,155,197,155,198,155,199,155,200,155,201,155,300,155,329,155,336,155,340,155,341,155,343,155,344,155,345,155,346,155,347,155,348,155,349,155,350,155,351,155,352,155,353,155,354,155,355,155,356,155,357,155,358,155,359,155,360,155,361,155,362,155,363,155,364,155,365,155,366,155,367,155,368,155,369,155,370,155,371,155,372,155,152,156,153,156,154,156,155,156,156,156,157,156,158,156,159,156,160,156,161,156,162,156,163,156,164,156,165,156,166,156,167,156,168,156,169,156,170,156,171,156,172,156,173,156,174,156,175,156,176,156,177,156,178,156,179,156,180,156,181,156,182,156,183,156,184,156,185,156,186,156,187,156,188,156,189,156,190,156,191,156,192,156,193,156,194,156,195,156,196,156,197,156,198,156,199,156,200,156,201,156,300,156,306,156,338,156,343,156,344,156,345,156,346,156,347,156,348,156,349,156,350,156,351,156,352,156,353,156,354,156,355,156,356,156,357,156,358,156,359,156,360,156,361,156,362,156,363,156,364,156,365,156,366,156,367,156,368,156,369,156,370,156,371,156,372,156,96,157,152,157,153,157,154,157,155,157,156,157,157,157,158,157,159,157,160,157,161,157,162,157,163,157,164,157,165,157,166,157,167,157,168,157,169,157,170,157,171,157,172,157,173,157,174,157,175,157,176,157,177,157,178,157,179,157,180,157,181,157,182,157,183,157,184,157,185,157,186,157,187,157,188,157,189,157,190,157,191,157,192,157,193,157,194,157,195,157,196,157,197,157,198,157,199,157,200,157,201,157,292,157,326,157,327,157,329,157,339,157,343,157,344,157,345,157,346,157,347,157,348,157,349,157,350,157,351,157,352,157,353,157,354,157,355,157,356,157,357,157,358,157,359,157,360,157,361,157,362,157,363,157,364,157,365,157,366,157,367,157,368,157,369,157,370,157,371,157,372,157,153,158,154,158,155,158,156,158,157,158,158,158,159,158,160,158,161,158,162,158,163,158,164,158,165,158,166,158,167,158,168,158,169,158,170,158,171,158,172,158,173,158,174,158,175,158,176,158,177,158,178,158,179,158,180,158,181,158,182,158,183,158,184,158,185,158,186,158,187,158,188,158,189,158,190,158,191,158,192,158,193,158,194,158,195,158,196,158,197,158,198,158,199,158,200,158,201,158,330,158,334,158,343,158,344,158,345,158,346,158,347,158,348,158,349,158,350,158,351,158,352,158,353,158,354,158,355,158,356,158,357,158,358,158,359,158,360,158,361,158,362,158,363,158,364,158,365,158,366,158,367,158,368,158,369,158,370,158,371,158,372,158,153,159,154,159,155,159,156,159,157,159,158,159,159,159,160,159,161,159,162,159,163,159,164,159,165,159,166,159,167,159,168,159,169,159,170,159,171,159,172,159,173,159,174,159,175,159,176,159,177,159,178,159,179,159,180,159,181,159,182,159,183,159,184,159,185,159,186,159,187,159,188,159,189,159,190,159,191,159,192,159,193,159,194,159,195,159,196,159,197,159,198,159,199,159,200,159,201,159,334,159,342,159,343,159,344,159,345,159,346,159,347,159,348,159,349,159,350,159,351,159,352,159,353,159,354,159,355,159,356,159,357,159,358,159,359,159,360,159,361,159,362,159,363,159,364,159,365,159,366,159,367,159,368,159,369,159,370,159,371,159,372,159,150,160,153,160,154,160,155,160,156,160,157,160,158,160,159,160,160,160,161,160,162,160,163,160,164,160,165,160,166,160,167,160,168,160,169,160,170,160,171,160,172,160,173,160,174,160,175,160,176,160,177,160,178,160,179,160,180,160,181,160,182,160,183,160,184,160,185,160,186,160,187,160,188,160,189,160,190,160,191,160,192,160,193,160,194,160,195,160,196,160,197,160,198,160,199,160,200,160,201,160,328,160,336,160,337,160,338,160,341,160,342,160,343,160,344,160,345,160,346,160,347,160,348,160,349,160,350,160,351,160,352,160,353,160,354,160,355,160,356,160,357,160,358,160,359,160,360,160,361,160,362,160,363,160,364,160,365,160,366,160,367,160,368,160,369,160,370,160,371,160,372,160,150,161,152,161,153,161,154,161,155,161,156,161,157,161,158,161,159,161,160,161,161,161,162,161,163,161,164,161,165,161,166,161,167,161,168,161,169,161,170,161,171,161,172,161,173,161,174,161,175,161,176,161,177,161,178,161,179,161,180,161,181,161,182,161,183,161,184,161,185,161,186,161,187,161,188,161,189,161,190,161,191,161,192,161,193,161,194,161,195,161,196,161,197,161,198,161,199,161,200,161,201,161,338,161,339,161,340,161,343,161,344,161,345,161,346,161,347,161,348,161,349,161,350,161,351,161,352,161,353,161,354,161,355,161,356,161,357,161,358,161,359,161,360,161,361,161,362,161,363,161,364,161,365,161,366,161,367,161,368,161,369,161,370,161,371,161,372,161,151,162,152,162,153,162,154,162,155,162,156,162,157,162,158,162,159,162,160,162,161,162,162,162,163,162,164,162,165,162,166,162,167,162,168,162,169,162,170,162,171,162,172,162,173,162,174,162,175,162,176,162,177,162,178,162,179,162,180,162,181,162,182,162,183,162,184,162,185,162,186,162,187,162,188,162,189,162,190,162,191,162,192,162,193,162,194,162,195,162,196,162,197,162,198,162,199,162,200,162,201,162,294,162,333,162,343,162,344,162,345,162,346,162,347,162,348,162,349,162,350,162,351,162,352,162,353,162,354,162,355,162,356,162,357,162,358,162,359,162,360,162,361,162,362,162,363,162,364,162,365,162,366,162,367,162,368,162,369,162,370,162,371,162,372,162,150,163,153,163,154,163,155,163,156,163,157,163,158,163,159,163,160,163,161,163,162,163,163,163,164,163,165,163,166,163,167,163,168,163,169,163,170,163,171,163,172,163,173,163,174,163,175,163,176,163,177,163,178,163,179,163,180,163,181,163,182,163,183,163,184,163,185,163,186,163,187,163,188,163,189,163,190,163,191,163,192,163,193,163,194,163,195,163,196,163,197,163,198,163,199,163,200,163,201,163,202,163,328,163,343,163,344,163,345,163,346,163,347,163,348,163,349,163,350,163,351,163,352,163,353,163,354,163,355,163,356,163,357,163,358,163,359,163,360,163,361,163,362,163,363,163,364,163,365,163,366,163,367,163,368,163,369,163,370,163,371,163,372,163,150,164,153,164,154,164,155,164,156,164,157,164,158,164,159,164,160,164,161,164,162,164,163,164,164,164,165,164,166,164,167,164,168,164,169,164,170,164,171,164,172,164,173,164,174,164,175,164,176,164,177,164,178,164,179,164,180,164,181,164,182,164,183,164,184,164,185,164,186,164,187,164,188,164,189,164,190,164,191,164,192,164,193,164,194,164,195,164,196,164,197,164,198,164,199,164,200,164,201,164,202,164,328,164,330,164,331,164,341,164,343,164,344,164,345,164,346,164,347,164,348,164,349,164,350,164,351,164,352,164,353,164,354,164,355,164,356,164,357,164,358,164,359,164,360,164,361,164,362,164,363,164,364,164,365,164,366,164,367,164,368,164,369,164,370,164,371,164,372,164,152,165,153,165,154,165,155,165,156,165,157,165,158,165,159,165,160,165,161,165,162,165,163,165,164,165,165,165,166,165,167,165,168,165,169,165,170,165,171,165,172,165,173,165,174,165,175,165,176,165,177,165,178,165,179,165,180,165,181,165,182,165,183,165,184,165,185,165,186,165,187,165,188,165,189,165,190,165,191,165,192,165,193,165,194,165,195,165,196,165,197,165,198,165,199,165,200,165,201,165,202,165,301,165,343,165,344,165,345,165,346,165,347,165,348,165,349,165,350,165,351,165,352,165,353,165,354,165,355,165,356,165,357,165,358,165,359,165,360,165,361,165,362,165,363,165,364,165,365,165,366,165,367,165,368,165,369,165,370,165,371,165,372,165,152,166,153,166,154,166,155,166,156,166,157,166,158,166,159,166,160,166,161,166,162,166,163,166,164,166,165,166,166,166,167,166,168,166,169,166,170,166,171,166,172,166,173,166,174,166,175,166,176,166,177,166,178,166,179,166,180,166,181,166,182,166,183,166,184,166,185,166,186,166,187,166,188,166,189,166,190,166,191,166,192,166,193,166,194,166,195,166,196,166,197,166,198,166,199,166,200,166,201,166,202,166,334,166,337,166,340,166,343,166,344,166,345,166,346,166,347,166,348,166,349,166,350,166,351,166,352,166,353,166,354,166,355,166,356,166,357,166,358,166,359,166,360,166,361,166,362,166,363,166,364,166,365,166,366,166,367,166,368,166,369,166,370,166,371,166,372,166,67,167,68,167,75,167,79,167,93,167,153,167,154,167,155,167,156,167,157,167,158,167,159,167,160,167,161,167,162,167,163,167,164,167,165,167,166,167,167,167,168,167,169,167,170,167,171,167,172,167,173,167,174,167,175,167,176,167,177,167,178,167,179,167,180,167,181,167,182,167,183,167,184,167,185,167,186,167,187,167,188,167,189,167,190,167,191,167,192,167,193,167,194,167,195,167,196,167,197,167,198,167,199,167,200,167,201,167,202,167,300,167,327,167,339,167,340,167,343,167,344,167,345,167,346,167,347,167,348,167,349,167,350,167,351,167,352,167,353,167,354,167,355,167,356,167,357,167,358,167,359,167,360,167,361,167,362,167,363,167,364,167,365,167,366,167,367,167,368,167,369,167,370,167,371,167,372,167,62,168,63,168,74,168,154,168,155,168,156,168,157,168,158,168,159,168,160,168,161,168,162,168,163,168,164,168,165,168,166,168,167,168,168,168,169,168,170,168,171,168,172,168,173,168,174,168,175,168,176,168,177,168,178,168,179,168,180,168,181,168,182,168,183,168,184,168,185,168,186,168,187,168,188,168,189,168,190,168,191,168,192,168,193,168,194,168,195,168,196,168,197,168,198,168,199,168,200,168,201,168,202,168,203,168,327,168,341,168,343,168,344,168,345,168,346,168,347,168,348,168,349,168,350,168,351,168,352,168,353,168,354,168,355,168,356,168,357,168,358,168,359,168,360,168,361,168,362,168,363,168,364,168,365,168,366,168,367,168,368,168,369,168,370,168,371,168,372,168,74,169,77,169,85,169,90,169,140,169,154,169,155,169,156,169,157,169,158,169,159,169,160,169,161,169,162,169,163,169,164,169,165,169,166,169,167,169,168,169,169,169,170,169,171,169,172,169,173,169,174,169,175,169,176,169,177,169,178,169,179,169,180,169,181,169,182,169,183,169,184,169,185,169,186,169,187,169,188,169,189,169,190,169,191,169,192,169,193,169,194,169,195,169,196,169,197,169,198,169,199,169,200,169,201,169,202,169,203,169,245,169,295,169,329,169,332,169,341,169,343,169,344,169,345,169,346,169,347,169,348,169,349,169,350,169,351,169,352,169,353,169,354,169,355,169,356,169,357,169,358,169,359,169,360,169,361,169,362,169,363,169,364,169,365,169,366,169,367,169,368,169,369,169,370,169,371,169,372,169,75,170,98,170,102,170,152,170,153,170,154,170,155,170,156,170,157,170,158,170,159,170,160,170,161,170,162,170,163,170,164,170,165,170,166,170,167,170,168,170,169,170,170,170,171,170,172,170,173,170,174,170,175,170,176,170,177,170,178,170,179,170,180,170,181,170,182,170,183,170,184,170,185,170,186,170,187,170,188,170,189,170,190,170,191,170,192,170,193,170,194,170,195,170,196,170,197,170,198,170,199,170,200,170,201,170,202,170,203,170,328,170,330,170,331,170,332,170,336,170,337,170,343,170,344,170,345,170,346,170,347,170,348,170,349,170,350,170,351,170,352,170,353,170,354,170,355,170,356,170,357,170,358,170,359,170,360,170,361,170,362,170,363,170,364,170,365,170,366,170,367,170,368,170,369,170,370,170,371,170,372,170,100,171,150,171,154,171,155,171,156,171,157,171,158,171,159,171,160,171,161,171,162,171,163,171,164,171,165,171,166,171,167,171,168,171,169,171,170,171,171,171,172,171,173,171,174,171,175,171,176,171,177,171,178,171,179,171,180,171,181,171,182,171,183,171,184,171,185,171,186,171,187,171,188,171,189,171,190,171,191,171,192,171,193,171,194,171,195,171,196,171,197,171,198,171,199,171,200,171,201,171,202,171,203,171,328,171,331,171,333,171,335,171,337,171,341,171,343,171,344,171,345,171,346,171,347,171,348,171,349,171,350,171,351,171,352,171,353,171,354,171,355,171,356,171,357,171,358,171,359,171,360,171,361,171,362,171,363,171,364,171,365,171,366,171,367,171,368,171,369,171,370,171,371,171,155,172,156,172,157,172,158,172,159,172,160,172,161,172,162,172,163,172,164,172,165,172,166,172,167,172,168,172,169,172,170,172,171,172,172,172,173,172,174,172,175,172,176,172,177,172,178,172,179,172,180,172,181,172,182,172,183,172,184,172,185,172,186,172,187,172,188,172,189,172,190,172,191,172,192,172,193,172,194,172,195,172,196,172,197,172,198,172,199,172,200,172,201,172,202,172,203,172,294,172,330,172,331,172,333,172,334,172,335,172,338,172,341,172,343,172,344,172,345,172,346,172,347,172,348,172,349,172,350,172,351,172,352,172,353,172,354,172,355,172,356,172,357,172,358,172,359,172,360,172,361,172,362,172,363,172,364,172,365,172,366,172,367,172,368,172,369,172,370,172,371,172,154,173,155,173,156,173,157,173,158,173,159,173,160,173,161,173,162,173,163,173,164,173,165,173,166,173,167,173,168,173,169,173,170,173,171,173,172,173,173,173,174,173,175,173,176,173,177,173,178,173,179,173,180,173,181,173,182,173,183,173,184,173,185,173,186,173,187,173,188,173,189,173,190,173,191,173,192,173,193,173,194,173,195,173,196,173,197,173,198,173,199,173,200,173,201,173,202,173,203,173,204,173,334,173,335,173,336,173,341,173,343,173,344,173,345,173,346,173,347,173,348,173,349,173,350,173,351,173,352,173,353,173,354,173,355,173,356,173,357,173,358,173,359,173,360,173,361,173,362,173,363,173,364,173,365,173,366,173,367,173,368,173,369,173,370,173,371,173,92,174,154,174,155,174,156,174,157,174,158,174,159,174,160,174,161,174,162,174,163,174,164,174,165,174,166,174,167,174,168,174,169,174,170,174,171,174,172,174,173,174,174,174,175,174,176,174,177,174,178,174,179,174,180,174,181,174,182,174,183,174,184,174,185,174,186,174,187,174,188,174,189,174,190,174,191,174,192,174,193,174,194,174,195,174,196,174,197,174,198,174,199,174,200,174,201,174,202,174,203,174,204,174,333,174,334,174,337,174,343,174,344,174,345,174,346,174,347,174,348,174,349,174,350,174,351,174,352,174,353,174,354,174,355,174,356,174,357,174,358,174,359,174,360,174,361,174,362,174,363,174,364,174,365,174,366,174,367,174,368,174,369,174,370,174,371,174,156,175,157,175,158,175,159,175,160,175,161,175,162,175,163,175,164,175,165,175,166,175,167,175,168,175,169,175,170,175,171,175,172,175,173,175,174,175,175,175,176,175,177,175,178,175,179,175,180,175,181,175,182,175,183,175,184,175,185,175,186,175,187,175,188,175,189,175,190,175,191,175,192,175,193,175,194,175,195,175,196,175,197,175,198,175,199,175,200,175,201,175,202,175,203,175,204,175,294,175,327,175,338,175,339,175,342,175,343,175,344,175,345,175,346,175,347,175,348,175,349,175,350,175,351,175,352,175,353,175,354,175,355,175,356,175,357,175,358,175,359,175,360,175,361,175,362,175,363,175,364,175,365,175,366,175,367,175,368,175,369,175,370,175,371,175,85,176,91,176,155,176,156,176,157,176,158,176,159,176,160,176,161,176,162,176,163,176,164,176,165,176,166,176,167,176,168,176,169,176,170,176,171,176,172,176,173,176,174,176,175,176,176,176,177,176,178,176,179,176,180,176,181,176,182,176,183,176,184,176,185,176,186,176,187,176,188,176,189,176,190,176,191,176,192,176,193,176,194,176,195,176,196,176,197,176,198,176,199,176,200,176,201,176,202,176,203,176,204,176,205,176,301,176,329,176,330,176,341,176,342,176,343,176,344,176,345,176,346,176,347,176,348,176,349,176,350,176,351,176,352,176,353,176,354,176,355,176,356,176,357,176,358,176,359,176,360,176,361,176,362,176,363,176,364,176,365,176,366,176,367,176,368,176,369,176,370,176,371,176,87,177,156,177,157,177,158,177,159,177,160,177,161,177,162,177,163,177,164,177,165,177,166,177,167,177,168,177,169,177,170,177,171,177,172,177,173,177,174,177,175,177,176,177,177,177,178,177,179,177,180,177,181,177,182,177,183,177,184,177,185,177,186,177,187,177,188,177,189,177,190,177,191,177,192,177,193,177,194,177,195,177,196,177,197,177,198,177,199,177,200,177,201,177,202,177,203,177,204,177,205,177,328,177,330,177,331,177,332,177,341,177,342,177,343,177,344,177,345,177,346,177,347,177,348,177,349,177,350,177,351,177,352,177,353,177,354,177,355,177,356,177,357,177,358,177,359,177,360,177,361,177,362,177,363,177,364,177,365,177,366,177,367,177,368,177,369,177,370,177,156,178,157,178,158,178,159,178,160,178,161,178,162,178,163,178,164,178,165,178,166,178,167,178,168,178,169,178,170,178,171,178,172,178,173,178,174,178,175,178,176,178,177,178,178,178,179,178,180,178,181,178,182,178,183,178,184,178,185,178,186,178,187,178,188,178,189,178,190,178,191,178,192,178,193,178,194,178,195,178,196,178,197,178,198,178,199,178,200,178,201,178,202,178,203,178,204,178,205,178,294,178,330,178,336,178,341,178,342,178,343,178,344,178,345,178,346,178,347,178,348,178,349,178,350,178,351,178,352,178,353,178,354,178,355,178,356,178,357,178,358,178,359,178,360,178,361,178,362,178,363,178,364,178,365,178,366,178,367,178,368,178,369,178,370,178,102,179,157,179,158,179,159,179,160,179,161,179,162,179,163,179,164,179,165,179,166,179,167,179,168,179,169,179,170,179,171,179,172,179,173,179,174,179,175,179,176,179,177,179,178,179,179,179,180,179,181,179,182,179,183,179,184,179,185,179,186,179,187,179,188,179,189,179,190,179,191,179,192,179,193,179,194,179,195,179,196,179,197,179,198,179,199,179,200,179,201,179,202,179,203,179,204,179,205,179,206,179,327,179,328,179,336,179,340,179,341,179,342,179,343,179,344,179,345,179,346,179,347,179,348,179,349,179,350,179,351,179,352,179,353,179,354,179,355,179,356,179,357,179,358,179,359,179,360,179,361,179,362,179,363,179,364,179,365,179,366,179,367,179,368,179,369,179,370,179,157,180,158,180,159,180,160,180,161,180,162,180,163,180,164,180,165,180,166,180,167,180,168,180,169,180,170,180,171,180,172,180,173,180,174,180,175,180,176,180,177,180,178,180,179,180,180,180,181,180,182,180,183,180,184,180,185,180,186,180,187,180,188,180,189,180,190,180,191,180,192,180,193,180,194,180,195,180,196,180,197,180,198,180,199,180,200,180,201,180,202,180,203,180,204,180,205,180,206,180,337,180,342,180,343,180,344,180,345,180,346,180,347,180,348,180,349,180,350,180,351,180,352,180,353,180,354,180,355,180,356,180,357,180,358,180,359,180,360,180,361,180,362,180,363,180,364,180,365,180,366,180,367,180,368,180,369,180,370,180,142,181,158,181,159,181,160,181,161,181,162,181,163,181,164,181,165,181,166,181,167,181,168,181,169,181,170,181,171,181,172,181,173,181,174,181,175,181,176,181,177,181,178,181,179,181,180,181,181,181,182,181,183,181,184,181,185,181,186,181,187,181,188,181,189,181,190,181,191,181,192,181,193,181,194,181,195,181,196,181,197,181,198,181,199,181,200,181,201,181,202,181,203,181,204,181,205,181,206,181,207,181,298,181,327,181,328,181,330,181,331,181,332,181,334,181,335,181,337,181,338,181,339,181,340,181,342,181,343,181,344,181,345,181,346,181,347,181,348,181,349,181,350,181,351,181,352,181,353,181,354,181,355,181,356,181,357,181,358,181,359,181,360,181,361,181,362,181,363,181,364,181,365,181,158,182,159,182,160,182,161,182,162,182,163,182,164,182,165,182,166,182,167,182,168,182,169,182,170,182,171,182,172,182,173,182,174,182,175,182,176,182,177,182,178,182,179,182,180,182,181,182,182,182,183,182,184,182,185,182,186,182,187,182,188,182,189,182,190,182,191,182,192,182,193,182,194,182,195,182,196,182,197,182,198,182,199,182,200,182,201,182,202,182,203,182,204,182,205,182,206,182,207,182,328,182,331,182,332,182,335,182,337,182,339,182,340,182,342,182,343,182,344,182,345,182,346,182,347,182,348,182,349,182,350,182,351,182,352,182,353,182,354,182,355,182,356,182,357,182,358,182,156,183,159,183,160,183,161,183,162,183,163,183,164,183,165,183,166,183,167,183,168,183,169,183,170,183,171,183,172,183,173,183,174,183,175,183,176,183,177,183,178,183,179,183,180,183,181,183,182,183,183,183,184,183,185,183,186,183,187,183,188,183,189,183,190,183,191,183,192,183,193,183,194,183,195,183,196,183,197,183,198,183,199,183,200,183,201,183,202,183,203,183,204,183,205,183,206,183,207,183,208,183,299,183,306,183,327,183,329,183,335,183,337,183,338,183,342,183,343,183,344,183,345,183,346,183,347,183,348,183,349,183,350,183,351,183,352,183,159,184,160,184,161,184,162,184,163,184,164,184,165,184,166,184,167,184,168,184,169,184,170,184,171,184,172,184,173,184,174,184,175,184,176,184,177,184,178,184,179,184,180,184,181,184,182,184,183,184,184,184,185,184,186,184,187,184,188,184,189,184,190,184,191,184,192,184,193,184,194,184,195,184,196,184,197,184,198,184,199,184,200,184,201,184,202,184,203,184,204,184,205,184,206,184,207,184,208,184,324,184,327,184,330,184,331,184,332,184,335,184,339,184,341,184,342,184,343,184,344,184,345,184,346,184,159,185,160,185,161,185,162,185,163,185,164,185,165,185,166,185,167,185,168,185,169,185,170,185,171,185,172,185,173,185,174,185,175,185,176,185,177,185,178,185,179,185,180,185,181,185,182,185,183,185,184,185,185,185,186,185,187,185,188,185,189,185,190,185,191,185,192,185,193,185,194,185,195,185,196,185,197,185,198,185,199,185,200,185,201,185,202,185,203,185,204,185,205,185,206,185,207,185,208,185,209,185,308,185,310,185,330,185,335,185,339,185,341,185,342,185,343,185,344,185,345,185,161,186,162,186,163,186,164,186,165,186,166,186,167,186,168,186,169,186,170,186,171,186,172,186,173,186,174,186,175,186,176,186,177,186,178,186,179,186,180,186,181,186,182,186,183,186,184,186,185,186,186,186,187,186,188,186,189,186,190,186,191,186,192,186,193,186,194,186,195,186,196,186,197,186,198,186,199,186,200,186,201,186,202,186,203,186,204,186,205,186,206,186,207,186,208,186,209,186,335,186,336,186,338,186,340,186,341,186,342,186,343,186,344,186,161,187,162,187,163,187,164,187,165,187,166,187,167,187,168,187,169,187,170,187,171,187,172,187,173,187,174,187,175,187,176,187,177,187,178,187,179,187,180,187,181,187,182,187,183,187,184,187,185,187,186,187,187,187,188,187,189,187,190,187,191,187,192,187,193,187,194,187,195,187,196,187,197,187,198,187,199,187,200,187,201,187,202,187,203,187,204,187,205,187,206,187,207,187,208,187,209,187,210,187,291,187,338,187,340,187,341,187,342,187,343,187,344,187,162,188,163,188,164,188,165,188,166,188,167,188,168,188,169,188,170,188,171,188,172,188,173,188,174,188,175,188,176,188,177,188,178,188,179,188,180,188,181,188,182,188,183,188,184,188,185,188,186,188,187,188,188,188,189,188,190,188,191,188,192,188,193,188,194,188,195,188,196,188,197,188,198,188,199,188,200,188,201,188,202,188,203,188,204,188,205,188,206,188,207,188,208,188,209,188,210,188,211,188,291,188,338,188,339,188,340,188,341,188,342,188,343,188,344,188,148,189,160,189,163,189,164,189,165,189,166,189,167,189,168,189,169,189,170,189,171,189,172,189,173,189,174,189,175,189,176,189,177,189,178,189,179,189,180,189,181,189,182,189,183,189,184,189,185,189,186,189,187,189,188,189,189,189,190,189,191,189,192,189,193,189,194,189,195,189,196,189,197,189,198,189,199,189,200,189,201,189,202,189,203,189,204,189,205,189,206,189,207,189,208,189,209,189,210,189,211,189,212,189,331,189,332,189,333,189,334,189,335,189,336,189,337,189,338,189,339,189,340,189,341,189,342,189,343,189,344,189,162,190,164,190,165,190,166,190,167,190,168,190,169,190,170,190,171,190,172,190,173,190,174,190,175,190,176,190,177,190,178,190,179,190,180,190,181,190,182,190,183,190,184,190,185,190,186,190,187,190,188,190,189,190,190,190,191,190,192,190,193,190,194,190,195,190,196,190,197,190,198,190,199,190,200,190,201,190,202,190,203,190,204,190,205,190,206,190,207,190,208,190,209,190,210,190,211,190,212,190,287,190,322,190,323,190,324,190,325,190,326,190,327,190,328,190,329,190,330,190,331,190,332,190,333,190,334,190,335,190,336,190,337,190,338,190,339,190,340,190,341,190,342,190,343,190,164,191,165,191,166,191,167,191,168,191,169,191,170,191,171,191,172,191,173,191,174,191,175,191,176,191,177,191,178,191,179,191,180,191,181,191,182,191,183,191,184,191,185,191,186,191,187,191,188,191,189,191,190,191,191,191,192,191,193,191,194,191,195,191,196,191,197,191,198,191,199,191,200,191,201,191,202,191,203,191,204,191,205,191,206,191,207,191,208,191,209,191,210,191,211,191,212,191,213,191,311,191,315,191,316,191,317,191,318,191,319,191,320,191,321,191,322,191,323,191,324,191,325,191,326,191,327,191,328,191,329,191,330,191,331,191,332,191,333,191,334,191,335,191,336,191,337,191,338,191,339,191,340,191,341,191,342,191,343,191,164,192,165,192,166,192,167,192,168,192,169,192,170,192,171,192,172,192,173,192,174,192,175,192,176,192,177,192,178,192,179,192,180,192,181,192,182,192,183,192,184,192,185,192,186,192,187,192,188,192,189,192,190,192,191,192,192,192,193,192,194,192,195,192,196,192,197,192,198,192,199,192,200,192,201,192,202,192,203,192,204,192,205,192,206,192,207,192,208,192,209,192,210,192,211,192,212,192,213,192,214,192,295,192,310,192,311,192,312,192,313,192,314,192,315,192,316,192,317,192,318,192,319,192,320,192,321,192,322,192,323,192,324,192,325,192,326,192,327,192,328,192,329,192,330,192,331,192,332,192,333,192,334,192,335,192,336,192,337,192,338,192,339,192,340,192,341,192,342,192,165,193,167,193,168,193,169,193,170,193,171,193,172,193,173,193,174,193,175,193,176,193,177,193,178,193,179,193,180,193,181,193,182,193,183,193,184,193,185,193,186,193,187,193,188,193,189,193,190,193,191,193,192,193,193,193,194,193,195,193,196,193,197,193,198,193,199,193,200,193,201,193,202,193,203,193,204,193,205,193,206,193,207,193,208,193,209,193,210,193,211,193,212,193,213,193,214,193,215,193,310,193,311,193,312,193,313,193,314,193,315,193,316,193,317,193,318,193,319,193,320,193,321,193,322,193,323,193,324,193,325,193,326,193,327,193,328,193,329,193,330,193,331,193,332,193,333,193,334,193,335,193,336,193,337,193,338,193,339,193,340,193,341,193,342,193,166,194,167,194,168,194,169,194,170,194,171,194,172,194,173,194,174,194,175,194,176,194,177,194,178,194,179,194,180,194,181,194,182,194,183,194,184,194,185,194,186,194,187,194,188,194,189,194,190,194,191,194,192,194,193,194,194,194,195,194,196,194,197,194,198,194,199,194,200,194,201,194,202,194,203,194,204,194,205,194,206,194,207,194,208,194,209,194,210,194,211,194,212,194,213,194,214,194,215,194,216,194,310,194,311,194,312,194,313,194,314,194,315,194,316,194,317,194,318,194,319,194,320,194,321,194,322,194,323,194,324,194,325,194,326,194,327,194,328,194,329,194,330,194,331,194,332,194,333,194,334,194,335,194,336,194,337,194,338,194,339,194,340,194,341,194,168,195,169,195,170,195,171,195,172,195,173,195,174,195,175,195,176,195,177,195,178,195,179,195,180,195,181,195,182,195,183,195,184,195,185,195,186,195,187,195,188,195,189,195,190,195,191,195,192,195,193,195,194,195,195,195,196,195,197,195,198,195,199,195,200,195,201,195,202,195,203,195,204,195,205,195,206,195,207,195,208,195,209,195,210,195,211,195,212,195,213,195,214,195,215,195,216,195,217,195,308,195,309,195,310,195,311,195,312,195,313,195,314,195,315,195,316,195,317,195,318,195,319,195,320,195,321,195,322,195,323,195,324,195,325,195,326,195,327,195,328,195,329,195,330,195,331,195,332,195,333,195,334,195,335,195,336,195,337,195,338,195,339,195,340,195,341,195,168,196,169,196,170,196,171,196,172,196,173,196,174,196,175,196,176,196,177,196,178,196,179,196,180,196,181,196,182,196,183,196,184,196,185,196,186,196,187,196,188,196,189,196,190,196,191,196,192,196,193,196,194,196,195,196,196,196,197,196,198,196,199,196,200,196,201,196,202,196,203,196,204,196,205,196,206,196,207,196,208,196,209,196,210,196,211,196,212,196,213,196,214,196,215,196,216,196,217,196,218,196,293,196,309,196,310,196,311,196,312,196,313,196,314,196,315,196,316,196,317,196,318,196,319,196,320,196,321,196,322,196,323,196,324,196,325,196,326,196,327,196,328,196,329,196,330,196,331,196,332,196,333,196,334,196,335,196,336,196,337,196,338,196,339,196,340,196,341,196,171,197,172,197,173,197,174,197,175,197,176,197,177,197,178,197,179,197,180,197,181,197,182,197,183,197,184,197,185,197,186,197,187,197,188,197,189,197,190,197,191,197,192,197,193,197,194,197,195,197,196,197,197,197,198,197,199,197,200,197,201,197,202,197,203,197,204,197,205,197,206,197,207,197,208,197,209,197,210,197,211,197,212,197,213,197,214,197,215,197,216,197,217,197,218,197,219,197,290,197,308,197,309,197,310,197,311,197,312,197,313,197,314,197,315,197,316,197,317,197,318,197,319,197,320,197,321,197,322,197,323,197,324,197,325,197,326,197,327,197,328,197,329,197,330,197,331,197,332,197,333,197,334,197,335,197,336,197,337,197,338,197,339,197,340,197,172,198,173,198,174,198,175,198,176,198,177,198,178,198,179,198,180,198,181,198,182,198,183,198,184,198,185,198,186,198,187,198,188,198,189,198,190,198,191,198,192,198,193,198,194,198,195,198,196,198,197,198,198,198,199,198,200,198,201,198,202,198,203,198,204,198,205,198,206,198,207,198,208,198,209,198,210,198,211,198,212,198,213,198,214,198,215,198,216,198,217,198,218,198,219,198,220,198,290,198,307,198,308,198,309,198,310,198,311,198,312,198,313,198,314,198,315,198,316,198,317,198,318,198,319,198,320,198,321,198,322,198,323,198,324,198,325,198,326,198,327,198,328,198,329,198,330,198,331,198,332,198,333,198,334,198,335,198,336,198,337,198,338,198,339,198,340,198,173,199,174,199,175,199,176,199,177,199,178,199,179,199,180,199,181,199,182,199,183,199,184,199,185,199,186,199,187,199,188,199,189,199,190,199,191,199,192,199,193,199,194,199,195,199,196,199,197,199,198,199,199,199,200,199,201,199,202,199,203,199,204,199,205,199,206,199,207,199,208,199,209,199,210,199,211,199,212,199,213,199,214,199,215,199,216,199,217,199,218,199,219,199,220,199,221,199,307,199,308,199,309,199,310,199,311,199,312,199,313,199,314,199,315,199,316,199,317,199,318,199,319,199,320,199,321,199,322,199,323,199,324,199,325,199,326,199,327,199,328,199,329,199,330,199,331,199,332,199,333,199,334,199,335,199,336,199,337,199,338,199,339,199,176,200,177,200,178,200,179,200,180,200,181,200,182,200,183,200,184,200,185,200,186,200,187,200,188,200,189,200,190,200,191,200,192,200,193,200,194,200,195,200,196,200,197,200,198,200,199,200,200,200,201,200,202,200,203,200,204,200,205,200,206,200,207,200,208,200,209,200,210,200,211,200,212,200,213,200,214,200,215,200,216,200,217,200,218,200,219,200,220,200,221,200,222,200,286,200,289,200,306,200,307,200,308,200,309,200,310,200,311,200,312,200,313,200,314,200,315,200,316,200,317,200,318,200,319,200,320,200,321,200,322,200,323,200,324,200,325,200,326,200,327,200,328,200,329,200,330,200,331,200,332,200,333,200,334,200,335,200,336,200,337,200,338,200,339,200,176,201,177,201,178,201,179,201,180,201,181,201,182,201,183,201,184,201,185,201,186,201,187,201,188,201,189,201,190,201,191,201,192,201,193,201,194,201,195,201,196,201,197,201,198,201,199,201,200,201,201,201,202,201,203,201,204,201,205,201,206,201,207,201,208,201,209,201,210,201,211,201,212,201,213,201,214,201,215,201,216,201,217,201,218,201,219,201,220,201,285,201,288,201,306,201,307,201,308,201,309,201,310,201,311,201,312,201,313,201,314,201,315,201,316,201,317,201,318,201,319,201,320,201,321,201,322,201,323,201,324,201,325,201,326,201,327,201,328,201,329,201,330,201,331,201,332,201,333,201,334,201,335,201,336,201,337,201,338,201,179,202,180,202,181,202,182,202,183,202,184,202,185,202,186,202,187,202,188,202,189,202,190,202,191,202,192,202,193,202,194,202,195,202,196,202,197,202,198,202,199,202,200,202,201,202,202,202,203,202,204,202,205,202,206,202,207,202,208,202,209,202,210,202,211,202,212,202,213,202,214,202,215,202,216,202,217,202,306,202,307,202,308,202,309,202,310,202,311,202,312,202,313,202,314,202,315,202,316,202,317,202,318,202,319,202,320,202,321,202,322,202,323,202,324,202,325,202,326,202,327,202,328,202,329,202,330,202,331,202,332,202,333,202,334,202,335,202,336,202,337,202,338,202,181,203,182,203,183,203,184,203,185,203,186,203,187,203,188,203,189,203,190,203,191,203,192,203,193,203,194,203,195,203,196,203,197,203,198,203,199,203,200,203,201,203,202,203,203,203,204,203,205,203,206,203,207,203,208,203,209,203,210,203,211,203,212,203,213,203,214,203,215,203,290,203,306,203,307,203,308,203,309,203,310,203,311,203,312,203,313,203,314,203,315,203,316,203,317,203,318,203,319,203,320,203,321,203,322,203,323,203,324,203,325,203,326,203,327,203,328,203,329,203,330,203,331,203,332,203,333,203,334,203,335,203,336,203,337,203,185,204,186,204,187,204,188,204,189,204,190,204,191,204,192,204,193,204,194,204,195,204,196,204,197,204,198,204,199,204,200,204,201,204,202,204,203,204,204,204,205,204,206,204,207,204,208,204,209,204,210,204,211,204,213,204,305,204,306,204,307,204,308,204,309,204,310,204,311,204,312,204,313,204,314,204,315,204,316,204,317,204,318,204,319,204,320,204,321,204,322,204,323,204,324,204,325,204,326,204,327,204,328,204,329,204,330,204,331,204,332,204,333,204,334,204,335,204,336,204,337,204,186,205,189,205,190,205,191,205,192,205,193,205,194,205,195,205,196,205,197,205,198,205,199,205,200,205,201,205,202,205,203,205,204,205,205,205,206,205,207,205,305,205,306,205,307,205,308,205,309,205,310,205,311,205,312,205,313,205,314,205,315,205,316,205,317,205,318,205,319,205,320,205,321,205,322,205,323,205,324,205,325,205,326,205,327,205,328,205,329,205,330,205,331,205,332,205,333,205,334,205,335,205,336,205,337,205,160,206,191,206,196,206,197,206,198,206,199,206,200,206,201,206,202,206,203,206,304,206,305,206,306,206,307,206,308,206,309,206,310,206,311,206,312,206,313,206,314,206,315,206,316,206,317,206,318,206,319,206,320,206,321,206,322,206,323,206,324,206,325,206,326,206,327,206,328,206,329,206,330,206,331,206,332,206,333,206,334,206,335,206,336,206,304,207,305,207,306,207,307,207,308,207,309,207,310,207,311,207,312,207,313,207,314,207,315,207,316,207,317,207,318,207,319,207,320,207,321,207,322,207,323,207,324,207,325,207,326,207,327,207,328,207,329,207,330,207,331,207,332,207,333,207,334,207,335,207,336,207,281,208,303,208,304,208,305,208,306,208,307,208,308,208,309,208,310,208,311,208,312,208,313,208,314,208,315,208,316,208,317,208,318,208,319,208,320,208,321,208,322,208,323,208,324,208,325,208,326,208,327,208,328,208,329,208,330,208,331,208,332,208,333,208,334,208,335,208,162,209,281,209,302,209,303,209,304,209,305,209,306,209,307,209,308,209,309,209,310,209,311,209,312,209,313,209,314,209,315,209,316,209,317,209,318,209,319,209,320,209,321,209,322,209,323,209,324,209,325,209,326,209,327,209,328,209,329,209,330,209,331,209,332,209,333,209,334,209,292,210,302,210,303,210,304,210,305,210,306,210,307,210,308,210,309,210,310,210,311,210,312,210,313,210,314,210,315,210,316,210,317,210,318,210,319,210,320,210,321,210,322,210,323,210,324,210,325,210,326,210,327,210,328,210,329,210,330,210,331,210,332,210,333,210,334,210,302,211,303,211,304,211,305,211,306,211,307,211,308,211,309,211,310,211,311,211,312,211,313,211,314,211,315,211,316,211,317,211,318,211,319,211,320,211,321,211,322,211,323,211,324,211,325,211,326,211,327,211,328,211,329,211,330,211,331,211,332,211,333,211,334,211,283,212,301,212,302,212,303,212,304,212,305,212,306,212,307,212,308,212,309,212,310,212,311,212,312,212,313,212,314,212,315,212,316,212,317,212,318,212,319,212,320,212,321,212,322,212,323,212,324,212,325,212,326,212,327,212,328,212,329,212,330,212,331,212,332,212,333,212,283,213,301,213,302,213,303,213,304,213,305,213,306,213,307,213,308,213,309,213,310,213,311,213,312,213,313,213,314,213,315,213,316,213,317,213,318,213,319,213,320,213,321,213,322,213,323,213,324,213,325,213,326,213,327,213,328,213,329,213,330,213,331,213,332,213,333,213,300,214,301,214,302,214,303,214,304,214,305,214,306,214,307,214,308,214,309,214,310,214,311,214,312,214,313,214,314,214,315,214,316,214,317,214,318,214,319,214,320,214,321,214,322,214,323,214,324,214,325,214,326,214,327,214,328,214,329,214,330,214,331,214,332,214,299,215,300,215,301,215,302,215,303,215,304,215,305,215,306,215,307,215,308,215,309,215,310,215,311,215,312,215,313,215,314,215,315,215,316,215,317,215,318,215,319,215,320,215,321,215,322,215,323,215,324,215,325,215,326,215,327,215,328,215,329,215,330,215,331,215,299,216,300,216,301,216,302,216,303,216,304,216,305,216,306,216,307,216,308,216,309,216,310,216,311,216,312,216,313,216,314,216,315,216,316,216,317,216,318,216,319,216,320,216,321,216,322,216,323,216,324,216,325,216,326,216,327,216,328,216,329,216,330,216,331,216,299,217,300,217,301,217,302,217,303,217,304,217,305,217,306,217,307,217,308,217,309,217,310,217,311,217,312,217,313,217,314,217,315,217,316,217,317,217,318,217,319,217,320,217,321,217,322,217,323,217,324,217,325,217,326,217,327,217,328,217,329,217,330,217,298,218,299,218,300,218,301,218,302,218,303,218,304,218,305,218,306,218,307,218,308,218,309,218,310,218,311,218,312,218,313,218,314,218,315,218,316,218,317,218,318,218,319,218,320,218,321,218,322,218,323,218,324,218,325,218,326,218,327,218,328,218,329,218,330,218,290,219,297,219,298,219,299,219,300,219,301,219,302,219,303,219,304,219,305,219,306,219,307,219,308,219,309,219,310,219,311,219,312,219,313,219,314,219,315,219,316,219,317,219,318,219,319,219,320,219,321,219,322,219,323,219,324,219,325,219,326,219,327,219,328,219,329,219,297,220,298,220,299,220,300,220,301,220,302,220,303,220,304,220,305,220,306,220,307,220,308,220,309,220,310,220,311,220,312,220,313,220,314,220,315,220,316,220,317,220,318,220,319,220,320,220,321,220,322,220,323,220,324,220,325,220,326,220,327,220,328,220,329,220,281,221,282,221,296,221,297,221,298,221,299,221,300,221,301,221,302,221,303,221,304,221,305,221,306,221,307,221,308,221,309,221,310,221,311,221,312,221,313,221,314,221,315,221,316,221,317,221,318,221,319,221,320,221,321,221,322,221,323,221,324,221,325,221,326,221,327,221,328,221,295,222,296,222,297,222,298,222,299,222,300,222,301,222,302,222,303,222,304,222,305,222,306,222,307,222,308,222,309,222,310,222,311,222,312,222,313,222,314,222,315,222,316,222,317,222,318,222,319,222,320,222,321,222,322,222,323,222,324,222,325,222,326,222,327,222,328,222,280,223,295,223,296,223,297,223,298,223,299,223,300,223,301,223,302,223,303,223,304,223,305,223,306,223,307,223,308,223,309,223,310,223,311,223,312,223,313,223,314,223,315,223,316,223,317,223,318,223,319,223,320,223,321,223,322,223,323,223,324,223,325,223,326,223,327,223,328,223,294,224,295,224,296,224,297,224,298,224,299,224,300,224,301,224,302,224,303,224,304,224,305,224,306,224,307,224,308,224,309,224,310,224,311,224,312,224,313,224,314,224,315,224,316,224,317,224,318,224,319,224,320,224,321,224,322,224,323,224,324,224,325,224,326,224,327,224,328,224,329,224,294,225,295,225,296,225,297,225,298,225,299,225,300,225,301,225,302,225,303,225,304,225,305,225,306,225,307,225,308,225,309,225,310,225,311,225,312,225,313,225,314,225,315,225,316,225,317,225,318,225,319,225,320,225,321,225,322,225,323,225,324,225,325,225,326,225,327,225,328,225,329,225,294,226,295,226,296,226,297,226,298,226,299,226,300,226,301,226,302,226,303,226,304,226,305,226,306,226,307,226,308,226,309,226,310,226,311,226,312,226,313,226,314,226,315,226,316,226,317,226,318,226,319,226,320,226,321,226,322,226,323,226,324,226,325,226,326,226,327,226,328,226,329,226,330,226,278,227,281,227,292,227,293,227,294,227,295,227,296,227,297,227,298,227,299,227,300,227,301,227,302,227,303,227,304,227,305,227,306,227,307,227,308,227,309,227,310,227,311,227,312,227,313,227,314,227,315,227,316,227,317,227,318,227,319,227,320,227,321,227,322,227,323,227,324,227,325,227,326,227,327,227,328,227,329,227,330,227,292,228,293,228,294,228,295,228,296,228,297,228,298,228,299,228,300,228,301,228,302,228,303,228,304,228,305,228,306,228,307,228,308,228,309,228,310,228,311,228,312,228,313,228,314,228,315,228,316,228,317,228,318,228,319,228,320,228,321,228,322,228,323,228,324,228,325,228,326,228,327,228,328,228,329,228,330,228,331,228,264,229,291,229,292,229,293,229,294,229,295,229,296,229,297,229,298,229,299,229,300,229,301,229,302,229,303,229,304,229,305,229,306,229,307,229,308,229,309,229,310,229,311,229,312,229,313,229,314,229,315,229,316,229,317,229,318,229,319,229,320,229,321,229,322,229,323,229,324,229,325,229,326,229,327,229,328,229,329,229,330,229,331,229,283,230,291,230,292,230,293,230,294,230,295,230,296,230,297,230,298,230,299,230,300,230,301,230,302,230,303,230,304,230,305,230,306,230,307,230,308,230,309,230,310,230,311,230,312,230,313,230,314,230,315,230,316,230,317,230,318,230,319,230,320,230,321,230,322,230,323,230,324,230,325,230,326,230,327,230,328,230,329,230,330,230,331,230,332,230,274,231,291,231,292,231,293,231,294,231,295,231,296,231,297,231,298,231,299,231,300,231,301,231,302,231,303,231,304,231,305,231,306,231,307,231,308,231,309,231,310,231,311,231,312,231,313,231,314,231,315,231,316,231,317,231,318,231,319,231,320,231,321,231,322,231,323,231,324,231,325,231,326,231,327,231,328,231,329,231,330,231,331,231,332,231,291,232,292,232,293,232,294,232,295,232,296,232,297,232,298,232,299,232,300,232,301,232,302,232,303,232,304,232,305,232,306,232,307,232,308,232,309,232,310,232,311,232,312,232,313,232,314,232,315,232,316,232,317,232,318,232,319,232,320,232,321,232,322,232,323,232,324,232,325,232,326,232,327,232,328,232,329,232,330,232,331,232,332,232,333,232,261,233,285,233,292,233,293,233,294,233,295,233,296,233,297,233,298,233,299,233,300,233,301,233,302,233,303,233,304,233,305,233,306,233,307,233,308,233,309,233,310,233,311,233,312,233,313,233,314,233,315,233,316,233,317,233,318,233,319,233,320,233,321,233,322,233,323,233,324,233,325,233,326,233,327,233,328,233,329,233,330,233,331,233,332,233,333,233,334,233,269,234,292,234,293,234,294,234,295,234,296,234,297,234,298,234,299,234,300,234,301,234,302,234,303,234,304,234,305,234,306,234,307,234,308,234,309,234,310,234,311,234,312,234,313,234,314,234,315,234,316,234,317,234,318,234,319,234,320,234,321,234,322,234,323,234,324,234,325,234,326,234,327,234,328,234,329,234,330,234,331,234,332,234,333,234,334,234,255,235,273,235,286,235,293,235,294,235,295,235,296,235,297,235,298,235,299,235,300,235,301,235,302,235,303,235,304,235,305,235,306,235,307,235,308,235,309,235,310,235,311,235,312,235,313,235,314,235,315,235,316,235,317,235,318,235,319,235,320,235,321,235,322,235,323,235,324,235,325,235,326,235,327,235,328,235,329,235,330,235,331,235,332,235,333,235,334,235,335,235,286,236,287,236,293,236,294,236,295,236,296,236,297,236,298,236,299,236,300,236,301,236,302,236,303,236,304,236,305,236,306,236,307,236,308,236,309,236,310,236,311,236,312,236,313,236,314,236,315,236,316,236,317,236,318,236,319,236,320,236,321,236,322,236,323,236,324,236,325,236,326,236,327,236,328,236,329,236,330,236,331,236,332,236,333,236,334,236,335,236,94,237,96,237,295,237,296,237,297,237,298,237,299,237,300,237,301,237,302,237,303,237,304,237,305,237,306,237,307,237,308,237,309,237,310,237,311,237,312,237,313,237,314,237,315,237,316,237,317,237,318,237,319,237,320,237,321,237,322,237,323,237,324,237,325,237,326,237,327,237,328,237,329,237,330,237,331,237,332,237,333,237,334,237,335,237,336,237,91,238,94,238,140,238,266,238,288,238,289,238,295,238,296,238,297,238,298,238,299,238,300,238,301,238,302,238,303,238,304,238,305,238,306,238,307,238,308,238,309,238,310,238,311,238,312,238,313,238,314,238,315,238,316,238,317,238,318,238,319,238,320,238,321,238,322,238,323,238,324,238,325,238,326,238,327,238,328,238,329,238,330,238,331,238,332,238,333,238,334,238,335,238,336,238,337,238,88,239,90,239,91,239,93,239,97,239,295,239,296,239,297,239,298,239,299,239,300,239,301,239,302,239,303,239,304,239,305,239,306,239,307,239,308,239,309,239,310,239,311,239,312,239,313,239,314,239,315,239,316,239,317,239,318,239,319,239,320,239,321,239,322,239,323,239,324,239,325,239,326,239,327,239,328,239,329,239,330,239,331,239,332,239,333,239,334,239,335,239,336,239,337,239,86,240,96,240,98,240,99,240,254,240,291,240,296,240,297,240,298,240,299,240,300,240,301,240,302,240,303,240,304,240,305,240,306,240,307,240,308,240,309,240,310,240,311,240,312,240,313,240,314,240,315,240,316,240,317,240,318,240,319,240,320,240,321,240,322,240,323,240,324,240,325,240,326,240,327,240,328,240,329,240,330,240,331,240,332,240,333,240,334,240,335,240,336,240,337,240,83,241,86,241,89,241,91,241,92,241,96,241,100,241,290,241,291,241,292,241,297,241,298,241,299,241,300,241,301,241,302,241,303,241,304,241,305,241,306,241,307,241,308,241,309,241,310,241,311,241,312,241,313,241,314,241,315,241,316,241,317,241,318,241,319,241,320,241,321,241,322,241,323,241,324,241,325,241,326,241,327,241,328,241,329,241,330,241,331,241,332,241,333,241,334,241,335,241,336,241,337,241,338,241,87,242,97,242,98,242,101,242,259,242,291,242,292,242,297,242,298,242,299,242,300,242,301,242,302,242,303,242,304,242,305,242,306,242,307,242,308,242,309,242,310,242,311,242,312,242,313,242,314,242,315,242,316,242,317,242,318,242,319,242,320,242,321,242,322,242,323,242,324,242,325,242,326,242,327,242,328,242,329,242,330,242,331,242,332,242,333,242,334,242,335,242,336,242,337,242,338,242,339,242,84,243,85,243,93,243,94,243,97,243,99,243,129,243,146,243,293,243,294,243,297,243,298,243,299,243,300,243,301,243,302,243,303,243,304,243,305,243,306,243,307,243,308,243,309,243,310,243,311,243,312,243,313,243,314,243,315,243,316,243,317,243,318,243,319,243,320,243,321,243,322,243,323,243,324,243,325,243,326,243,327,243,328,243,329,243,330,243,331,243,332,243,333,243,334,243,335,243,336,243,337,243,338,243,339,243,84,244,85,244,86,244,87,244,91,244,97,244,98,244,99,244,102,244,127,244,128,244,145,244,299,244,300,244,301,244,302,244,303,244,304,244,305,244,306,244,307,244,308,244,309,244,310,244,311,244,312,244,313,244,314,244,315,244,316,244,317,244,318,244,319,244,320,244,321,244,322,244,323,244,324,244,325,244,326,244,327,244,328,244,329,244,330,244,331,244,332,244,333,244,334,244,335,244,336,244,337,244,338,244,339,244,340,244,84,245,85,245,97,245,99,245,101,245,103,245,126,245,146,245,295,245,299,245,300,245,301,245,302,245,303,245,304,245,305,245,306,245,307,245,308,245,309,245,310,245,311,245,312,245,313,245,314,245,315,245,316,245,317,245,318,245,319,245,320,245,321,245,322,245,323,245,324,245,325,245,326,245,327,245,328,245,329,245,330,245,331,245,332,245,333,245,334,245,335,245,336,245,337,245,338,245,339,245,340,245,94,246,96,246,97,246,98,246,102,246,103,246,104,246,147,246,296,246,299,246,300,246,301,246,302,246,303,246,304,246,305,246,306,246,307,246,308,246,309,246,310,246,311,246,312,246,313,246,314,246,315,246,316,246,317,246,318,246,319,246,320,246,321,246,322,246,323,246,324,246,325,246,326,246,327,246,328,246,329,246,330,246,331,246,332,246,333,246,334,246,335,246,336,246,337,246,338,246,339,246,340,246,87,247,93,247,95,247,97,247,103,247,149,247,153,247,297,247,301,247,302,247,303,247,304,247,305,247,306,247,307,247,308,247,309,247,310,247,311,247,312,247,313,247,314,247,315,247,316,247,317,247,318,247,319,247,320,247,321,247,322,247,323,247,324,247,325,247,326,247,327,247,328,247,329,247,330,247,331,247,332,247,333,247,334,247,335,247,336,247,337,247,338,247,86,248,88,248,90,248,91,248,92,248,94,248,96,248,98,248,99,248,103,248,105,248,106,248,237,248,295,248,296,248,297,248,300,248,301,248,302,248,303,248,304,248,305,248,306,248,307,248,308,248,309,248,310,248,311,248,312,248,313,248,314,248,315,248,316,248,317,248,318,248,319,248,320,248,321,248,322,248,323,248,324,248,325,248,326,248,327,248,328,248,329,248,330,248,331,248,332,248,333,248,334,248,335,248,336,248,337,248,90,249,91,249,95,249,97,249,98,249,103,249,105,249,163,249,165,249,235,249,294,249,296,249,297,249,298,249,299,249,301,249,302,249,303,249,304,249,305,249,306,249,307,249,308,249,309,249,310,249,311,249,312,249,313,249,314,249,315,249,316,249,317,249,318,249,319,249,320,249,321,249,322,249,323,249,324,249,325,249,326,249,327,249,328,249,329,249,330,249,331,249,332,249,333,249,334,249,335,249,336,249,337,249,90,250,92,250,93,250,94,250,96,250,97,250,98,250,100,250,106,250,156,250,294,250,302,250,303,250,304,250,305,250,306,250,307,250,308,250,309,250,310,250,311,250,312,250,313,250,314,250,315,250,316,250,317,250,318,250,319,250,320,250,321,250,322,250,323,250,324,250,325,250,326,250,327,250,328,250,329,250,330,250,331,250,332,250,333,250,334,250,335,250,336,250,337,250,90,251,92,251,93,251,94,251,95,251,96,251,103,251,105,251,107,251,118,251,166,251,230,251,253,251,288,251,300,251,302,251,303,251,304,251,305,251,306,251,307,251,308,251,309,251,310,251,311,251,312,251,313,251,314,251,315,251,316,251,317,251,318,251,319,251,320,251,321,251,322,251,323,251,324,251,325,251,326,251,327,251,328,251,329,251,330,251,331,251,332,251,333,251,334,251,335,251,336,251,92,252,97,252,102,252,103,252,104,252,105,252,107,252,108,252,109,252,162,252,264,252,289,252,290,252,295,252,298,252,300,252,301,252,304,252,305,252,306,252,307,252,308,252,309,252,310,252,311,252,312,252,313,252,314,252,315,252,316,252,317,252,318,252,319,252,320,252,321,252,322,252,323,252,324,252,325,252,326,252,327,252,328,252,329,252,330,252,331,252,332,252,333,252,334,252,335,252,98,253,100,253,107,253,129,253,256,253,302,253,304,253,305,253,306,253,307,253,308,253,309,253,310,253,311,253,312,253,313,253,314,253,315,253,316,253,317,253,318,253,319,253,320,253,321,253,322,253,323,253,324,253,325,253,326,253,327,253,328,253,329,253,330,253,331,253,332,253,333,253,334,253,94,254,95,254,96,254,99,254,103,254,108,254,110,254,126,254,127,254,128,254,129,254,130,254,131,254,176,254,177,254,258,254,300,254,302,254,303,254,304,254,305,254,306,254,307,254,308,254,309,254,310,254,311,254,312,254,313,254,314,254,315,254,316,254,317,254,318,254,319,254,320,254,321,254,322,254,323,254,324,254,325,254,326,254,327,254,328,254,329,254,330,254,331,254,332,254,92,255,94,255,95,255,97,255,100,255,101,255,102,255,103,255,106,255,107,255,108,255,111,255,123,255,124,255,125,255,126,255,127,255,128,255,129,255,130,255,131,255,133,255,157,255,259,255,283,255,303,255,305,255,306,255,307,255,308,255,309,255,310,255,311,255,312,255,313,255,314,255,315,255,316,255,317,255,318,255,319,255,320,255,321,255,322,255,323,255,324,255,325,255,326,255,327,255,328,255,329,255,330,255,331,255,96,256,98,256,99,256,100,256,101,256,102,256,105,256,106,256,107,256,109,256,121,256,122,256,123,256,124,256,125,256,126,256,127,256,128,256,129,256,130,256,131,256,132,256,133,256,134,256,183,256,306,256,307,256,308,256,309,256,310,256,311,256,312,256,313,256,314,256,315,256,316,256,317,256,318,256,319,256,320,256,321,256,322,256,323,256,324,256,325,256,326,256,327,256,328,256,329,256,330,256,94,257,95,257,97,257,98,257,99,257,100,257,101,257,102,257,104,257,105,257,106,257,108,257,120,257,121,257,122,257,123,257,124,257,125,257,126,257,127,257,128,257,129,257,130,257,131,257,132,257,133,257,134,257,135,257,136,257,188,257,190,257,287,257,290,257,297,257,306,257,307,257,308,257,309,257,310,257,311,257,312,257,313,257,314,257,315,257,316,257,317,257,318,257,319,257,320,257,321,257,322,257,323,257,324,257,325,257,326,257,327,257,328,257,329,257,94,258,97,258,102,258,103,258,106,258,108,258,117,258,119,258,120,258,121,258,122,258,123,258,124,258,125,258,126,258,127,258,128,258,129,258,130,258,131,258,132,258,133,258,134,258,135,258,136,258,137,258,138,258,158,258,300,258,304,258,305,258,306,258,307,258,308,258,309,258,310,258,311,258,312,258,313,258,314,258,315,258,316,258,317,258,318,258,319,258,320,258,321,258,322,258,323,258,324,258,325,258,326,258,327,258,328,258,99,259,100,259,101,259,104,259,105,259,106,259,107,259,116,259,117,259,118,259,119,259,120,259,121,259,122,259,123,259,124,259,125,259,126,259,127,259,128,259,129,259,130,259,131,259,132,259,133,259,134,259,135,259,136,259,137,259,138,259,139,259,140,259,290,259,303,259,304,259,305,259,306,259,307,259,308,259,309,259,310,259,311,259,312,259,313,259,314,259,315,259,316,259,317,259,318,259,319,259,320,259,321,259,322,259,323,259,324,259,325,259,326,259,327,259,99,260,102,260,103,260,104,260,105,260,106,260,115,260,116,260,117,260,118,260,119,260,120,260,121,260,122,260,123,260,124,260,125,260,126,260,127,260,128,260,129,260,130,260,131,260,132,260,133,260,134,260,135,260,136,260,137,260,138,260,281,260,287,260,290,260,303,260,304,260,305,260,306,260,307,260,308,260,309,260,310,260,311,260,312,260,313,260,314,260,315,260,316,260,317,260,318,260,319,260,320,260,321,260,322,260,323,260,324,260,325,260,326,260,100,261,101,261,102,261,103,261,104,261,106,261,113,261,114,261,115,261,116,261,117,261,118,261,119,261,120,261,121,261,122,261,123,261,124,261,125,261,126,261,127,261,128,261,129,261,130,261,131,261,132,261,133,261,302,261,303,261,304,261,305,261,306,261,307,261,308,261,309,261,310,261,311,261,312,261,313,261,314,261,315,261,316,261,317,261,318,261,319,261,320,261,321,261,322,261,323,261,324,261,325,261,102,262,104,262,111,262,112,262,113,262,114,262,115,262,116,262,117,262,118,262,119,262,120,262,121,262,122,262,123,262,124,262,125,262,172,262,183,262,253,262,254,262,255,262,256,262,282,262,301,262,302,262,303,262,304,262,305,262,306,262,307,262,308,262,309,262,310,262,311,262,312,262,313,262,314,262,315,262,316,262,317,262,318,262,319,262,320,262,321,262,322,262,323,262,100,263,102,263,103,263,110,263,111,263,112,263,113,263,114,263,115,263,116,263,117,263,118,263,119,263,120,263,121,263,194,263,197,263,198,263,206,263,250,263,251,263,252,263,253,263,254,263,255,263,256,263,257,263,258,263,288,263,294,263,300,263,301,263,302,263,303,263,304,263,305,263,306,263,307,263,308,263,309,263,310,263,311,263,312,263,313,263,314,263,315,263,316,263,317,263,318,263,319,263,320,263,321,263,322,263,101,264,103,264,111,264,112,264,113,264,114,264,115,264,116,264,117,264,118,264,209,264,247,264,249,264,250,264,251,264,252,264,253,264,254,264,255,264,256,264,257,264,258,264,276,264,300,264,301,264,302,264,303,264,304,264,305,264,306,264,307,264,308,264,309,264,310,264,311,264,312,264,313,264,314,264,315,264,316,264,317,264,318,264,319,264,320,264,321,264,102,265,112,265,113,265,172,265,245,265,247,265,248,265,249,265,250,265,251,265,252,265,253,265,254,265,255,265,256,265,257,265,258,265,259,265,297,265,299,265,300,265,301,265,302,265,303,265,304,265,305,265,306,265,307,265,308,265,309,265,310,265,311,265,312,265,313,265,314,265,315,265,316,265,317,265,318,265,319,265,320,265,174,266,207,266,243,266,244,266,245,266,246,266,247,266,248,266,249,266,250,266,251,266,252,266,253,266,254,266,255,266,256,266,257,266,258,266,259,266,260,266,261,266,282,266,296,266,297,266,298,266,299,266,300,266,301,266,302,266,303,266,304,266,305,266,306,266,307,266,308,266,309,266,310,266,311,266,312,266,313,266,314,266,315,266,316,266,317,266,240,267,241,267,242,267,243,267,244,267,245,267,246,267,247,267,248,267,249,267,250,267,251,267,252,267,253,267,254,267,255,267,256,267,257,267,258,267,259,267,260,267,261,267,262,267,276,267,296,267,297,267,298,267,299,267,300,267,301,267,302,267,303,267,304,267,305,267,306,267,307,267,308,267,309,267,310,267,311,267,312,267,313,267,314,267,208,268,237,268,238,268,239,268,240,268,241,268,242,268,243,268,244,268,245,268,246,268,247,268,248,268,249,268,250,268,251,268,252,268,253,268,254,268,255,268,256,268,257,268,258,268,259,268,260,268,261,268,262,268,294,268,295,268,296,268,297,268,298,268,299,268,300,268,301,268,302,268,303,268,304,268,305,268,306,268,307,268,308,268,309,268,236,269,237,269,238,269,239,269,240,269,241,269,242,269,243,269,244,269,245,269,246,269,247,269,248,269,249,269,250,269,251,269,252,269,253,269,254,269,255,269,256,269,257,269,258,269,259,269,260,269,261,269,293,269,294,269,295,269,296,269,297,269,298,269,299,269,300,269,301,269,302,269,303,269,304,269,305,269,208,270,233,270,234,270,235,270,236,270,237,270,238,270,239,270,240,270,241,270,242,270,243,270,244,270,245,270,246,270,247,270,248,270,249,270,250,270,251,270,252,270,253,270,254,270,255,270,256,270,257,270,258,270,259,270,260,270,261,270,292,270,293,270,294,270,295,270,296,270,297,270,298,270,299,270,300,270,301,270,302,270,229,271,230,271,231,271,232,271,233,271,234,271,235,271,236,271,237,271,238,271,239,271,240,271,241,271,242,271,243,271,244,271,245,271,246,271,247,271,248,271,249,271,250,271,251,271,252,271,253,271,254,271,255,271,256,271,257,271,258,271,259,271,260,271,261,271,268,271,292,271,293,271,294,271,295,271,296,271,297,271,298,271,299,271,300,271,207,272,225,272,226,272,227,272,228,272,229,272,230,272,231,272,232,272,233,272,234,272,235,272,236,272,237,272,238,272,239,272,240,272,241,272,242,272,243,272,244,272,245,272,246,272,247,272,248,272,249,272,250,272,251,272,252,272,253,272,254,272,255,272,256,272,257,272,258,272,259,272,260,272,269,272,290,272,291,272,292,272,293,272,294,272,295,272,296,272,173,273,207,273,220,273,221,273,222,273,223,273,224,273,225,273,226,273,227,273,228,273,229,273,230,273,231,273,232,273,233,273,234,273,235,273,236,273,237,273,238,273,239,273,240,273,241,273,242,273,243,273,244,273,245,273,246,273,247,273,248,273,249,273,250,273,251,273,252,273,253,273,254,273,255,273,256,273,257,273,258,273,259,273,260,273,270,273,288,273,289,273,290,273,291,273,207,274,219,274,220,274,221,274,222,274,223,274,224,274,225,274,226,274,227,274,228,274,229,274,230,274,231,274,232,274,233,274,234,274,235,274,236,274,237,274,238,274,239,274,240,274,241,274,242,274,243,274,244,274,245,274,246,274,247,274,248,274,249,274,250,274,251,274,252,274,253,274,254,274,255,274,256,274,257,274,258,274,259,274,260,274,271,274,272,274,277,274,288,274,207,275,216,275,217,275,218,275,219,275,220,275,221,275,222,275,223,275,224,275,225,275,226,275,227,275,228,275,229,275,230,275,231,275,232,275,233,275,234,275,235,275,236,275,237,275,238,275,239,275,240,275,241,275,242,275,243,275,244,275,245,275,246,275,247,275,248,275,249,275,250,275,251,275,252,275,253,275,254,275,255,275,256,275,257,275,258,275,259,275,260,275,272,275,273,275,173,276,214,276,215,276,216,276,217,276,218,276,219,276,220,276,221,276,222,276,223,276,224,276,225,276,226,276,227,276,228,276,229,276,230,276,231,276,232,276,233,276,234,276,235,276,236,276,237,276,238,276,239,276,240,276,241,276,242,276,243,276,244,276,245,276,246,276,247,276,248,276,249,276,250,276,251,276,252,276,253,276,254,276,255,276,256,276,257,276,258,276,259,276,273,276,274,276,173,277,213,277,214,277,215,277,216,277,217,277,218,277,219,277,220,277,221,277,222,277,223,277,224,277,225,277,226,277,227,277,228,277,229,277,230,277,231,277,232,277,233,277,234,277,235,277,236,277,237,277,238,277,239,277,240,277,241,277,242,277,243,277,244,277,245,277,246,277,247,277,248,277,249,277,250,277,251,277,252,277,253,277,254,277,255,277,256,277,257,277,258,277,259,277,275,277,276,277,173,278,213,278,214,278,215,278,216,278,217,278,218,278,219,278,220,278,221,278,222,278,223,278,224,278,225,278,226,278,227,278,228,278,229,278,230,278,231,278,232,278,233,278,234,278,235,278,236,278,237,278,238,278,239,278,240,278,241,278,242,278,243,278,244,278,245,278,246,278,247,278,248,278,249,278,250,278,251,278,252,278,253,278,254,278,255,278,256,278,257,278,258,278,259,278,173,279,213,279,214,279,215,279,216,279,217,279,218,279,219,279,220,279,221,279,222,279,223,279,224,279,225,279,226,279,227,279,228,279,229,279,230,279,231,279,232,279,233,279,234,279,235,279,236,279,237,279,238,279,239,279,240,279,241,279,242,279,243,279,244,279,245,279,246,279,247,279,248,279,249,279,250,279,251,279,252,279,253,279,254,279,255,279,256,279,257,279,258,279,259,279,173,280,212,280,213,280,214,280,215,280,216,280,217,280,218,280,219,280,220,280,221,280,222,280,223,280,224,280,225,280,226,280,227,280,228,280,229,280,230,280,231,280,232,280,233,280,234,280,235,280,236,280,237,280,238,280,239,280,240,280,241,280,242,280,243,280,244,280,245,280,246,280,247,280,248,280,249,280,250,280,251,280,252,280,253,280,254,280,255,280,256,280,257,280,258,280,173,281,213,281,214,281,215,281,216,281,217,281,218,281,219,281,220,281,221,281,222,281,223,281,224,281,225,281,226,281,227,281,228,281,229,281,230,281,231,281,232,281,233,281,234,281,235,281,236,281,237,281,238,281,239,281,240,281,241,281,242,281,243,281,244,281,245,281,246,281,247,281,248,281,249,281,250,281,251,281,252,281,253,281,254,281,255,281,256,281,257,281,258,281,212,282,213,282,214,282,215,282,216,282,217,282,218,282,219,282,220,282,221,282,222,282,223,282,224,282,225,282,226,282,227,282,228,282,229,282,230,282,231,282,232,282,233,282,234,282,235,282,236,282,237,282,238,282,239,282,240,282,241,282,242,282,243,282,244,282,245,282,246,282,247,282,248,282,249,282,250,282,251,282,252,282,253,282,254,282,255,282,256,282,257,282,258,282,212,283,213,283,214,283,215,283,216,283,217,283,218,283,219,283,220,283,221,283,222,283,223,283,224,283,225,283,226,283,227,283,228,283,229,283,230,283,231,283,232,283,233,283,234,283,235,283,236,283,237,283,238,283,239,283,240,283,241,283,242,283,243,283,244,283,245,283,246,283,247,283,248,283,249,283,250,283,251,283,252,283,253,283,254,283,255,283,256,283,257,283,258,283,212,284,213,284,214,284,215,284,216,284,217,284,218,284,219,284,220,284,221,284,222,284,223,284,224,284,225,284,226,284,227,284,228,284,229,284,230,284,231,284,232,284,233,284,234,284,235,284,236,284,237,284,238,284,239,284,240,284,241,284,242,284,243,284,244,284,245,284,246,284,247,284,248,284,249,284,250,284,251,284,252,284,253,284,254,284,255,284,256,284,257,284,258,284,170,285,173,285,205,285,212,285,213,285,214,285,215,285,216,285,217,285,218,285,219,285,220,285,221,285,222,285,223,285,224,285,225,285,226,285,227,285,228,285,229,285,230,285,231,285,232,285,233,285,234,285,235,285,236,285,237,285,238,285,239,285,240,285,241,285,242,285,243,285,244,285,245,285,246,285,247,285,248,285,249,285,250,285,251,285,252,285,253,285,254,285,255,285,256,285,257,285,173,286,179,286,211,286,212,286,213,286,214,286,215,286,216,286,217,286,218,286,219,286,220,286,221,286,222,286,223,286,224,286,225,286,226,286,227,286,228,286,229,286,230,286,231,286,232,286,233,286,234,286,235,286,236,286,237,286,238,286,239,286,240,286,241,286,242,286,243,286,244,286,245,286,246,286,247,286,248,286,249,286,250,286,251,286,252,286,253,286,254,286,255,286,256,286,257,286,173,287,177,287,187,287,188,287,193,287,202,287,204,287,210,287,211,287,212,287,213,287,214,287,215,287,216,287,217,287,218,287,219,287,220,287,221,287,222,287,223,287,224,287,225,287,226,287,227,287,228,287,229,287,230,287,231,287,232,287,233,287,234,287,235,287,236,287,237,287,238,287,239,287,240,287,241,287,242,287,243,287,244,287,245,287,246,287,247,287,248,287,249,287,250,287,251,287,252,287,253,287,254,287,255,287,256,287,257,287,176,288,211,288,212,288,213,288,214,288,215,288,216,288,217,288,218,288,219,288,220,288,221,288,222,288,223,288,224,288,225,288,226,288,227,288,228,288,229,288,230,288,231,288,232,288,233,288,234,288,235,288,236,288,237,288,238,288,239,288,240,288,241,288,242,288,243,288,244,288,245,288,246,288,247,288,248,288,249,288,250,288,251,288,252,288,253,288,254,288,255,288,256,288,171,289,211,289,212,289,213,289,214,289,215,289,216,289,217,289,218,289,219,289,220,289,221,289,222,289,223,289,224,289,225,289,226,289,227,289,228,289,229,289,230,289,231,289,232,289,233,289,234,289,235,289,236,289,237,289,238,289,239,289,240,289,241,289,242,289,243,289,244,289,245,289,246,289,247,289,248,289,249,289,250,289,251,289,252,289,253,289,171,290,172,290,181,290,210,290,211,290,212,290,213,290,214,290,215,290,216,290,217,290,218,290,219,290,220,290,221,290,222,290,223,290,224,290,225,290,226,290,227,290,228,290,229,290,230,290,231,290,232,290,233,290,234,290,235,290,236,290,237,290,238,290,239,290,240,290,241,290,242,290,243,290,244,290,245,290,246,290,247,290,248,290,249,290,250,290,171,291,175,291,209,291,210,291,211,291,212,291,213,291,214,291,215,291,216,291,217,291,218,291,219,291,220,291,221,291,222,291,223,291,224,291,225,291,226,291,227,291,228,291,229,291,230,291,231,291,232,291,233,291,234,291,235,291,236,291,237,291,238,291,239,291,240,291,241,291,242,291,243,291,244,291,245,291,246,291,247,291,209,292,210,292,211,292,212,292,213,292,214,292,215,292,216,292,217,292,218,292,219,292,220,292,221,292,222,292,223,292,224,292,225,292,226,292,227,292,228,292,229,292,230,292,231,292,232,292,233,292,234,292,235,292,236,292,237,292,238,292,239,292,240,292,241,292,242,292,243,292,244,292,184,293,209,293,210,293,211,293,212,293,213,293,214,293,215,293,216,293,217,293,218,293,219,293,220,293,221,293,222,293,223,293,224,293,225,293,226,293,227,293,228,293,229,293,230,293,231,293,232,293,233,293,234,293,235,293,236,293,237,293,238,293,239,293,181,294,209,294,210,294,211,294,212,294,213,294,214,294,215,294,216,294,217,294,218,294,219,294,220,294,221,294,222,294,223,294,224,294,225,294,226,294,227,294,228,294,229,294,230,294,231,294,232,294,233,294,234,294,235,294,236,294,209,295,210,295,211,295,212,295,213,295,214,295,215,295,216,295,217,295,218,295,219,295,220,295,221,295,222,295,223,295,224,295,225,295,226,295,227,295,228,295,229,295,230,295,231,295,232,295,233,295,208,296,209,296,210,296,211,296,212,296,213,296,214,296,215,296,216,296,217,296,218,296,219,296,220,296,221,296,222,296,223,296,224,296,225,296,226,296,227,296,228,296,229,296,230,296,208,297,209,297,210,297,211,297,212,297,213,297,214,297,215,297,216,297,217,297,218,297,219,297,220,297,221,297,222,297,223,297,224,297,225,297,226,297,227,297,173,298,189,298,208,298,209,298,210,298,211,298,212,298,213,298,214,298,215,298,216,298,217,298,218,298,219,298,220,298,221,298,222,298,223,298,173,299,208,299,209,299,210,299,211,299,212,299,213,299,214,299,215,299,216,299,217,299,218,299,219,299,207,300,208,300,209,300,210,300,211,300,212,300,213,300,214,300,215,300,216,300,208,301,209,301,210,301,211,301,212,301,213,301,181,302,199,302,207,302,208,302,209,302,198,303,206,303,207,303,196,320,142,321,143,321,144,321,145,321,359,321,360,321,361,321,362,321,363,321,101,322,102,322,103,322,238,322,239,322,279,322,280,322,308,322,309,322,310,322,361,322,362,322,363,322,364,322,365,322,102,323,103,323,104,323,105,323,106,323,107,323,239,323,240,323,241,323,242,323,243,323,245,323,280,323,281,323,282,323,283,323,284,323,308,323,309,323,310,323,311,323,312,323,313,323,314,323,103,324,104,324,105,324,106,324,107,324,108,324,240,324,241,324,242,324,243,324,244,324,280,324,281,324,282,324,283,324,308,324,309,324,310,324,311,324,312,324,313,324,314,324,315,324,316,324,317,324,318,324,319,324,51,325,104,325,105,325,106,325,107,325,108,325,188,325,242,325,243,325,281,325,282,325,283,325,308,325,309,325,310,325,311,325,312,325,313,325,314,325,315,325,316,325,317,325,318,325,319,325,320,325,321,325,322,325,101,326,106,326,107,326,243,326,282,326,308,326,309,326,310,326,311,326,312,326,313,326,314,326,315,326,316,326,317,326,318,326,319,326,320,326,321,326,188,327,308,327,309,327,310,327,311,327,312,327,313,327,314,327,315,327,316,327,317,327,318,327,319,327,320,327,321,327,377,327,378,327,379,327,51,328,308,328,309,328,310,328,311,328,312,328,313,328,314,328,315,328,316,328,317,328,318,328,319,328,320,328,378,328,379,328,380,328,381,328,382,328,383,328,384,328,385,328,386,328,34,329,37,329,39,329,40,329,42,329,43,329,44,329,45,329,47,329,48,329,49,329,50,329,308,329,309,329,310,329,311,329,312,329,313,329,314,329,315,329,316,329,317,329,318,329,319,329,320,329,321,329,322,329,323,329,378,329,379,329,380,329,381,329,382,329,383,329,384,329,385,329,386,329,387,329,63,330,74,330,80,330,82,330,84,330,101,330,198,330,200,330,204,330,207,330,210,330,212,330,213,330,215,330,217,330,218,330,220,330,221,330,260,330,308,330,309,330,310,330,311,330,312,330,313,330,314,330,315,330,316,330,317,330,318,330,319,330,320,330,321,330,322,330,379,330,380,330,381,330,382,330,383,330,384,330,385,330,386,330,387,330,388,330,308,331,309,331,310,331,311,331,312,331,313,331,314,331,315,331,316,331,317,331,318,331,319,331,320,331,321,331,379,331,380,331,381,331,382,331,383,331,384,331,385,331,386,331,387,331,388,331,389,331,101,332,308,332,309,332,310,332,311,332,312,332,313,332,314,332,315,332,316,332,317,332,318,332,319,332,320,332,321,332,378,332,379,332,380,332,381,332,382,332,383,332,384,332,385,332,386,332,387,332,388,332,308,333,309,333,310,333,311,333,312,333,313,333,314,333,315,333,316,333,317,333,318,333,319,333,320,333,321,333,377,333,378,333,379,333,380,333,381,333,382,333,383,333,384,333,385,333,386,333,387,333,308,334,309,334,310,334,311,334,312,334,313,334,314,334,376,334,377,334,378,334,379,334,380,334,381,334,382,334,383,334,384,334,385,334,386,334,86,335,101,335,308,335,309,335,310,335,311,335,312,335,313,335,314,335,359,335,374,335,375,335,376,335,377,335,378,335,379,335,380,335,381,335,382,335,383,335,384,335,385,335,7,336,32,336,33,336,34,336,35,336,308,336,309,336,310,336,311,336,312,336,313,336,314,336,378,336,379,336,380,336,381,336,382,336,383,336,384,336,385,336,7,337,80,337,83,337,84,337,143,337,201,337,202,337,203,337,205,337,208,337,308,337,309,337,310,337,311,337,312,337,313,337,374,337,382,337,383,337,384,337,385,337,386,337,46,338,47,338,101,338,126,338,127,338,128,338,129,338,130,338,131,338,132,338,133,338,134,338,135,338,136,338,137,338,138,338,139,338,140,338,262,338,263,338,264,338,265,338,266,338,267,338,268,338,269,338,270,338,271,338,272,338,273,338,274,338,275,338,276,338,344,338,345,338,346,338,347,338,348,338,349,338,350,338,351,338,382,338,383,338,384,338,385,338,386,338,387,338,46,339,47,339,126,339,127,339,128,339,129,339,130,339,131,339,132,339,133,339,134,339,135,339,136,339,137,339,138,339,139,339,140,339,262,339,263,339,264,339,265,339,266,339,267,339,268,339,269,339,270,339,271,339,272,339,273,339,274,339,275,339,276,339,305,339,341,339,342,339,343,339,344,339,345,339,346,339,347,339,348,339,349,339,350,339,382,339,383,339,384,339,385,339,386,339,387,339,47,340,126,340,127,340,128,340,129,340,130,340,131,340,132,340,133,340,134,340,135,340,136,340,137,340,138,340,139,340,140,340,262,340,263,340,264,340,265,340,266,340,267,340,268,340,269,340,270,340,271,340,272,340,273,340,274,340,275,340,276,340,340,340,341,340,342,340,343,340,344,340,345,340,346,340,347,340,348,340,349,340,383,340,384,340,385,340,386,340,387,340,388,340,47,341,126,341,127,341,128,341,129,341,130,341,131,341,132,341,133,341,134,341,135,341,136,341,137,341,138,341,139,341,140,341,262,341,263,341,264,341,265,341,266,341,267,341,268,341,269,341,270,341,271,341,272,341,273,341,274,341,275,341,276,341,339,341,340,341,341,341,342,341,343,341,344,341,345,341,346,341,347,341,348,341,384,341,385,341,386,341,387,341,388,341,47,342,126,342,127,342,128,342,129,342,130,342,131,342,132,342,133,342,134,342,135,342,136,342,137,342,138,342,139,342,140,342,262,342,263,342,264,342,265,342,266,342,267,342,268,342,269,342,270,342,271,342,272,342,273,342,274,342,275,342,276,342,311,342,338,342,339,342,340,342,341,342,342,342,343,342,344,342,345,342,346,342,347,342,348,342,359,342,384,342,385,342,386,342,387,342,388,342,126,343,127,343,128,343,129,343,130,343,131,343,132,343,133,343,134,343,135,343,136,343,137,343,138,343,139,343,140,343,262,343,263,343,264,343,265,343,266,343,267,343,268,343,269,343,270,343,271,343,272,343,273,343,274,343,275,343,276,343,338,343,339,343,340,343,341,343,342,343,343,343,344,343,345,343,346,343,347,343,348,343,376,343,384,343,385,343,386,343,387,343,388,343,389,343,48,344,57,344,126,344,127,344,128,344,129,344,130,344,131,344,132,344,133,344,134,344,135,344,136,344,137,344,138,344,139,344,140,344,262,344,263,344,264,344,265,344,266,344,267,344,268,344,269,344,270,344,271,344,272,344,273,344,274,344,275,344,276,344,338,344,339,344,340,344,341,344,342,344,343,344,344,344,345,344,346,344,347,344,385,344,386,344,387,344,388,344,389,344,390,344,391,344,392,344,393,344,394,344,48,345,49,345,50,345,51,345,52,345,53,345,54,345,55,345,56,345,125,345,126,345,127,345,128,345,129,345,130,345,131,345,132,345,133,345,134,345,135,345,136,345,137,345,138,345,139,345,140,345,181,345,182,345,183,345,184,345,185,345,186,345,187,345,188,345,189,345,190,345,191,345,192,345,193,345,262,345,263,345,264,345,265,345,266,345,267,345,268,345,269,345,270,345,271,345,272,345,273,345,274,345,275,345,276,345,307,345,340,345,341,345,342,345,343,345,344,345,345,345,346,345,347,345,386,345,387,345,388,345,389,345,390,345,391,345,392,345,393,345,394,345,395,345,396,345,48,346,49,346,50,346,51,346,52,346,53,346,54,346,55,346,139,346,140,346,181,346,182,346,183,346,184,346,185,346,186,346,187,346,188,346,189,346,190,346,191,346,192,346,262,346,263,346,264,346,265,346,266,346,267,346,268,346,269,346,270,346,271,346,272,346,273,346,274,346,275,346,276,346,308,346,309,346,310,346,341,346,342,346,343,346,344,346,345,346,346,346,347,346,385,346,386,346,387,346,388,346,389,346,390,346,391,346,392,346,393,346,394,346,395,346,396,346,48,347,49,347,50,347,51,347,52,347,53,347,54,347,55,347,140,347,156,347,181,347,182,347,183,347,184,347,185,347,186,347,187,347,188,347,189,347,190,347,191,347,192,347,262,347,263,347,264,347,265,347,266,347,267,347,268,347,269,347,270,347,271,347,272,347,273,347,274,347,275,347,276,347,308,347,309,347,310,347,344,347,345,347,346,347,347,347,348,347,369,347,385,347,386,347,387,347,388,347,389,347,390,347,391,347,392,347,393,347,394,347,395,347,396,347,48,348,49,348,50,348,51,348,52,348,53,348,54,348,55,348,101,348,140,348,181,348,182,348,183,348,184,348,185,348,186,348,187,348,188,348,189,348,190,348,191,348,192,348,193,348,262,348,263,348,264,348,265,348,266,348,267,348,268,348,269,348,270,348,271,348,272,348,273,348,274,348,275,348,276,348,308,348,309,348,310,348,311,348,312,348,313,348,314,348,315,348,385,348,386,348,387,348,388,348,389,348,390,348,391,348,392,348,393,348,394,348,395,348,48,349,49,349,50,349,51,349,52,349,53,349,54,349,55,349,181,349,182,349,183,349,184,349,185,349,186,349,187,349,188,349,189,349,190,349,191,349,192,349,193,349,262,349,263,349,264,349,265,349,266,349,267,349,268,349,269,349,270,349,271,349,272,349,273,349,274,349,275,349,276,349,308,349,309,349,310,349,311,349,312,349,313,349,314,349,315,349,316,349,317,349,318,349,385,349,386,349,387,349,388,349,389,349,390,349,391,349,49,350,50,350,51,350,52,350,53,350,54,350,55,350,61,350,181,350,182,350,183,350,184,350,185,350,186,350,187,350,188,350,189,350,190,350,191,350,192,350,193,350,262,350,263,350,264,350,265,350,266,350,267,350,268,350,269,350,270,350,271,350,272,350,273,350,274,350,275,350,276,350,308,350,309,350,310,350,311,350,312,350,313,350,314,350,315,350,316,350,317,350,318,350,385,350,386,350,387,350,388,350,49,351,50,351,51,351,52,351,53,351,54,351,55,351,181,351,182,351,183,351,184,351,185,351,186,351,187,351,188,351,189,351,190,351,191,351,192,351,193,351,262,351,263,351,264,351,265,351,266,351,267,351,268,351,269,351,270,351,271,351,272,351,273,351,274,351,275,351,276,351,308,351,309,351,310,351,311,351,312,351,313,351,314,351,315,351,316,351,317,351,318,351,319,351,364,351,382,351,383,351,384,351,385,351,386,351,387,351,49,352,50,352,51,352,52,352,53,352,54,352,55,352,181,352,182,352,183,352,184,352,185,352,186,352,187,352,188,352,189,352,190,352,191,352,192,352,193,352,194,352,198,352,262,352,263,352,264,352,265,352,266,352,267,352,268,352,269,352,270,352,271,352,272,352,273,352,274,352,275,352,276,352,308,352,309,352,310,352,311,352,312,352,313,352,314,352,315,352,316,352,317,352,318,352,319,352,377,352,378,352,379,352,380,352,381,352,382,352,383,352,384,352,385,352,386,352,49,353,50,353,51,353,52,353,53,353,54,353,182,353,183,353,184,353,185,353,186,353,187,353,188,353,189,353,190,353,191,353,192,353,262,353,263,353,264,353,265,353,266,353,267,353,268,353,269,353,270,353,271,353,272,353,273,353,274,353,275,353,276,353,308,353,309,353,310,353,311,353,312,353,313,353,314,353,315,353,316,353,317,353,318,353,319,353,331,353,376,353,377,353,378,353,379,353,380,353,381,353,382,353,383,353,384,353,385,353,386,353,49,354,50,354,56,354,182,354,183,354,184,354,185,354,186,354,187,354,188,354,189,354,190,354,191,354,192,354,262,354,263,354,264,354,265,354,266,354,267,354,268,354,269,354,270,354,271,354,272,354,273,354,274,354,275,354,276,354,308,354,309,354,310,354,311,354,312,354,313,354,314,354,315,354,316,354,317,354,318,354,319,354,376,354,377,354,378,354,379,354,380,354,381,354,382,354,383,354,384,354,385,354,48,355,143,355,144,355,145,355,146,355,147,355,148,355,149,355,150,355,151,355,152,355,153,355,154,355,155,355,182,355,183,355,184,355,185,355,186,355,187,355,188,355,189,355,190,355,191,355,192,355,262,355,263,355,264,355,265,355,266,355,267,355,268,355,269,355,270,355,271,355,272,355,273,355,274,355,275,355,276,355,308,355,309,355,310,355,311,355,312,355,313,355,314,355,315,355,316,355,317,355,318,355,352,355,353,355,375,355,376,355,377,355,378,355,379,355,380,355,381,355,382,355,383,355,384,355,9,356,32,356,33,356,34,356,35,356,36,356,37,356,38,356,39,356,40,356,41,356,42,356,43,356,44,356,45,356,46,356,47,356,76,356,77,356,78,356,79,356,80,356,81,356,82,356,83,356,84,356,85,356,143,356,144,356,145,356,146,356,147,356,148,356,149,356,150,356,151,356,152,356,153,356,154,356,155,356,158,356,167,356,170,356,172,356,174,356,182,356,183,356,184,356,185,356,186,356,187,356,188,356,189,356,190,356,191,356,192,356,262,356,263,356,264,356,265,356,266,356,267,356,268,356,269,356,270,356,271,356,272,356,273,356,274,356,275,356,276,356,300,356,308,356,309,356,310,356,311,356,312,356,313,356,314,356,315,356,316,356,317,356,318,356,342,356,374,356,375,356,376,356,377,356,378,356,379,356,380,356,381,356,382,356,383,356,32,357,33,357,34,357,35,357,36,357,37,357,38,357,39,357,40,357,41,357,42,357,43,357,44,357,45,357,46,357,47,357,77,357,78,357,79,357,80,357,81,357,82,357,83,357,84,357,85,357,86,357,143,357,144,357,145,357,146,357,147,357,148,357,149,357,150,357,151,357,152,357,153,357,154,357,155,357,182,357,183,357,184,357,185,357,186,357,187,357,188,357,189,357,190,357,191,357,192,357,193,357,262,357,263,357,264,357,265,357,266,357,267,357,268,357,269,357,270,357,271,357,272,357,273,357,274,357,275,357,276,357,308,357,309,357,310,357,311,357,312,357,313,357,314,357,315,357,316,357,317,357,318,357,374,357,375,357,376,357,377,357,378,357,379,357,380,357,381,357,382,357,383,357,32,358,33,358,34,358,35,358,36,358,37,358,38,358,39,358,40,358,41,358,42,358,43,358,44,358,45,358,46,358,47,358,77,358,78,358,79,358,80,358,81,358,82,358,83,358,84,358,85,358,86,358,144,358,145,358,146,358,147,358,148,358,149,358,150,358,151,358,152,358,153,358,154,358,155,358,182,358,183,358,184,358,185,358,186,358,187,358,188,358,189,358,190,358,191,358,192,358,262,358,263,358,264,358,265,358,266,358,267,358,268,358,269,358,270,358,271,358,272,358,273,358,274,358,275,358,276,358,308,358,309,358,310,358,311,358,312,358,313,358,314,358,315,358,316,358,317,358,374,358,375,358,376,358,377,358,378,358,379,358,380,358,381,358,382,358,383,358,384,358,32,359,33,359,34,359,35,359,36,359,37,359,38,359,39,359,40,359,41,359,42,359,43,359,44,359,45,359,46,359,47,359,77,359,78,359,79,359,80,359,81,359,82,359,83,359,84,359,85,359,86,359,144,359,145,359,146,359,147,359,148,359,149,359,150,359,151,359,152,359,153,359,154,359,155,359,182,359,183,359,184,359,185,359,186,359,187,359,188,359,189,359,190,359,191,359,192,359,262,359,263,359,264,359,265,359,266,359,267,359,268,359,269,359,270,359,271,359,272,359,273,359,274,359,275,359,276,359,308,359,309,359,310,359,311,359,312,359,313,359,314,359,315,359,316,359,317,359,375,359,376,359,377,359,378,359,379,359,380,359,381,359,382,359,383,359,384,359,385,359,7,360,32,360,33,360,34,360,35,360,36,360,37,360,38,360,39,360,40,360,41,360,42,360,43,360,44,360,45,360,46,360,47,360,76,360,77,360,78,360,79,360,80,360,81,360,82,360,83,360,84,360,85,360,86,360,144,360,145,360,146,360,147,360,148,360,149,360,150,360,151,360,152,360,153,360,154,360,155,360,182,360,183,360,184,360,185,360,186,360,187,360,188,360,189,360,190,360,191,360,192,360,193,360,262,360,263,360,264,360,265,360,266,360,267,360,268,360,269,360,270,360,271,360,272,360,273,360,274,360,275,360,276,360,308,360,309,360,310,360,311,360,312,360,313,360,314,360,315,360,316,360,375,360,376,360,377,360,378,360,379,360,380,360,381,360,382,360,383,360,384,360,385,360,386,360,7,361,32,361,33,361,34,361,35,361,36,361,37,361,38,361,39,361,40,361,41,361,42,361,43,361,44,361,45,361,46,361,47,361,76,361,77,361,78,361,79,361,80,361,81,361,82,361,83,361,84,361,85,361,86,361,144,361,145,361,146,361,147,361,148,361,149,361,150,361,151,361,152,361,153,361,154,361,155,361,182,361,183,361,184,361,185,361,186,361,187,361,188,361,189,361,190,361,191,361,192,361,262,361,263,361,264,361,265,361,266,361,267,361,268,361,269,361,270,361,271,361,272,361,273,361,274,361,275,361,276,361,283,361,308,361,309,361,310,361,311,361,312,361,313,361,314,361,315,361,316,361,317,361,375,361,376,361,377,361,378,361,379,361,380,361,381,361,382,361,383,361,384,361,385,361,386,361,32,362,33,362,34,362,35,362,36,362,37,362,38,362,39,362,40,362,41,362,42,362,43,362,44,362,45,362,46,362,47,362,76,362,77,362,78,362,79,362,80,362,81,362,82,362,83,362,84,362,85,362,86,362,144,362,145,362,146,362,147,362,148,362,149,362,150,362,151,362,152,362,153,362,154,362,155,362,156,362,182,362,183,362,184,362,185,362,186,362,187,362,188,362,189,362,190,362,191,362,192,362,262,362,263,362,264,362,265,362,266,362,267,362,268,362,269,362,270,362,271,362,272,362,273,362,274,362,275,362,276,362,308,362,309,362,310,362,311,362,312,362,313,362,314,362,315,362,316,362,317,362,318,362,376,362,377,362,378,362,379,362,380,362,381,362,382,362,383,362,384,362,385,362,32,363,33,363,34,363,35,363,36,363,37,363,38,363,39,363,40,363,41,363,42,363,43,363,44,363,45,363,46,363,47,363,76,363,77,363,78,363,79,363,80,363,81,363,82,363,83,363,84,363,85,363,86,363,144,363,145,363,146,363,147,363,148,363,149,363,150,363,151,363,152,363,153,363,154,363,155,363,156,363,182,363,183,363,184,363,185,363,186,363,187,363,188,363,189,363,190,363,191,363,192,363,262,363,263,363,264,363,265,363,266,363,267,363,268,363,269,363,270,363,271,363,272,363,273,363,274,363,275,363,276,363,308,363,309,363,310,363,311,363,312,363,313,363,314,363,315,363,316,363,317,363,318,363,319,363,320,363,329,363,330,363,376,363,377,363,378,363,379,363,380,363,381,363,382,363,383,363,384,363,32,364,33,364,34,364,35,364,36,364,37,364,38,364,39,364,40,364,41,364,42,364,43,364,44,364,45,364,46,364,47,364,76,364,77,364,78,364,79,364,80,364,81,364,82,364,83,364,84,364,85,364,86,364,144,364,145,364,146,364,147,364,148,364,149,364,150,364,151,364,152,364,153,364,154,364,155,364,182,364,183,364,184,364,185,364,186,364,187,364,188,364,189,364,190,364,191,364,192,364,262,364,263,364,264,364,265,364,266,364,267,364,268,364,269,364,270,364,271,364,272,364,273,364,274,364,275,364,276,364,308,364,309,364,310,364,311,364,312,364,313,364,314,364,315,364,316,364,317,364,326,364,334,364,375,364,376,364,377,364,378,364,379,364,380,364,381,364,382,364,32,365,33,365,34,365,35,365,36,365,37,365,38,365,39,365,40,365,41,365,42,365,43,365,44,365,76,365,77,365,78,365,79,365,80,365,81,365,82,365,83,365,84,365,85,365,86,365,106,365,144,365,145,365,146,365,147,365,148,365,149,365,150,365,151,365,152,365,153,365,154,365,155,365,182,365,183,365,184,365,185,365,186,365,187,365,188,365,189,365,190,365,191,365,192,365,193,365,243,365,262,365,263,365,264,365,265,365,266,365,267,365,268,365,269,365,270,365,271,365,272,365,273,365,274,365,307,365,308,365,309,365,310,365,311,365,312,365,313,365,314,365,315,365,316,365,360,365,361,365,362,365,363,365,374,365,375,365,376,365,377,365,32,366,33,366,34,366,35,366,36,366,37,366,38,366,39,366,40,366,41,366,76,366,77,366,78,366,79,366,80,366,81,366,82,366,83,366,84,366,85,366,86,366,105,366,106,366,107,366,144,366,145,366,146,366,147,366,148,366,149,366,150,366,151,366,152,366,182,366,183,366,184,366,185,366,186,366,187,366,188,366,189,366,190,366,242,366,243,366,262,366,263,366,264,366,265,366,266,366,267,366,268,366,269,366,270,366,271,366,306,366,307,366,308,366,309,366,310,366,311,366,312,366,313,366,356,366,357,366,358,366,359,366,360,366,361,366,362,366,363,366,364,366,372,366,32,367,33,367,34,367,35,367,36,367,37,367,38,367,76,367,77,367,78,367,79,367,80,367,81,367,82,367,83,367,84,367,85,367,104,367,105,367,106,367,107,367,108,367,144,367,145,367,146,367,147,367,148,367,149,367,182,367,183,367,184,367,185,367,186,367,187,367,241,367,242,367,243,367,244,367,245,367,262,367,263,367,264,367,265,367,266,367,267,367,268,367,269,367,286,367,305,367,306,367,307,367,308,367,309,367,310,367,352,367,353,367,354,367,355,367,356,367,357,367,358,367,359,367,360,367,361,367,362,367,363,367,364,367,32,368,33,368,34,368,35,368,76,368,77,368,78,368,79,368,80,368,81,368,103,368,104,368,144,368,145,368,146,368,147,368,182,368,183,368,184,368,240,368,241,368,262,368,263,368,264,368,265,368,266,368,304,368,305,368,306,368,352,368,353,368,354,368,355,368,356,368,357,368,358,368,359,368,360,368,361,368,362,368,363,368,32,369,76,369,144,369,262,369,263,369,303,369,352,369,353,369,354,369,355,369,356,369,357,369,358,369,359,369,360,369,100,370,341,370,351,370,352,370,353,370,354,370,355,370}
listdrydirt = {214,17,218,18,225,23,225,24,224,28,199,38,236,54,294,54,154,55,234,55,236,55,241,55,240,56,231,57,233,57,234,57,236,57,240,57,239,58,245,58,229,59,234,59,238,59,239,59,242,59,243,59,246,59,249,59,251,59,231,60,235,60,241,60,250,60,253,60,235,61,231,65,189,80,147,84,252,87,170,88,220,88,263,91,256,94,176,95,232,95,235,96,187,97,197,101,141,102,121,103,273,103,224,104,116,117,150,119,111,120,247,124,119,127,121,128,103,131,140,133,141,136,137,138,135,139,270,144,137,147,123,148,135,148,136,150,257,153,254,160,97,165,91,166,118,166,123,166,130,167,307,167,126,171,326,173,121,174,92,175,89,176,92,176,86,178,87,178,91,178,87,179,108,179,325,181,324,182,116,183,117,194,120,194,128,196,273,200,155,206,111,215,152,221,270,221,186,222,268,222,149,223,158,223,117,226,181,229,124,231,206,232,167,233,105,234,99,236,277,236,106,240,106,241,267,245,263,246,255,248,282,248,272,256,264,259,189,265,175,266,271,267,197,268,177,286,176,287,154,317,155,317,86,318,201,318,204,318,206,318,208,318,202,319,61,322,149,329,163,329,110,330,110,332,223,333,332,333,223,334,223,335,160,337,163,337,110,339,110,343,321,351,325,355}
listgrass1 = {193,49,223,49,223,50,230,50,231,50,190,51,223,52,234,52,223,53,192,54,223,54,239,54,240,54,214,56,224,57,219,58,219,59,197,60,224,60,194,61,195,61,196,61,223,61,224,61,223,62,224,62,210,63,213,63,223,63,214,66,223,66,165,67,225,68,233,69,145,71,232,71,231,72,231,73,240,74,141,75,245,75,246,75,247,75,246,76,135,77,136,77,249,77,250,77,136,78,266,78,267,78,131,79,255,80,258,80,259,80,260,80,139,81,258,81,259,81,260,81,254,82,255,82,256,82,257,82,258,82,260,82,261,82,211,83,259,84,260,84,127,86,253,86,265,86,253,87,254,87,265,87,268,87,271,87,112,88,113,88,251,88,252,88,264,88,265,88,268,88,265,89,259,90,250,91,267,91,109,92,120,92,232,92,300,92,117,93,118,93,262,93,265,93,215,94,273,94,121,95,202,95,267,95,275,95,276,95,298,95,121,96,271,96,272,96,275,96,276,96,128,97,200,97,303,97,183,98,192,98,270,98,274,98,294,98,295,98,124,99,125,99,274,99,293,99,177,100,195,100,266,100,273,100,275,100,293,100,122,101,180,101,187,101,279,101,280,101,193,102,197,102,198,102,215,102,279,102,292,102,189,103,192,103,194,103,195,103,196,103,197,103,200,103,201,103,202,103,206,103,216,103,248,103,249,103,299,103,186,104,187,104,188,104,189,104,191,104,195,104,196,104,197,104,199,104,203,104,205,104,206,104,209,104,210,104,283,104,289,104,179,105,180,105,183,105,186,105,187,105,189,105,190,105,191,105,193,105,195,105,196,105,197,105,198,105,199,105,200,105,201,105,202,105,203,105,204,105,205,105,206,105,208,105,209,105,210,105,211,105,212,105,213,105,214,105,283,105,176,106,182,106,183,106,184,106,185,106,186,106,187,106,188,106,189,106,190,106,191,106,193,106,195,106,196,106,197,106,198,106,199,106,200,106,201,106,202,106,203,106,205,106,207,106,208,106,209,106,210,106,211,106,212,106,213,106,214,106,288,106,176,107,177,107,181,107,182,107,184,107,186,107,187,107,189,107,190,107,191,107,192,107,194,107,195,107,196,107,197,107,198,107,199,107,200,107,201,107,202,107,203,107,204,107,205,107,206,107,207,107,208,107,209,107,212,107,215,107,216,107,217,107,218,107,278,107,279,107,280,107,282,107,283,107,158,108,159,108,164,108,167,108,175,108,176,108,180,108,181,108,183,108,184,108,187,108,189,108,190,108,192,108,193,108,194,108,195,108,196,108,197,108,198,108,199,108,201,108,207,108,208,108,210,108,211,108,214,108,215,108,216,108,217,108,220,108,226,108,279,108,280,108,281,108,282,108,286,108,287,108,170,109,171,109,175,109,179,109,180,109,181,109,183,109,185,109,187,109,188,109,192,109,193,109,195,109,196,109,197,109,200,109,202,109,203,109,204,109,205,109,206,109,207,109,208,109,210,109,211,109,213,109,222,109,223,109,224,109,226,109,285,109,286,109,287,109,170,110,171,110,173,110,174,110,175,110,177,110,179,110,180,110,181,110,182,110,183,110,184,110,185,110,189,110,190,110,192,110,197,110,199,110,202,110,203,110,205,110,206,110,207,110,208,110,210,110,213,110,218,110,220,110,221,110,223,110,235,110,283,110,286,110,168,111,169,111,170,111,171,111,172,111,174,111,176,111,179,111,180,111,181,111,182,111,183,111,184,111,187,111,188,111,190,111,192,111,193,111,195,111,196,111,197,111,203,111,205,111,206,111,207,111,212,111,213,111,217,111,218,111,221,111,222,111,224,111,225,111,226,111,227,111,283,111,286,111,169,112,170,112,172,112,173,112,174,112,177,112,178,112,183,112,184,112,185,112,186,112,187,112,190,112,195,112,205,112,210,112,211,112,216,112,220,112,224,112,226,112,227,112,287,112,297,112,165,113,167,113,168,113,170,113,171,113,175,113,177,113,178,113,179,113,180,113,182,113,184,113,185,113,186,113,194,113,195,113,202,113,203,113,213,113,215,113,216,113,218,113,219,113,221,113,224,113,225,113,226,113,234,113,235,113,280,113,281,113,284,113,286,113,163,114,164,114,165,114,167,114,170,114,172,114,174,114,175,114,176,114,178,114,179,114,180,114,181,114,182,114,183,114,188,114,214,114,219,114,220,114,224,114,225,114,229,114,230,114,231,114,233,114,238,114,276,114,277,114,284,114,302,114,165,115,168,115,169,115,170,115,171,115,174,115,177,115,178,115,179,115,180,115,183,115,220,115,221,115,224,115,228,115,229,115,230,115,231,115,238,115,284,115,162,116,163,116,164,116,165,116,166,116,168,116,169,116,170,116,172,116,173,116,175,116,177,116,178,116,229,116,230,116,231,116,163,117,164,117,165,117,166,117,167,117,170,117,172,117,173,117,174,117,179,117,223,117,226,117,227,117,233,117,234,117,286,117,147,118,162,118,163,118,164,118,166,118,169,118,170,118,171,118,172,118,173,118,174,118,175,118,176,118,177,118,226,118,230,118,233,118,234,118,280,118,286,118,287,118,303,118,151,119,158,119,159,119,160,119,161,119,162,119,163,119,165,119,166,119,167,119,169,119,170,119,171,119,172,119,173,119,229,119,230,119,234,119,285,119,300,119,302,119,158,120,159,120,160,120,161,120,162,120,163,120,165,120,166,120,167,120,170,120,171,120,237,120,153,121,158,121,159,121,160,121,161,121,162,121,164,121,166,121,167,121,168,121,169,121,170,121,152,122,156,122,157,122,158,122,160,122,162,122,163,122,164,122,166,122,167,122,168,122,169,122,235,122,113,123,156,123,157,123,159,123,160,123,161,123,163,123,164,123,165,123,231,123,248,123,269,123,288,123,289,123,296,123,297,123,302,123,303,123,156,124,157,124,158,124,159,124,162,124,163,124,164,124,165,124,166,124,239,124,248,124,288,124,289,124,304,124,155,125,158,125,159,125,160,125,161,125,163,125,164,125,165,125,166,125,239,125,288,125,152,126,155,126,156,126,157,126,159,126,160,126,161,126,162,126,163,126,288,126,151,127,152,127,154,127,155,127,156,127,157,127,160,127,161,127,162,127,163,127,286,127,287,127,149,128,153,128,154,128,155,128,156,128,159,128,161,128,245,128,144,129,153,129,155,129,156,129,157,129,159,129,160,129,161,129,283,129,291,129,102,130,149,130,151,130,153,130,154,130,155,130,156,130,157,130,158,130,159,130,160,130,162,130,308,130,102,131,148,131,151,131,152,131,153,131,154,131,155,131,159,131,284,131,302,131,141,132,147,132,151,132,153,132,155,132,156,132,157,132,158,132,159,132,246,132,252,132,291,132,141,133,151,133,152,133,153,133,154,133,155,133,156,133,157,133,158,133,159,133,292,133,295,133,142,134,151,134,152,134,153,134,154,134,155,134,156,134,291,134,292,134,97,135,105,135,142,135,147,135,154,135,155,135,138,136,142,136,147,136,149,136,150,136,151,136,154,136,155,136,255,136,292,136,138,137,141,137,149,137,150,137,151,137,152,137,154,137,157,137,293,137,138,138,148,138,149,138,150,138,151,138,152,138,154,138,155,138,310,138,148,139,150,139,151,139,153,139,155,139,156,139,291,139,293,139,294,139,295,139,138,140,150,140,151,140,152,140,154,140,294,140,145,141,146,141,147,141,148,141,150,141,151,141,152,141,294,141,143,142,145,142,148,142,149,142,150,142,151,142,152,142,95,143,96,143,134,143,147,143,148,143,150,143,151,143,152,143,293,143,295,143,296,143,133,144,138,144,143,144,144,144,146,144,150,144,151,144,152,144,154,144,256,144,286,144,295,144,312,144,138,145,143,145,144,145,146,145,149,145,150,145,152,145,300,145,138,146,139,146,142,146,143,146,144,146,146,146,147,146,149,146,150,146,151,146,296,146,301,146,142,147,145,147,146,147,147,147,149,147,150,147,151,147,152,147,153,147,295,147,296,147,315,147,318,147,96,148,143,148,145,148,146,148,147,148,149,148,150,148,151,148,152,148,296,148,134,149,137,149,144,149,145,149,146,149,147,149,148,149,150,149,295,149,296,149,94,150,100,150,138,150,142,150,143,150,144,150,145,150,146,150,149,150,150,150,296,150,297,150,298,150,300,150,94,151,133,151,143,151,149,151,150,151,152,151,296,151,297,151,298,151,299,151,300,151,301,151,141,152,143,152,144,152,145,152,146,152,147,152,148,152,149,152,150,152,151,152,152,152,296,152,297,152,298,152,299,152,300,152,98,153,141,153,144,153,145,153,146,153,147,153,149,153,295,153,297,153,298,153,299,153,300,153,141,154,143,154,146,154,147,154,148,154,149,154,257,154,295,154,296,154,297,154,298,154,299,154,300,154,301,154,137,155,141,155,144,155,146,155,147,155,149,155,297,155,298,155,137,156,140,156,141,156,144,156,145,156,146,156,147,156,148,156,149,156,150,156,151,156,296,156,297,156,298,156,92,157,95,157,137,157,143,157,144,157,147,157,148,157,149,157,151,157,296,157,297,157,298,157,299,157,136,158,137,158,143,158,144,158,145,158,146,158,147,158,148,158,149,158,150,158,151,158,296,158,297,158,298,158,299,158,329,158,339,158,141,159,143,159,147,159,148,159,149,159,151,159,296,159,298,159,299,159,94,160,134,160,142,160,145,160,146,160,149,160,296,160,297,160,299,160,145,161,146,161,148,161,254,161,296,161,297,161,299,161,145,162,146,162,147,162,148,162,293,162,296,162,297,162,299,162,339,162,142,163,143,163,144,163,145,163,146,163,147,163,148,163,149,163,293,163,296,163,297,163,298,163,299,163,300,163,140,164,141,164,142,164,143,164,144,164,145,164,146,164,147,164,148,164,149,164,246,164,296,164,297,164,298,164,299,164,300,164,301,164,91,165,140,165,142,165,143,165,144,165,146,165,147,165,149,165,150,165,295,165,296,165,297,165,298,165,299,165,300,165,335,165,144,166,145,166,146,166,148,166,151,166,261,166,294,166,295,166,296,166,297,166,298,166,299,166,77,167,78,167,86,167,141,167,142,167,143,167,144,167,145,167,146,167,147,167,148,167,149,167,150,167,151,167,296,167,297,167,298,167,299,167,79,168,86,168,100,168,142,168,143,168,144,168,145,168,148,168,149,168,150,168,151,168,152,168,296,168,297,168,299,168,339,168,86,169,89,169,142,169,143,169,145,169,146,169,147,169,148,169,149,169,152,169,296,169,297,169,299,169,339,169,88,170,91,170,133,170,143,170,144,170,145,170,146,170,147,170,148,170,149,170,295,170,296,170,297,170,299,170,333,170,339,170,102,171,146,171,147,171,148,171,149,171,152,171,295,171,296,171,297,171,299,171,95,172,96,172,100,172,142,172,143,172,144,172,148,172,149,172,150,172,151,172,152,172,295,172,296,172,298,172,299,172,329,172,80,173,100,173,143,173,144,173,145,173,146,173,148,173,149,173,150,173,151,173,153,173,295,173,296,173,299,173,333,173,145,174,146,174,147,174,148,174,150,174,153,174,295,174,296,174,299,174,328,174,88,175,121,175,143,175,145,175,146,175,147,175,148,175,149,175,150,175,151,175,295,175,298,175,143,176,146,176,147,176,148,176,149,176,150,176,151,176,152,176,295,176,298,176,338,176,340,176,145,177,146,177,147,177,148,177,149,177,150,177,151,177,152,177,295,177,296,177,298,177,144,178,147,178,148,178,149,178,150,178,151,178,295,178,296,178,297,178,298,178,299,178,142,179,143,179,144,179,148,179,149,179,150,179,151,179,155,179,294,179,295,179,296,179,297,179,298,179,299,179,300,179,333,179,142,180,146,180,147,180,148,180,149,180,151,180,152,180,294,180,295,180,296,180,297,180,298,180,299,180,300,180,304,180,101,181,146,181,147,181,148,181,149,181,150,181,153,181,287,181,294,181,296,181,297,181,304,181,100,182,104,182,145,182,146,182,147,182,148,182,151,182,152,182,153,182,154,182,294,182,297,182,147,183,149,183,150,183,151,183,152,183,153,183,157,183,293,183,295,183,296,183,297,183,298,183,308,183,116,184,117,184,143,184,149,184,150,184,151,184,152,184,153,184,154,184,155,184,253,184,292,184,294,184,316,184,323,184,127,185,148,185,149,185,150,185,153,185,154,185,155,185,156,185,292,185,293,185,306,185,307,185,312,185,146,186,147,186,148,186,149,186,150,186,152,186,154,186,155,186,156,186,159,186,287,186,293,186,146,187,147,187,149,187,150,187,151,187,153,187,154,187,155,187,156,187,158,187,287,187,293,187,339,187,151,188,152,188,153,188,155,188,156,188,157,188,158,188,287,188,151,189,152,189,155,189,156,189,157,189,159,189,148,190,149,190,150,190,151,190,155,190,156,190,158,190,290,190,291,190,154,191,155,191,156,191,157,191,160,191,161,191,291,191,151,192,152,192,154,192,156,192,159,192,160,192,162,192,289,192,291,192,152,193,153,193,154,193,155,193,156,193,159,193,160,193,161,193,288,193,289,193,154,194,156,194,159,194,162,194,165,194,287,194,288,194,289,194,308,194,153,195,155,195,162,195,163,195,246,195,285,195,288,195,289,195,290,195,146,196,152,196,153,196,158,196,160,196,162,196,164,196,165,196,246,196,287,196,152,197,155,197,157,197,158,197,159,197,160,197,161,197,245,197,287,197,288,197,147,198,157,198,158,198,163,198,164,198,165,198,166,198,281,198,285,198,286,198,157,199,162,199,163,199,164,199,245,199,246,199,288,199,156,200,159,200,160,200,161,200,166,200,117,201,159,201,163,201,164,201,168,201,162,202,167,202,171,202,173,202,162,203,167,203,170,203,173,203,284,203,155,204,161,204,162,204,168,204,169,204,170,204,173,204,175,204,284,204,161,205,163,205,166,205,167,205,168,205,170,205,173,205,174,205,175,205,178,205,179,205,166,206,167,206,175,206,285,206,166,207,169,207,170,207,171,207,172,207,175,207,177,207,179,207,180,207,181,207,239,207,282,207,168,208,169,208,170,208,174,208,178,208,179,208,183,208,282,208,283,208,174,209,184,209,185,209,188,209,194,209,237,209,282,209,283,209,173,210,179,210,185,210,190,210,200,210,230,210,113,211,173,211,176,211,182,211,185,211,200,211,229,211,277,211,279,211,280,211,281,211,112,212,181,212,182,212,184,212,235,212,279,212,280,212,112,213,177,213,180,213,181,213,184,213,187,213,279,213,280,213,281,213,116,214,123,214,165,214,186,214,187,214,188,214,279,214,116,215,184,215,188,215,278,215,279,215,115,216,116,216,200,216,203,216,204,216,278,216,112,217,115,217,277,217,278,217,117,218,188,218,226,218,277,218,117,219,118,219,187,219,188,219,276,219,276,220,277,220,120,221,275,221,291,221,295,221,120,222,270,222,271,222,274,222,120,223,121,223,267,223,269,223,270,223,271,223,273,223,279,223,120,224,121,224,123,224,268,224,269,224,270,224,271,224,272,224,273,224,121,225,123,225,267,225,268,225,269,225,271,225,272,225,277,225,278,225,281,225,122,226,123,226,124,226,271,226,276,226,278,226,281,226,282,226,122,227,123,227,126,227,269,227,270,227,275,227,279,227,282,227,283,227,291,227,268,228,269,228,274,228,282,228,283,228,284,228,285,228,126,229,129,229,267,229,268,229,273,229,283,229,284,229,285,229,125,230,126,230,127,230,129,230,267,230,268,230,272,230,273,230,284,230,285,230,286,230,127,231,128,231,129,231,130,231,131,231,180,231,266,231,267,231,273,231,285,231,286,231,287,231,127,232,129,232,130,232,263,232,264,232,265,232,266,232,267,232,274,232,280,232,286,232,287,232,288,232,290,232,129,233,130,233,252,233,263,233,264,233,266,233,278,233,279,233,280,233,286,233,287,233,288,233,289,233,131,234,261,234,262,234,263,234,265,234,276,234,278,234,280,234,281,234,286,234,287,234,288,234,289,234,290,234,291,234,131,235,134,235,260,235,261,235,262,235,263,235,264,235,272,235,276,235,277,235,283,235,284,235,287,235,288,235,289,235,290,235,132,236,133,236,134,236,158,236,254,236,258,236,260,236,262,236,263,236,288,236,289,236,290,236,291,236,133,237,134,237,135,237,136,237,137,237,259,237,260,237,261,237,262,237,284,237,287,237,288,237,289,237,290,237,293,237,133,238,134,238,136,238,139,238,258,238,259,238,284,238,287,238,290,238,291,238,293,238,131,239,134,239,140,239,258,239,259,239,290,239,291,239,292,239,293,239,90,240,92,240,134,240,141,240,142,240,255,240,256,240,257,240,258,240,292,240,293,240,87,241,133,241,142,241,254,241,255,241,256,241,257,241,293,241,294,241,295,241,130,242,131,242,144,242,145,242,146,242,253,242,254,242,255,242,293,242,294,242,295,242,102,243,252,243,257,243,258,243,292,243,295,243,249,244,250,244,258,244,295,244,104,245,246,245,247,245,248,245,249,245,255,245,266,245,296,245,297,245,125,246,126,246,152,246,244,246,245,246,246,246,254,246,255,246,261,246,262,246,297,246,298,246,94,247,124,247,154,247,158,247,159,247,241,247,242,247,243,247,252,247,253,247,254,247,262,247,291,247,298,247,107,248,123,248,155,248,156,248,157,248,158,248,159,248,238,248,239,248,240,248,290,248,299,248,121,249,159,249,160,249,161,249,229,249,236,249,119,250,165,250,232,250,233,250,234,250,235,250,256,250,257,250,162,251,233,251,261,251,299,251,96,252,165,252,166,252,167,252,168,252,213,252,229,252,254,252,263,252,286,252,115,253,168,253,171,253,172,253,181,253,220,253,221,253,225,253,255,253,285,253,172,254,173,254,174,254,175,254,181,254,215,254,219,254,220,254,221,254,222,254,223,254,257,254,105,255,171,255,175,255,176,255,178,255,180,255,188,255,190,255,216,255,257,255,258,255,180,256,181,256,182,256,208,256,209,256,210,256,211,256,212,256,216,256,118,257,172,257,181,257,186,257,187,257,204,257,205,257,206,257,210,257,276,257,98,258,196,258,199,258,200,258,279,258,173,259,277,259,278,259,174,260,263,260,264,260,174,261,253,261,264,261,265,261,175,262,179,262,184,262,185,262,195,262,157,263,180,263,189,263,190,263,195,263,199,263,202,263,203,263,204,263,205,263,171,264,200,264,268,264,171,265,177,265,197,265,209,265,269,265,270,265,171,266,209,266,171,267,172,267,173,267,174,267,206,267,238,267,171,268,172,268,173,268,174,268,192,268,202,268,265,268,270,268,170,269,171,269,209,269,271,269,170,270,171,270,172,270,209,270,171,271,172,271,269,271,272,271,170,272,171,272,172,272,270,272,170,273,171,273,172,273,198,273,208,273,273,273,287,273,170,274,171,274,172,274,203,274,273,274,274,274,286,274,169,275,170,275,171,275,172,275,274,275,170,276,171,276,172,276,207,276,277,276,170,277,171,277,172,277,207,277,170,278,171,278,172,278,206,278,207,278,170,279,171,279,172,279,206,279,170,280,171,280,172,280,170,281,171,281,172,281,171,282,172,282,173,282,206,282,207,282,170,283,171,283,172,283,173,283,170,284,171,284,172,284,203,284,206,284,171,285,172,285,206,285,207,285,171,286,172,286,180,286,181,286,182,286,183,286,185,286,186,286,206,286,172,287,189,287,190,287,191,287,192,287,196,287,197,287,198,287,199,287,200,287,206,287,172,288,205,289,206,289,206,291,206,292,206,294,206,295,206,299,138,319,53,320,138,320,139,320,189,320,190,320,197,320,305,320,52,321,53,321,54,321,55,321,57,321,138,321,139,321,140,321,141,321,189,321,190,321,191,321,192,321,194,321,195,321,197,321,52,322,53,322,54,322,55,322,57,322,59,322,60,322,139,322,140,322,141,322,142,322,143,322,144,322,145,322,146,322,189,322,190,322,191,322,194,322,195,322,196,322,197,322,52,323,53,323,54,323,55,323,57,323,59,323,60,323,139,323,140,323,141,323,142,323,144,323,145,323,146,323,189,323,190,323,191,323,194,323,195,323,196,323,197,323,52,324,53,324,54,324,57,324,58,324,59,324,60,324,102,324,109,324,139,324,140,324,141,324,142,324,145,324,146,324,189,324,190,324,191,324,195,324,196,324,197,324,239,324,245,324,278,324,279,324,324,324,52,325,53,325,54,325,58,325,59,325,60,325,101,325,102,325,103,325,109,325,139,325,140,325,141,325,145,325,146,325,147,325,189,325,190,325,191,325,195,325,196,325,197,325,238,325,239,325,240,325,244,325,245,325,278,325,279,325,280,325,284,325,323,325,324,325,52,326,53,326,54,326,58,326,60,326,102,326,103,326,104,326,108,326,109,326,138,326,139,326,140,326,141,326,145,326,146,326,147,326,188,326,189,326,190,326,191,326,195,326,196,326,197,326,238,326,244,326,245,326,278,326,279,326,280,326,281,326,283,326,284,326,306,326,322,326,323,326,324,326,325,326,52,327,53,327,54,327,58,327,60,327,101,327,102,327,103,327,104,327,105,327,107,327,108,327,109,327,138,327,139,327,140,327,141,327,145,327,146,327,147,327,189,327,190,327,191,327,195,327,197,327,238,327,243,327,244,327,245,327,278,327,282,327,283,327,284,327,305,327,306,327,322,327,323,327,324,327,325,327,326,327,373,327,374,327,375,327,52,328,53,328,54,328,58,328,60,328,102,328,103,328,104,328,107,328,108,328,109,328,138,328,139,328,140,328,141,328,145,328,146,328,147,328,188,328,189,328,190,328,191,328,195,328,197,328,238,328,244,328,245,328,278,328,283,328,284,328,305,328,306,328,323,328,324,328,325,328,343,328,344,328,345,328,346,328,347,328,372,328,373,328,375,328,32,329,33,329,36,329,41,329,51,329,52,329,53,329,54,329,58,329,59,329,60,329,102,329,103,329,107,329,108,329,109,329,138,329,139,329,140,329,141,329,145,329,146,329,147,329,188,329,189,329,190,329,191,329,195,329,196,329,197,329,238,329,244,329,245,329,277,329,284,329,305,329,306,329,324,329,325,329,340,329,341,329,342,329,343,329,344,329,345,329,346,329,347,329,348,329,371,329,372,329,373,329,374,329,375,329,376,329,31,330,46,330,47,330,48,330,50,330,51,330,52,330,53,330,54,330,58,330,59,330,60,330,61,330,81,330,102,330,103,330,107,330,108,330,109,330,123,330,124,330,131,330,134,330,136,330,137,330,138,330,140,330,141,330,145,330,146,330,147,330,149,330,150,330,151,330,152,330,153,330,154,330,155,330,183,330,184,330,185,330,186,330,187,330,189,330,190,330,191,330,195,330,196,330,197,330,219,330,238,330,244,330,245,330,275,330,276,330,277,330,284,330,305,330,306,330,323,330,324,330,338,330,339,330,340,330,341,330,342,330,352,330,372,330,373,330,374,330,375,330,376,330,377,330,31,331,48,331,50,331,51,331,52,331,53,331,54,331,58,331,59,331,60,331,101,331,102,331,103,331,107,331,108,331,109,331,123,331,136,331,137,331,138,331,139,331,141,331,145,331,146,331,148,331,149,331,150,331,151,331,152,331,153,331,154,331,155,331,156,331,157,331,158,331,179,331,187,331,188,331,190,331,195,331,196,331,201,331,238,331,244,331,245,331,275,331,276,331,277,331,278,331,284,331,305,331,306,331,337,331,338,331,339,331,354,331,373,331,374,331,375,331,376,331,377,331,31,332,50,332,58,332,59,332,102,332,103,332,108,332,109,332,137,332,138,332,139,332,145,332,146,332,148,332,149,332,150,332,151,332,152,332,153,332,154,332,155,332,156,332,157,332,158,332,159,332,162,332,195,332,196,332,200,332,201,332,202,332,204,332,238,332,244,332,245,332,277,332,284,332,294,332,306,332,307,332,336,332,337,332,338,332,343,332,356,332,373,332,374,332,375,332,376,332,31,333,58,333,59,333,102,333,108,333,109,333,149,333,150,333,151,333,152,333,153,333,154,333,155,333,156,333,195,333,201,333,203,333,204,333,238,333,244,333,245,333,306,333,307,333,336,333,337,333,357,333,373,333,31,334,58,334,102,334,103,334,108,334,109,334,148,334,150,334,151,334,152,334,153,334,155,334,203,334,238,334,244,334,245,334,335,334,336,334,358,334,31,335,102,335,103,335,108,335,109,335,238,335,244,335,245,335,307,335,334,335,335,335,336,335,358,335,44,336,86,336,101,336,102,336,103,336,108,336,109,336,159,336,160,336,161,336,162,336,163,336,164,336,165,336,166,336,167,336,168,336,169,336,170,336,171,336,172,336,173,336,174,336,175,336,176,336,177,336,238,336,244,336,245,336,307,336,334,336,335,336,357,336,358,336,359,336,48,337,61,337,64,337,71,337,73,337,75,337,76,337,77,337,79,337,101,337,102,337,108,337,151,337,153,337,154,337,178,337,206,337,207,337,209,337,210,337,211,337,212,337,213,337,215,337,217,337,218,337,238,337,244,337,245,337,286,337,287,337,288,337,289,337,290,337,291,337,292,337,293,337,294,337,295,337,296,337,297,337,298,337,299,337,300,337,301,337,302,337,303,337,304,337,305,337,334,337,335,337,358,337,359,337,108,338,109,338,178,338,238,338,244,338,245,338,314,338,334,338,335,338,358,338,359,338,108,339,109,339,178,339,238,339,244,339,245,339,314,339,334,339,335,339,359,339,373,339,374,339,102,340,108,340,109,340,178,340,238,340,244,340,245,340,305,340,313,340,314,340,316,340,317,340,318,340,334,340,335,340,359,340,373,340,46,341,60,341,102,341,108,341,109,341,178,341,197,341,238,341,244,341,245,341,305,341,312,341,313,341,314,341,335,341,336,341,359,341,373,341,382,341,60,342,102,342,108,342,109,342,178,342,197,342,238,342,244,342,245,342,305,342,312,342,313,342,335,342,336,342,373,342,381,342,382,342,383,342,59,343,60,343,102,343,108,343,109,343,178,343,196,343,197,343,238,343,244,343,245,343,305,343,306,343,311,343,312,343,336,343,372,343,373,343,382,343,383,343,31,344,32,344,33,344,34,344,35,344,36,344,37,344,38,344,39,344,40,344,41,344,42,344,43,344,44,344,47,344,58,344,59,344,60,344,102,344,108,344,109,344,124,344,157,344,178,344,195,344,196,344,197,344,238,344,244,344,245,344,284,344,311,344,312,344,323,344,337,344,371,344,373,344,374,344,376,344,378,344,379,344,380,344,381,344,382,344,383,344,31,345,39,345,40,345,42,345,44,345,46,345,47,345,57,345,58,345,59,345,60,345,76,345,77,345,79,345,80,345,81,345,82,345,83,345,84,345,85,345,108,345,109,345,124,345,157,345,178,345,180,345,194,345,195,345,196,345,197,345,238,345,244,345,245,345,284,345,311,345,321,345,322,345,371,345,373,345,374,345,376,345,377,345,378,345,379,345,380,345,381,345,382,345,383,345,384,345,31,346,38,346,39,346,40,346,41,346,42,346,43,346,46,346,47,346,57,346,58,346,59,346,60,346,76,346,108,346,109,346,157,346,178,346,179,346,180,346,194,346,195,346,196,346,197,346,238,346,244,346,245,346,284,346,311,346,321,346,322,346,324,346,370,346,374,346,375,346,378,346,379,346,380,346,381,346,382,346,384,346,31,347,40,347,41,347,42,347,43,347,44,347,46,347,47,347,57,347,60,347,76,347,102,347,108,347,109,347,138,347,139,347,178,347,179,347,180,347,194,347,195,347,196,347,197,347,238,347,244,347,245,347,284,347,305,347,313,347,320,347,321,347,322,347,323,347,371,347,378,347,379,347,380,347,381,347,382,347,383,347,31,348,40,348,42,348,43,348,44,348,46,348,47,348,57,348,60,348,76,348,108,348,109,348,139,348,178,348,179,348,180,348,194,348,196,348,197,348,238,348,244,348,245,348,305,348,318,348,320,348,321,348,322,348,323,348,324,348,371,348,380,348,381,348,382,348,383,348,384,348,31,349,39,349,40,349,42,349,43,349,44,349,46,349,47,349,57,349,60,349,76,349,101,349,108,349,109,349,139,349,178,349,179,349,180,349,197,349,238,349,244,349,245,349,261,349,305,349,307,349,319,349,320,349,321,349,322,349,368,349,370,349,371,349,372,349,382,349,383,349,384,349,31,350,41,350,42,350,43,350,44,350,45,350,46,350,47,350,57,350,59,350,60,350,76,350,108,350,109,350,139,350,140,350,179,350,180,350,197,350,238,350,244,350,245,350,261,350,284,350,305,350,307,350,320,350,321,350,366,350,367,350,368,350,370,350,371,350,384,350,11,351,31,351,39,351,40,351,42,351,43,351,44,351,45,351,46,351,47,351,57,351,59,351,60,351,76,351,101,351,102,351,108,351,109,351,139,351,140,351,179,351,180,351,197,351,238,351,244,351,245,351,261,351,305,351,307,351,320,351,365,351,366,351,371,351,372,351,11,352,31,352,42,352,43,352,44,352,45,352,46,352,47,352,57,352,59,352,60,352,76,352,101,352,102,352,108,352,109,352,110,352,139,352,140,352,178,352,179,352,180,352,196,352,197,352,237,352,244,352,245,352,246,352,261,352,304,352,320,352,363,352,364,352,365,352,371,352,373,352,11,353,12,353,13,353,31,353,43,353,44,353,45,353,46,353,47,353,57,353,58,353,59,353,60,353,76,353,100,353,108,353,109,353,110,353,139,353,140,353,141,353,178,353,179,353,180,353,194,353,196,353,197,353,236,353,244,353,245,353,261,353,285,353,303,353,320,353,321,353,332,353,333,353,361,353,362,353,363,353,372,353,10,354,11,354,12,354,13,354,14,354,31,354,44,354,45,354,46,354,57,354,58,354,59,354,60,354,63,354,76,354,102,354,108,354,109,354,111,354,139,354,140,354,141,354,178,354,179,354,180,354,194,354,196,354,235,354,244,354,245,354,248,354,261,354,284,354,285,354,286,354,320,354,321,354,322,354,323,354,329,354,335,354,336,354,358,354,361,354,372,354,10,355,11,355,12,355,13,355,14,355,31,355,43,355,44,355,45,355,47,355,57,355,58,355,59,355,60,355,62,355,76,355,98,355,103,355,108,355,111,355,139,355,140,355,141,355,178,355,179,355,180,355,194,355,195,355,196,355,234,355,244,355,249,355,261,355,284,355,285,355,286,355,287,355,320,355,321,355,322,355,323,355,324,355,327,355,328,355,332,355,333,355,334,355,335,355,336,355,337,355,338,355,339,355,354,355,371,355,372,355,10,356,11,356,12,356,13,356,14,356,15,356,27,356,28,356,29,356,57,356,58,356,59,356,61,356,62,356,97,356,108,356,110,356,111,356,138,356,139,356,140,356,141,356,142,356,161,356,162,356,163,356,166,356,168,356,169,356,171,356,173,356,176,356,177,356,179,356,180,356,194,356,195,356,196,356,233,356,244,356,250,356,252,356,253,356,254,356,255,356,256,356,257,356,258,356,259,356,260,356,261,356,284,356,285,356,286,356,287,356,288,356,319,356,320,356,321,356,322,356,323,356,324,356,325,356,326,356,327,356,328,356,333,356,334,356,335,356,336,356,337,356,338,356,339,356,340,356,343,356,345,356,346,356,348,356,349,356,359,356,360,356,363,356,369,356,370,356,371,356,372,356,373,356,9,357,10,357,11,357,12,357,13,357,14,357,15,357,31,357,57,357,58,357,59,357,60,357,61,357,62,357,63,357,64,357,69,357,70,357,71,357,72,357,73,357,74,357,75,357,87,357,88,357,89,357,90,357,91,357,92,357,93,357,94,357,95,357,108,357,109,357,110,357,111,357,112,357,113,357,140,357,141,357,142,357,158,357,179,357,194,357,195,357,196,357,204,357,208,357,209,357,210,357,218,357,219,357,221,357,222,357,223,357,225,357,227,357,229,357,247,357,248,357,261,357,284,357,285,357,286,357,287,357,288,357,289,357,290,357,291,357,292,357,294,357,295,357,296,357,297,357,298,357,319,357,320,357,321,357,322,357,323,357,324,357,325,357,326,357,327,357,328,357,331,357,332,357,333,357,334,357,335,357,336,357,337,357,338,357,339,357,340,357,351,357,353,357,354,357,355,357,359,357,361,357,364,357,367,357,368,357,369,357,370,357,371,357,372,357,373,357,9,358,10,358,11,358,12,358,13,358,14,358,15,358,31,358,57,358,58,358,59,358,60,358,61,358,62,358,63,358,64,358,65,358,108,358,109,358,110,358,111,358,112,358,113,358,140,358,141,358,142,358,158,358,179,358,194,358,195,358,197,358,198,358,199,358,200,358,245,358,246,358,247,358,248,358,249,358,261,358,284,358,285,358,286,358,287,358,288,358,289,358,318,358,319,358,320,358,321,358,322,358,323,358,324,358,325,358,326,358,327,358,328,358,331,358,332,358,333,358,334,358,335,358,336,358,337,358,338,358,339,358,340,358,354,358,356,358,357,358,358,358,361,358,364,358,365,358,366,358,367,358,368,358,369,358,370,358,371,358,372,358,373,358,8,359,9,359,10,359,11,359,12,359,13,359,14,359,31,359,57,359,58,359,59,359,60,359,61,359,62,359,63,359,64,359,65,359,66,359,90,359,93,359,95,359,108,359,109,359,110,359,111,359,112,359,113,359,140,359,141,359,142,359,179,359,194,359,195,359,196,359,197,359,198,359,199,359,200,359,245,359,246,359,247,359,248,359,249,359,261,359,284,359,285,359,286,359,287,359,288,359,289,359,318,359,319,359,320,359,321,359,322,359,323,359,324,359,325,359,326,359,327,359,328,359,331,359,332,359,333,359,334,359,335,359,336,359,337,359,338,359,339,359,340,359,352,359,353,359,354,359,355,359,356,359,357,359,358,359,359,359,360,359,364,359,365,359,366,359,367,359,368,359,369,359,370,359,371,359,372,359,373,359,8,360,9,360,10,360,11,360,12,360,13,360,14,360,31,360,57,360,58,360,59,360,60,360,61,360,62,360,63,360,64,360,65,360,66,360,71,360,87,360,90,360,108,360,109,360,110,360,111,360,112,360,113,360,141,360,142,360,194,360,196,360,197,360,198,360,199,360,200,360,246,360,247,360,248,360,249,360,261,360,284,360,285,360,286,360,287,360,288,360,289,360,294,360,318,360,319,360,320,360,321,360,322,360,323,360,324,360,325,360,326,360,327,360,331,360,332,360,333,360,334,360,335,360,336,360,337,360,338,360,339,360,340,360,341,360,350,360,352,360,354,360,355,360,356,360,357,360,358,360,360,360,365,360,366,360,367,360,368,360,369,360,370,360,371,360,372,360,373,360,8,361,9,361,10,361,11,361,12,361,13,361,14,361,31,361,57,361,58,361,59,361,60,361,61,361,62,361,63,361,64,361,65,361,87,361,92,361,93,361,94,361,108,361,109,361,110,361,111,361,112,361,113,361,120,361,141,361,142,361,157,361,166,361,167,361,168,361,169,361,194,361,196,361,197,361,198,361,199,361,200,361,224,361,245,361,246,361,247,361,248,361,249,361,255,361,256,361,257,361,261,361,284,361,285,361,286,361,287,361,288,361,289,361,319,361,320,361,321,361,322,361,323,361,324,361,325,361,333,361,334,361,335,361,336,361,337,361,338,361,339,361,340,361,341,361,352,361,353,361,354,361,355,361,357,361,358,361,360,361,366,361,367,361,369,361,370,361,371,361,372,361,373,361,374,361,7,362,8,362,9,362,10,362,11,362,12,362,13,362,14,362,31,362,57,362,58,362,59,362,60,362,61,362,62,362,63,362,64,362,65,362,72,362,75,362,87,362,89,362,92,362,109,362,110,362,111,362,112,362,113,362,115,362,116,362,122,362,131,362,141,362,142,362,157,362,167,362,168,362,169,362,171,362,196,362,197,362,198,362,199,362,200,362,207,362,221,362,224,362,229,362,246,362,247,362,248,362,254,362,255,362,256,362,257,362,283,362,284,362,285,362,286,362,287,362,288,362,289,362,294,362,320,362,321,362,322,362,323,362,324,362,325,362,330,362,333,362,334,362,336,362,337,362,338,362,339,362,341,362,342,362,343,362,344,362,345,362,346,362,347,362,348,362,349,362,353,362,355,362,358,362,360,362,361,362,362,362,366,362,367,362,368,362,369,362,370,362,371,362,372,362,373,362,374,362,7,363,8,363,9,363,10,363,11,363,12,363,13,363,31,363,57,363,58,363,59,363,60,363,61,363,62,363,63,363,64,363,72,363,75,363,87,363,91,363,109,363,110,363,111,363,112,363,113,363,114,363,115,363,116,363,121,363,122,363,142,363,143,363,157,363,161,363,196,363,197,363,198,363,199,363,200,363,201,363,222,363,223,363,224,363,228,363,246,363,247,363,248,363,253,363,254,363,255,363,256,363,257,363,283,363,284,363,285,363,286,363,287,363,288,363,289,363,303,363,321,363,322,363,323,363,324,363,327,363,334,363,335,363,336,363,337,363,338,363,339,363,340,363,341,363,342,363,343,363,344,363,345,363,346,363,347,363,348,363,349,363,356,363,357,363,358,363,367,363,368,363,369,363,370,363,371,363,372,363,373,363,374,363,7,364,8,364,9,364,10,364,11,364,12,364,13,364,31,364,57,364,58,364,59,364,60,364,61,364,62,364,63,364,64,364,75,364,87,364,93,364,94,364,95,364,109,364,110,364,111,364,112,364,113,364,114,364,115,364,116,364,121,364,123,364,142,364,143,364,161,364,165,364,169,364,196,364,197,364,198,364,199,364,200,364,209,364,222,364,223,364,224,364,226,364,246,364,247,364,248,364,255,364,256,364,257,364,258,364,283,364,284,364,285,364,286,364,287,364,288,364,289,364,292,364,301,364,303,364,322,364,323,364,324,364,336,364,337,364,338,364,339,364,341,364,342,364,343,364,344,364,345,364,346,364,347,364,349,364,353,364,361,364,367,364,368,364,370,364,371,364,372,364,8,365,9,365,10,365,11,365,12,365,13,365,31,365,58,365,59,365,60,365,61,365,62,365,63,365,64,365,73,365,75,365,87,365,89,365,90,365,110,365,111,365,113,365,114,365,115,365,117,365,123,365,142,365,143,365,166,365,168,365,196,365,197,365,198,365,199,365,200,365,222,365,223,365,224,365,226,365,229,365,247,365,248,365,255,365,256,365,257,365,258,365,284,365,285,365,286,365,287,365,288,365,289,365,302,365,303,365,306,365,339,365,340,365,341,365,342,365,343,365,344,365,345,365,346,365,347,365,348,365,357,365,365,365,367,365,368,365,370,365,372,365,9,366,10,366,11,366,12,366,13,366,31,366,59,366,60,366,61,366,62,366,63,366,65,366,66,366,70,366,71,366,89,366,114,366,115,366,120,366,131,366,134,366,135,366,143,366,156,366,161,366,197,366,198,366,199,366,209,366,222,366,223,366,224,366,226,366,229,366,248,366,254,366,285,366,286,366,287,366,288,366,289,366,292,366,295,366,340,366,341,366,342,366,343,366,344,366,345,366,346,366,347,366,348,366,349,366,367,366,368,366,10,367,11,367,12,367,31,367,60,367,61,367,62,367,63,367,65,367,89,367,93,367,95,367,109,367,115,367,116,367,117,367,120,367,131,367,132,367,135,367,136,367,143,367,156,367,161,367,197,367,198,367,246,367,287,367,288,367,289,367,304,367,341,367,342,367,343,367,344,367,345,367,346,367,347,367,348,367,349,367,11,368,12,368,31,368,61,368,62,368,117,368,118,368,120,368,132,368,135,368,138,368,247,368,287,368,288,368,289,368,303,368,341,368,342,368,343,368,344,368,345,368,346,368,347,368,348,368,349,368,12,369,31,369,133,369,156,369,288,369,302,369,341,369,342,369,343,369,344,369,345,369,346,369,347,369,348,369,349,369,13,370,14,370,23,370,67,370,69,370,71,370,72,370,89,370,90,370,91,370,93,370,95,370,96,370,97,370,98,370,115,370,116,370,117,370,119,370,120,370,121,370,122,370,127,370,128,370,129,370,130,370,132,370,133,370,134,370,138,370,159,370,200,370,205,370,207,370,208,370,209,370,210,370,211,370,212,370,213,370,214,370,215,370,216,370,217,370,218,370,219,370,220,370,221,370,222,370,223,370,224,370,225,370,226,370,227,370,232,370,236,370,250,370,251,370,252,370,253,370,256,370,259,370,290,370,291,370,292,370,294,370,296,370,299,370,342,370,343,370,344,370,345,370,346,370,347,370,348,370,349,370,342,371,343,371,344,371,345,371,346,371,348,371}
listgrass2 = {235,53,238,54,224,67,232,70,249,80,189,81,254,86,235,89,240,92,198,104,215,105,145,111,276,111,199,112,283,112,192,113,200,113,204,113,190,114,209,114,187,115,179,116,147,117,176,117,177,117,178,117,241,117,171,121,170,122,169,123,249,123,142,124,167,125,144,126,286,126,163,128,163,129,161,130,146,132,160,133,156,135,156,136,157,136,139,138,156,138,311,138,139,139,140,139,141,139,156,140,137,142,138,143,154,143,140,146,141,147,151,149,151,151,292,151,152,153,140,155,136,157,326,158,261,165,80,167,140,170,154,178,141,179,156,182,131,184,317,184,251,187,252,187,105,191,162,191,163,191,143,195,113,196,210,205,194,210,161,211,113,212,186,212,196,212,113,213,180,214,121,221,114,222,269,222,267,224,124,227,276,227,126,228,127,233,128,233,162,233,251,234,158,235,285,238,103,244,294,244,109,250,262,251,114,253,284,254,272,255,280,257,263,259,275,262,272,263,269,264,271,265,270,267,274,271,275,272,275,274,275,275,275,276,276,276,277,277,205,283,52,319,189,319,52,320,140,320,60,321,146,321,196,321,305,321,306,321,305,322,306,322,238,323,278,323,279,323,305,323,306,323,238,324,305,324,306,324,307,324,305,325,306,325,325,325,305,326,101,328,322,328,348,328,374,328,376,328,35,329,38,329,349,329,377,329,64,330,65,330,69,330,70,330,72,330,201,330,202,330,205,330,208,330,209,330,211,330,216,330,222,330,304,330,86,331,372,331,86,334,62,337,63,337,65,337,66,337,67,337,68,337,69,337,70,337,72,337,74,337,78,337,123,337,204,337,360,338,360,339,381,340,382,340,101,341,381,341,383,341,337,343,375,343,381,343,101,344,384,344,339,345,7,346,383,346,101,347,384,347,59,349,178,350,369,350,178,351,284,351,62,353,284,353,302,354,113,355,142,355,319,355,160,356,164,356,165,356,175,356,251,356,347,356,365,357,143,358,157,360,156,364,156,365,338,365}
listgrass3 = {208,16,214,16,219,17,220,17,221,17,222,17,223,17,223,18,233,19,226,20,226,21,250,22,251,22,253,22,258,23,263,24,268,25,227,26,227,27,274,27,227,28,227,31,228,35,275,35,128,41,137,42,138,42,139,42,140,42,141,42,145,43,146,43,147,43,148,43,149,43,122,44,169,49,231,49,166,50,233,50,164,51,235,52,239,53,278,54,296,54,298,54,152,55,291,55,245,56,246,56,298,56,312,56,283,57,300,58,327,58,328,58,329,58,330,58,331,58,256,61,281,61,303,61,258,62,276,64,263,65,274,65,339,65,265,66,308,66,340,66,271,67,311,70,346,73,315,75,316,81,317,81,351,81,351,82,314,85,313,86,345,90,303,98,300,103,297,104,300,104,302,111,193,113,197,113,303,113,197,114,206,114,186,115,190,115,206,115,304,115,341,115,181,116,182,116,185,116,153,117,215,117,305,117,342,118,174,119,175,119,178,119,176,120,173,121,170,124,308,126,166,127,308,127,345,127,345,128,164,129,309,129,309,130,310,133,206,135,312,142,313,144,155,145,153,146,318,146,357,146,154,147,321,147,322,147,361,147,324,148,325,148,153,150,153,151,153,152,202,152,244,153,152,154,151,155,136,156,135,158,152,158,152,159,202,162,244,166,60,168,61,168,153,168,153,169,326,170,326,171,372,171,154,172,155,175,341,175,87,176,155,177,371,177,155,178,206,178,371,178,371,179,156,180,207,180,157,181,341,181,341,182,158,183,341,183,325,184,160,186,345,186,162,189,163,190,213,190,312,191,313,191,314,191,166,193,287,193,309,194,342,194,308,196,341,197,171,198,222,199,175,200,305,203,184,204,212,204,187,205,188,205,208,205,209,205,304,205,193,206,194,206,195,206,204,206,303,207,163,208,335,209,298,217,331,217,330,225,293,226,332,229,335,234,294,237,144,244,298,244,151,247,300,247,297,252,303,252,126,253,127,253,128,253,125,254,132,255,305,256,305,257,118,258,176,262,248,264,259,264,273,264,299,264,246,265,260,265,298,265,263,268,264,268,235,269,265,269,232,270,291,271,217,274,218,274,287,274,215,275,259,280,212,281,259,281,211,284,211,285,258,285,210,288,210,289,207,301,188,303,307,321,364,321,365,321,104,322,240,322,241,322,281,322,282,322,307,322,311,322,366,322,108,323,244,323,307,323,315,323,320,324,380,327,377,328,378,330,322,331,389,332,388,333,387,334,386,335,386,336,277,338,352,338,277,339,277,340,350,340,277,341,349,341,277,342,389,342,277,343,390,343,49,344,277,344,348,344,395,344,277,345,310,345,348,345,385,345,277,346,348,346,277,347,277,348,396,348,277,349,392,349,393,349,394,349,395,349,277,350,277,351,277,352,387,352,55,353,277,353,51,354,142,354,143,354,144,354,145,354,146,354,147,354,148,354,149,354,150,354,151,354,152,354,153,354,277,354,277,355,385,355,277,356,384,356,277,357,384,357,277,358,277,359,277,360,277,361,277,362,386,362,277,363,318,364,45,365,275,365,317,365,378,365,42,366,153,366,272,366,314,366,373,366,39,367,86,367,150,367,188,367,311,367,36,368,82,368,105,368,185,368,242,368,307,368,364,368,33,369,77,369,78,369,102,369,145,369,182,369,239,369,304,369,361,369,362,369,356,370,357,370,351,371}
listgrass4 = {221,18,227,30,228,38,230,49,232,50,241,54,153,55,227,56,247,57,142,59,225,62,264,66,315,82,314,83,315,83,313,84,308,86,309,86,310,86,311,86,307,87,308,87,309,87,310,87,311,87,308,88,309,88,310,88,304,89,306,89,307,89,308,89,309,89,304,90,305,90,306,90,307,90,308,90,309,90,110,91,303,91,304,91,305,91,306,91,307,91,308,91,110,92,301,92,302,92,303,92,304,92,305,92,306,92,307,92,300,93,301,93,302,93,303,93,304,93,305,93,306,93,116,94,301,94,302,94,304,94,305,94,299,95,300,95,301,95,302,95,303,95,304,95,297,96,298,96,299,96,300,96,301,96,302,96,303,96,304,96,296,97,297,97,298,97,299,97,300,97,301,97,302,97,296,98,297,98,298,98,299,98,300,98,301,98,296,99,297,99,298,99,299,99,300,99,301,99,296,100,297,100,298,100,299,100,301,100,293,101,294,101,295,101,296,101,297,101,298,101,299,101,300,101,294,102,295,102,296,102,297,102,298,102,299,102,291,103,292,103,293,103,294,103,295,103,296,103,297,103,298,103,291,104,292,104,293,104,294,104,295,104,296,104,298,104,290,105,291,105,292,105,293,105,294,105,295,105,296,105,290,106,291,106,292,106,293,106,294,106,296,106,300,106,290,107,292,107,293,107,294,107,298,107,299,107,288,108,289,108,300,108,288,109,287,110,288,110,287,111,288,111,297,111,298,111,288,112,290,112,287,113,288,113,293,113,294,113,191,114,192,114,203,114,204,114,205,114,287,114,291,114,188,115,209,115,210,115,290,115,292,115,303,115,287,116,288,117,178,118,288,118,300,118,291,120,291,121,290,122,292,122,304,123,169,124,290,124,292,124,168,125,167,126,295,128,308,128,294,129,293,130,293,133,294,133,296,133,160,134,296,134,158,136,157,138,297,138,297,139,310,139,311,139,296,140,297,140,300,140,296,142,297,143,312,143,296,144,297,144,298,144,154,145,297,145,313,145,297,146,298,146,299,146,314,146,315,146,316,146,297,147,298,147,299,147,316,147,319,147,320,147,153,148,297,148,323,148,153,149,297,149,152,155,335,155,338,155,340,156,327,158,328,159,151,161,342,164,151,165,69,167,71,167,76,167,152,167,59,168,64,168,65,168,66,168,67,168,68,168,69,168,70,168,71,168,72,168,73,168,75,168,76,168,77,168,78,168,80,168,81,168,340,168,65,169,66,169,67,169,68,169,69,169,70,169,71,169,72,169,73,169,75,169,76,169,78,169,79,169,80,169,81,169,82,169,84,169,87,169,333,169,70,170,71,170,72,170,73,170,74,170,76,170,77,170,78,170,79,170,80,170,81,170,82,170,83,170,84,170,85,170,86,170,90,170,92,170,93,170,94,170,101,170,329,170,72,171,73,171,74,171,75,171,76,171,77,171,78,171,79,171,80,171,81,171,82,171,83,171,84,171,85,171,87,171,88,171,89,171,90,171,91,171,93,171,94,171,95,171,97,171,98,171,99,171,153,171,329,171,330,171,76,172,77,172,78,172,79,172,80,172,81,172,82,172,83,172,84,172,85,172,86,172,87,172,88,172,89,172,90,172,91,172,92,172,153,172,81,173,83,173,88,173,89,173,90,173,91,173,92,173,93,173,94,173,328,173,86,174,89,174,91,174,86,175,87,175,154,175,340,175,86,176,154,176,331,176,339,176,339,177,328,178,333,178,339,178,156,179,327,180,328,180,334,180,338,180,340,180,341,180,329,181,336,181,157,182,298,182,329,182,330,182,336,182,330,183,339,183,158,184,297,184,334,184,297,185,311,185,313,185,314,185,315,185,319,185,320,185,324,185,325,185,327,185,329,185,332,185,333,185,334,185,292,186,316,186,328,186,331,186,332,186,333,186,334,186,339,186,294,187,299,187,300,187,293,188,294,188,297,188,298,188,299,188,330,188,332,188,333,188,334,188,335,188,336,188,337,188,291,189,293,189,296,189,297,189,298,189,299,189,300,189,323,189,324,189,325,189,326,189,327,189,328,189,329,189,330,189,293,190,296,190,297,190,298,190,299,190,300,190,301,190,315,190,316,190,317,190,318,190,319,190,320,190,321,190,292,191,293,191,295,191,296,191,297,191,298,191,299,191,300,191,301,191,303,191,292,192,293,192,294,192,296,192,297,192,299,192,300,192,301,192,302,192,291,193,292,193,294,193,295,193,296,193,297,193,299,193,309,193,294,194,295,194,296,194,297,194,298,194,299,194,302,194,292,195,295,195,296,195,298,195,299,195,302,195,289,196,290,196,291,196,292,196,294,196,295,196,296,196,307,196,289,197,291,197,292,197,293,197,295,197,296,197,297,197,307,197,287,198,289,198,291,198,293,198,294,198,297,198,298,198,287,199,289,199,290,199,291,199,292,199,293,199,294,199,295,199,297,199,298,199,299,199,306,199,288,200,290,200,292,200,294,200,295,200,297,200,298,200,299,200,287,201,290,201,291,201,294,201,295,201,296,201,298,201,299,201,300,201,305,201,285,202,287,202,289,202,290,202,292,202,293,202,294,202,296,202,297,202,298,202,299,202,300,202,305,202,285,203,286,203,287,203,289,203,291,203,292,203,293,203,294,203,295,203,296,203,297,203,304,203,286,204,289,204,290,204,291,204,293,204,294,204,295,204,296,204,297,204,303,204,304,204,283,205,288,205,289,205,290,205,291,205,293,205,294,205,295,205,296,205,297,205,299,205,283,206,286,206,287,206,288,206,289,206,290,206,291,206,292,206,293,206,294,206,296,206,299,206,300,206,303,206,283,207,285,207,287,207,288,207,289,207,290,207,291,207,292,207,296,207,298,207,299,207,300,207,284,208,285,208,287,208,288,208,290,208,294,208,295,208,296,208,297,208,298,208,302,208,284,209,285,209,286,209,287,209,288,209,289,209,290,209,292,209,293,209,294,209,295,209,297,209,281,210,284,210,285,210,286,210,287,210,289,210,290,210,291,210,293,210,294,210,295,210,299,210,300,210,301,210,282,211,283,211,287,211,288,211,289,211,291,211,293,211,295,211,296,211,301,211,282,212,286,212,287,212,288,212,289,212,290,212,292,212,293,212,294,212,295,212,296,212,300,212,282,213,284,213,285,213,286,213,287,213,288,213,289,213,290,213,293,213,294,213,295,213,298,213,299,213,300,213,280,214,281,214,282,214,284,214,285,214,286,214,287,214,288,214,290,214,292,214,293,214,294,214,297,214,298,214,299,214,282,215,283,215,286,215,287,215,292,215,293,215,294,215,295,215,296,215,297,215,282,216,283,216,284,216,287,216,288,216,291,216,292,216,293,216,294,216,295,216,296,216,297,216,298,216,285,217,287,217,288,217,289,217,290,217,291,217,292,217,293,217,296,217,297,217,281,218,282,218,285,218,286,218,287,218,288,218,289,218,290,218,291,218,293,218,296,218,297,218,279,219,280,219,281,219,282,219,284,219,285,219,286,219,287,219,288,219,289,219,291,219,292,219,293,219,294,219,296,219,278,220,279,220,280,220,281,220,282,220,284,220,285,220,286,220,287,220,288,220,289,220,290,220,291,220,293,220,294,220,296,220,277,221,278,221,279,221,280,221,285,221,286,221,287,221,288,221,289,221,290,221,292,221,293,221,294,221,278,222,279,222,280,222,281,222,283,222,284,222,285,222,286,222,287,222,290,222,291,222,293,222,294,222,281,223,283,223,284,223,285,223,286,223,287,223,288,223,289,223,290,223,291,223,292,223,294,223,279,224,280,224,281,224,282,224,283,224,284,224,285,224,286,224,287,224,288,224,289,224,292,224,282,225,283,225,284,225,286,225,287,225,288,225,289,225,291,225,293,225,283,226,284,226,285,226,286,226,291,226,292,226,284,227,285,227,286,227,289,227,286,228,289,228,291,228,288,229,290,229,290,230,271,231,284,231,290,231,270,232,285,232,277,233,291,233,292,235,291,237,292,237,264,238,265,238,292,238,294,238,92,239,264,239,294,239,138,240,139,240,140,240,262,240,294,240,295,240,99,241,260,241,261,241,296,241,136,242,137,242,138,242,139,242,140,242,142,242,143,242,296,242,98,243,130,243,131,243,138,243,141,243,143,243,144,243,145,243,296,243,129,244,138,244,139,244,140,244,296,244,297,244,102,245,127,245,128,245,136,245,138,245,143,245,144,245,145,245,147,245,298,245,132,246,137,246,140,246,141,246,143,246,146,246,148,246,149,246,150,246,292,246,96,247,125,247,135,247,136,247,137,247,141,247,142,247,145,247,146,247,148,247,150,247,292,247,299,247,87,248,132,248,133,248,134,248,138,248,139,248,142,248,143,248,144,248,145,248,146,248,147,248,149,248,151,248,152,248,154,248,246,248,251,248,291,248,292,248,293,248,294,248,298,248,87,249,135,249,136,249,139,249,141,249,142,249,144,249,145,249,146,249,148,249,149,249,150,249,151,249,152,249,154,249,155,249,156,249,157,249,158,249,162,249,243,249,244,249,247,249,248,249,251,249,290,249,291,249,293,249,295,249,300,249,138,250,139,250,140,250,141,250,142,250,143,250,144,250,146,250,147,250,148,250,149,250,150,250,152,250,154,250,157,250,158,250,162,250,163,250,164,250,242,250,244,250,246,250,289,250,290,250,291,250,292,250,295,250,296,250,297,250,300,250,301,250,106,251,109,251,119,251,137,251,138,251,139,251,141,251,143,251,144,251,145,251,146,251,147,251,149,251,150,251,151,251,152,251,154,251,155,251,156,251,157,251,158,251,160,251,161,251,238,251,243,251,244,251,289,251,290,251,291,251,294,251,295,251,296,251,297,251,301,251,106,252,117,252,127,252,128,252,138,252,139,252,140,252,141,252,142,252,143,252,145,252,146,252,147,252,148,252,149,252,150,252,151,252,152,252,153,252,157,252,158,252,159,252,161,252,163,252,228,252,234,252,235,252,236,252,237,252,238,252,239,252,241,252,242,252,244,252,245,252,246,252,287,252,291,252,292,252,293,252,294,252,296,252,299,252,302,252,90,253,108,253,125,253,130,253,140,253,143,253,146,253,147,253,148,253,149,253,150,253,151,253,153,253,154,253,155,253,156,253,157,253,158,253,160,253,161,253,162,253,163,253,164,253,165,253,173,253,230,253,231,253,286,253,287,253,288,253,289,253,290,253,291,253,293,253,294,253,295,253,296,253,297,253,298,253,299,253,301,253,303,253,93,254,98,254,104,254,105,254,109,254,112,254,113,254,114,254,124,254,132,254,141,254,143,254,144,254,145,254,148,254,149,254,150,254,151,254,152,254,153,254,154,254,155,254,157,254,158,254,159,254,160,254,161,254,162,254,163,254,164,254,165,254,226,254,227,254,228,254,231,254,232,254,233,254,234,254,235,254,239,254,240,254,242,254,255,254,256,254,285,254,287,254,288,254,289,254,290,254,291,254,292,254,294,254,295,254,296,254,298,254,301,254,96,255,104,255,109,255,110,255,112,255,113,255,114,255,122,255,134,255,142,255,144,255,147,255,148,255,149,255,150,255,151,255,152,255,153,255,154,255,155,255,156,255,158,255,161,255,162,255,164,255,165,255,166,255,167,255,168,255,169,255,170,255,217,255,225,255,226,255,230,255,232,255,284,255,285,255,287,255,288,255,289,255,290,255,291,255,292,255,293,255,294,255,295,255,296,255,297,255,298,255,299,255,300,255,301,255,302,255,304,255,95,256,103,256,104,256,108,256,110,256,111,256,120,256,135,256,144,256,145,256,146,256,147,256,148,256,149,256,150,256,151,256,152,256,153,256,154,256,155,256,156,256,157,256,158,256,160,256,161,256,162,256,163,256,164,256,165,256,166,256,167,256,168,256,170,256,171,256,222,256,225,256,226,256,227,256,228,256,236,256,258,256,282,256,283,256,286,256,287,256,288,256,289,256,290,256,291,256,292,256,293,256,294,256,295,256,296,256,297,256,298,256,299,256,300,256,301,256,303,256,304,256,103,257,110,257,111,257,119,257,137,257,143,257,145,257,146,257,147,257,148,257,150,257,151,257,154,257,156,257,157,257,158,257,159,257,160,257,161,257,162,257,164,257,165,257,166,257,167,257,168,257,169,257,170,257,171,257,218,257,219,257,220,257,221,257,222,257,225,257,226,257,230,257,235,257,260,257,281,257,283,257,284,257,285,257,286,257,288,257,289,257,291,257,292,257,293,257,294,257,295,257,296,257,298,257,299,257,300,257,301,257,302,257,304,257,95,258,99,258,100,258,109,258,110,258,139,258,150,258,151,258,152,258,153,258,154,258,155,258,157,258,159,258,160,258,161,258,162,258,163,258,164,258,165,258,166,258,167,258,168,258,170,258,214,258,217,258,221,258,225,258,227,258,229,258,239,258,260,258,261,258,280,258,282,258,283,258,284,258,285,258,287,258,288,258,289,258,290,258,291,258,292,258,293,258,294,258,295,258,296,258,297,258,299,258,302,258,95,259,96,259,98,259,102,259,108,259,109,259,115,259,141,259,151,259,152,259,153,259,154,259,155,259,156,259,157,259,158,259,159,259,160,259,161,259,162,259,163,259,165,259,166,259,167,259,168,259,171,259,214,259,222,259,223,259,225,259,226,259,233,259,234,259,262,259,279,259,280,259,281,259,282,259,283,259,284,259,285,259,286,259,287,259,288,259,289,259,291,259,292,259,293,259,294,259,295,259,296,259,299,259,300,259,96,260,107,260,108,260,113,260,114,260,152,260,153,260,154,260,155,260,156,260,157,260,158,260,159,260,160,260,161,260,162,260,163,260,164,260,165,260,166,260,167,260,168,260,169,260,170,260,171,260,173,260,217,260,218,260,220,260,222,260,239,260,277,260,278,260,280,260,282,260,283,260,284,260,285,260,286,260,288,260,289,260,291,260,292,260,293,260,294,260,296,260,298,260,302,260,107,261,112,261,153,261,154,261,155,261,156,261,157,261,158,261,159,261,160,261,161,261,162,261,163,261,166,261,167,261,168,261,169,261,170,261,171,261,172,261,177,261,181,261,182,261,220,261,222,261,230,261,231,261,254,261,255,261,256,261,278,261,279,261,280,261,281,261,282,261,283,261,284,261,286,261,287,261,288,261,289,261,290,261,291,261,292,261,293,261,294,261,295,261,296,261,298,261,299,261,301,261,100,262,101,262,105,262,106,262,110,262,151,262,154,262,155,262,156,262,157,262,158,262,159,262,160,262,161,262,162,262,163,262,164,262,166,262,167,262,169,262,170,262,171,262,180,262,187,262,188,262,219,262,224,262,233,262,251,262,252,262,257,262,265,262,266,262,276,262,278,262,279,262,280,262,281,262,283,262,284,262,285,262,286,262,288,262,289,262,290,262,291,262,292,262,293,262,294,262,295,262,296,262,297,262,298,262,300,262,104,263,155,263,156,263,158,263,159,263,160,263,161,263,162,263,163,263,165,263,166,263,167,263,168,263,170,263,171,263,196,263,201,263,208,263,221,263,222,263,224,263,226,263,249,263,267,263,274,263,277,263,278,263,279,263,280,263,281,263,282,263,283,263,284,263,285,263,286,263,287,263,289,263,290,263,291,263,292,263,293,263,295,263,297,263,298,263,299,263,104,264,158,264,159,264,160,264,161,264,162,264,164,264,165,264,166,264,168,264,169,264,170,264,213,264,224,264,277,264,278,264,279,264,280,264,282,264,283,264,284,264,285,264,286,264,287,264,288,264,289,264,290,264,291,264,292,264,293,264,294,264,296,264,297,264,298,264,103,265,158,265,160,265,161,265,163,265,164,265,165,265,170,265,224,265,225,265,228,265,244,265,261,265,272,265,273,265,275,265,276,265,277,265,278,265,279,265,280,265,281,265,282,265,283,265,284,265,285,265,286,265,288,265,289,265,290,265,292,265,293,265,296,265,159,266,163,266,164,266,166,266,172,266,214,266,241,266,242,266,262,266,272,266,273,266,275,266,276,266,277,266,278,266,279,266,280,266,283,266,284,266,285,266,286,266,288,266,289,266,291,266,292,266,293,266,294,266,295,266,160,267,163,267,167,267,168,267,213,267,239,267,263,267,273,267,275,267,277,267,278,267,279,267,281,267,282,267,283,267,284,267,285,267,286,267,287,267,288,267,289,267,290,267,291,267,292,267,294,267,295,267,163,268,168,268,236,268,273,268,274,268,275,268,278,268,279,268,281,268,282,268,283,268,284,268,285,268,286,268,287,268,288,268,289,268,172,269,233,269,234,269,266,269,274,269,277,269,279,269,280,269,281,269,282,269,283,269,284,269,285,269,286,269,287,269,229,270,230,270,231,270,267,270,275,270,276,270,277,270,278,270,279,270,280,270,281,270,282,270,283,270,284,270,285,270,286,270,287,270,288,270,290,270,291,270,208,271,225,271,226,271,227,271,228,271,275,271,277,271,278,271,279,271,280,271,281,271,282,271,283,271,284,271,286,271,287,271,290,271,208,272,222,272,223,272,224,272,276,272,278,272,279,272,280,272,281,272,283,272,284,272,289,272,219,273,271,273,276,273,280,273,281,273,282,273,283,273,284,273,285,273,173,274,216,274,283,274,284,274,173,275,214,275,277,275,278,275,279,275,281,275,285,275,213,276,278,276,279,276,281,276,282,276,212,278,212,279,207,280,206,281,170,282,211,283,205,286,210,286,171,287,178,287,179,287,180,287,181,287,182,287,183,287,184,287,185,287,186,287,194,287,195,287,201,287,205,287,171,288,179,288,180,288,181,288,182,288,183,288,186,288,190,288,194,288,195,288,196,288,197,288,198,288,200,288,201,288,205,288,172,289,177,289,178,289,180,289,181,289,182,289,183,289,184,289,187,289,188,289,189,289,190,289,192,289,194,289,195,289,198,289,201,289,202,289,204,289,176,290,177,290,178,290,179,290,180,290,182,290,183,290,185,290,186,290,187,290,188,290,189,290,190,290,191,290,192,290,194,290,195,290,197,290,199,290,202,290,203,290,204,290,209,290,176,291,177,291,178,291,179,291,180,291,182,291,184,291,185,291,186,291,187,291,188,291,189,291,190,291,191,291,194,291,195,291,200,291,201,291,202,291,203,291,204,291,175,292,176,292,177,292,178,292,179,292,180,292,181,292,185,292,186,292,188,292,189,292,190,292,191,292,192,292,193,292,194,292,195,292,197,292,200,292,201,292,202,292,204,292,205,292,175,293,176,293,177,293,178,293,179,293,180,293,181,293,182,293,183,293,185,293,186,293,187,293,188,293,189,293,191,293,192,293,193,293,194,293,195,293,196,293,197,293,200,293,201,293,203,293,204,293,208,293,174,294,175,294,176,294,177,294,178,294,179,294,180,294,182,294,183,294,184,294,185,294,186,294,187,294,188,294,189,294,190,294,191,294,192,294,193,294,196,294,197,294,199,294,201,294,202,294,203,294,204,294,208,294,174,295,175,295,177,295,178,295,179,295,180,295,181,295,182,295,184,295,185,295,186,295,187,295,188,295,189,295,190,295,191,295,192,295,193,295,194,295,195,295,196,295,197,295,198,295,201,295,202,295,203,295,208,295,174,296,175,296,176,296,177,296,178,296,180,296,183,296,184,296,185,296,186,296,187,296,188,296,189,296,190,296,191,296,192,296,193,296,194,296,195,296,196,296,197,296,198,296,201,296,202,296,203,296,204,296,205,296,206,296,207,296,174,297,175,297,176,297,177,297,178,297,179,297,180,297,181,297,182,297,183,297,185,297,188,297,189,297,190,297,191,297,192,297,193,297,194,297,195,297,196,297,197,297,198,297,201,297,202,297,203,297,207,297,174,298,175,298,176,298,178,298,179,298,180,298,181,298,183,298,184,298,185,298,186,298,187,298,188,298,190,298,191,298,192,298,193,298,194,298,195,298,196,298,197,298,201,298,202,298,203,298,204,298,207,298,174,299,175,299,176,299,179,299,180,299,182,299,183,299,184,299,185,299,187,299,189,299,190,299,191,299,192,299,193,299,194,299,195,299,196,299,197,299,198,299,200,299,201,299,202,299,203,299,204,299,207,299,172,300,173,300,174,300,175,300,176,300,178,300,179,300,180,300,183,300,185,300,186,300,187,300,188,300,189,300,190,300,192,300,194,300,195,300,196,300,197,300,199,300,204,300,205,300,206,300,175,301,176,301,177,301,178,301,179,301,180,301,181,301,182,301,186,301,187,301,189,301,190,301,193,301,194,301,195,301,196,301,199,301,200,301,201,301,202,301,204,301,205,301,206,301,180,302,182,302,183,302,185,302,186,302,187,302,188,302,191,302,192,302,193,302,197,302,198,302,200,302,201,302,202,302,205,302,206,302,186,303,187,303,189,303,191,303,192,303,193,303,196,303,197,303,199,303,201,303,202,303,204,303,205,303,56,321,193,321,284,324,241,325,307,325,105,326,242,326,307,326,106,327,307,327,376,327,307,328,307,329,307,330,307,331,378,331,377,332,376,333,307,334,375,334,49,337,50,337,51,337,52,337,53,337,54,337,55,337,56,337,57,337,58,337,59,337,60,337,142,337,144,337,150,337,152,337,155,337,156,337,157,337,179,337,180,337,181,337,182,337,183,337,184,337,185,337,186,337,187,337,188,337,189,337,190,337,191,337,192,337,193,337,194,337,195,337,196,337,197,337,198,337,278,337,279,337,280,337,281,337,282,337,283,337,284,337,285,337,307,337,346,337,347,337,348,337,349,337,350,337,45,338,125,338,342,338,343,338,354,338,125,339,340,339,46,340,125,340,339,340,125,341,338,341,125,342,337,342,47,343,125,343,125,344,56,346,193,346,307,346,56,347,193,347,307,347,311,347,312,347,56,348,307,348,316,348,317,348,56,349,140,349,48,350,56,350,319,350,48,351,56,351,377,351,378,351,379,351,380,351,381,351,12,352,48,352,56,352,61,352,376,352,48,353,56,353,181,353,193,353,247,353,48,354,181,354,193,354,375,354,15,355,46,355,181,355,193,355,374,355,65,356,181,356,193,356,76,357,181,357,76,358,181,358,193,358,76,359,143,359,181,359,193,359,374,359,143,360,181,360,317,360,374,360,143,361,181,361,193,361,318,361,143,362,181,362,193,362,319,362,375,362,181,363,193,363,328,363,331,363,332,363,375,363,106,364,181,364,193,364,307,364,325,364,335,364,362,364,363,364,374,364,105,365,181,365,194,365,242,365,358,365,359,365,364,365,373,365,75,366,87,366,104,366,181,366,195,366,241,366,244,366,353,366,354,366,355,366,371,366,75,367,87,367,103,367,181,367,240,367,369,367,75,368,102,368,143,368,156,368,181,368,239,368,351,368,75,369,101,369,143,369,181,369,238,369,248,369,351,369,31,370,74,370,99,370,114,370,141,370,142,370,180,370,261,370,289,370,300,370,301,370,350,371}
listlabdark1 = {302,98,300,100,280,102,293,102,194,104,200,104,290,104,299,104,194,105,289,105,298,105,299,105,172,106,194,106,204,106,289,106,298,106,299,106,288,107,289,107,184,109,178,110,188,110,177,111,178,111,220,111,172,113,173,113,171,114,163,115,164,115,175,115,174,116,162,117,287,117,167,118,164,119,164,120,163,121,159,122,162,123,290,123,160,124,161,124,156,125,287,126,157,128,158,129,293,129,157,131,152,132,153,135,153,136,153,137,153,138,154,139,146,142,147,142,146,143,149,143,144,147,144,148,148,150,148,151,296,153,143,155,148,155,299,155,143,156,299,156,144,159,145,159,146,159,297,159,298,160,147,161,298,161,298,162,147,166,298,168,83,169,298,169,69,170,87,170,89,170,298,170,92,171,96,171,298,171,93,172,94,172,97,172,297,172,82,173,84,173,85,173,86,173,87,173,297,173,298,173,84,174,85,174,87,174,88,174,90,174,297,174,298,174,85,175,296,175,297,175,296,176,297,176,297,177,295,181,295,182,296,182,294,183,293,184,295,184,296,184,326,184,294,185,295,185,296,185,316,185,317,185,318,185,321,185,322,185,323,185,326,185,294,186,295,186,296,186,297,186,298,186,299,186,300,186,301,186,302,186,303,186,304,186,305,186,306,186,307,186,308,186,309,186,310,186,311,186,312,186,313,186,314,186,315,186,317,186,318,186,319,186,320,186,321,186,322,186,323,186,324,186,325,186,326,186,327,186,329,186,330,186,292,187,295,187,296,187,297,187,298,187,301,187,302,187,303,187,304,187,305,187,306,187,307,187,308,187,309,187,310,187,311,187,312,187,313,187,314,187,315,187,316,187,317,187,318,187,319,187,320,187,321,187,322,187,323,187,324,187,325,187,326,187,327,187,328,187,329,187,330,187,331,187,332,187,333,187,334,187,335,187,336,187,337,187,292,188,295,188,296,188,300,188,301,188,302,188,303,188,304,188,305,188,306,188,307,188,308,188,309,188,310,188,311,188,312,188,313,188,314,188,315,188,316,188,317,188,318,188,319,188,320,188,321,188,322,188,323,188,324,188,325,188,326,188,327,188,328,188,329,188,331,188,292,189,294,189,295,189,301,189,302,189,303,189,304,189,305,189,306,189,307,189,308,189,309,189,310,189,311,189,312,189,313,189,314,189,315,189,316,189,317,189,318,189,319,189,320,189,321,189,322,189,292,190,294,190,295,190,302,190,303,190,304,190,305,190,306,190,307,190,308,190,309,190,310,190,311,190,312,190,313,190,314,190,290,191,294,191,302,191,304,191,305,191,306,191,307,191,308,191,309,191,310,191,155,192,290,192,298,192,303,192,304,192,305,192,306,192,307,192,308,192,309,192,290,193,293,193,298,193,300,193,301,193,302,193,303,193,304,193,305,193,306,193,307,193,308,193,290,194,291,194,292,194,293,194,300,194,301,194,303,194,304,194,305,194,306,194,307,194,154,195,291,195,293,195,294,195,297,195,300,195,301,195,303,195,304,195,305,195,306,195,307,195,161,196,288,196,297,196,298,196,299,196,300,196,301,196,302,196,303,196,304,196,305,196,306,196,294,197,298,197,299,197,300,197,301,197,302,197,303,197,304,197,305,197,306,197,288,198,292,198,295,198,296,198,299,198,300,198,301,198,302,198,303,198,304,198,305,198,306,198,296,199,300,199,301,199,302,199,303,199,304,199,305,199,287,200,291,200,293,200,296,200,300,200,301,200,302,200,303,200,304,200,305,200,286,201,292,201,293,201,297,201,301,201,302,201,303,201,304,201,286,202,288,202,291,202,295,202,301,202,302,202,303,202,304,202,288,203,298,203,299,203,300,203,301,203,302,203,303,203,285,204,287,204,288,204,292,204,298,204,299,204,300,204,301,204,302,204,284,205,285,205,286,205,287,205,292,205,298,205,300,205,301,205,302,205,303,205,284,206,295,206,297,206,298,206,301,206,302,206,284,207,293,207,294,207,295,207,297,207,301,207,302,207,289,208,291,208,292,208,293,208,299,208,300,208,301,208,291,209,296,209,298,209,299,209,300,209,301,209,282,210,283,210,288,210,296,210,297,210,298,210,284,211,285,211,286,211,290,211,294,211,297,211,298,211,299,211,300,211,281,212,284,212,285,212,291,212,297,212,298,212,299,212,291,213,292,213,296,213,297,213,289,214,291,214,295,214,296,214,280,215,281,215,284,215,285,215,288,215,289,215,290,215,291,215,298,215,279,216,280,216,281,216,285,216,286,216,289,216,290,216,279,217,280,217,281,217,286,217,294,217,295,217,278,218,279,218,280,218,283,218,292,218,294,218,295,218,277,219,278,219,283,219,295,219,283,220,292,220,295,220,276,221,283,221,284,221,275,222,276,222,277,222,282,222,288,222,289,222,292,222,268,223,274,223,275,223,276,223,277,223,278,223,282,223,293,223,274,224,275,224,276,224,277,224,278,224,290,224,291,224,293,224,273,225,274,225,275,225,276,225,285,225,290,225,292,225,272,226,273,226,274,226,275,226,277,226,287,226,288,226,289,226,290,226,271,227,272,227,273,227,274,227,287,227,288,227,290,227,270,228,271,228,272,228,273,228,287,228,288,228,290,228,269,229,270,229,271,229,272,229,286,229,287,229,289,229,269,230,270,230,271,230,287,230,288,230,289,230,268,231,269,231,270,231,288,231,289,231,262,232,268,232,269,232,289,232,262,233,267,233,268,233,269,233,290,233,266,234,267,234,268,234,277,234,265,235,266,235,267,235,291,235,264,236,265,236,266,236,292,236,263,237,264,237,265,237,266,237,137,238,138,238,260,238,261,238,262,238,263,238,135,239,136,239,137,239,138,239,139,239,260,239,261,239,262,239,263,239,135,240,136,240,137,240,259,240,260,240,261,240,134,241,135,241,136,241,137,241,138,241,139,241,140,241,141,241,258,241,259,241,132,242,133,242,134,242,135,242,141,242,256,242,257,242,258,242,132,243,133,243,134,243,135,243,136,243,137,243,253,243,254,243,255,243,256,243,130,244,131,244,132,244,133,244,134,244,135,244,136,244,137,244,141,244,142,244,251,244,252,244,253,244,254,244,255,244,129,245,130,245,131,245,132,245,133,245,134,245,135,245,137,245,139,245,140,245,141,245,142,245,250,245,251,245,252,245,253,245,254,245,127,246,128,246,129,246,130,246,131,246,133,246,134,246,135,246,136,246,138,246,139,246,144,246,145,246,247,246,248,246,249,246,250,246,251,246,252,246,253,246,126,247,127,247,128,247,129,247,130,247,131,247,132,247,133,247,134,247,138,247,139,247,140,247,143,247,144,247,147,247,244,247,245,247,246,247,247,247,248,247,249,247,250,247,251,247,122,248,124,248,125,248,126,248,127,248,128,248,129,248,130,248,131,248,135,248,136,248,137,248,140,248,141,248,148,248,241,248,242,248,243,248,244,248,245,248,247,248,248,248,249,248,250,248,122,249,123,249,124,249,125,249,126,249,127,249,128,249,129,249,130,249,131,249,132,249,133,249,134,249,137,249,138,249,140,249,143,249,147,249,153,249,237,249,238,249,239,249,240,249,241,249,242,249,245,249,246,249,249,249,250,249,292,249,120,250,121,250,122,250,123,250,124,250,125,250,126,250,127,250,128,250,129,250,130,250,131,250,132,250,133,250,134,250,135,250,136,250,137,250,145,250,151,250,153,250,159,250,160,250,161,250,236,250,237,250,238,250,239,250,240,250,241,250,245,250,247,250,248,250,249,250,250,250,251,250,120,251,121,251,122,251,123,251,124,251,125,251,126,251,127,251,128,251,129,251,130,251,131,251,132,251,133,251,134,251,135,251,136,251,140,251,142,251,148,251,153,251,159,251,163,251,164,251,165,251,231,251,232,251,234,251,235,251,236,251,237,251,239,251,240,251,241,251,242,251,245,251,246,251,247,251,248,251,249,251,250,251,251,251,252,251,292,251,118,252,119,252,120,252,121,252,122,252,123,252,124,252,125,252,126,252,129,252,130,252,131,252,132,252,133,252,134,252,135,252,136,252,137,252,144,252,154,252,155,252,156,252,160,252,164,252,230,252,231,252,232,252,233,252,240,252,243,252,247,252,248,252,249,252,250,252,251,252,252,252,253,252,116,253,117,253,118,253,119,253,120,253,121,253,122,253,123,253,124,253,131,253,132,253,133,253,134,253,135,253,136,253,137,253,138,253,139,253,141,253,142,253,144,253,145,253,152,253,159,253,166,253,167,253,169,253,170,253,226,253,227,253,228,253,229,253,232,253,233,253,234,253,235,253,236,253,237,253,238,253,239,253,240,253,241,253,242,253,243,253,244,253,245,253,246,253,247,253,248,253,249,253,250,253,251,253,252,253,253,253,254,253,292,253,115,254,116,254,117,254,118,254,119,254,120,254,121,254,122,254,123,254,133,254,134,254,135,254,136,254,137,254,138,254,139,254,140,254,142,254,146,254,147,254,156,254,166,254,167,254,168,254,169,254,170,254,171,254,224,254,225,254,236,254,237,254,238,254,241,254,243,254,244,254,245,254,246,254,247,254,248,254,249,254,250,254,251,254,252,254,253,254,254,254,293,254,297,254,115,255,116,255,117,255,118,255,119,255,120,255,121,255,135,255,136,255,137,255,138,255,139,255,140,255,141,255,143,255,145,255,146,255,159,255,160,255,172,255,173,255,174,255,177,255,179,255,214,255,215,255,218,255,219,255,220,255,221,255,222,255,223,255,224,255,231,255,233,255,234,255,235,255,236,255,237,255,238,255,239,255,240,255,241,255,242,255,243,255,244,255,245,255,246,255,247,255,248,255,249,255,250,255,251,255,252,255,253,255,254,255,255,255,256,255,112,256,113,256,114,256,115,256,116,256,117,256,118,256,119,256,136,256,137,256,138,256,139,256,140,256,141,256,142,256,143,256,159,256,169,256,172,256,173,256,174,256,175,256,176,256,177,256,178,256,179,256,213,256,214,256,215,256,217,256,218,256,219,256,220,256,221,256,223,256,224,256,229,256,230,256,231,256,232,256,233,256,234,256,235,256,237,256,238,256,239,256,240,256,241,256,242,256,243,256,244,256,245,256,246,256,247,256,248,256,249,256,250,256,251,256,252,256,253,256,254,256,255,256,256,256,257,256,259,256,285,256,302,256,112,257,113,257,114,257,115,257,116,257,117,257,138,257,139,257,140,257,141,257,142,257,144,257,149,257,152,257,153,257,155,257,163,257,173,257,174,257,175,257,176,257,177,257,178,257,179,257,180,257,182,257,183,257,184,257,185,257,207,257,208,257,209,257,211,257,212,257,213,257,214,257,215,257,216,257,217,257,223,257,224,257,227,257,228,257,229,257,231,257,232,257,233,257,234,257,236,257,237,257,238,257,239,257,240,257,241,257,242,257,243,257,244,257,245,257,246,257,247,257,248,257,249,257,250,257,251,257,252,257,253,257,254,257,255,257,256,257,257,257,258,257,259,257,282,257,303,257,111,258,112,258,113,258,114,258,115,258,116,258,140,258,141,258,142,258,143,258,144,258,145,258,146,258,147,258,148,258,149,258,156,258,169,258,171,258,172,258,173,258,174,258,175,258,176,258,177,258,178,258,179,258,180,258,181,258,182,258,183,258,184,258,185,258,186,258,187,258,188,258,189,258,190,258,191,258,192,258,193,258,194,258,195,258,197,258,198,258,201,258,202,258,203,258,204,258,205,258,206,258,207,258,208,258,209,258,210,258,211,258,212,258,213,258,215,258,216,258,218,258,219,258,222,258,223,258,224,258,226,258,228,258,230,258,231,258,232,258,233,258,234,258,235,258,236,258,237,258,238,258,240,258,241,258,242,258,243,258,244,258,245,258,246,258,247,258,248,258,249,258,250,258,251,258,252,258,253,258,254,258,255,258,256,258,257,258,258,258,259,258,281,258,286,258,298,258,303,258,110,259,111,259,112,259,113,259,114,259,142,259,143,259,144,259,145,259,146,259,147,259,148,259,149,259,150,259,164,259,169,259,170,259,172,259,174,259,175,259,176,259,177,259,178,259,179,259,180,259,181,259,182,259,183,259,184,259,185,259,186,259,187,259,188,259,189,259,190,259,191,259,192,259,193,259,194,259,195,259,196,259,197,259,198,259,199,259,200,259,201,259,202,259,203,259,204,259,205,259,206,259,207,259,208,259,209,259,210,259,211,259,212,259,213,259,215,259,216,259,217,259,218,259,219,259,220,259,221,259,224,259,227,259,228,259,229,259,230,259,231,259,232,259,235,259,236,259,237,259,238,259,239,259,240,259,241,259,242,259,243,259,244,259,245,259,246,259,247,259,248,259,249,259,250,259,251,259,252,259,253,259,254,259,255,259,256,259,257,259,258,259,259,259,260,259,261,259,297,259,298,259,301,259,302,259,109,260,110,260,111,260,112,260,145,260,146,260,147,260,148,260,149,260,150,260,151,260,172,260,175,260,176,260,177,260,178,260,179,260,180,260,181,260,182,260,183,260,184,260,185,260,186,260,187,260,188,260,189,260,190,260,191,260,192,260,193,260,194,260,195,260,196,260,197,260,198,260,199,260,200,260,201,260,202,260,203,260,204,260,205,260,206,260,207,260,208,260,209,260,210,260,211,260,212,260,213,260,214,260,215,260,216,260,219,260,221,260,223,260,224,260,225,260,226,260,227,260,228,260,229,260,230,260,231,260,232,260,233,260,234,260,235,260,236,260,237,260,238,260,240,260,241,260,242,260,243,260,244,260,245,260,246,260,247,260,248,260,249,260,250,260,251,260,252,260,253,260,254,260,255,260,256,260,257,260,258,260,259,260,260,260,261,260,262,260,279,260,295,260,297,260,299,260,300,260,301,260,108,261,109,261,110,261,111,261,146,261,147,261,148,261,149,261,150,261,151,261,152,261,164,261,165,261,175,261,176,261,178,261,179,261,180,261,183,261,184,261,185,261,186,261,187,261,188,261,189,261,190,261,191,261,192,261,193,261,194,261,195,261,196,261,197,261,198,261,199,261,200,261,201,261,202,261,203,261,204,261,205,261,206,261,207,261,208,261,209,261,210,261,211,261,212,261,213,261,214,261,215,261,216,261,217,261,218,261,219,261,221,261,223,261,224,261,225,261,226,261,227,261,228,261,229,261,232,261,233,261,234,261,235,261,236,261,237,261,238,261,239,261,240,261,241,261,242,261,243,261,244,261,245,261,246,261,247,261,248,261,249,261,250,261,251,261,252,261,257,261,258,261,259,261,260,261,261,261,262,261,263,261,285,261,297,261,300,261,107,262,108,262,109,262,149,262,150,262,152,262,153,262,165,262,168,262,186,262,189,262,190,262,191,262,192,262,193,262,194,262,196,262,197,262,198,262,199,262,200,262,201,262,202,262,203,262,204,262,205,262,206,262,207,262,208,262,209,262,210,262,211,262,212,262,213,262,214,262,215,262,216,262,217,262,218,262,220,262,221,262,222,262,223,262,225,262,226,262,227,262,228,262,229,262,230,262,231,262,232,262,234,262,235,262,236,262,237,262,238,262,239,262,240,262,241,262,242,262,243,262,244,262,245,262,246,262,247,262,248,262,249,262,250,262,258,262,259,262,260,262,261,262,262,262,263,262,264,262,277,262,287,262,299,262,105,263,106,263,151,263,152,263,153,263,154,263,164,263,169,263,200,263,209,263,210,263,211,263,212,263,213,263,214,263,215,263,216,263,217,263,218,263,219,263,220,263,223,263,225,263,227,263,228,263,229,263,230,263,231,263,232,263,233,263,234,263,235,263,236,263,237,263,238,263,239,263,240,263,241,263,242,263,243,263,244,263,245,263,246,263,247,263,248,263,259,263,260,263,261,263,262,263,263,263,264,263,265,263,266,263,275,263,276,263,296,263,153,264,154,264,155,264,156,264,157,264,163,264,167,264,210,264,211,264,212,264,214,264,215,264,216,264,217,264,218,264,219,264,220,264,221,264,222,264,223,264,225,264,226,264,227,264,228,264,229,264,230,264,231,264,232,264,233,264,234,264,235,264,236,264,237,264,238,264,239,264,240,264,241,264,242,264,243,264,244,264,245,264,246,264,260,264,261,264,262,264,263,264,264,264,265,264,266,264,267,264,281,264,295,264,155,265,156,265,157,265,159,265,162,265,166,265,167,265,168,265,169,265,210,265,211,265,212,265,213,265,214,265,215,265,216,265,217,265,218,265,219,265,220,265,221,265,222,265,223,265,226,265,227,265,229,265,230,265,231,265,232,265,233,265,234,265,235,265,236,265,237,265,238,265,239,265,240,265,241,265,242,265,243,265,262,265,263,265,264,265,265,265,266,265,267,265,268,265,287,265,291,265,294,265,295,265,157,266,158,266,160,266,161,266,162,266,165,266,167,266,168,266,169,266,170,266,210,266,211,266,212,266,213,266,215,266,216,266,217,266,218,266,219,266,220,266,221,266,222,266,223,266,224,266,225,266,226,266,227,266,228,266,229,266,230,266,231,266,232,266,233,266,234,266,235,266,236,266,237,266,238,266,239,266,240,266,263,266,264,266,265,266,266,266,267,266,268,266,269,266,274,266,281,266,287,266,290,266,161,267,162,267,164,267,165,267,166,267,169,267,170,267,209,267,210,267,211,267,212,267,214,267,215,267,216,267,217,267,218,267,219,267,220,267,221,267,222,267,223,267,224,267,225,267,226,267,227,267,228,267,229,267,230,267,231,267,232,267,233,267,234,267,235,267,236,267,237,267,264,267,265,267,266,267,267,267,268,267,269,267,274,267,280,267,293,267,164,268,165,268,166,268,167,268,169,268,170,268,209,268,210,268,211,268,212,268,213,268,214,268,215,268,216,268,217,268,218,268,219,268,220,268,221,268,222,268,223,268,224,268,225,268,226,268,227,268,228,268,229,268,230,268,231,268,232,268,233,268,234,268,235,268,266,268,267,268,268,268,269,268,276,268,277,268,280,268,290,268,291,268,292,268,293,268,165,269,166,269,167,269,168,269,169,269,210,269,211,269,212,269,213,269,214,269,215,269,216,269,217,269,218,269,219,269,220,269,221,269,222,269,223,269,224,269,225,269,226,269,227,269,228,269,229,269,230,269,231,269,232,269,267,269,268,269,269,269,270,269,275,269,276,269,278,269,288,269,289,269,290,269,291,269,292,269,166,270,167,270,168,270,169,270,210,270,211,270,212,270,213,270,214,270,215,270,216,270,217,270,218,270,219,270,220,270,221,270,222,270,223,270,224,270,225,270,226,270,227,270,228,270,268,270,269,270,270,270,271,270,289,270,168,271,169,271,170,271,209,271,210,271,211,271,212,271,213,271,214,271,215,271,216,271,217,271,218,271,219,271,220,271,221,271,222,271,223,271,224,271,270,271,271,271,285,271,288,271,289,271,169,272,209,272,210,272,211,272,212,272,213,272,214,272,215,272,216,272,217,272,218,272,219,272,220,272,221,272,271,272,272,272,277,272,282,272,285,272,286,272,287,272,288,272,169,273,209,273,210,273,211,273,212,273,213,273,214,273,215,273,216,273,217,273,218,273,272,273,277,273,278,273,279,273,286,273,169,274,208,274,209,274,210,274,211,274,212,274,213,274,214,274,215,274,278,274,279,274,280,274,281,274,282,274,285,274,208,275,209,275,210,275,211,275,212,275,213,275,280,275,282,275,283,275,284,275,208,276,209,276,210,276,211,276,212,276,280,276,208,277,209,277,210,277,211,277,212,277,278,277,279,277,280,277,208,278,209,278,210,278,211,278,207,279,208,279,209,279,210,279,211,279,208,280,209,280,210,280,211,280,207,281,208,281,209,281,210,281,211,281,208,282,209,282,210,282,211,282,206,283,207,283,208,283,209,283,210,283,207,284,208,284,209,284,210,284,208,285,209,285,210,285,207,286,208,286,209,286,207,287,208,287,209,287,177,288,178,288,191,288,192,288,193,288,204,288,206,288,207,288,208,288,209,288,176,289,185,289,186,289,193,289,199,289,200,289,203,289,207,289,208,289,209,289,184,290,193,290,198,290,205,290,206,290,207,290,208,290,183,291,192,291,193,291,198,291,199,291,205,291,207,291,208,291,182,292,183,292,187,292,198,292,199,292,207,292,208,292,198,293,199,293,202,293,205,293,206,293,207,293,194,294,195,294,198,294,200,294,205,294,207,294,183,295,199,295,200,295,204,295,205,295,207,295,181,296,182,296,199,296,200,296,186,297,187,297,199,297,200,297,204,297,205,297,206,297,177,298,182,298,198,298,199,298,200,298,205,298,206,298,177,299,178,299,181,299,186,299,188,299,199,299,205,299,177,300,184,300,191,300,198,300,200,300,201,300,202,300,203,300,183,301,184,301,185,301,188,301,191,301,192,301,197,301,198,301,203,301,184,302,189,302,190,302,194,302,195,302,196,302,203,302,204,302,190,303,194,303,195,303,203,303,56,322,192,322,193,322,56,323,143,323,192,323,193,323,55,324,56,324,143,324,144,324,192,324,193,324,194,324,55,325,56,325,57,325,142,325,143,325,144,325,192,325,193,325,194,325,55,326,56,326,57,326,142,326,143,326,144,326,192,326,193,326,194,326,239,326,240,326,241,326,55,327,56,327,57,327,142,327,143,327,144,327,192,327,193,327,194,327,239,327,240,327,241,327,242,327,279,327,280,327,281,327,55,328,56,328,57,328,105,328,106,328,142,328,143,328,144,328,192,328,193,328,194,328,239,328,240,328,241,328,242,328,243,328,279,328,280,328,281,328,282,328,55,329,56,329,57,329,104,329,105,329,106,329,142,329,143,329,144,329,192,329,193,329,194,329,239,329,240,329,241,329,242,329,243,329,278,329,279,329,280,329,281,329,282,329,283,329,32,330,33,330,34,330,35,330,36,330,37,330,38,330,39,330,40,330,41,330,42,330,43,330,44,330,45,330,49,330,55,330,56,330,57,330,104,330,105,330,106,330,125,330,126,330,127,330,128,330,129,330,130,330,132,330,133,330,135,330,139,330,142,330,143,330,144,330,148,330,156,330,157,330,158,330,159,330,160,330,161,330,162,330,163,330,164,330,165,330,166,330,167,330,168,330,169,330,170,330,171,330,172,330,173,330,174,330,175,330,176,330,177,330,178,330,179,330,180,330,181,330,182,330,188,330,192,330,193,330,194,330,239,330,240,330,241,330,242,330,243,330,261,330,262,330,263,330,264,330,265,330,266,330,267,330,268,330,269,330,270,330,271,330,272,330,273,330,274,330,278,330,279,330,280,330,281,330,282,330,283,330,343,330,344,330,345,330,346,330,347,330,348,330,349,330,350,330,351,330,32,331,33,331,34,331,35,331,36,331,37,331,38,331,39,331,40,331,41,331,42,331,43,331,44,331,45,331,46,331,47,331,49,331,55,331,56,331,57,331,61,331,62,331,63,331,64,331,65,331,66,331,67,331,68,331,69,331,70,331,71,331,72,331,73,331,74,331,75,331,76,331,77,331,78,331,79,331,80,331,81,331,82,331,83,331,84,331,85,331,104,331,105,331,106,331,124,331,125,331,126,331,127,331,128,331,129,331,130,331,131,331,132,331,133,331,134,331,135,331,140,331,142,331,143,331,144,331,147,331,159,331,160,331,161,331,162,331,163,331,164,331,165,331,166,331,167,331,168,331,169,331,170,331,171,331,172,331,173,331,174,331,175,331,176,331,177,331,178,331,180,331,181,331,182,331,183,331,184,331,185,331,186,331,189,331,191,331,192,331,193,331,194,331,197,331,198,331,199,331,200,331,202,331,203,331,204,331,205,331,206,331,207,331,208,331,209,331,210,331,211,331,212,331,213,331,214,331,215,331,216,331,217,331,218,331,219,331,220,331,221,331,222,331,239,331,240,331,241,331,242,331,243,331,261,331,262,331,263,331,264,331,265,331,266,331,267,331,268,331,269,331,270,331,271,331,272,331,273,331,274,331,279,331,280,331,281,331,282,331,283,331,285,331,286,331,287,331,288,331,289,331,290,331,291,331,292,331,293,331,294,331,295,331,296,331,297,331,298,331,299,331,300,331,301,331,302,331,303,331,304,331,340,331,341,331,342,331,343,331,344,331,345,331,346,331,347,331,348,331,349,331,350,331,351,331,352,331,353,331,32,332,33,332,34,332,35,332,36,332,37,332,38,332,39,332,40,332,41,332,42,332,43,332,44,332,45,332,46,332,47,332,48,332,49,332,51,332,52,332,53,332,54,332,55,332,56,332,57,332,60,332,61,332,62,332,63,332,64,332,65,332,66,332,67,332,68,332,69,332,70,332,71,332,72,332,73,332,74,332,75,332,76,332,77,332,78,332,79,332,80,332,81,332,82,332,83,332,84,332,85,332,104,332,105,332,106,332,107,332,124,332,125,332,126,332,127,332,128,332,129,332,130,332,131,332,132,332,133,332,134,332,135,332,136,332,140,332,141,332,142,332,143,332,144,332,147,332,160,332,161,332,163,332,164,332,165,332,166,332,167,332,168,332,169,332,170,332,171,332,172,332,173,332,174,332,175,332,176,332,177,332,178,332,179,332,180,332,181,332,182,332,183,332,184,332,185,332,186,332,187,332,188,332,189,332,190,332,191,332,192,332,193,332,194,332,197,332,198,332,199,332,203,332,205,332,206,332,207,332,208,332,209,332,210,332,211,332,212,332,213,332,214,332,215,332,216,332,217,332,218,332,219,332,220,332,221,332,222,332,239,332,240,332,241,332,242,332,243,332,261,332,262,332,263,332,264,332,265,332,266,332,267,332,268,332,269,332,270,332,271,332,272,332,273,332,274,332,275,332,276,332,278,332,279,332,280,332,281,332,282,332,283,332,285,332,286,332,287,332,288,332,289,332,290,332,291,332,292,332,293,332,295,332,296,332,297,332,298,332,299,332,300,332,301,332,302,332,303,332,304,332,305,332,339,332,340,332,341,332,342,332,344,332,345,332,346,332,347,332,348,332,349,332,350,332,351,332,352,332,353,332,354,332,355,332,32,333,33,333,34,333,35,333,36,333,37,333,38,333,39,333,40,333,41,333,42,333,43,333,44,333,45,333,46,333,47,333,48,333,49,333,50,333,51,333,52,333,53,333,54,333,55,333,56,333,57,333,60,333,61,333,62,333,63,333,64,333,65,333,66,333,67,333,68,333,69,333,70,333,71,333,72,333,73,333,74,333,75,333,76,333,77,333,78,333,79,333,80,333,81,333,82,333,83,333,84,333,85,333,103,333,104,333,105,333,106,333,107,333,124,333,125,333,126,333,127,333,128,333,129,333,130,333,131,333,132,333,133,333,134,333,135,333,136,333,137,333,138,333,139,333,140,333,141,333,142,333,143,333,144,333,145,333,146,333,147,333,148,333,157,333,158,333,159,333,160,333,161,333,162,333,163,333,164,333,165,333,166,333,167,333,168,333,169,333,170,333,171,333,172,333,173,333,174,333,175,333,176,333,177,333,178,333,179,333,180,333,181,333,182,333,183,333,184,333,185,333,186,333,187,333,188,333,189,333,190,333,191,333,192,333,193,333,194,333,196,333,197,333,198,333,199,333,200,333,202,333,205,333,206,333,207,333,208,333,209,333,210,333,211,333,212,333,213,333,214,333,215,333,216,333,217,333,218,333,219,333,220,333,221,333,222,333,239,333,240,333,241,333,242,333,243,333,261,333,262,333,263,333,264,333,265,333,266,333,267,333,268,333,269,333,270,333,271,333,272,333,273,333,274,333,275,333,276,333,277,333,278,333,279,333,280,333,281,333,282,333,283,333,284,333,285,333,286,333,287,333,288,333,289,333,290,333,291,333,292,333,293,333,294,333,295,333,296,333,297,333,298,333,299,333,300,333,301,333,302,333,303,333,304,333,305,333,338,333,339,333,340,333,341,333,342,333,343,333,344,333,345,333,346,333,347,333,348,333,349,333,350,333,351,333,352,333,353,333,354,333,355,333,356,333,374,333,375,333,32,334,33,334,34,334,35,334,36,334,37,334,38,334,39,334,40,334,41,334,42,334,43,334,44,334,45,334,46,334,47,334,48,334,49,334,50,334,51,334,52,334,53,334,54,334,55,334,56,334,57,334,59,334,60,334,61,334,62,334,63,334,64,334,65,334,66,334,67,334,68,334,69,334,70,334,71,334,72,334,73,334,74,334,75,334,76,334,77,334,78,334,79,334,80,334,81,334,82,334,83,334,84,334,85,334,104,334,105,334,106,334,107,334,124,334,125,334,126,334,127,334,128,334,129,334,130,334,131,334,132,334,133,334,134,334,135,334,136,334,137,334,138,334,139,334,140,334,141,334,142,334,143,334,144,334,145,334,146,334,147,334,149,334,154,334,156,334,157,334,158,334,159,334,160,334,161,334,162,334,163,334,164,334,165,334,166,334,167,334,168,334,169,334,170,334,171,334,172,334,173,334,174,334,175,334,176,334,177,334,178,334,179,334,180,334,181,334,182,334,183,334,184,334,185,334,186,334,187,334,188,334,189,334,190,334,191,334,192,334,193,334,194,334,195,334,196,334,197,334,198,334,199,334,200,334,201,334,202,334,204,334,205,334,206,334,207,334,208,334,209,334,210,334,211,334,212,334,213,334,214,334,215,334,216,334,217,334,218,334,219,334,220,334,221,334,222,334,239,334,240,334,241,334,242,334,243,334,261,334,262,334,263,334,264,334,265,334,266,334,267,334,268,334,269,334,270,334,271,334,272,334,273,334,274,334,275,334,276,334,277,334,278,334,279,334,280,334,281,334,282,334,283,334,284,334,285,334,286,334,287,334,288,334,289,334,290,334,291,334,292,334,293,334,294,334,295,334,296,334,297,334,298,334,299,334,300,334,301,334,302,334,303,334,304,334,305,334,306,334,337,334,338,334,339,334,340,334,341,334,342,334,343,334,344,334,345,334,346,334,347,334,348,334,349,334,350,334,351,334,352,334,353,334,354,334,355,334,356,334,357,334,374,334,32,335,33,335,34,335,35,335,36,335,37,335,38,335,39,335,40,335,41,335,42,335,43,335,44,335,45,335,46,335,47,335,48,335,49,335,50,335,51,335,52,335,53,335,54,335,55,335,56,335,57,335,58,335,59,335,60,335,61,335,62,335,63,335,64,335,65,335,66,335,67,335,68,335,69,335,70,335,71,335,72,335,73,335,74,335,75,335,76,335,77,335,78,335,79,335,80,335,81,335,82,335,83,335,84,335,85,335,104,335,105,335,106,335,107,335,124,335,125,335,126,335,127,335,128,335,129,335,130,335,131,335,132,335,133,335,134,335,135,335,136,335,137,335,138,335,139,335,140,335,141,335,142,335,143,335,144,335,145,335,146,335,147,335,148,335,149,335,150,335,151,335,152,335,153,335,154,335,155,335,156,335,157,335,158,335,159,335,160,335,161,335,162,335,163,335,164,335,165,335,166,335,167,335,168,335,169,335,170,335,171,335,172,335,173,335,174,335,175,335,176,335,177,335,178,335,179,335,180,335,181,335,182,335,183,335,184,335,185,335,186,335,187,335,188,335,189,335,190,335,191,335,192,335,193,335,194,335,195,335,196,335,197,335,198,335,199,335,200,335,201,335,202,335,203,335,204,335,205,335,206,335,207,335,208,335,209,335,210,335,211,335,212,335,213,335,214,335,215,335,216,335,217,335,218,335,219,335,220,335,221,335,222,335,239,335,240,335,241,335,242,335,243,335,261,335,262,335,263,335,264,335,265,335,266,335,267,335,268,335,269,335,270,335,271,335,272,335,273,335,274,335,275,335,276,335,277,335,278,335,279,335,280,335,281,335,282,335,283,335,284,335,285,335,286,335,287,335,288,335,289,335,290,335,291,335,292,335,293,335,294,335,295,335,296,335,297,335,298,335,299,335,300,335,301,335,302,335,303,335,304,335,305,335,306,335,337,335,338,335,339,335,340,335,341,335,342,335,343,335,344,335,345,335,346,335,347,335,348,335,349,335,350,335,351,335,352,335,353,335,354,335,355,335,356,335,357,335,45,336,46,336,47,336,48,336,49,336,50,336,51,336,52,336,53,336,54,336,55,336,56,336,57,336,58,336,59,336,60,336,61,336,62,336,63,336,64,336,65,336,66,336,67,336,68,336,69,336,70,336,71,336,72,336,73,336,74,336,75,336,76,336,77,336,78,336,79,336,80,336,81,336,82,336,83,336,84,336,85,336,104,336,105,336,106,336,107,336,124,336,125,336,126,336,127,336,128,336,129,336,130,336,131,336,132,336,133,336,134,336,135,336,136,336,137,336,138,336,139,336,140,336,141,336,142,336,143,336,144,336,145,336,146,336,147,336,148,336,149,336,150,336,151,336,152,336,153,336,154,336,155,336,156,336,157,336,158,336,178,336,179,336,180,336,181,336,182,336,183,336,184,336,185,336,186,336,187,336,188,336,189,336,190,336,191,336,192,336,193,336,194,336,195,336,196,336,197,336,198,336,199,336,200,336,201,336,202,336,203,336,204,336,205,336,206,336,207,336,208,336,209,336,210,336,211,336,212,336,213,336,214,336,215,336,216,336,217,336,218,336,219,336,220,336,221,336,222,336,239,336,240,336,241,336,242,336,243,336,261,336,262,336,263,336,264,336,265,336,266,336,267,336,268,336,269,336,270,336,271,336,272,336,273,336,274,336,275,336,276,336,277,336,278,336,279,336,280,336,281,336,282,336,283,336,284,336,285,336,286,336,287,336,288,336,289,336,290,336,291,336,292,336,293,336,294,336,295,336,296,336,297,336,298,336,299,336,300,336,301,336,302,336,303,336,304,336,305,336,306,336,336,336,337,336,338,336,339,336,340,336,341,336,342,336,343,336,344,336,345,336,346,336,347,336,348,336,349,336,350,336,351,336,352,336,353,336,354,336,355,336,356,336,45,337,46,337,47,337,103,337,104,337,105,337,106,337,107,337,124,337,125,337,126,337,127,337,128,337,129,337,130,337,131,337,132,337,133,337,134,337,135,337,136,337,137,337,138,337,139,337,140,337,141,337,145,337,146,337,147,337,148,337,149,337,214,337,216,337,219,337,220,337,221,337,222,337,239,337,240,337,241,337,242,337,243,337,261,337,262,337,263,337,264,337,265,337,266,337,267,337,268,337,269,337,270,337,271,337,272,337,273,337,274,337,275,337,276,337,277,337,306,337,336,337,337,337,338,337,339,337,340,337,341,337,342,337,343,337,344,337,345,337,351,337,352,337,353,337,354,337,355,337,356,337,357,337,102,338,103,338,104,338,105,338,106,338,107,338,124,338,239,338,240,338,241,338,242,338,243,338,261,338,336,338,337,338,338,338,339,338,340,338,341,338,355,338,356,338,357,338,45,339,102,339,103,339,104,339,105,339,106,339,107,339,124,339,239,339,240,339,241,339,242,339,243,339,261,339,336,339,337,339,338,339,339,339,357,339,358,339,45,340,103,340,104,340,105,340,106,340,107,340,124,340,239,340,240,340,241,340,242,340,243,340,261,340,315,340,336,340,337,340,338,340,358,340,45,341,103,341,104,341,105,341,106,341,107,341,124,341,239,341,240,341,241,341,242,341,243,341,261,341,315,341,316,341,317,341,318,341,319,341,320,341,321,341,337,341,45,342,46,342,103,342,104,342,105,342,106,342,107,342,124,342,239,342,240,342,241,342,242,342,243,342,261,342,314,342,315,342,316,342,317,342,318,342,319,342,320,342,321,342,322,342,45,343,46,343,103,343,104,343,105,343,106,343,107,343,124,343,179,343,239,343,240,343,241,343,242,343,243,343,261,343,313,343,314,343,315,343,316,343,317,343,318,343,319,343,320,343,321,343,322,343,45,344,46,344,103,344,104,344,105,344,106,344,107,344,179,344,239,344,240,344,241,344,242,344,243,344,261,344,305,344,306,344,313,344,314,344,315,344,316,344,317,344,318,344,319,344,320,344,321,344,322,344,372,344,375,344,377,344,32,345,33,345,34,345,35,345,36,345,37,345,38,345,41,345,43,345,45,345,78,345,102,345,103,345,104,345,105,345,106,345,107,345,179,345,239,345,240,345,241,345,242,345,243,345,261,345,305,345,306,345,312,345,313,345,314,345,315,345,316,345,317,345,318,345,319,345,320,345,323,345,372,345,375,345,32,346,33,346,34,346,35,346,36,346,37,346,44,346,45,346,77,346,78,346,79,346,80,346,81,346,82,346,83,346,84,346,85,346,102,346,103,346,104,346,105,346,106,346,107,346,239,346,240,346,241,346,242,346,243,346,261,346,305,346,306,346,312,346,313,346,314,346,315,346,316,346,317,346,318,346,319,346,320,346,323,346,371,346,372,346,373,346,376,346,377,346,32,347,33,347,34,347,35,347,36,347,37,347,38,347,39,347,45,347,77,347,78,347,79,347,80,347,81,347,82,347,83,347,84,347,85,347,103,347,104,347,105,347,106,347,107,347,239,347,240,347,241,347,242,347,243,347,261,347,306,347,314,347,315,347,316,347,317,347,318,347,319,347,324,347,370,347,372,347,373,347,374,347,375,347,376,347,377,347,32,348,33,348,34,348,35,348,36,348,37,348,38,348,39,348,41,348,45,348,77,348,78,348,79,348,80,348,81,348,82,348,83,348,84,348,85,348,102,348,103,348,104,348,105,348,106,348,107,348,239,348,240,348,241,348,242,348,243,348,261,348,306,348,319,348,369,348,370,348,372,348,373,348,374,348,375,348,376,348,377,348,378,348,379,348,32,349,33,349,34,349,35,349,36,349,37,349,38,349,41,349,45,349,77,349,78,349,79,349,80,349,81,349,82,349,83,349,84,349,85,349,102,349,103,349,104,349,105,349,106,349,107,349,239,349,240,349,241,349,242,349,243,349,306,349,369,349,373,349,374,349,375,349,376,349,377,349,378,349,379,349,380,349,381,349,32,350,33,350,34,350,35,350,36,350,37,350,38,350,39,350,40,350,77,350,78,350,79,350,80,350,81,350,82,350,83,350,84,350,85,350,102,350,103,350,104,350,105,350,106,350,107,350,239,350,240,350,241,350,242,350,243,350,306,350,372,350,373,350,374,350,375,350,376,350,377,350,378,350,379,350,380,350,381,350,382,350,383,350,32,351,33,351,34,351,35,351,36,351,37,351,38,351,41,351,77,351,78,351,79,351,80,351,81,351,82,351,83,351,84,351,85,351,103,351,104,351,105,351,106,351,107,351,239,351,240,351,241,351,242,351,243,351,306,351,373,351,374,351,375,351,376,351,32,352,33,352,34,352,35,352,36,352,37,352,38,352,39,352,40,352,41,352,77,352,78,352,79,352,80,352,81,352,82,352,83,352,84,352,85,352,103,352,104,352,105,352,106,352,107,352,238,352,239,352,240,352,241,352,242,352,243,352,305,352,306,352,307,352,372,352,374,352,375,352,32,353,33,353,34,353,35,353,36,353,37,353,38,353,39,353,40,353,41,353,42,353,61,353,77,353,78,353,79,353,80,353,81,353,82,353,83,353,84,353,85,353,101,353,102,353,103,353,104,353,105,353,106,353,107,353,198,353,237,353,238,353,239,353,240,353,241,353,242,353,243,353,246,353,304,353,305,353,306,353,307,353,373,353,374,353,375,353,32,354,33,354,34,354,35,354,36,354,37,354,38,354,39,354,40,354,41,354,42,354,43,354,47,354,61,354,62,354,77,354,78,354,79,354,80,354,81,354,82,354,83,354,84,354,85,354,99,354,100,354,101,354,103,354,104,354,105,354,106,354,107,354,110,354,197,354,198,354,199,354,236,354,237,354,238,354,239,354,240,354,241,354,242,354,243,354,246,354,247,354,303,354,304,354,305,354,306,354,307,354,330,354,331,354,332,354,333,354,334,354,359,354,360,354,373,354,374,354,32,355,33,355,34,355,35,355,36,355,37,355,38,355,39,355,40,355,41,355,42,355,61,355,63,355,77,355,78,355,79,355,80,355,81,355,82,355,83,355,84,355,85,355,99,355,100,355,101,355,102,355,104,355,105,355,106,355,107,355,109,355,110,355,112,355,197,355,198,355,199,355,200,355,235,355,236,355,237,355,238,355,239,355,240,355,241,355,242,355,243,355,245,355,246,355,247,355,248,355,302,355,303,355,304,355,305,355,306,355,307,355,329,355,330,355,331,355,355,355,356,355,357,355,358,355,359,355,360,355,361,355,373,355,16,356,17,356,18,356,19,356,20,356,21,356,22,356,23,356,24,356,25,356,26,356,30,356,31,356,60,356,63,356,64,356,98,356,99,356,100,356,101,356,102,356,103,356,104,356,105,356,106,356,107,356,109,356,112,356,113,356,178,356,197,356,198,356,199,356,200,356,201,356,234,356,235,356,236,356,237,356,238,356,239,356,240,356,241,356,242,356,243,356,245,356,246,356,247,356,248,356,249,356,301,356,302,356,303,356,304,356,305,356,306,356,307,356,329,356,330,356,331,356,332,356,350,356,351,356,352,356,353,356,354,356,355,356,356,356,357,356,358,356,361,356,362,356,16,357,17,357,18,357,19,357,20,357,21,357,22,357,23,357,24,357,25,357,26,357,27,357,28,357,29,357,30,357,65,357,66,357,67,357,68,357,96,357,97,357,98,357,99,357,100,357,101,357,102,357,103,357,104,357,105,357,106,357,107,357,114,357,115,357,116,357,117,357,118,357,119,357,120,357,121,357,122,357,123,357,124,357,125,357,126,357,127,357,128,357,129,357,130,357,131,357,132,357,133,357,134,357,135,357,136,357,137,357,138,357,139,357,159,357,160,357,161,357,162,357,163,357,164,357,165,357,166,357,167,357,168,357,169,357,170,357,171,357,172,357,173,357,174,357,175,357,176,357,177,357,178,357,180,357,197,357,198,357,199,357,200,357,201,357,202,357,203,357,205,357,206,357,207,357,211,357,212,357,213,357,214,357,215,357,216,357,217,357,220,357,224,357,226,357,228,357,230,357,231,357,232,357,233,357,234,357,235,357,236,357,237,357,238,357,239,357,240,357,241,357,242,357,243,357,244,357,245,357,246,357,249,357,250,357,251,357,252,357,253,357,254,357,255,357,256,357,257,357,258,357,259,357,260,357,293,357,299,357,300,357,301,357,302,357,303,357,304,357,305,357,306,357,307,357,329,357,330,357,352,357,356,357,357,357,358,357,360,357,362,357,363,357,16,358,17,358,18,358,19,358,20,358,21,358,22,358,23,358,24,358,25,358,26,358,27,358,28,358,29,358,30,358,66,358,67,358,68,358,69,358,70,358,71,358,72,358,73,358,74,358,75,358,87,358,88,358,89,358,90,358,91,358,92,358,93,358,94,358,95,358,96,358,97,358,98,358,99,358,100,358,101,358,102,358,103,358,104,358,105,358,106,358,107,358,114,358,115,358,116,358,117,358,118,358,119,358,120,358,121,358,122,358,123,358,124,358,125,358,126,358,127,358,128,358,129,358,130,358,131,358,132,358,133,358,134,358,135,358,136,358,137,358,138,358,139,358,159,358,160,358,161,358,162,358,163,358,164,358,165,358,166,358,167,358,168,358,169,358,170,358,171,358,172,358,173,358,174,358,175,358,176,358,177,358,178,358,180,358,196,358,201,358,202,358,203,358,204,358,205,358,206,358,207,358,208,358,209,358,210,358,211,358,212,358,213,358,214,358,215,358,216,358,217,358,218,358,219,358,220,358,221,358,222,358,223,358,224,358,225,358,226,358,227,358,228,358,229,358,230,358,231,358,232,358,233,358,234,358,235,358,236,358,237,358,238,358,239,358,240,358,241,358,242,358,243,358,244,358,250,358,251,358,252,358,253,358,254,358,255,358,256,358,257,358,258,358,259,358,260,358,290,358,291,358,292,358,293,358,294,358,295,358,296,358,297,358,298,358,299,358,300,358,301,358,302,358,303,358,304,358,305,358,306,358,307,358,329,358,330,358,351,358,352,358,353,358,355,358,359,358,360,358,362,358,363,358,15,359,16,359,17,359,18,359,19,359,20,359,21,359,22,359,23,359,24,359,25,359,26,359,27,359,28,359,29,359,30,359,67,359,68,359,69,359,70,359,71,359,72,359,73,359,74,359,75,359,87,359,88,359,89,359,91,359,92,359,94,359,96,359,97,359,98,359,99,359,100,359,101,359,102,359,103,359,104,359,105,359,106,359,107,359,114,359,115,359,116,359,117,359,118,359,119,359,120,359,121,359,122,359,123,359,124,359,125,359,126,359,127,359,128,359,129,359,130,359,131,359,132,359,133,359,134,359,135,359,136,359,137,359,138,359,139,359,158,359,159,359,160,359,161,359,162,359,163,359,164,359,165,359,166,359,167,359,168,359,169,359,170,359,171,359,172,359,173,359,174,359,175,359,176,359,177,359,178,359,180,359,201,359,202,359,203,359,204,359,205,359,206,359,207,359,208,359,209,359,210,359,211,359,212,359,213,359,214,359,215,359,216,359,217,359,218,359,219,359,220,359,221,359,222,359,223,359,224,359,225,359,226,359,227,359,228,359,229,359,230,359,231,359,232,359,233,359,234,359,235,359,236,359,237,359,238,359,239,359,240,359,241,359,242,359,243,359,244,359,250,359,251,359,252,359,253,359,254,359,255,359,256,359,257,359,258,359,259,359,260,359,290,359,291,359,292,359,293,359,294,359,295,359,296,359,297,359,298,359,299,359,300,359,301,359,302,359,303,359,304,359,305,359,306,359,307,359,329,359,330,359,351,359,361,359,362,359,363,359,15,360,16,360,17,360,18,360,19,360,20,360,21,360,22,360,23,360,24,360,25,360,26,360,27,360,28,360,29,360,30,360,67,360,68,360,69,360,70,360,72,360,73,360,74,360,75,360,88,360,89,360,91,360,92,360,93,360,94,360,95,360,96,360,97,360,98,360,99,360,100,360,101,360,102,360,103,360,104,360,105,360,106,360,107,360,114,360,115,360,116,360,117,360,118,360,119,360,120,360,121,360,122,360,123,360,124,360,125,360,126,360,127,360,128,360,129,360,130,360,131,360,132,360,133,360,134,360,135,360,136,360,137,360,138,360,139,360,140,360,158,360,159,360,160,360,161,360,162,360,163,360,164,360,165,360,166,360,167,360,168,360,169,360,170,360,171,360,172,360,173,360,174,360,175,360,176,360,177,360,178,360,179,360,180,360,195,360,201,360,202,360,203,360,204,360,205,360,206,360,207,360,208,360,209,360,210,360,211,360,212,360,213,360,214,360,215,360,216,360,217,360,218,360,219,360,220,360,221,360,222,360,223,360,224,360,225,360,226,360,227,360,228,360,229,360,230,360,231,360,232,360,233,360,234,360,235,360,236,360,237,360,238,360,239,360,240,360,241,360,242,360,243,360,244,360,245,360,250,360,251,360,252,360,253,360,254,360,255,360,256,360,257,360,258,360,259,360,260,360,290,360,291,360,292,360,293,360,295,360,296,360,297,360,298,360,299,360,300,360,301,360,302,360,303,360,304,360,305,360,306,360,307,360,328,360,329,360,330,360,351,360,353,360,359,360,361,360,362,360,363,360,364,360,15,361,16,361,17,361,18,361,19,361,20,361,21,361,22,361,23,361,24,361,25,361,26,361,27,361,28,361,29,361,30,361,66,361,67,361,68,361,69,361,70,361,71,361,72,361,73,361,74,361,75,361,88,361,89,361,90,361,91,361,95,361,96,361,97,361,98,361,99,361,100,361,101,361,102,361,103,361,104,361,105,361,106,361,107,361,114,361,115,361,116,361,117,361,118,361,119,361,121,361,122,361,123,361,124,361,125,361,126,361,127,361,128,361,129,361,130,361,131,361,132,361,133,361,134,361,135,361,136,361,137,361,138,361,139,361,140,361,158,361,159,361,160,361,161,361,162,361,163,361,164,361,165,361,170,361,171,361,172,361,173,361,174,361,175,361,176,361,177,361,178,361,179,361,180,361,195,361,201,361,202,361,203,361,204,361,205,361,206,361,207,361,208,361,209,361,210,361,211,361,212,361,213,361,214,361,215,361,216,361,217,361,218,361,219,361,220,361,221,361,222,361,223,361,225,361,226,361,227,361,228,361,229,361,230,361,231,361,232,361,233,361,234,361,235,361,236,361,237,361,238,361,239,361,240,361,241,361,242,361,243,361,244,361,250,361,251,361,252,361,253,361,254,361,258,361,259,361,260,361,290,361,291,361,292,361,293,361,294,361,295,361,296,361,297,361,298,361,299,361,300,361,301,361,302,361,303,361,304,361,305,361,306,361,307,361,326,361,327,361,328,361,329,361,330,361,331,361,332,361,350,361,351,361,356,361,359,361,361,361,362,361,363,361,364,361,365,361,368,361,15,362,16,362,17,362,18,362,19,362,20,362,21,362,22,362,23,362,24,362,25,362,26,362,27,362,28,362,29,362,30,362,66,362,67,362,68,362,69,362,70,362,71,362,73,362,74,362,88,362,90,362,91,362,93,362,94,362,95,362,96,362,97,362,98,362,99,362,100,362,101,362,102,362,103,362,104,362,105,362,106,362,107,362,108,362,114,362,117,362,118,362,119,362,120,362,121,362,123,362,124,362,125,362,126,362,127,362,128,362,129,362,130,362,132,362,133,362,134,362,135,362,136,362,137,362,138,362,139,362,140,362,158,362,159,362,160,362,161,362,162,362,163,362,164,362,165,362,166,362,170,362,172,362,173,362,174,362,175,362,176,362,177,362,178,362,179,362,180,362,194,362,195,362,201,362,202,362,203,362,204,362,205,362,206,362,208,362,209,362,210,362,211,362,212,362,213,362,214,362,215,362,216,362,217,362,218,362,219,362,220,362,222,362,223,362,225,362,226,362,227,362,228,362,230,362,231,362,232,362,233,362,234,362,235,362,236,362,237,362,238,362,239,362,240,362,241,362,242,362,243,362,244,362,245,362,249,362,250,362,251,362,252,362,253,362,258,362,259,362,260,362,261,362,290,362,291,362,292,362,293,362,295,362,296,362,297,362,298,362,299,362,300,362,301,362,302,362,303,362,304,362,305,362,306,362,307,362,326,362,327,362,328,362,329,362,331,362,332,362,335,362,340,362,350,362,351,362,352,362,354,362,356,362,357,362,359,362,363,362,364,362,365,362,14,363,15,363,16,363,17,363,18,363,19,363,20,363,21,363,22,363,23,363,24,363,25,363,26,363,27,363,28,363,29,363,30,363,65,363,66,363,67,363,68,363,69,363,70,363,71,363,73,363,74,363,88,363,89,363,90,363,92,363,93,363,94,363,95,363,96,363,97,363,98,363,99,363,100,363,101,363,102,363,103,363,104,363,105,363,106,363,107,363,108,363,117,363,118,363,119,363,120,363,123,363,124,363,125,363,126,363,127,363,128,363,129,363,130,363,131,363,132,363,133,363,134,363,135,363,136,363,137,363,138,363,139,363,140,363,141,363,158,363,159,363,160,363,162,363,163,363,164,363,165,363,166,363,167,363,168,363,169,363,170,363,171,363,172,363,173,363,174,363,175,363,176,363,177,363,178,363,179,363,180,363,194,363,195,363,202,363,203,363,204,363,205,363,206,363,207,363,208,363,209,363,210,363,211,363,212,363,213,363,214,363,215,363,216,363,217,363,218,363,219,363,220,363,221,363,225,363,226,363,227,363,229,363,230,363,231,363,232,363,233,363,234,363,235,363,236,363,237,363,238,363,239,363,240,363,241,363,242,363,243,363,244,363,245,363,249,363,250,363,251,363,252,363,258,363,259,363,260,363,261,363,290,363,291,363,292,363,293,363,294,363,295,363,296,363,297,363,298,363,299,363,300,363,301,363,302,363,304,363,305,363,306,363,307,363,325,363,326,363,333,363,350,363,351,363,352,363,353,363,354,363,355,363,359,363,360,363,361,363,362,363,363,363,364,363,365,363,366,363,14,364,15,364,16,364,17,364,18,364,19,364,20,364,21,364,22,364,23,364,24,364,25,364,26,364,27,364,28,364,29,364,30,364,65,364,66,364,67,364,68,364,69,364,70,364,71,364,72,364,73,364,74,364,88,364,89,364,90,364,91,364,92,364,96,364,97,364,98,364,99,364,100,364,101,364,102,364,103,364,104,364,105,364,107,364,108,364,117,364,118,364,119,364,120,364,122,364,124,364,125,364,126,364,127,364,128,364,129,364,130,364,131,364,132,364,133,364,134,364,135,364,136,364,137,364,138,364,139,364,140,364,141,364,157,364,158,364,159,364,160,364,162,364,163,364,164,364,166,364,167,364,168,364,170,364,171,364,172,364,173,364,174,364,175,364,176,364,177,364,178,364,179,364,180,364,194,364,195,364,201,364,202,364,203,364,204,364,205,364,206,364,207,364,208,364,210,364,211,364,212,364,213,364,214,364,215,364,216,364,217,364,218,364,219,364,220,364,221,364,225,364,227,364,228,364,229,364,230,364,231,364,232,364,233,364,234,364,235,364,236,364,237,364,238,364,239,364,240,364,241,364,242,364,243,364,244,364,245,364,249,364,250,364,251,364,252,364,253,364,254,364,259,364,260,364,261,364,290,364,291,364,293,364,294,364,295,364,296,364,297,364,298,364,299,364,300,364,302,364,304,364,305,364,306,364,340,364,348,364,350,364,351,364,352,364,354,364,355,364,356,364,357,364,358,364,359,364,360,364,364,364,365,364,366,364,369,364,373,364,14,365,15,365,16,365,17,365,18,365,19,365,20,365,21,365,22,365,23,365,24,365,25,365,26,365,27,365,28,365,29,365,30,365,65,365,66,365,67,365,68,365,69,365,70,365,71,365,72,365,74,365,88,365,91,365,92,365,93,365,94,365,95,365,96,365,97,365,98,365,99,365,100,365,101,365,102,365,103,365,104,365,107,365,108,365,109,365,112,365,116,365,118,365,119,365,120,365,121,365,122,365,124,365,125,365,126,365,127,365,128,365,129,365,130,365,131,365,132,365,133,365,134,365,135,365,136,365,137,365,138,365,139,365,140,365,141,365,157,365,158,365,159,365,160,365,161,365,162,365,163,365,164,365,165,365,167,365,169,365,170,365,171,365,172,365,173,365,174,365,175,365,176,365,177,365,178,365,179,365,180,365,195,365,201,365,202,365,203,365,204,365,205,365,206,365,207,365,208,365,209,365,210,365,211,365,212,365,213,365,214,365,215,365,216,365,217,365,218,365,219,365,220,365,221,365,225,365,227,365,228,365,230,365,231,365,232,365,233,365,234,365,235,365,236,365,237,365,238,365,239,365,240,365,241,365,244,365,245,365,246,365,249,365,250,365,251,365,252,365,253,365,254,365,259,365,260,365,261,365,290,365,291,365,292,365,293,365,294,365,295,365,296,365,297,365,298,365,299,365,300,365,301,365,304,365,305,365,349,365,350,365,351,365,352,365,353,365,354,365,355,365,356,365,366,365,369,365,371,365,14,366,15,366,16,366,17,366,18,366,19,366,20,366,21,366,22,366,23,366,24,366,25,366,26,366,27,366,28,366,29,366,30,366,64,366,67,366,68,366,69,366,72,366,73,366,74,366,88,366,90,366,91,366,92,366,93,366,94,366,95,366,96,366,97,366,98,366,99,366,100,366,101,366,102,366,103,366,108,366,109,366,110,366,111,366,112,366,113,366,116,366,117,366,118,366,119,366,121,366,122,366,123,366,124,366,125,366,126,366,127,366,128,366,129,366,130,366,132,366,133,366,136,366,137,366,138,366,139,366,140,366,141,366,142,366,157,366,158,366,159,366,160,366,162,366,163,366,164,366,165,366,166,366,167,366,168,366,169,366,170,366,171,366,172,366,173,366,174,366,175,366,176,366,177,366,178,366,179,366,180,366,196,366,200,366,201,366,202,366,203,366,204,366,205,366,206,366,207,366,208,366,210,366,211,366,212,366,213,366,214,366,215,366,216,366,217,366,218,366,219,366,220,366,221,366,225,366,227,366,228,366,230,366,231,366,232,366,233,366,234,366,235,366,236,366,237,366,238,366,239,366,240,366,245,366,246,366,247,366,249,366,250,366,251,366,252,366,253,366,255,366,256,366,257,366,258,366,259,366,260,366,261,366,290,366,291,366,293,366,294,366,296,366,297,366,298,366,299,366,300,366,301,366,302,366,303,366,304,366,305,366,350,366,351,366,352,366,369,366,370,366,13,367,14,367,15,367,16,367,17,367,18,367,19,367,20,367,21,367,22,367,23,367,24,367,25,367,26,367,27,367,28,367,29,367,30,367,64,367,66,367,67,367,68,367,69,367,70,367,71,367,72,367,73,367,74,367,88,367,90,367,91,367,92,367,94,367,96,367,97,367,98,367,99,367,100,367,101,367,102,367,110,367,111,367,112,367,113,367,114,367,118,367,119,367,121,367,122,367,123,367,124,367,125,367,126,367,127,367,128,367,129,367,130,367,133,367,134,367,137,367,138,367,139,367,140,367,141,367,142,367,157,367,158,367,159,367,160,367,162,367,163,367,164,367,165,367,166,367,167,367,168,367,169,367,170,367,171,367,172,367,173,367,174,367,175,367,176,367,177,367,178,367,179,367,180,367,199,367,200,367,201,367,202,367,203,367,204,367,205,367,206,367,207,367,208,367,209,367,210,367,211,367,212,367,213,367,214,367,215,367,216,367,217,367,218,367,219,367,220,367,221,367,222,367,223,367,224,367,225,367,226,367,227,367,228,367,229,367,230,367,231,367,232,367,233,367,234,367,235,367,236,367,237,367,238,367,239,367,247,367,248,367,249,367,250,367,251,367,252,367,253,367,254,367,255,367,256,367,257,367,258,367,259,367,260,367,261,367,290,367,291,367,292,367,293,367,294,367,295,367,296,367,297,367,298,367,299,367,300,367,301,367,302,367,303,367,350,367,351,367,13,368,14,368,15,368,16,368,17,368,18,368,19,368,20,368,21,368,22,368,23,368,24,368,25,368,26,368,27,368,28,368,29,368,30,368,63,368,64,368,65,368,66,368,67,368,68,368,69,368,70,368,71,368,72,368,73,368,74,368,88,368,89,368,90,368,91,368,92,368,93,368,94,368,95,368,96,368,97,368,98,368,99,368,100,368,101,368,111,368,112,368,113,368,114,368,115,368,116,368,119,368,121,368,122,368,123,368,124,368,125,368,126,368,127,368,128,368,129,368,130,368,131,368,133,368,134,368,136,368,137,368,139,368,140,368,141,368,142,368,157,368,158,368,159,368,160,368,161,368,162,368,163,368,164,368,165,368,166,368,167,368,168,368,169,368,170,368,171,368,172,368,173,368,174,368,175,368,176,368,177,368,178,368,179,368,180,368,198,368,199,368,200,368,201,368,202,368,203,368,204,368,205,368,206,368,207,368,208,368,209,368,210,368,211,368,212,368,213,368,214,368,215,368,216,368,217,368,218,368,219,368,220,368,221,368,222,368,223,368,224,368,225,368,226,368,227,368,228,368,229,368,230,368,231,368,232,368,233,368,234,368,235,368,236,368,237,368,238,368,248,368,249,368,250,368,251,368,252,368,253,368,254,368,255,368,256,368,257,368,258,368,259,368,260,368,261,368,290,368,291,368,292,368,293,368,294,368,295,368,296,368,297,368,298,368,299,368,300,368,301,368,302,368,350,368,13,369,14,369,15,369,16,369,17,369,18,369,19,369,20,369,21,369,22,369,23,369,24,369,25,369,26,369,27,369,28,369,29,369,30,369,62,369,63,369,64,369,65,369,66,369,67,369,68,369,69,369,70,369,71,369,72,369,73,369,74,369,88,369,89,369,90,369,91,369,92,369,93,369,94,369,95,369,96,369,97,369,98,369,99,369,100,369,112,369,113,369,114,369,115,369,116,369,117,369,118,369,119,369,120,369,121,369,122,369,123,369,124,369,125,369,126,369,127,369,128,369,129,369,130,369,131,369,132,369,134,369,135,369,136,369,137,369,138,369,139,369,140,369,141,369,142,369,157,369,158,369,159,369,160,369,161,369,162,369,163,369,164,369,165,369,166,369,167,369,168,369,169,369,170,369,171,369,172,369,173,369,174,369,175,369,176,369,177,369,178,369,179,369,180,369,199,369,200,369,201,369,202,369,203,369,204,369,205,369,206,369,207,369,208,369,209,369,210,369,211,369,212,369,213,369,214,369,215,369,216,369,217,369,218,369,219,369,220,369,221,369,222,369,223,369,224,369,225,369,226,369,227,369,228,369,229,369,230,369,231,369,232,369,233,369,234,369,235,369,236,369,237,369,249,369,250,369,251,369,252,369,253,369,254,369,255,369,256,369,257,369,258,369,259,369,260,369,261,369,289,369,290,369,291,369,292,369,293,369,294,369,295,369,296,369,297,369,298,369,299,369,300,369,301,369,350,369,15,370,16,370,17,370,18,370,19,370,20,370,21,370,22,370,24,370,25,370,26,370,27,370,28,370,29,370,30,370,63,370,64,370,65,370,66,370,68,370,70,370,73,370,92,370,94,370,118,370,123,370,124,370,125,370,126,370,131,370,135,370,136,370,137,370,139,370,140,370,157,370,158,370,160,370,161,370,162,370,163,370,164,370,165,370,166,370,167,370,168,370,169,370,170,370,171,370,172,370,173,370,174,370,175,370,176,370,177,370,178,370,179,370,201,370,202,370,203,370,204,370,206,370,228,370,229,370,230,370,231,370,233,370,234,370,235,370,254,370,255,370,257,370,258,370,260,370,293,370,295,370,297,370,298,370,350,370,347,371,349,371}
listlabdark2 = {303,90,291,108,70,167,86,171,328,185,337,186,289,201,286,208,292,211,282,217,283,217,284,218,139,243,140,243,142,243,143,244,142,246,150,248,153,248,155,250,243,250,293,250,293,251,288,252,229,254,230,254,286,254,299,254,163,255,227,255,228,255,229,255,286,255,284,256,220,258,301,258,277,261,274,264,275,264,274,265,276,271,184,288,185,288,187,288,199,288,202,288,203,288,179,289,191,289,196,289,197,289,196,290,200,290,201,290,181,291,196,291,197,291,184,292,196,292,203,292,190,293,176,295,179,296,184,297,181,300,182,300,193,300,200,303}
listlabwhite = {192,35,192,36,190,43,188,51,188,52,187,55,126,56,186,58,122,59,119,61,120,61,118,62,114,65,113,66,114,66,111,68,110,69,111,69,167,69,110,70,147,72,106,73,156,73,106,74,145,74,146,74,152,74,146,75,148,75,149,75,150,75,270,75,143,76,144,76,139,77,140,77,141,77,143,77,144,77,138,78,139,78,140,78,141,78,143,78,144,78,145,78,140,79,141,79,135,80,136,80,134,81,135,81,136,81,137,81,141,81,142,81,134,82,135,82,141,82,137,83,138,83,139,83,140,83,132,84,133,84,136,84,137,84,139,84,140,84,133,85,134,85,129,86,130,86,131,86,132,86,133,86,134,86,135,86,136,86,129,87,130,87,131,87,132,87,135,87,136,87,127,88,130,88,131,88,133,88,134,88,128,89,130,89,132,89,133,89,128,90,129,90,130,90,131,90,132,90,123,91,125,91,126,91,128,91,129,91,123,92,124,92,125,92,126,92,128,92,121,93,122,93,123,93,124,93,126,93,127,93,122,94,126,94,127,94,126,95,127,95,123,96,124,96,125,96,126,96,118,97,123,97,124,97,125,97,126,97,118,98,119,98,120,98,121,98,122,98,123,98,118,99,119,99,120,99,121,99,122,99,120,100,121,100,120,101,121,101,118,102,119,102,120,102,118,103,119,103,120,103,118,104,119,104,118,105,119,105,117,106,118,106,119,106,118,107,115,109,115,110,114,111,113,112,114,112,113,113,114,113,111,116,112,116,111,117,112,117,110,118,111,118,110,119,111,119,108,123,109,123,110,123,108,124,109,124,109,125,106,126,107,126,106,127,107,127,106,128,107,128,106,129,107,129,106,130,107,130,104,131,105,131,106,131,104,132,105,132,103,133,104,133,105,133,99,134,101,134,103,134,101,135,103,135,103,136,74,137,99,137,103,137,104,137,74,138,102,138,103,138,74,139,102,139,73,140,74,140,102,140,99,141,102,141,99,142,102,142,98,143,99,143,102,143,98,145,102,146,100,147,101,147,102,147,98,148,99,148,100,148,101,148,102,148,97,149,98,149,101,149,97,150,98,150,102,150,102,151,97,154,100,154,72,155,97,155,97,156,101,156,102,156,255,158,97,159,251,159,255,159,256,159,96,160,97,160,97,163,101,163,253,163,254,163,255,163,98,164,101,164,251,164,250,165,253,165,101,166,250,166,253,166,101,167,252,167,101,168,102,168,255,168,254,169,249,170,250,170,251,170,254,170,255,170,249,171,250,171,249,172,252,172,253,172,249,173,251,173,252,173,248,174,249,174,250,174,251,174,246,175,250,175,251,175,254,175,246,176,253,176,254,176,246,177,247,177,248,177,249,177,254,177,245,178,246,178,247,178,248,178,251,178,252,178,253,178,254,178,246,179,250,179,251,179,252,179,253,179,247,180,253,180,245,181,246,181,250,181,251,181,244,182,245,182,246,182,247,182,248,182,249,182,251,182,246,183,247,183,248,183,251,183,242,184,246,184,247,184,250,184,251,184,242,185,243,185,244,185,245,185,247,185,248,185,242,186,243,186,244,186,247,186,248,186,241,187,242,187,243,187,247,187,248,187,249,187,241,188,244,188,247,188,249,188,240,189,241,189,243,189,244,189,246,189,247,189,248,189,241,190,243,190,244,190,245,190,246,190,247,190,239,191,240,191,241,191,245,191,246,191,247,191,238,192,239,192,240,192,241,192,246,192,247,192,236,193,237,193,238,193,239,193,241,193,245,193,246,193,236,194,237,194,238,194,239,194,241,194,242,194,243,194,244,194,245,194,235,195,236,195,241,195,242,195,243,195,244,195,245,195,234,196,235,196,239,196,240,196,241,196,242,196,244,196,234,197,235,197,238,197,239,197,242,197,243,197,232,198,233,198,234,198,235,198,238,198,239,198,240,198,241,198,242,198,243,198,230,199,231,199,234,199,235,199,238,199,239,199,240,199,241,199,231,200,232,200,236,200,237,200,238,200,239,200,240,200,228,201,229,201,230,201,231,201,232,201,234,201,235,201,238,201,239,201,240,201,231,202,235,202,237,202,226,203,227,203,229,203,230,203,231,203,234,203,235,203,224,204,229,204,230,204,231,204,232,204,235,204,236,204,226,205,227,205,229,205,233,205,235,205,226,206,227,206,223,207,224,207,225,207,227,207,228,207,230,207,231,207,232,207,224,208,225,208,228,208,229,208,230,208,231,208,232,208,219,209,220,209,228,209,212,210,216,210,227,210,215,211,222,211,223,211,226,211,227,211,209,212,225,212,221,213,106,216,213,216,214,216,213,217,206,218,111,325,111,326,111,327,111,328,111,329,111,330,358,330,357,331,358,331,359,331,358,332,359,332,360,332,359,333,360,333,361,333,360,334,361,334,111,335,361,335,362,335,361,336,362,336,361,337,362,337,322,338,362,339,111,341,111,346,111,347,326,347,326,348,327,348,327,349,328,349,111,350,329,350,330,351,331,351}
listreddesert1 = {225,30,224,31,223,35,224,36,224,41,224,43,121,44,224,44,225,45,161,52,137,57,296,57,225,60,228,60,300,60,237,61,199,63,304,65,263,66,272,67,306,67,218,68,270,68,96,69,189,70,307,72,303,73,239,74,293,74,101,75,248,75,294,75,315,77,106,78,301,78,301,79,313,79,314,79,153,80,301,80,310,80,315,80,311,81,308,82,304,83,305,85,233,90,121,91,116,92,251,92,137,93,201,95,156,97,194,98,250,102,166,107,234,111,115,114,249,118,131,121,144,125,306,129,127,131,254,135,245,138,104,141,116,145,135,145,337,154,255,155,331,156,328,157,341,157,338,158,136,159,339,160,327,161,341,162,127,164,100,166,113,169,138,173,95,174,306,175,326,177,91,179,128,180,325,183,103,187,104,188,104,193,113,194,139,195,107,197,151,207,217,211,211,212,122,213,164,214,112,220,254,229,120,230,150,233,95,234,130,236,270,242,267,244,272,245,124,246,211,247,288,247,252,248,263,249,263,255,268,256,274,259,208,264,189,266,206,268,174,292,171,294,172,299,203,318,218,318,61,325,148,328,125,329,351,329,331,336,332,336,312,339,61,340,219,345,223,345,158,346,158,353,86,356,350,357,349,361}
listreddesert2 = {211,17,210,18,216,18,215,19,222,19,200,20,209,23,224,24,224,27,212,29,223,30,197,31,209,32,222,32,222,33,194,34,195,34,201,34,212,34,213,34,196,35,203,35,215,35,197,36,201,36,202,36,204,36,206,36,208,36,209,36,222,36,196,37,198,37,200,37,201,37,202,37,205,37,208,37,217,37,218,37,219,37,195,38,202,38,207,38,208,38,212,38,217,38,220,38,221,38,195,39,202,39,207,39,221,39,193,40,195,40,196,40,198,40,205,40,207,40,214,40,215,40,193,41,194,41,196,41,197,41,200,41,204,41,207,41,208,41,210,41,213,41,194,42,195,42,196,42,197,42,200,42,202,42,203,42,205,42,210,42,211,42,212,42,213,42,216,42,217,42,218,42,219,42,220,42,221,42,192,43,193,43,196,43,197,43,198,43,200,43,202,43,203,43,204,43,206,43,210,43,211,43,212,43,213,43,220,43,193,44,194,44,197,44,198,44,199,44,200,44,202,44,204,44,210,44,211,44,212,44,214,44,216,44,217,44,121,45,193,45,199,45,203,45,204,45,205,45,207,45,208,45,211,45,212,45,214,45,216,45,217,45,219,45,123,46,185,46,193,46,194,46,195,46,196,46,197,46,205,46,206,46,207,46,211,46,214,46,216,46,217,46,218,46,219,46,220,46,221,46,222,46,124,47,193,47,194,47,196,47,197,47,202,47,204,47,207,47,211,47,212,47,217,47,218,47,219,47,222,47,125,48,175,48,176,48,191,48,194,48,195,48,196,48,205,48,206,48,207,48,208,48,212,48,217,48,218,48,221,48,126,49,183,49,185,49,186,49,194,49,196,49,197,49,200,49,202,49,205,49,206,49,207,49,208,49,211,49,213,49,219,49,221,49,126,50,127,50,181,50,182,50,187,50,190,50,194,50,196,50,199,50,200,50,202,50,205,50,206,50,207,50,208,50,211,50,212,50,217,50,218,50,126,51,127,51,184,51,185,51,186,51,187,51,191,51,192,51,195,51,197,51,205,51,212,51,216,51,217,51,218,51,219,51,222,51,130,52,162,52,183,52,184,52,194,52,197,52,200,52,201,52,202,52,203,52,209,52,212,52,213,52,214,52,222,52,130,53,131,53,159,53,189,53,194,53,196,53,198,53,201,53,203,53,204,53,205,53,206,53,211,53,212,53,215,53,217,53,219,53,220,53,222,53,132,54,156,54,184,54,190,54,195,54,196,54,198,54,199,54,201,54,202,54,203,54,204,54,205,54,206,54,211,54,212,54,214,54,215,54,216,54,217,54,218,54,222,54,132,55,133,55,134,55,182,55,184,55,185,55,193,55,195,55,198,55,199,55,202,55,203,55,204,55,205,55,208,55,209,55,214,55,215,55,216,55,218,55,219,55,293,55,115,56,135,56,183,56,185,56,186,56,187,56,188,56,189,56,193,56,196,56,202,56,203,56,204,56,206,56,209,56,212,56,216,56,218,56,223,56,229,56,230,56,231,56,295,56,297,56,129,57,136,57,149,57,179,57,181,57,185,57,189,57,194,57,195,57,196,57,198,57,205,57,207,57,218,57,221,57,232,57,289,57,293,57,294,57,295,57,130,58,132,58,138,58,180,58,181,58,183,58,184,58,193,58,200,58,201,58,208,58,214,58,218,58,222,58,232,58,287,58,294,58,295,58,298,58,129,59,130,59,135,59,136,59,138,59,140,59,173,59,174,59,178,59,182,59,187,59,198,59,199,59,202,59,203,59,212,59,216,59,217,59,231,59,233,59,237,59,240,59,244,59,248,59,250,59,294,59,295,59,127,60,139,60,140,60,141,60,142,60,143,60,173,60,178,60,182,60,189,60,190,60,192,60,193,60,194,60,195,60,200,60,201,60,202,60,203,60,206,60,207,60,210,60,212,60,222,60,227,60,239,60,240,60,242,60,243,60,244,60,245,60,246,60,249,60,284,60,291,60,294,60,295,60,296,60,297,60,298,60,126,61,127,61,129,61,130,61,132,61,133,61,134,61,139,61,140,61,141,61,142,61,143,61,144,61,176,61,178,61,182,61,186,61,187,61,227,61,228,61,230,61,236,61,238,61,239,61,241,61,245,61,250,61,252,61,253,61,254,61,293,61,294,61,295,61,297,61,299,61,124,62,130,62,133,62,134,62,136,62,137,62,139,62,140,62,141,62,168,62,172,62,179,62,180,62,181,62,182,62,183,62,187,62,198,62,202,62,205,62,226,62,231,62,235,62,244,62,254,62,255,62,281,62,288,62,289,62,291,62,293,62,294,62,302,62,303,62,119,63,120,63,125,63,126,63,129,63,134,63,135,63,136,63,137,63,139,63,141,63,142,63,168,63,169,63,172,63,177,63,179,63,180,63,184,63,200,63,207,63,208,63,231,63,233,63,234,63,240,63,243,63,257,63,258,63,279,63,288,63,293,63,294,63,296,63,297,63,300,63,301,63,302,63,303,63,304,63,118,64,122,64,125,64,127,64,128,64,129,64,130,64,136,64,138,64,141,64,146,64,171,64,173,64,174,64,176,64,184,64,188,64,194,64,198,64,205,64,214,64,218,64,219,64,232,64,234,64,235,64,236,64,237,64,240,64,243,64,259,64,277,64,288,64,292,64,293,64,116,65,127,65,129,65,131,65,132,65,139,65,140,65,141,65,142,65,146,65,164,65,168,65,171,65,173,65,183,65,197,65,216,65,217,65,228,65,229,65,232,65,235,65,252,65,287,65,288,65,289,65,293,65,299,65,300,65,119,66,120,66,122,66,125,66,126,66,127,66,129,66,130,66,131,66,132,66,133,66,134,66,137,66,138,66,139,66,142,66,144,66,157,66,162,66,166,66,167,66,170,66,172,66,176,66,177,66,185,66,192,66,200,66,203,66,213,66,225,66,230,66,231,66,251,66,274,66,287,66,288,66,290,66,293,66,294,66,295,66,299,66,119,67,123,67,128,67,129,67,130,67,132,67,137,67,145,67,152,67,164,67,167,67,173,67,174,67,182,67,183,67,185,67,186,67,188,67,193,67,197,67,200,67,203,67,207,67,208,67,209,67,221,67,234,67,237,67,239,67,240,67,285,67,288,67,289,67,292,67,297,67,113,68,114,68,116,68,123,68,124,68,125,68,131,68,134,68,137,68,138,68,142,68,144,68,151,68,152,68,154,68,155,68,157,68,159,68,160,68,164,68,177,68,178,68,179,68,180,68,181,68,186,68,187,68,188,68,192,68,195,68,196,68,197,68,198,68,199,68,200,68,203,68,204,68,205,68,206,68,214,68,217,68,231,68,235,68,240,68,241,68,266,68,271,68,287,68,288,68,289,68,290,68,296,68,97,69,113,69,114,69,120,69,121,69,125,69,128,69,130,69,131,69,136,69,138,69,139,69,144,69,155,69,156,69,159,69,173,69,174,69,179,69,187,69,188,69,189,69,192,69,193,69,197,69,198,69,199,69,201,69,206,69,210,69,213,69,223,69,224,69,227,69,238,69,240,69,241,69,281,69,282,69,285,69,287,69,288,69,296,69,297,69,298,69,303,69,309,69,98,70,112,70,114,70,117,70,121,70,125,70,126,70,127,70,128,70,131,70,132,70,133,70,135,70,136,70,137,70,138,70,140,70,144,70,146,70,151,70,157,70,158,70,159,70,166,70,172,70,173,70,177,70,178,70,179,70,181,70,190,70,193,70,194,70,197,70,199,70,200,70,201,70,205,70,206,70,207,70,208,70,211,70,213,70,214,70,217,70,220,70,229,70,234,70,238,70,239,70,241,70,244,70,245,70,281,70,282,70,286,70,288,70,290,70,296,70,297,70,303,70,111,71,114,71,115,71,116,71,126,71,129,71,131,71,132,71,134,71,135,71,136,71,144,71,147,71,158,71,160,71,167,71,174,71,177,71,178,71,179,71,182,71,189,71,191,71,193,71,195,71,196,71,199,71,200,71,203,71,204,71,206,71,207,71,208,71,210,71,211,71,212,71,213,71,214,71,219,71,220,71,223,71,225,71,226,71,235,71,247,71,249,71,264,71,286,71,287,71,288,71,296,71,297,71,298,71,299,71,300,71,301,71,306,71,111,72,112,72,119,72,120,72,124,72,125,72,126,72,129,72,130,72,133,72,134,72,135,72,137,72,138,72,141,72,143,72,150,72,152,72,153,72,155,72,163,72,168,72,172,72,173,72,180,72,182,72,183,72,184,72,185,72,187,72,190,72,191,72,194,72,198,72,207,72,208,72,213,72,214,72,216,72,217,72,221,72,237,72,241,72,242,72,245,72,249,72,250,72,278,72,286,72,287,72,289,72,292,72,293,72,294,72,301,72,302,72,309,72,310,72,102,73,120,73,122,73,123,73,124,73,125,73,127,73,128,73,129,73,135,73,143,73,164,73,168,73,169,73,171,73,172,73,177,73,178,73,179,73,181,73,182,73,183,73,187,73,188,73,189,73,190,73,191,73,193,73,195,73,199,73,202,73,203,73,206,73,214,73,216,73,217,73,218,73,219,73,220,73,221,73,222,73,227,73,232,73,235,73,237,73,252,73,255,73,256,73,261,73,277,73,282,73,283,73,284,73,285,73,287,73,288,73,289,73,292,73,293,73,297,73,299,73,300,73,301,73,104,74,112,74,115,74,119,74,120,74,122,74,123,74,124,74,126,74,127,74,128,74,129,74,132,74,138,74,139,74,144,74,155,74,157,74,158,74,159,74,164,74,169,74,174,74,175,74,177,74,178,74,183,74,184,74,190,74,191,74,192,74,195,74,202,74,205,74,212,74,214,74,215,74,216,74,217,74,218,74,219,74,220,74,227,74,228,74,237,74,242,74,245,74,246,74,247,74,249,74,250,74,251,74,252,74,253,74,255,74,262,74,263,74,266,74,274,74,279,74,286,74,289,74,290,74,292,74,297,74,298,74,299,74,105,75,115,75,116,75,123,75,124,75,129,75,130,75,131,75,138,75,144,75,155,75,158,75,159,75,163,75,164,75,168,75,169,75,170,75,175,75,184,75,186,75,187,75,191,75,198,75,200,75,201,75,205,75,210,75,212,75,218,75,219,75,225,75,226,75,227,75,231,75,236,75,238,75,241,75,261,75,262,75,263,75,265,75,266,75,274,75,276,75,291,75,292,75,302,75,312,75,107,76,109,76,110,76,117,76,118,76,121,76,123,76,125,76,129,76,130,76,131,76,134,76,136,76,139,76,154,76,155,76,156,76,157,76,160,76,161,76,164,76,165,76,166,76,167,76,168,76,179,76,186,76,191,76,196,76,198,76,205,76,214,76,216,76,218,76,219,76,225,76,228,76,229,76,234,76,237,76,253,76,263,76,264,76,265,76,285,76,288,76,293,76,295,76,296,76,297,76,298,76,312,76,107,77,108,77,111,77,115,77,127,77,129,77,133,77,147,77,149,77,152,77,154,77,155,77,156,77,158,77,159,77,165,77,172,77,173,77,174,77,176,77,177,77,182,77,185,77,186,77,187,77,188,77,196,77,198,77,200,77,202,77,204,77,210,77,214,77,216,77,217,77,220,77,221,77,222,77,224,77,225,77,232,77,233,77,237,77,242,77,244,77,246,77,251,77,252,77,257,77,259,77,260,77,263,77,264,77,265,77,270,77,272,77,278,77,284,77,293,77,294,77,296,77,298,77,300,77,303,77,306,77,312,77,314,77,108,78,109,78,110,78,113,78,114,78,115,78,120,78,123,78,124,78,127,78,130,78,149,78,150,78,155,78,156,78,158,78,160,78,165,78,168,78,174,78,176,78,177,78,183,78,184,78,185,78,188,78,190,78,193,78,194,78,195,78,197,78,198,78,201,78,207,78,208,78,209,78,213,78,216,78,220,78,225,78,228,78,232,78,233,78,234,78,236,78,237,78,239,78,241,78,246,78,248,78,252,78,253,78,254,78,259,78,261,78,268,78,269,78,274,78,277,78,283,78,284,78,287,78,289,78,291,78,292,78,294,78,298,78,309,78,315,78,108,79,109,79,110,79,112,79,113,79,114,79,115,79,117,79,123,79,125,79,126,79,127,79,129,79,156,79,157,79,158,79,159,79,160,79,161,79,163,79,164,79,168,79,173,79,174,79,175,79,177,79,183,79,185,79,193,79,198,79,202,79,206,79,207,79,208,79,209,79,211,79,212,79,216,79,221,79,225,79,226,79,228,79,230,79,232,79,233,79,236,79,240,79,243,79,265,79,270,79,271,79,272,79,273,79,275,79,276,79,278,79,280,79,281,79,282,79,283,79,284,79,288,79,289,79,292,79,293,79,294,79,295,79,296,79,298,79,306,79,310,79,108,80,110,80,113,80,115,80,117,80,118,80,123,80,124,80,125,80,128,80,143,80,144,80,148,80,150,80,151,80,152,80,154,80,155,80,161,80,162,80,164,80,165,80,172,80,173,80,175,80,182,80,183,80,190,80,192,80,193,80,194,80,199,80,201,80,203,80,207,80,213,80,215,80,221,80,222,80,224,80,226,80,228,80,229,80,231,80,232,80,233,80,242,80,248,80,266,80,271,80,272,80,273,80,275,80,276,80,278,80,279,80,280,80,281,80,283,80,284,80,285,80,286,80,287,80,288,80,289,80,292,80,296,80,299,80,308,80,114,81,117,81,118,81,119,81,121,81,124,81,128,81,132,81,154,81,168,81,172,81,174,81,175,81,179,81,180,81,187,81,191,81,192,81,194,81,198,81,199,81,203,81,208,81,219,81,224,81,225,81,228,81,229,81,233,81,239,81,241,81,245,81,246,81,247,81,251,81,263,81,264,81,265,81,271,81,273,81,274,81,275,81,278,81,282,81,283,81,284,81,285,81,286,81,289,81,290,81,291,81,297,81,300,81,308,81,111,82,112,82,115,82,117,82,118,82,119,82,120,82,122,82,124,82,128,82,129,82,130,82,148,82,151,82,152,82,154,82,156,82,157,82,165,82,171,82,175,82,176,82,182,82,187,82,189,82,190,82,191,82,196,82,197,82,198,82,199,82,202,82,203,82,204,82,216,82,219,82,220,82,223,82,224,82,226,82,229,82,231,82,232,82,235,82,237,82,238,82,240,82,242,82,265,82,266,82,268,82,269,82,270,82,271,82,273,82,274,82,275,82,276,82,279,82,280,82,281,82,282,82,283,82,284,82,285,82,286,82,287,82,290,82,291,82,292,82,293,82,296,82,297,82,298,82,301,82,112,83,117,83,118,83,119,83,121,83,124,83,126,83,127,83,130,83,131,83,145,83,146,83,150,83,151,83,153,83,157,83,166,83,169,83,170,83,175,83,177,83,178,83,179,83,181,83,190,83,191,83,195,83,202,83,210,83,212,83,219,83,222,83,223,83,229,83,231,83,237,83,249,83,254,83,255,83,256,83,266,83,274,83,277,83,278,83,280,83,281,83,282,83,283,83,285,83,287,83,290,83,291,83,293,83,297,83,298,83,299,83,301,83,306,83,112,84,113,84,116,84,118,84,121,84,123,84,125,84,142,84,149,84,157,84,160,84,168,84,170,84,175,84,181,84,185,84,186,84,188,84,191,84,196,84,200,84,203,84,209,84,211,84,218,84,228,84,229,84,232,84,234,84,238,84,242,84,245,84,246,84,247,84,250,84,252,84,269,84,270,84,271,84,272,84,273,84,274,84,277,84,278,84,280,84,281,84,283,84,286,84,288,84,289,84,294,84,306,84,115,85,121,85,122,85,123,85,125,85,126,85,127,85,144,85,145,85,148,85,152,85,155,85,156,85,158,85,159,85,160,85,175,85,178,85,179,85,180,85,181,85,185,85,186,85,191,85,200,85,201,85,202,85,211,85,215,85,224,85,228,85,231,85,232,85,234,85,236,85,240,85,241,85,242,85,246,85,249,85,251,85,252,85,254,85,258,85,271,85,272,85,273,85,274,85,277,85,278,85,279,85,280,85,281,85,285,85,287,85,288,85,291,85,292,85,293,85,294,85,299,85,300,85,301,85,303,85,113,86,114,86,119,86,120,86,121,86,124,86,146,86,152,86,154,86,155,86,159,86,160,86,161,86,166,86,168,86,169,86,174,86,176,86,178,86,180,86,181,86,182,86,187,86,188,86,189,86,190,86,191,86,192,86,193,86,200,86,201,86,206,86,207,86,210,86,211,86,213,86,215,86,216,86,221,86,222,86,223,86,227,86,228,86,234,86,235,86,237,86,238,86,239,86,240,86,243,86,245,86,246,86,249,86,252,86,257,86,274,86,276,86,279,86,282,86,287,86,288,86,291,86,292,86,293,86,294,86,295,86,299,86,300,86,301,86,302,86,115,87,116,87,121,87,141,87,143,87,146,87,150,87,162,87,163,87,165,87,168,87,174,87,175,87,176,87,177,87,178,87,180,87,181,87,184,87,187,87,194,87,195,87,205,87,208,87,211,87,213,87,215,87,221,87,233,87,234,87,237,87,238,87,240,87,243,87,244,87,247,87,255,87,276,87,278,87,279,87,280,87,281,87,283,87,288,87,291,87,294,87,295,87,298,87,299,87,301,87,115,88,142,88,149,88,163,88,166,88,167,88,168,88,174,88,175,88,179,88,183,88,191,88,192,88,193,88,194,88,195,88,209,88,214,88,216,88,221,88,224,88,233,88,236,88,243,88,259,88,261,88,274,88,277,88,280,88,284,88,285,88,289,88,290,88,294,88,295,88,302,88,116,89,118,89,120,89,121,89,122,89,124,89,125,89,143,89,148,89,152,89,153,89,157,89,158,89,161,89,162,89,166,89,168,89,170,89,171,89,174,89,175,89,176,89,184,89,186,89,188,89,199,89,200,89,201,89,202,89,208,89,209,89,210,89,214,89,217,89,218,89,219,89,220,89,221,89,223,89,231,89,232,89,236,89,237,89,238,89,243,89,244,89,245,89,249,89,250,89,255,89,256,89,257,89,260,89,263,89,273,89,274,89,276,89,279,89,280,89,282,89,286,89,287,89,288,89,289,89,290,89,291,89,294,89,301,89,302,89,116,90,117,90,122,90,139,90,142,90,143,90,145,90,146,90,149,90,151,90,152,90,156,90,157,90,162,90,166,90,174,90,180,90,187,90,188,90,198,90,200,90,201,90,202,90,209,90,210,90,213,90,215,90,216,90,217,90,218,90,220,90,229,90,236,90,242,90,243,90,248,90,249,90,252,90,257,90,261,90,262,90,263,90,275,90,278,90,279,90,282,90,283,90,284,90,286,90,287,90,288,90,289,90,290,90,291,90,292,90,294,90,298,90,301,90,116,91,117,91,118,91,146,91,149,91,152,91,155,91,157,91,166,91,167,91,169,91,173,91,174,91,176,91,178,91,181,91,185,91,186,91,189,91,192,91,193,91,198,91,200,91,204,91,205,91,206,91,215,91,216,91,217,91,229,91,232,91,235,91,242,91,245,91,246,91,247,91,248,91,261,91,277,91,278,91,281,91,282,91,283,91,286,91,288,91,289,91,290,91,292,91,294,91,295,91,296,91,300,91,118,92,139,92,143,92,144,92,148,92,150,92,151,92,152,92,156,92,163,92,164,92,165,92,166,92,167,92,168,92,171,92,172,92,173,92,176,92,179,92,182,92,183,92,184,92,186,92,189,92,190,92,191,92,193,92,199,92,200,92,204,92,206,92,210,92,211,92,212,92,215,92,216,92,222,92,235,92,238,92,241,92,248,92,249,92,250,92,254,92,266,92,279,92,280,92,282,92,284,92,285,92,286,92,287,92,288,92,289,92,290,92,293,92,294,92,295,92,130,93,135,93,139,93,141,93,149,93,150,93,154,93,156,93,162,93,163,93,167,93,175,93,176,93,178,93,181,93,183,93,190,93,196,93,197,93,199,93,200,93,201,93,206,93,208,93,209,93,210,93,212,93,232,93,235,93,237,93,238,93,239,93,241,93,242,93,246,93,247,93,254,93,257,93,258,93,260,93,267,93,276,93,281,93,282,93,284,93,286,93,287,93,288,93,289,93,290,93,293,93,294,93,295,93,296,93,109,94,110,94,111,94,112,94,124,94,125,94,129,94,138,94,142,94,143,94,144,94,145,94,147,94,149,94,150,94,152,94,154,94,155,94,158,94,169,94,170,94,176,94,181,94,183,94,184,94,189,94,194,94,195,94,196,94,201,94,203,94,206,94,208,94,210,94,213,94,216,94,230,94,233,94,234,94,238,94,239,94,242,94,249,94,251,94,252,94,253,94,277,94,278,94,279,94,282,94,286,94,287,94,288,94,289,94,297,94,110,95,113,95,123,95,131,95,139,95,143,95,149,95,158,95,161,95,165,95,166,95,167,95,168,95,171,95,177,95,186,95,188,95,191,95,192,95,193,95,204,95,206,95,207,95,209,95,210,95,216,95,219,95,222,95,224,95,230,95,231,95,238,95,239,95,242,95,245,95,249,95,250,95,251,95,254,95,255,95,261,95,264,95,269,95,278,95,280,95,284,95,285,95,288,95,289,95,290,95,291,95,293,95,296,95,120,96,128,96,129,96,133,96,136,96,137,96,140,96,141,96,147,96,148,96,158,96,160,96,161,96,163,96,164,96,165,96,168,96,170,96,173,96,176,96,177,96,182,96,188,96,192,96,197,96,206,96,207,96,215,96,217,96,218,96,223,96,226,96,233,96,238,96,244,96,245,96,246,96,248,96,249,96,254,96,260,96,262,96,263,96,266,96,267,96,269,96,279,96,280,96,283,96,286,96,287,96,288,96,289,96,290,96,291,96,293,96,117,97,121,97,129,97,131,97,132,97,137,97,158,97,160,97,161,97,164,97,166,97,167,97,168,97,169,97,171,97,185,97,189,97,199,97,203,97,205,97,209,97,213,97,218,97,219,97,222,97,226,97,227,97,232,97,235,97,237,97,239,97,247,97,248,97,249,97,252,97,254,97,255,97,258,97,260,97,271,97,279,97,280,97,282,97,284,97,285,97,286,97,292,97,293,97,125,98,131,98,132,98,135,98,139,98,147,98,155,98,156,98,157,98,160,98,161,98,164,98,167,98,173,98,174,98,176,98,177,98,186,98,195,98,201,98,202,98,204,98,210,98,211,98,212,98,222,98,228,98,236,98,240,98,242,98,247,98,251,98,255,98,258,98,259,98,261,98,265,98,271,98,280,98,284,98,285,98,287,98,288,98,293,98,131,99,133,99,135,99,138,99,141,99,142,99,144,99,147,99,148,99,151,99,155,99,156,99,157,99,162,99,163,99,164,99,166,99,167,99,176,99,177,99,186,99,193,99,197,99,198,99,201,99,204,99,210,99,211,99,212,99,215,99,216,99,219,99,222,99,225,99,230,99,233,99,235,99,238,99,239,99,242,99,243,99,246,99,251,99,253,99,254,99,255,99,256,99,257,99,258,99,259,99,264,99,265,99,282,99,283,99,286,99,292,99,115,100,122,100,125,100,128,100,133,100,138,100,141,100,142,100,144,100,145,100,146,100,147,100,148,100,150,100,151,100,153,100,154,100,155,100,156,100,157,100,160,100,161,100,162,100,164,100,165,100,166,100,168,100,171,100,172,100,173,100,179,100,181,100,182,100,192,100,208,100,209,100,211,100,213,100,214,100,216,100,218,100,221,100,223,100,227,100,228,100,230,100,231,100,233,100,237,100,238,100,239,100,240,100,249,100,251,100,258,100,259,100,260,100,262,100,267,100,270,100,271,100,281,100,285,100,286,100,287,100,288,100,289,100,115,101,123,101,131,101,132,101,136,101,138,101,141,101,142,101,144,101,145,101,153,101,155,101,156,101,159,101,160,101,163,101,166,101,167,101,173,101,174,101,178,101,193,101,195,101,196,101,201,101,205,101,211,101,213,101,216,101,221,101,222,101,223,101,225,101,226,101,230,101,231,101,232,101,233,101,234,101,235,101,239,101,241,101,243,101,244,101,252,101,254,101,255,101,259,101,261,101,262,101,263,101,264,101,267,101,268,101,271,101,272,101,273,101,284,101,285,101,286,101,287,101,289,101,290,101,116,102,125,102,127,102,128,102,130,102,131,102,135,102,136,102,137,102,142,102,143,102,144,102,145,102,151,102,152,102,155,102,156,102,166,102,167,102,172,102,176,102,182,102,187,102,188,102,201,102,204,102,209,102,210,102,213,102,221,102,222,102,228,102,230,102,234,102,237,102,238,102,239,102,253,102,254,102,260,102,261,102,262,102,263,102,264,102,266,102,270,102,274,102,284,102,287,102,290,102,113,103,115,103,116,103,117,103,124,103,126,103,133,103,136,103,137,103,140,103,141,103,143,103,145,103,149,103,150,103,155,103,160,103,161,103,162,103,168,103,171,103,173,103,180,103,181,103,182,103,184,103,185,103,208,103,209,103,211,103,212,103,220,103,222,103,229,103,230,103,237,103,240,103,242,103,243,103,247,103,253,103,256,103,257,103,259,103,265,103,266,103,268,103,275,103,288,103,113,104,115,104,125,104,131,104,133,104,138,104,140,104,144,104,148,104,153,104,154,104,160,104,168,104,173,104,176,104,177,104,179,104,182,104,214,104,217,104,220,104,221,104,222,104,232,104,233,104,242,104,250,104,254,104,255,104,258,104,259,104,260,104,265,104,266,104,268,104,269,104,270,104,285,104,288,104,111,105,112,105,114,105,115,105,122,105,138,105,139,105,142,105,145,105,148,105,151,105,156,105,160,105,162,105,169,105,170,105,175,105,177,105,216,105,217,105,218,105,219,105,220,105,225,105,227,105,228,105,230,105,231,105,232,105,233,105,237,105,238,105,240,105,244,105,246,105,247,105,248,105,251,105,254,105,255,105,258,105,262,105,263,105,264,105,271,105,272,105,276,105,111,106,114,106,116,106,125,106,126,106,129,106,131,106,137,106,138,106,141,106,142,106,143,106,144,106,145,106,148,106,149,106,153,106,156,106,157,106,174,106,175,106,219,106,220,106,222,106,223,106,224,106,225,106,226,106,231,106,232,106,233,106,235,106,236,106,238,106,240,106,241,106,246,106,247,106,248,106,249,106,251,106,252,106,256,106,257,106,261,106,262,106,266,106,269,106,271,106,276,106,286,106,287,106,121,107,123,107,124,107,125,107,126,107,127,107,129,107,133,107,140,107,142,107,143,107,151,107,153,107,157,107,159,107,160,107,161,107,163,107,174,107,227,107,235,107,236,107,237,107,239,107,242,107,244,107,245,107,248,107,249,107,256,107,261,107,262,107,263,107,266,107,270,107,272,107,275,107,287,107,114,108,122,108,123,108,125,108,126,108,127,108,130,108,139,108,141,108,144,108,149,108,151,108,152,108,153,108,154,108,156,108,161,108,170,108,227,108,233,108,239,108,242,108,244,108,245,108,247,108,251,108,260,108,261,108,264,108,267,108,270,108,276,108,108,109,112,109,127,109,128,109,137,109,138,109,139,109,144,109,145,109,147,109,148,109,158,109,159,109,167,109,168,109,230,109,232,109,234,109,238,109,241,109,243,109,244,109,251,109,253,109,256,109,257,109,259,109,260,109,263,109,268,109,269,109,273,109,274,109,277,109,279,109,108,110,109,110,110,110,118,110,122,110,127,110,128,110,129,110,130,110,138,110,142,110,145,110,146,110,148,110,151,110,155,110,158,110,159,110,167,110,230,110,232,110,233,110,239,110,242,110,250,110,255,110,256,110,257,110,260,110,261,110,265,110,266,110,268,110,269,110,270,110,275,110,276,110,277,110,110,111,111,111,118,111,119,111,122,111,123,111,136,111,141,111,144,111,146,111,147,111,153,111,154,111,155,111,160,111,162,111,165,111,231,111,235,111,242,111,243,111,244,111,259,111,261,111,262,111,266,111,268,111,269,111,270,111,278,111,279,111,117,112,118,112,123,112,124,112,125,112,126,112,128,112,134,112,136,112,137,112,141,112,143,112,148,112,149,112,153,112,155,112,157,112,162,112,238,112,241,112,243,112,244,112,247,112,249,112,250,112,252,112,255,112,256,112,266,112,267,112,268,112,269,112,273,112,274,112,277,112,279,112,108,113,111,113,115,113,120,113,122,113,123,113,124,113,125,113,130,113,135,113,142,113,143,113,144,113,147,113,149,113,150,113,159,113,161,113,206,113,207,113,238,113,244,113,245,113,246,113,249,113,250,113,263,113,264,113,266,113,267,113,269,113,270,113,272,113,274,113,277,113,278,113,111,114,119,114,125,114,126,114,128,114,133,114,134,114,135,114,140,114,142,114,146,114,149,114,155,114,161,114,241,114,246,114,248,114,249,114,253,114,260,114,265,114,266,114,268,114,270,114,273,114,117,115,118,115,119,115,125,115,126,115,140,115,141,115,142,115,143,115,146,115,150,115,155,115,157,115,159,115,235,115,240,115,245,115,250,115,251,115,252,115,253,115,256,115,257,115,258,115,259,115,266,115,267,115,268,115,269,115,271,115,274,115,276,115,278,115,282,115,107,116,120,116,121,116,122,116,125,116,126,116,127,116,130,116,131,116,133,116,134,116,135,116,143,116,144,116,146,116,147,116,150,116,151,116,152,116,155,116,157,116,159,116,236,116,239,116,241,116,244,116,247,116,250,116,252,116,256,116,257,116,258,116,265,116,267,116,268,116,271,116,274,116,276,116,277,116,278,116,279,116,108,117,122,117,126,117,127,117,131,117,132,117,133,117,134,117,140,117,144,117,146,117,148,117,150,117,151,117,237,117,239,117,240,117,245,117,246,117,247,117,252,117,253,117,254,117,256,117,257,117,260,117,261,117,264,117,266,117,267,117,268,117,270,117,272,117,276,117,277,117,281,117,282,117,105,118,108,118,117,118,122,118,123,118,124,118,125,118,127,118,128,118,133,118,134,118,138,118,140,118,141,118,144,118,157,118,237,118,238,118,241,118,243,118,246,118,250,118,253,118,254,118,256,118,258,118,259,118,260,118,261,118,262,118,265,118,266,118,268,118,269,118,270,118,271,118,276,118,283,118,105,119,108,119,113,119,118,119,122,119,124,119,127,119,128,119,131,119,132,119,133,119,137,119,138,119,141,119,146,119,147,119,155,119,224,119,239,119,240,119,241,119,245,119,250,119,251,119,252,119,254,119,255,119,256,119,258,119,259,119,262,119,263,119,265,119,269,119,271,119,275,119,278,119,279,119,283,119,97,120,105,120,115,120,119,120,121,120,123,120,125,120,128,120,131,120,132,120,133,120,134,120,137,120,138,120,140,120,141,120,142,120,143,120,146,120,147,120,224,120,240,120,244,120,248,120,253,120,255,120,256,120,257,120,258,120,259,120,261,120,265,120,266,120,272,120,275,120,278,120,120,121,121,121,122,121,124,121,128,121,132,121,137,121,139,121,141,121,142,121,146,121,147,121,148,121,149,121,151,121,245,121,246,121,250,121,253,121,255,121,256,121,257,121,258,121,259,121,260,121,265,121,266,121,272,121,278,121,279,121,280,121,284,121,104,122,110,122,119,122,120,122,121,122,127,122,128,122,133,122,138,122,142,122,143,122,145,122,149,122,227,122,242,122,243,122,249,122,252,122,253,122,254,122,255,122,256,122,263,122,264,122,265,122,266,122,269,122,270,122,273,122,274,122,275,122,277,122,284,122,286,122,106,123,112,123,116,123,118,123,119,123,120,123,121,123,127,123,136,123,140,123,143,123,144,123,242,123,253,123,254,123,256,123,260,123,262,123,270,123,273,123,277,123,283,123,284,123,285,123,286,123,105,124,107,124,112,124,113,124,115,124,118,124,123,124,124,124,125,124,130,124,133,124,136,124,140,124,146,124,147,124,150,124,231,124,243,124,249,124,260,124,262,124,263,124,264,124,265,124,269,124,273,124,274,124,275,124,278,124,279,124,280,124,281,124,285,124,111,125,114,125,118,125,120,125,121,125,131,125,132,125,139,125,143,125,145,125,150,125,151,125,244,125,247,125,253,125,255,125,257,125,259,125,264,125,266,125,268,125,269,125,271,125,281,125,286,125,111,126,115,126,120,126,124,126,125,126,126,126,128,126,129,126,131,126,132,126,135,126,137,126,141,126,145,126,146,126,148,126,149,126,245,126,246,126,247,126,252,126,254,126,255,126,256,126,258,126,261,126,264,126,266,126,268,126,269,126,270,126,275,126,280,126,281,126,284,126,101,127,109,127,110,127,116,127,117,127,124,127,128,127,129,127,130,127,133,127,134,127,135,127,136,127,141,127,143,127,144,127,145,127,148,127,247,127,252,127,253,127,254,127,256,127,258,127,265,127,267,127,268,127,276,127,279,127,281,127,97,128,98,128,104,128,105,128,110,128,117,128,122,128,125,128,129,128,130,128,131,128,133,128,138,128,139,128,140,128,142,128,145,128,146,128,246,128,247,128,253,128,254,128,256,128,261,128,268,128,275,128,276,128,279,128,280,128,284,128,285,128,287,128,98,129,102,129,110,129,112,129,113,129,118,129,121,129,122,129,123,129,125,129,129,129,131,129,134,129,135,129,137,129,139,129,142,129,143,129,146,129,246,129,247,129,248,129,251,129,253,129,254,129,255,129,256,129,258,129,261,129,263,129,269,129,270,129,273,129,275,129,276,129,278,129,282,129,284,129,286,129,287,129,100,130,114,130,119,130,120,130,124,130,129,130,130,130,133,130,134,130,140,130,145,130,146,130,239,130,247,130,249,130,252,130,256,130,257,130,258,130,262,130,267,130,269,130,273,130,275,130,276,130,278,130,279,130,282,130,286,130,288,130,82,131,99,131,109,131,111,131,113,131,119,131,120,131,121,131,128,131,129,131,130,131,132,131,133,131,136,131,146,131,236,131,262,131,267,131,271,131,274,131,278,131,287,131,98,132,99,132,101,132,111,132,113,132,114,132,115,132,119,132,120,132,123,132,124,132,130,132,133,132,135,132,137,132,139,132,144,132,237,132,248,132,254,132,256,132,260,132,261,132,264,132,265,132,267,132,268,132,269,132,278,132,279,132,283,132,113,133,114,133,115,133,119,133,120,133,121,133,127,133,128,133,131,133,134,133,138,133,144,133,238,133,244,133,269,133,272,133,277,133,279,133,286,133,288,133,88,134,93,134,94,134,107,134,108,134,110,134,111,134,115,134,121,134,122,134,124,134,128,134,133,134,135,134,136,134,146,134,238,134,244,134,245,134,247,134,256,134,257,134,260,134,265,134,267,134,268,134,273,134,275,134,276,134,277,134,278,134,279,134,281,134,285,134,286,134,287,134,288,134,289,134,95,135,107,135,109,135,110,135,117,135,120,135,121,135,126,135,130,135,135,135,139,135,145,135,239,135,240,135,241,135,242,135,244,135,250,135,256,135,257,135,260,135,263,135,264,135,268,135,269,135,271,135,272,135,273,135,275,135,277,135,281,135,282,135,283,135,284,135,288,135,289,135,82,136,83,136,87,136,91,136,111,136,117,136,118,136,120,136,125,136,126,136,128,136,129,136,130,136,131,136,137,136,143,136,240,136,244,136,246,136,250,136,253,136,257,136,258,136,260,136,261,136,262,136,267,136,278,136,280,136,281,136,283,136,284,136,288,136,289,136,57,137,79,137,83,137,86,137,87,137,88,137,90,137,92,137,95,137,96,137,97,137,110,137,112,137,114,137,119,137,120,137,124,137,127,137,132,137,133,137,135,137,140,137,144,137,240,137,246,137,254,137,256,137,261,137,262,137,263,137,265,137,266,137,268,137,269,137,272,137,274,137,278,137,279,137,280,137,281,137,283,137,284,137,287,137,289,137,78,138,80,138,87,138,88,138,89,138,93,138,94,138,96,138,111,138,114,138,129,138,132,138,133,138,134,138,135,138,243,138,248,138,249,138,251,138,255,138,259,138,260,138,261,138,263,138,264,138,265,138,266,138,268,138,269,138,274,138,275,138,276,138,282,138,283,138,285,138,82,139,84,139,86,139,87,139,90,139,93,139,95,139,106,139,111,139,112,139,113,139,114,139,117,139,119,139,124,139,125,139,126,139,127,139,128,139,130,139,134,139,142,139,143,139,241,139,242,139,246,139,259,139,261,139,262,139,268,139,273,139,274,139,275,139,279,139,282,139,289,139,79,140,82,140,83,140,90,140,94,140,95,140,100,140,106,140,110,140,111,140,112,140,113,140,114,140,118,140,119,140,123,140,125,140,127,140,128,140,133,140,135,140,137,140,142,140,242,140,245,140,246,140,247,140,252,140,254,140,256,140,260,140,261,140,267,140,268,140,272,140,281,140,282,140,286,140,287,140,288,140,289,140,290,140,76,141,82,141,85,141,90,141,93,141,94,141,96,141,97,141,106,141,108,141,109,141,111,141,115,141,116,141,117,141,121,141,123,141,134,141,139,141,242,141,243,141,244,141,246,141,247,141,248,141,256,141,258,141,260,141,261,141,270,141,271,141,273,141,275,141,276,141,283,141,284,141,285,141,287,141,290,141,75,142,80,142,84,142,85,142,87,142,88,142,90,142,95,142,101,142,104,142,110,142,111,142,114,142,116,142,118,142,119,142,120,142,126,142,132,142,133,142,135,142,139,142,142,142,243,142,247,142,250,142,251,142,256,142,258,142,259,142,260,142,262,142,264,142,273,142,276,142,279,142,280,142,283,142,284,142,285,142,286,142,287,142,288,142,84,143,86,143,91,143,92,143,110,143,112,143,114,143,117,143,118,143,120,143,121,143,122,143,125,143,126,143,130,143,135,143,136,143,140,143,242,143,243,143,248,143,249,143,250,143,260,143,263,143,275,143,276,143,281,143,282,143,289,143,290,143,291,143,75,144,76,144,78,144,79,144,84,144,85,144,87,144,88,144,92,144,101,144,104,144,107,144,109,144,112,144,113,144,114,144,115,144,118,144,119,144,122,144,243,144,246,144,247,144,248,144,251,144,252,144,258,144,260,144,263,144,265,144,266,144,268,144,271,144,277,144,278,144,279,144,292,144,71,145,74,145,77,145,78,145,79,145,87,145,89,145,91,145,106,145,108,145,113,145,114,145,117,145,122,145,125,145,129,145,130,145,131,145,141,145,243,145,244,145,246,145,248,145,256,145,262,145,265,145,266,145,268,145,269,145,270,145,273,145,276,145,279,145,285,145,286,145,80,146,83,146,93,146,104,146,106,146,115,146,117,146,121,146,122,146,123,146,124,146,125,146,130,146,131,146,132,146,135,146,243,146,244,146,245,146,246,146,247,146,248,146,251,146,252,146,257,146,262,146,263,146,264,146,265,146,269,146,270,146,273,146,276,146,282,146,283,146,284,146,285,146,291,146,74,147,79,147,80,147,81,147,82,147,89,147,90,147,94,147,95,147,98,147,104,147,106,147,114,147,115,147,116,147,117,147,119,147,120,147,121,147,125,147,126,147,129,147,132,147,139,147,244,147,245,147,246,147,247,147,248,147,252,147,253,147,257,147,258,147,259,147,261,147,262,147,269,147,270,147,271,147,273,147,274,147,275,147,288,147,289,147,292,147,74,148,79,148,81,148,83,148,84,148,88,148,89,148,90,148,94,148,104,148,108,148,110,148,111,148,112,148,113,148,115,148,116,148,118,148,119,148,120,148,124,148,125,148,127,148,128,148,129,148,130,148,131,148,132,148,140,148,244,148,245,148,251,148,258,148,259,148,260,148,265,148,266,148,268,148,269,148,270,148,274,148,275,148,279,148,280,148,287,148,288,148,289,148,293,148,302,148,74,149,79,149,80,149,83,149,90,149,94,149,102,149,103,149,109,149,110,149,112,149,113,149,117,149,118,149,124,149,128,149,129,149,132,149,138,149,245,149,247,149,250,149,252,149,258,149,259,149,260,149,261,149,262,149,263,149,265,149,267,149,268,149,269,149,279,149,280,149,281,149,285,149,286,149,301,149,302,149,303,149,79,150,80,150,82,150,83,150,84,150,85,150,93,150,111,150,116,150,117,150,120,150,122,150,124,150,125,150,126,150,131,150,140,150,245,150,247,150,253,150,257,150,264,150,267,150,279,150,280,150,281,150,283,150,284,150,285,150,286,150,290,150,291,150,292,150,293,150,302,150,304,150,305,150,76,151,80,151,82,151,83,151,85,151,89,151,92,151,106,151,107,151,108,151,109,151,110,151,111,151,112,151,113,151,114,151,115,151,118,151,121,151,126,151,132,151,136,151,245,151,246,151,247,151,252,151,260,151,265,151,269,151,273,151,275,151,276,151,277,151,278,151,279,151,280,151,281,151,283,151,285,151,287,151,302,151,305,151,308,151,309,151,310,151,311,151,73,152,74,152,78,152,84,152,85,152,87,152,89,152,90,152,92,152,97,152,101,152,109,152,111,152,112,152,113,152,114,152,117,152,118,152,119,152,120,152,121,152,122,152,123,152,126,152,127,152,132,152,134,152,136,152,245,152,246,152,248,152,249,152,252,152,260,152,261,152,263,152,264,152,267,152,273,152,274,152,275,152,276,152,278,152,279,152,286,152,288,152,303,152,307,152,308,152,309,152,313,152,317,152,318,152,319,152,73,153,77,153,86,153,88,153,89,153,90,153,91,153,95,153,97,153,101,153,102,153,105,153,110,153,111,153,113,153,114,153,115,153,122,153,123,153,126,153,127,153,246,153,247,153,248,153,252,153,253,153,259,153,261,153,264,153,270,153,273,153,275,153,278,153,285,153,289,153,291,153,292,153,303,153,305,153,306,153,307,153,309,153,310,153,311,153,314,153,315,153,317,153,321,153,322,153,323,153,70,154,80,154,81,154,82,154,86,154,87,154,88,154,89,154,90,154,92,154,103,154,106,154,108,154,110,154,115,154,121,154,124,154,128,154,131,154,132,154,246,154,247,154,260,154,261,154,265,154,266,154,268,154,269,154,273,154,274,154,276,154,280,154,283,154,287,154,290,154,292,154,304,154,305,154,308,154,317,154,76,155,82,155,83,155,86,155,90,155,105,155,108,155,111,155,113,155,114,155,115,155,116,155,121,155,122,155,127,155,129,155,132,155,133,155,135,155,139,155,246,155,247,155,262,155,263,155,266,155,267,155,268,155,269,155,270,155,272,155,273,155,274,155,277,155,278,155,287,155,291,155,293,155,302,155,303,155,304,155,306,155,307,155,313,155,315,155,317,155,318,155,319,155,82,156,84,156,86,156,90,156,92,156,93,156,100,156,109,156,111,156,112,156,115,156,116,156,121,156,122,156,124,156,127,156,128,156,129,156,245,156,247,156,248,156,255,156,259,156,262,156,263,156,273,156,282,156,283,156,284,156,285,156,286,156,301,156,302,156,308,156,309,156,310,156,311,156,312,156,316,156,317,156,320,156,322,156,325,156,76,157,82,157,85,157,107,157,108,157,109,157,114,157,115,157,121,157,123,157,124,157,128,157,246,157,247,157,248,157,249,157,260,157,262,157,263,157,264,157,265,157,266,157,270,157,271,157,273,157,274,157,277,157,281,157,284,157,285,157,288,157,289,157,301,157,309,157,310,157,312,157,315,157,316,157,317,157,321,157,322,157,323,157,324,157,325,157,74,158,75,158,76,158,78,158,79,158,82,158,83,158,86,158,87,158,88,158,93,158,101,158,106,158,113,158,114,158,115,158,116,158,117,158,118,158,119,158,121,158,124,158,128,158,130,158,131,158,139,158,246,158,247,158,259,158,263,158,264,158,268,158,271,158,275,158,276,158,281,158,284,158,285,158,286,158,287,158,288,158,289,158,291,158,292,158,293,158,302,158,304,158,305,158,306,158,310,158,314,158,319,158,320,158,321,158,324,158,78,159,85,159,88,159,89,159,90,159,100,159,101,159,106,159,107,159,110,159,111,159,117,159,118,159,119,159,120,159,125,159,138,159,257,159,261,159,267,159,272,159,278,159,280,159,281,159,283,159,284,159,287,159,289,159,294,159,302,159,303,159,304,159,306,159,307,159,309,159,311,159,312,159,317,159,318,159,324,159,79,160,81,160,83,160,84,160,88,160,92,160,100,160,106,160,107,160,111,160,113,160,114,160,117,160,119,160,120,160,121,160,122,160,128,160,129,160,131,160,132,160,247,160,253,160,261,160,264,160,269,160,271,160,272,160,274,160,276,160,277,160,280,160,281,160,283,160,287,160,288,160,291,160,292,160,302,160,303,160,304,160,305,160,309,160,310,160,311,160,313,160,319,160,320,160,323,160,324,160,325,160,77,161,78,161,79,161,81,161,87,161,88,161,89,161,92,161,93,161,98,161,99,161,107,161,108,161,115,161,116,161,125,161,129,161,247,161,248,161,261,161,262,161,263,161,265,161,266,161,269,161,270,161,271,161,277,161,279,161,282,161,283,161,286,161,287,161,292,161,303,161,304,161,305,161,310,161,312,161,319,161,320,161,323,161,74,162,81,162,89,162,91,162,92,162,95,162,99,162,103,162,106,162,107,162,111,162,112,162,118,162,121,162,122,162,129,162,247,162,248,162,262,162,263,162,265,162,268,162,270,162,272,162,277,162,278,162,279,162,280,162,283,162,285,162,287,162,289,162,290,162,291,162,302,162,304,162,309,162,310,162,311,162,312,162,318,162,319,162,320,162,321,162,323,162,69,163,75,163,81,163,85,163,86,163,88,163,89,163,91,163,92,163,93,163,106,163,107,163,111,163,112,163,118,163,119,163,121,163,127,163,128,163,132,163,247,163,260,163,262,163,263,163,265,163,268,163,269,163,270,163,272,163,275,163,276,163,279,163,283,163,285,163,286,163,287,163,289,163,302,163,304,163,305,163,307,163,310,163,313,163,320,163,323,163,324,163,325,163,68,164,69,164,74,164,81,164,82,164,84,164,88,164,89,164,90,164,94,164,95,164,102,164,104,164,105,164,108,164,109,164,113,164,120,164,128,164,129,164,138,164,247,164,258,164,259,164,262,164,263,164,265,164,266,164,267,164,270,164,273,164,274,164,275,164,276,164,282,164,287,164,288,164,302,164,304,164,306,164,308,164,309,164,316,164,321,164,322,164,324,164,72,165,73,165,74,165,75,165,80,165,82,165,85,165,93,165,106,165,108,165,109,165,116,165,117,165,118,165,119,165,120,165,121,165,124,165,125,165,131,165,138,165,247,165,252,165,263,165,267,165,268,165,269,165,270,165,272,165,273,165,274,165,282,165,283,165,286,165,288,165,289,165,293,165,303,165,305,165,306,165,312,165,313,165,314,165,319,165,322,165,323,165,324,165,63,166,73,166,74,166,84,166,87,166,92,166,95,166,96,166,99,166,104,166,105,166,109,166,110,166,112,166,115,166,120,166,121,166,126,166,128,166,130,166,134,166,136,166,139,166,260,166,263,166,265,166,266,166,267,166,268,166,270,166,272,166,273,166,274,166,275,166,279,166,280,166,282,166,283,166,284,166,285,166,286,166,288,166,291,166,293,166,303,166,304,166,305,166,307,166,312,166,313,166,314,166,316,166,318,166,324,166,58,167,59,167,84,167,87,167,88,167,92,167,94,167,99,167,103,167,107,167,109,167,110,167,113,167,115,167,117,167,118,167,119,167,121,167,123,167,125,167,128,167,258,167,259,167,263,167,266,167,267,167,268,167,269,167,272,167,273,167,274,167,275,167,282,167,283,167,284,167,288,167,289,167,290,167,291,167,301,167,304,167,305,167,309,167,310,167,316,167,317,167,324,167,325,167,92,168,107,168,108,168,109,168,110,168,111,168,113,168,117,168,124,168,129,168,130,168,135,168,138,168,139,168,247,168,261,168,265,168,266,168,268,168,275,168,281,168,288,168,289,168,290,168,301,168,304,168,305,168,309,168,311,168,312,168,315,168,317,168,318,168,322,168,323,168,324,168,325,168,99,169,106,169,108,169,110,169,112,169,115,169,116,169,126,169,132,169,135,169,138,169,252,169,262,169,267,169,269,169,270,169,272,169,273,169,274,169,278,169,280,169,281,169,285,169,287,169,301,169,302,169,304,169,305,169,307,169,308,169,312,169,313,169,316,169,317,169,318,169,319,169,322,169,323,169,325,169,107,170,108,170,109,170,111,170,114,170,115,170,117,170,118,170,121,170,139,170,256,170,261,170,263,170,266,170,267,170,269,170,270,170,272,170,281,170,285,170,288,170,289,170,290,170,292,170,302,170,303,170,305,170,307,170,309,170,316,170,317,170,320,170,321,170,322,170,324,170,107,171,109,171,112,171,113,171,115,171,116,171,118,171,121,171,122,171,125,171,128,171,131,171,134,171,137,171,138,171,246,171,263,171,267,171,268,171,269,171,271,171,277,171,278,171,280,171,283,171,285,171,287,171,288,171,290,171,292,171,293,171,304,171,305,171,308,171,309,171,310,171,311,171,312,171,314,171,316,171,317,171,318,171,319,171,321,171,322,171,324,171,109,172,113,172,115,172,116,172,118,172,119,172,120,172,123,172,128,172,140,172,246,172,255,172,257,172,260,172,264,172,265,172,267,172,268,172,269,172,271,172,277,172,279,172,280,172,282,172,284,172,290,172,291,172,292,172,303,172,304,172,305,172,309,172,310,172,312,172,313,172,314,172,315,172,316,172,321,172,322,172,323,172,99,173,104,173,108,173,111,173,113,173,114,173,119,173,122,173,124,173,126,173,132,173,135,173,136,173,139,173,141,173,244,173,245,173,258,173,259,173,260,173,262,173,264,173,266,173,271,173,272,173,279,173,286,173,290,173,291,173,292,173,304,173,305,173,306,173,308,173,313,173,314,173,316,173,325,173,99,174,104,174,109,174,113,174,117,174,127,174,130,174,132,174,133,174,135,174,141,174,244,174,256,174,257,174,258,174,263,174,264,174,271,174,272,174,273,174,278,174,279,174,289,174,305,174,307,174,309,174,314,174,315,174,318,174,324,174,325,174,326,174,94,175,95,175,99,175,100,175,104,175,107,175,117,175,120,175,122,175,126,175,127,175,133,175,140,175,141,175,243,175,244,175,257,175,258,175,259,175,260,175,261,175,262,175,263,175,264,175,265,175,266,175,270,175,271,175,272,175,283,175,284,175,285,175,286,175,288,175,289,175,302,175,303,175,307,175,308,175,311,175,312,175,313,175,315,175,316,175,323,175,90,176,93,176,94,176,95,176,99,176,100,176,101,176,104,176,110,176,115,176,116,176,119,176,120,176,122,176,123,176,124,176,125,176,133,176,134,176,136,176,138,176,139,176,244,176,248,176,257,176,259,176,262,176,263,176,266,176,270,176,283,176,286,176,289,176,291,176,304,176,305,176,306,176,308,176,310,176,311,176,318,176,320,176,321,176,322,176,89,177,90,177,92,177,93,177,94,177,97,177,98,177,111,177,114,177,117,177,118,177,120,177,121,177,122,177,124,177,126,177,131,177,134,177,138,177,141,177,242,177,257,177,259,177,266,177,267,177,283,177,284,177,286,177,288,177,289,177,290,177,301,177,304,177,305,177,306,177,307,177,308,177,309,177,312,177,314,177,315,177,321,177,322,177,323,177,325,177,90,178,99,178,101,178,104,178,107,178,109,178,112,178,116,178,117,178,118,178,120,178,121,178,122,178,128,178,133,178,136,178,137,178,139,178,140,178,242,178,243,178,255,178,256,178,257,178,258,178,259,178,260,178,265,178,266,178,271,178,273,178,279,178,282,178,284,178,286,178,287,178,289,178,290,178,301,178,306,178,311,178,315,178,316,178,318,178,319,178,321,178,322,178,323,178,95,179,96,179,98,179,99,179,101,179,112,179,116,179,118,179,120,179,122,179,123,179,126,179,128,179,134,179,139,179,140,179,242,179,255,179,257,179,259,179,260,179,271,179,273,179,274,179,275,179,280,179,284,179,285,179,301,179,305,179,306,179,307,179,311,179,312,179,314,179,315,179,316,179,318,179,321,179,322,179,323,179,88,180,89,180,91,180,92,180,97,180,98,180,102,180,107,180,111,180,113,180,114,180,121,180,122,180,129,180,130,180,132,180,133,180,134,180,139,180,140,180,141,180,241,180,242,180,255,180,259,180,260,180,261,180,264,180,266,180,267,180,268,180,269,180,270,180,274,180,275,180,278,180,280,180,281,180,282,180,284,180,285,180,287,180,288,180,302,180,309,180,312,180,316,180,319,180,320,180,321,180,324,180,87,181,88,181,89,181,92,181,93,181,97,181,100,181,106,181,109,181,110,181,117,181,123,181,128,181,137,181,139,181,140,181,241,181,242,181,255,181,259,181,260,181,261,181,263,181,266,181,267,181,270,181,277,181,278,181,279,181,283,181,284,181,285,181,286,181,300,181,306,181,307,181,308,181,311,181,312,181,313,181,314,181,317,181,321,181,322,181,102,182,103,182,106,182,107,182,108,182,113,182,115,182,121,182,122,182,123,182,124,182,125,182,126,182,130,182,134,182,138,182,140,182,142,182,143,182,253,182,258,182,265,182,277,182,278,182,279,182,280,182,282,182,283,182,284,182,300,182,301,182,302,182,303,182,311,182,313,182,314,182,318,182,319,182,325,182,100,183,106,183,108,183,109,183,111,183,114,183,118,183,119,183,121,183,122,183,123,183,124,183,125,183,126,183,130,183,135,183,136,183,138,183,240,183,241,183,252,183,254,183,258,183,263,183,272,183,276,183,278,183,279,183,284,183,287,183,289,183,303,183,311,183,312,183,315,183,319,183,320,183,322,183,97,184,98,184,101,184,105,184,108,184,110,184,111,184,112,184,113,184,118,184,119,184,120,184,122,184,123,184,124,184,125,184,126,184,127,184,129,184,136,184,142,184,239,184,240,184,252,184,256,184,257,184,258,184,261,184,263,184,265,184,266,184,276,184,278,184,287,184,288,184,299,184,300,184,301,184,302,184,305,184,307,184,308,184,309,184,310,184,313,184,318,184,92,185,99,185,109,185,112,185,113,185,115,185,118,185,119,185,121,185,122,185,124,185,130,185,132,185,135,185,144,185,145,185,238,185,239,185,255,185,256,185,257,185,258,185,261,185,266,185,281,185,283,185,287,185,288,185,302,185,96,186,99,186,102,186,105,186,111,186,112,186,113,186,114,186,116,186,118,186,119,186,121,186,122,186,123,186,124,186,125,186,130,186,131,186,135,186,137,186,141,186,238,186,239,186,253,186,254,186,255,186,256,186,259,186,260,186,266,186,270,186,276,186,278,186,281,186,283,186,102,187,111,187,112,187,115,187,116,187,118,187,119,187,121,187,124,187,125,187,128,187,137,187,140,187,237,187,238,187,239,187,259,187,273,187,274,187,278,187,279,187,280,187,284,187,286,187,110,188,111,188,112,188,118,188,119,188,120,188,121,188,122,188,123,188,124,188,126,188,127,188,128,188,129,188,130,188,133,188,134,188,141,188,144,188,145,188,237,188,238,188,254,188,258,188,276,188,278,188,279,188,283,188,100,189,104,189,105,189,108,189,109,189,110,189,112,189,118,189,119,189,126,189,128,189,129,189,131,189,135,189,136,189,138,189,139,189,143,189,144,189,147,189,236,189,237,189,252,189,254,189,263,189,264,189,274,189,279,189,281,189,283,189,284,189,288,189,101,190,109,190,111,190,114,190,115,190,119,190,122,190,124,190,126,190,128,190,129,190,136,190,141,190,144,190,236,190,237,190,239,190,251,190,253,190,254,190,255,190,257,190,261,190,262,190,272,190,273,190,274,190,286,190,100,191,103,191,110,191,111,191,113,191,115,191,117,191,118,191,119,191,124,191,125,191,127,191,128,191,133,191,135,191,136,191,139,191,144,191,148,191,235,191,237,191,251,191,252,191,257,191,258,191,260,191,261,191,276,191,277,191,281,191,282,191,288,191,100,192,106,192,107,192,112,192,115,192,117,192,120,192,123,192,124,192,127,192,133,192,134,192,135,192,136,192,141,192,144,192,148,192,149,192,234,192,235,192,249,192,250,192,251,192,255,192,257,192,260,192,271,192,278,192,280,192,106,193,110,193,111,193,114,193,117,193,118,193,120,193,132,193,141,193,142,193,143,193,144,193,149,193,233,193,234,193,253,193,254,193,257,193,260,193,268,193,274,193,278,193,279,193,280,193,281,193,285,193,286,193,98,194,102,194,104,194,106,194,118,194,126,194,128,194,134,194,136,194,137,194,139,194,151,194,232,194,233,194,246,194,250,194,252,194,255,194,256,194,261,194,262,194,270,194,278,194,279,194,94,195,98,195,101,195,102,195,103,195,104,195,105,195,107,195,110,195,112,195,116,195,117,195,118,195,119,195,123,195,126,195,129,195,131,195,134,195,135,195,140,195,144,195,148,195,231,195,232,195,250,195,251,195,252,195,256,195,257,195,259,195,260,195,262,195,263,195,266,195,279,195,280,195,282,195,107,196,110,196,112,196,116,196,117,196,118,196,122,196,125,196,129,196,131,196,132,196,133,196,134,196,140,196,141,196,143,196,148,196,151,196,230,196,231,196,247,196,250,196,255,196,259,196,267,196,268,196,269,196,270,196,271,196,273,196,276,196,277,196,280,196,283,196,284,196,95,197,106,197,108,197,111,197,116,197,119,197,120,197,125,197,126,197,131,197,140,197,141,197,148,197,228,197,229,197,231,197,250,197,253,197,254,197,255,197,256,197,257,197,264,197,265,197,266,197,267,197,270,197,271,197,274,197,275,197,276,197,278,197,279,197,282,197,283,197,284,197,107,198,108,198,112,198,113,198,114,198,116,198,117,198,120,198,124,198,126,198,130,198,132,198,133,198,134,198,135,198,136,198,137,198,139,198,140,198,141,198,143,198,149,198,153,198,227,198,228,198,229,198,237,198,250,198,253,198,254,198,255,198,257,198,259,198,269,198,270,198,272,198,273,198,275,198,277,198,278,198,279,198,282,198,283,198,103,199,104,199,105,199,106,199,107,199,114,199,118,199,122,199,130,199,131,199,135,199,136,199,140,199,141,199,142,199,145,199,146,199,147,199,149,199,152,199,153,199,226,199,227,199,228,199,244,199,247,199,248,199,249,199,250,199,251,199,252,199,254,199,260,199,262,199,272,199,276,199,277,199,280,199,283,199,102,200,103,200,106,200,107,200,115,200,116,200,117,200,118,200,121,200,122,200,123,200,125,200,126,200,135,200,137,200,140,200,142,200,143,200,145,200,148,200,223,200,224,200,225,200,226,200,227,200,243,200,245,200,248,200,249,200,250,200,251,200,253,200,256,200,260,200,262,200,272,200,275,200,278,200,281,200,283,200,96,201,97,201,104,201,107,201,108,201,110,201,115,201,123,201,126,201,129,201,130,201,134,201,135,201,136,201,137,201,141,201,148,201,153,201,155,201,174,201,222,201,223,201,225,201,242,201,243,201,244,201,249,201,250,201,251,201,252,201,253,201,256,201,262,201,263,201,264,201,266,201,267,201,275,201,276,201,277,201,104,202,110,202,112,202,117,202,122,202,126,202,133,202,134,202,137,202,144,202,147,202,151,202,157,202,158,202,175,202,221,202,222,202,223,202,224,202,241,202,243,202,247,202,248,202,249,202,250,202,257,202,261,202,262,202,263,202,268,202,269,202,270,202,274,202,100,203,101,203,104,203,106,203,107,203,110,203,112,203,115,203,119,203,120,203,131,203,132,203,133,203,137,203,138,203,139,203,141,203,151,203,153,203,159,203,217,203,218,203,219,203,222,203,239,203,244,203,248,203,249,203,250,203,251,203,252,203,253,203,256,203,257,203,258,203,261,203,263,203,267,203,270,203,271,203,272,203,273,203,274,203,277,203,281,203,100,204,101,204,102,204,104,204,105,204,106,204,107,204,108,204,112,204,116,204,118,204,120,204,127,204,128,204,132,204,135,204,138,204,140,204,141,204,145,204,149,204,154,204,214,204,215,204,216,204,217,204,220,204,244,204,249,204,250,204,255,204,256,204,257,204,258,204,262,204,269,204,270,204,271,204,274,204,275,204,277,204,279,204,280,204,282,204,102,205,103,205,104,205,105,205,106,205,107,205,108,205,116,205,118,205,119,205,120,205,127,205,128,205,129,205,132,205,133,205,138,205,139,205,142,205,143,205,144,205,145,205,146,205,147,205,148,205,182,205,212,205,213,205,214,205,216,205,217,205,219,205,220,205,221,205,241,205,249,205,251,205,255,205,268,205,271,205,272,205,273,205,274,205,277,205,278,205,279,205,280,205,282,205,101,206,104,206,105,206,109,206,116,206,118,206,123,206,124,206,125,206,127,206,129,206,136,206,152,206,153,206,157,206,162,206,186,206,209,206,210,206,211,206,212,206,213,206,216,206,224,206,241,206,245,206,246,206,248,206,249,206,253,206,261,206,266,206,267,206,272,206,276,206,279,206,102,207,105,207,107,207,115,207,117,207,118,207,119,207,120,207,124,207,125,207,126,207,129,207,130,207,132,207,134,207,135,207,137,207,141,207,144,207,145,207,149,207,150,207,153,207,154,207,155,207,159,207,160,207,189,207,192,207,193,207,204,207,205,207,206,207,208,207,212,207,213,207,220,207,234,207,235,207,240,207,245,207,249,207,250,207,252,207,253,207,256,207,259,207,265,207,266,207,274,207,279,207,102,208,105,208,106,208,116,208,117,208,122,208,123,208,128,208,131,208,132,208,137,208,138,208,140,208,142,208,144,208,148,208,150,208,151,208,152,208,155,208,162,208,164,208,195,208,196,208,203,208,204,208,211,208,212,208,213,208,214,208,221,208,239,208,241,208,242,208,243,208,244,208,249,208,252,208,256,208,257,208,258,208,259,208,262,208,263,208,264,208,271,208,272,208,273,208,274,208,275,208,277,208,278,208,279,208,104,209,105,209,114,209,118,209,119,209,122,209,123,209,131,209,135,209,136,209,139,209,140,209,141,209,143,209,147,209,152,209,156,209,158,209,164,209,165,209,167,209,207,209,215,209,222,209,223,209,241,209,244,209,256,209,257,209,258,209,261,209,262,209,263,209,272,209,274,209,275,209,277,209,279,209,103,210,104,210,118,210,123,210,126,210,131,210,146,210,147,210,148,210,151,210,159,210,162,210,168,210,169,210,204,210,207,210,210,210,231,210,235,210,239,210,242,210,243,210,245,210,246,210,247,210,255,210,258,210,260,210,261,210,262,210,265,210,268,210,269,210,270,210,271,210,273,210,274,210,105,211,118,211,120,211,121,211,122,211,123,211,125,211,126,211,127,211,134,211,142,211,144,211,147,211,149,211,150,211,152,211,155,211,156,211,157,211,159,211,162,211,168,211,170,211,171,211,193,211,196,211,197,211,198,211,201,211,203,211,204,211,205,211,208,211,212,211,213,211,233,211,238,211,239,211,240,211,241,211,242,211,243,211,245,211,246,211,247,211,250,211,255,211,258,211,260,211,261,211,264,211,265,211,267,211,269,211,270,211,271,211,272,211,274,211,102,212,103,212,104,212,110,212,111,212,116,212,118,212,124,212,129,212,133,212,134,212,135,212,141,212,145,212,151,212,152,212,156,212,164,212,165,212,166,212,168,212,173,212,198,212,199,212,200,212,202,212,204,212,217,212,218,212,236,212,238,212,239,212,246,212,247,212,248,212,252,212,253,212,254,212,258,212,259,212,261,212,265,212,271,212,272,212,273,212,274,212,103,213,104,213,106,213,117,213,119,213,127,213,128,213,129,213,131,213,132,213,138,213,147,213,150,213,152,213,153,213,155,213,156,213,157,213,158,213,159,213,160,213,168,213,170,213,171,213,175,213,210,213,228,213,229,213,237,213,238,213,241,213,245,213,246,213,247,213,256,213,257,213,259,213,260,213,263,213,266,213,276,213,277,213,99,214,105,214,109,214,111,214,112,214,117,214,118,214,119,214,120,214,121,214,125,214,134,214,139,214,147,214,148,214,149,214,150,214,153,214,154,214,155,214,159,214,162,214,170,214,172,214,176,214,178,214,179,214,202,214,212,214,214,214,224,214,227,214,229,214,230,214,234,214,235,214,236,214,237,214,238,214,241,214,245,214,251,214,256,214,257,214,258,214,259,214,268,214,270,214,272,214,275,214,276,214,277,214,101,215,104,215,109,215,120,215,121,215,122,215,126,215,127,215,128,215,133,215,137,215,138,215,147,215,150,215,153,215,155,215,156,215,162,215,168,215,169,215,170,215,177,215,180,215,193,215,197,215,225,215,226,215,229,215,230,215,236,215,238,215,240,215,241,215,242,215,244,215,245,215,248,215,249,215,251,215,258,215,259,215,265,215,266,215,269,215,271,215,274,215,275,215,276,215,101,216,103,216,104,216,118,216,119,216,122,216,128,216,130,216,131,216,132,216,134,216,144,216,145,216,146,216,148,216,152,216,155,216,157,216,158,216,159,216,162,216,163,216,168,216,170,216,173,216,181,216,183,216,185,216,186,216,187,216,192,216,196,216,197,216,199,216,216,216,218,216,219,216,220,216,225,216,231,216,233,216,234,216,236,216,237,216,243,216,244,216,251,216,257,216,258,216,259,216,263,216,265,216,267,216,268,216,269,216,98,217,100,217,101,217,110,217,121,217,123,217,127,217,131,217,133,217,135,217,144,217,146,217,147,217,149,217,150,217,151,217,155,217,159,217,160,217,166,217,170,217,172,217,174,217,178,217,181,217,183,217,189,217,191,217,194,217,195,217,205,217,218,217,220,217,223,217,228,217,229,217,233,217,234,217,237,217,242,217,243,217,249,217,255,217,265,217,267,217,268,217,269,217,272,217,274,217,275,217,98,218,107,218,108,218,110,218,111,218,114,218,120,218,121,218,124,218,128,218,130,218,131,218,132,218,135,218,137,218,138,218,140,218,141,218,145,218,150,218,151,218,153,218,156,218,159,218,160,218,161,218,162,218,165,218,166,218,167,218,168,218,170,218,171,218,172,218,173,218,175,218,189,218,196,218,214,218,221,218,225,218,229,218,230,218,237,218,239,218,240,218,242,218,243,218,245,218,249,218,254,218,260,218,264,218,265,218,266,218,267,218,268,218,105,219,106,219,109,219,110,219,121,219,122,219,124,219,126,219,128,219,129,219,131,219,137,219,138,219,148,219,151,219,152,219,153,219,154,219,155,219,157,219,159,219,160,219,161,219,165,219,167,219,171,219,173,219,181,219,182,219,189,219,195,219,196,219,199,219,212,219,214,219,216,219,218,219,219,219,224,219,227,219,229,219,230,219,232,219,245,219,247,219,248,219,252,219,253,219,254,219,255,219,258,219,259,219,263,219,264,219,265,219,266,219,267,219,268,219,270,219,105,220,110,220,111,220,123,220,128,220,132,220,133,220,137,220,138,220,142,220,144,220,145,220,148,220,152,220,154,220,155,220,157,220,160,220,161,220,174,220,184,220,189,220,192,220,195,220,198,220,199,220,200,220,201,220,203,220,204,220,207,220,208,220,211,220,212,220,213,220,216,220,218,220,222,220,224,220,230,220,232,220,236,220,238,220,239,220,240,220,246,220,247,220,250,220,251,220,253,220,264,220,265,220,266,220,271,220,104,221,108,221,109,221,110,221,112,221,113,221,115,221,117,221,125,221,128,221,129,221,130,221,132,221,136,221,142,221,143,221,144,221,146,221,148,221,160,221,161,221,165,221,166,221,170,221,171,221,175,221,182,221,188,221,195,221,199,221,203,221,204,221,206,221,208,221,211,221,216,221,217,221,218,221,220,221,226,221,231,221,233,221,234,221,243,221,248,221,249,221,252,221,253,221,258,221,261,221,263,221,264,221,265,221,104,222,106,222,107,222,108,222,109,222,110,222,118,222,123,222,124,222,126,222,127,222,131,222,133,222,134,222,136,222,141,222,144,222,146,222,147,222,154,222,156,222,159,222,165,222,166,222,168,222,169,222,171,222,172,222,183,222,188,222,190,222,191,222,192,222,194,222,195,222,199,222,202,222,206,222,208,222,211,222,215,222,217,222,218,222,220,222,225,222,226,222,232,222,236,222,240,222,242,222,245,222,250,222,258,222,260,222,264,222,266,222,103,223,104,223,105,223,106,223,107,223,109,223,110,223,112,223,115,223,117,223,124,223,127,223,130,223,131,223,133,223,135,223,141,223,142,223,143,223,145,223,150,223,152,223,159,223,162,223,164,223,165,223,167,223,171,223,173,223,178,223,182,223,190,223,191,223,193,223,201,223,209,223,210,223,217,223,218,223,219,223,226,223,229,223,245,223,246,223,251,223,258,223,259,223,260,223,261,223,262,223,264,223,102,224,103,224,104,224,105,224,109,224,113,224,114,224,117,224,127,224,130,224,131,224,132,224,133,224,134,224,137,224,141,224,142,224,143,224,144,224,145,224,146,224,147,224,148,224,149,224,150,224,151,224,152,224,154,224,155,224,158,224,159,224,163,224,168,224,169,224,170,224,172,224,174,224,177,224,178,224,184,224,186,224,192,224,193,224,196,224,202,224,205,224,206,224,217,224,223,224,224,224,225,224,228,224,229,224,230,224,231,224,232,224,233,224,241,224,256,224,258,224,260,224,264,224,101,225,102,225,106,225,107,225,109,225,113,225,114,225,119,225,127,225,129,225,131,225,135,225,137,225,139,225,140,225,141,225,145,225,146,225,149,225,151,225,153,225,154,225,155,225,158,225,159,225,161,225,162,225,168,225,172,225,174,225,177,225,180,225,181,225,184,225,185,225,186,225,190,225,191,225,196,225,197,225,202,225,205,225,206,225,207,225,216,225,217,225,221,225,222,225,223,225,229,225,230,225,238,225,239,225,241,225,244,225,246,225,251,225,257,225,258,225,103,226,104,226,105,226,106,226,107,226,118,226,119,226,127,226,130,226,132,226,134,226,139,226,145,226,149,226,152,226,153,226,154,226,155,226,156,226,157,226,158,226,160,226,164,226,165,226,174,226,175,226,177,226,178,226,181,226,184,226,186,226,189,226,191,226,197,226,216,226,221,226,222,226,225,226,228,226,229,226,235,226,238,226,239,226,248,226,249,226,253,226,258,226,259,226,261,226,263,226,265,226,99,227,101,227,102,227,105,227,106,227,108,227,109,227,110,227,111,227,114,227,116,227,119,227,131,227,132,227,136,227,137,227,140,227,142,227,143,227,145,227,150,227,151,227,152,227,155,227,156,227,159,227,160,227,163,227,166,227,171,227,177,227,183,227,185,227,187,227,188,227,189,227,195,227,197,227,200,227,203,227,205,227,210,227,212,227,215,227,216,227,224,227,225,227,227,227,235,227,239,227,240,227,245,227,252,227,256,227,258,227,259,227,262,227,263,227,266,227,102,228,103,228,104,228,106,228,107,228,110,228,112,228,114,228,115,228,118,228,119,228,131,228,133,228,134,228,135,228,136,228,137,228,138,228,140,228,142,228,147,228,150,228,151,228,154,228,162,228,164,228,165,228,166,228,169,228,171,228,172,228,175,228,182,228,183,228,186,228,187,228,189,228,191,228,192,228,195,228,197,228,198,228,200,228,201,228,206,228,210,228,211,228,215,228,219,228,220,228,225,228,227,228,228,228,234,228,236,228,243,228,246,228,247,228,252,228,255,228,256,228,259,228,261,228,263,228,97,229,99,229,110,229,116,229,118,229,119,229,133,229,134,229,135,229,136,229,137,229,138,229,140,229,141,229,144,229,146,229,147,229,148,229,150,229,151,229,154,229,167,229,168,229,171,229,174,229,177,229,184,229,187,229,191,229,193,229,195,229,196,229,198,229,199,229,202,229,205,229,206,229,211,229,212,229,213,229,228,229,233,229,236,229,237,229,241,229,250,229,251,229,253,229,256,229,257,229,258,229,259,229,263,229,275,229,96,230,98,230,108,230,109,230,111,230,113,230,122,230,131,230,134,230,136,230,138,230,139,230,140,230,148,230,150,230,152,230,156,230,157,230,159,230,160,230,163,230,180,230,183,230,187,230,189,230,201,230,202,230,206,230,208,230,209,230,211,230,212,230,213,230,214,230,222,230,223,230,236,230,237,230,241,230,252,230,256,230,258,230,259,230,275,230,278,230,279,230,281,230,282,230,96,231,98,231,99,231,100,231,103,231,104,231,105,231,108,231,111,231,112,231,114,231,115,231,117,231,118,231,120,231,122,231,134,231,136,231,140,231,144,231,146,231,149,231,151,231,156,231,157,231,161,231,163,231,175,231,176,231,177,231,179,231,185,231,187,231,188,231,192,231,201,231,202,231,211,231,212,231,213,231,216,231,217,231,220,231,222,231,223,231,224,231,238,231,239,231,240,231,244,231,245,231,247,231,256,231,278,231,98,232,101,232,102,232,106,232,108,232,109,232,110,232,114,232,116,232,118,232,119,232,122,232,124,232,134,232,136,232,138,232,139,232,140,232,141,232,144,232,145,232,146,232,147,232,148,232,150,232,151,232,152,232,153,232,157,232,162,232,165,232,169,232,176,232,177,232,180,232,181,232,184,232,187,232,190,232,191,232,194,232,196,232,197,232,208,232,209,232,212,232,218,232,224,232,238,232,240,232,244,232,250,232,252,232,255,232,256,232,276,232,277,232,283,232,94,233,97,233,104,233,105,233,107,233,109,233,113,233,115,233,116,233,117,233,120,233,122,233,123,233,126,233,140,233,144,233,145,233,146,233,148,233,149,233,152,233,154,233,158,233,160,233,161,233,163,233,164,233,169,233,172,233,173,233,177,233,181,233,182,233,196,233,200,233,201,233,203,233,205,233,206,233,208,233,212,233,217,233,223,233,224,233,227,233,228,233,233,233,234,233,240,233,243,233,244,233,256,233,258,233,91,234,92,234,96,234,102,234,109,234,113,234,114,234,115,234,116,234,118,234,123,234,128,234,137,234,140,234,144,234,146,234,151,234,152,234,155,234,156,234,157,234,158,234,161,234,163,234,171,234,172,234,173,234,177,234,178,234,179,234,182,234,187,234,189,234,190,234,195,234,196,234,205,234,206,234,208,234,209,234,210,234,212,234,216,234,220,234,222,234,224,234,233,234,246,234,247,234,253,234,255,234,256,234,257,234,90,235,100,235,102,235,106,235,107,235,108,235,109,235,110,235,115,235,116,235,118,235,137,235,144,235,145,235,147,235,149,235,152,235,153,235,155,235,160,235,161,235,162,235,163,235,165,235,168,235,170,235,171,235,184,235,186,235,200,235,205,235,210,235,218,235,219,235,222,235,233,235,236,235,245,235,247,235,252,235,253,235,256,235,257,235,269,235,270,235,89,236,100,236,105,236,106,236,109,236,111,236,115,236,116,236,119,236,120,236,123,236,124,236,138,236,139,236,141,236,146,236,147,236,162,236,166,236,167,236,171,236,176,236,182,236,185,236,187,236,189,236,192,236,195,236,201,236,203,236,204,236,205,236,210,236,211,236,213,236,219,236,222,236,231,236,236,236,237,236,242,236,243,236,244,236,246,236,250,236,252,236,256,236,270,236,273,236,276,236,278,236,87,237,100,237,106,237,114,237,115,237,118,237,119,237,120,237,123,237,128,237,145,237,147,237,152,237,159,237,163,237,166,237,170,237,174,237,175,237,183,237,186,237,187,237,190,237,191,237,200,237,206,237,211,237,216,237,218,237,224,237,225,237,226,237,227,237,228,237,232,237,233,237,235,237,236,237,240,237,241,237,244,237,246,237,251,237,268,237,269,237,280,237,281,237,98,238,105,238,106,238,107,238,108,238,111,238,113,238,114,238,118,238,119,238,120,238,121,238,123,238,126,238,132,238,145,238,146,238,148,238,149,238,154,238,156,238,160,238,163,238,166,238,167,238,168,238,169,238,170,238,171,238,172,238,175,238,179,238,181,238,182,238,183,238,191,238,193,238,194,238,200,238,205,238,206,238,218,238,234,238,239,238,240,238,241,238,243,238,244,238,246,238,247,238,250,238,252,238,253,238,273,238,274,238,278,238,84,239,100,239,102,239,103,239,104,239,107,239,115,239,119,239,120,239,121,239,123,239,125,239,144,239,145,239,148,239,151,239,153,239,156,239,157,239,158,239,159,239,161,239,162,239,164,239,165,239,166,239,172,239,173,239,176,239,177,239,180,239,187,239,188,239,191,239,192,239,198,239,199,239,200,239,201,239,203,239,210,239,212,239,213,239,215,239,217,239,218,239,220,239,224,239,229,239,235,239,236,239,237,239,239,239,243,239,244,239,252,239,266,239,267,239,274,239,275,239,286,239,287,239,103,240,110,240,119,240,121,240,123,240,124,240,125,240,127,240,128,240,130,240,132,240,144,240,145,240,146,240,150,240,151,240,153,240,154,240,158,240,160,240,162,240,163,240,164,240,165,240,171,240,172,240,173,240,174,240,175,240,179,240,183,240,186,240,187,240,198,240,199,240,205,240,206,240,214,240,222,240,223,240,225,240,233,240,234,240,235,240,239,240,242,240,243,240,244,240,245,240,247,240,248,240,267,240,271,240,273,240,275,240,278,240,279,240,280,240,281,240,285,240,286,240,288,240,108,241,109,241,110,241,117,241,119,241,121,241,124,241,125,241,127,241,150,241,154,241,155,241,156,241,157,241,160,241,161,241,164,241,166,241,167,241,169,241,170,241,171,241,172,241,174,241,175,241,178,241,179,241,182,241,183,241,193,241,210,241,211,241,214,241,215,241,217,241,218,241,219,241,222,241,223,241,224,241,230,241,233,241,243,241,244,241,247,241,263,241,264,241,272,241,273,241,275,241,277,241,278,241,280,241,281,241,285,241,103,242,104,242,106,242,108,242,110,242,115,242,116,242,118,242,119,242,121,242,123,242,148,242,149,242,155,242,157,242,159,242,160,242,164,242,166,242,169,242,170,242,175,242,179,242,197,242,200,242,203,242,210,242,211,242,214,242,217,242,218,242,219,242,223,242,229,242,230,242,231,242,233,242,237,242,238,242,241,242,243,242,246,242,247,242,248,242,268,242,271,242,276,242,277,242,279,242,280,242,282,242,286,242,106,243,108,243,111,243,116,243,118,243,120,243,123,243,124,243,151,243,152,243,153,243,154,243,155,243,156,243,158,243,164,243,165,243,168,243,169,243,170,243,171,243,174,243,180,243,181,243,184,243,185,243,195,243,196,243,202,243,208,243,211,243,217,243,219,243,220,243,226,243,227,243,235,243,236,243,238,243,239,243,240,243,241,243,242,243,243,243,261,243,266,243,267,243,273,243,275,243,276,243,279,243,283,243,287,243,288,243,289,243,105,244,108,244,109,244,110,244,114,244,116,244,117,244,122,244,123,244,155,244,159,244,160,244,165,244,167,244,172,244,175,244,176,244,177,244,191,244,194,244,195,244,197,244,199,244,203,244,204,244,206,244,207,244,209,244,213,244,215,244,219,244,220,244,221,244,222,244,225,244,226,244,227,244,228,244,230,244,233,244,234,244,235,244,241,244,268,244,269,244,274,244,279,244,280,244,281,244,105,245,108,245,110,245,111,245,112,245,113,245,117,245,118,245,119,245,120,245,123,245,124,245,155,245,157,245,161,245,169,245,171,245,175,245,176,245,179,245,184,245,188,245,189,245,194,245,195,245,202,245,206,245,208,245,209,245,213,245,214,245,218,245,219,245,230,245,232,245,235,245,236,245,240,245,268,245,274,245,278,245,281,245,282,245,287,245,289,245,290,245,106,246,107,246,116,246,122,246,123,246,159,246,163,246,164,246,165,246,167,246,172,246,174,246,176,246,179,246,184,246,186,246,187,246,188,246,193,246,194,246,195,246,198,246,202,246,205,246,206,246,207,246,209,246,213,246,214,246,216,246,217,246,223,246,224,246,225,246,230,246,231,246,232,246,234,246,237,246,238,246,240,246,258,246,270,246,273,246,280,246,282,246,287,246,290,246,107,247,113,247,114,247,120,247,163,247,164,247,167,247,169,247,170,247,176,247,179,247,181,247,185,247,187,247,192,247,198,247,208,247,212,247,213,247,217,247,220,247,231,247,232,247,233,247,234,247,235,247,237,247,264,247,266,247,267,247,275,247,281,247,282,247,283,247,286,247,289,247,108,248,112,248,113,248,116,248,117,248,118,248,119,248,161,248,164,248,166,248,167,248,169,248,170,248,171,248,174,248,177,248,178,248,181,248,183,248,185,248,186,248,187,248,193,248,194,248,199,248,200,248,203,248,206,248,208,248,210,248,212,248,216,248,219,248,221,248,224,248,231,248,232,248,235,248,269,248,270,248,273,248,274,248,275,248,276,248,283,248,284,248,285,248,288,248,109,249,110,249,112,249,114,249,118,249,167,249,169,249,170,249,173,249,175,249,176,249,177,249,178,249,187,249,190,249,191,249,192,249,193,249,197,249,199,249,202,249,203,249,208,249,209,249,210,249,212,249,222,249,223,249,226,249,228,249,255,249,260,249,261,249,262,249,264,249,267,249,275,249,276,249,277,249,279,249,280,249,284,249,286,249,287,249,112,250,113,250,115,250,116,250,117,250,168,250,171,250,173,250,174,250,175,250,177,250,178,250,179,250,180,250,182,250,184,250,190,250,192,250,193,250,199,250,200,250,201,250,204,250,205,250,207,250,208,250,209,250,210,250,211,250,213,250,217,250,218,250,219,250,222,250,224,250,225,250,255,250,259,250,260,250,266,250,273,250,279,250,280,250,285,250,286,250,111,251,116,251,169,251,173,251,174,251,175,251,176,251,177,251,178,251,184,251,187,251,188,251,189,251,190,251,191,251,192,251,199,251,200,251,201,251,202,251,203,251,204,251,206,251,211,251,217,251,220,251,224,251,255,251,260,251,269,251,270,251,271,251,275,251,279,251,280,251,281,251,283,251,285,251,286,251,115,252,173,252,179,252,181,252,182,252,185,252,186,252,188,252,192,252,195,252,201,252,202,252,210,252,211,252,217,252,222,252,223,252,224,252,260,252,270,252,271,252,273,252,275,252,280,252,281,252,282,252,284,252,176,253,177,253,178,253,179,253,180,253,183,253,185,253,192,253,193,253,194,253,195,253,198,253,200,253,202,253,203,253,204,253,209,253,211,253,213,253,216,253,258,253,265,253,268,253,270,253,276,253,277,253,280,253,281,253,282,253,182,254,184,254,185,254,187,254,192,254,195,254,196,254,198,254,200,254,207,254,209,254,211,254,212,254,216,254,217,254,261,254,262,254,271,254,273,254,274,254,276,254,277,254,278,254,279,254,281,254,183,255,184,255,192,255,193,255,195,255,197,255,199,255,202,255,206,255,207,255,210,255,260,255,264,255,265,255,266,255,270,255,271,255,276,255,278,255,279,255,281,255,196,256,203,256,261,256,264,256,266,256,269,256,270,256,275,256,276,256,278,256,279,256,280,256,261,257,267,257,268,257,270,257,271,257,272,257,275,257,269,258,274,258,275,258,266,259,268,259,269,259,273,259,275,259,267,260,268,260,271,260,272,260,273,260,274,260,275,260,266,261,267,261,268,261,269,261,271,261,272,261,177,262,178,263,187,263,270,263,175,264,177,264,178,264,179,264,182,264,188,264,190,264,191,264,192,264,193,264,194,264,195,264,178,265,182,265,183,265,184,265,187,265,192,265,199,265,201,265,173,266,180,266,183,266,191,266,198,266,203,266,181,267,186,267,189,267,190,267,193,267,198,267,199,267,201,267,205,267,183,268,184,268,185,268,186,268,187,268,198,268,201,268,204,268,175,269,177,269,180,269,183,269,186,269,187,269,191,269,192,269,194,269,197,269,201,269,204,269,205,269,206,269,174,270,186,270,188,270,189,270,191,270,192,270,194,270,195,270,197,270,203,270,204,270,175,271,176,271,179,271,180,271,181,271,185,271,186,271,188,271,189,271,191,271,192,271,197,271,199,271,200,271,204,271,174,272,176,272,181,272,183,272,186,272,190,272,191,272,192,272,194,272,198,272,201,272,204,272,176,273,178,273,180,273,182,273,183,273,187,273,192,273,194,273,199,273,204,273,205,273,175,274,177,274,179,274,181,274,185,274,186,274,188,274,195,274,200,274,206,274,176,275,177,275,178,275,179,275,183,275,184,275,186,275,188,275,197,275,200,275,201,275,203,275,174,276,176,276,177,276,178,276,179,276,181,276,182,276,186,276,188,276,189,276,190,276,192,276,194,276,195,276,197,276,201,276,203,276,205,276,177,277,178,277,184,277,185,277,188,277,194,277,198,277,199,277,203,277,205,277,180,278,181,278,184,278,185,278,189,278,190,278,193,278,198,278,202,278,205,278,174,279,182,279,183,279,185,279,189,279,191,279,192,279,195,279,199,279,200,279,201,279,202,279,176,280,178,280,179,280,180,280,182,280,185,280,186,280,187,280,188,280,192,280,194,280,195,280,198,280,199,280,200,280,205,280,177,281,178,281,179,281,180,281,188,281,190,281,195,281,196,281,200,281,201,281,180,282,182,282,184,282,185,282,189,282,193,282,198,282,200,282,177,283,179,283,181,283,183,283,184,283,185,283,187,283,189,283,192,283,195,283,198,283,199,283,200,283,202,283,181,284,189,284,194,284,195,284,196,284,197,284,198,284,204,284,177,285,178,285,179,285,182,285,183,285,185,285,186,285,190,285,197,285,201,285,202,285,174,286,176,286,188,286,193,286,195,286,199,286,175,288,174,290,174,291,172,293,171,295,173,295,347,316,25,317,26,317,27,317,29,317,30,317,31,317,32,317,33,317,35,317,36,317,37,317,38,317,39,317,40,317,41,317,42,317,43,317,44,317,45,317,46,317,47,317,151,317,152,317,153,317,156,317,157,317,158,317,159,317,160,317,163,317,165,317,166,317,167,317,168,317,170,317,172,317,174,317,175,317,176,317,177,317,178,317,179,317,180,317,181,317,182,317,183,317,185,317,255,317,256,317,258,317,259,317,260,317,261,317,262,317,263,317,265,317,266,317,267,317,268,317,270,317,347,317,353,317,24,318,25,318,45,318,46,318,49,318,63,318,64,318,65,318,66,318,68,318,79,318,80,318,83,318,84,318,85,318,87,318,88,318,89,318,90,318,91,318,92,318,93,318,94,318,95,318,148,318,150,318,168,318,169,318,173,318,174,318,177,318,178,318,180,318,182,318,186,318,205,318,207,318,209,318,210,318,211,318,212,318,213,318,214,318,215,318,216,318,217,318,219,318,220,318,221,318,222,318,224,318,226,318,228,318,251,318,252,318,253,318,254,318,255,318,256,318,257,318,258,318,259,318,260,318,261,318,262,318,264,318,265,318,266,318,267,318,268,318,269,318,270,318,271,318,272,318,296,318,297,318,299,318,301,318,347,318,348,318,349,318,350,318,351,318,30,319,33,319,48,319,49,319,61,319,95,319,96,319,115,319,116,319,126,319,128,319,130,319,131,319,133,319,135,319,136,319,179,319,186,319,200,319,201,319,203,319,204,319,205,319,207,319,218,319,219,319,220,319,221,319,223,319,224,319,225,319,226,319,227,319,228,319,229,319,230,319,231,319,232,319,233,319,250,319,251,319,253,319,254,319,255,319,258,319,269,319,270,319,271,319,272,319,273,319,290,319,291,319,292,319,293,319,294,319,295,319,296,319,297,319,298,319,299,319,300,319,301,319,302,319,350,319,353,319,354,319,31,320,32,320,49,320,61,320,128,320,148,320,181,320,186,320,200,320,201,320,202,320,222,320,223,320,225,320,227,320,228,320,229,320,230,320,231,320,232,320,233,320,234,320,249,320,252,320,253,320,254,320,272,320,274,320,289,320,290,320,291,320,292,320,296,320,302,320,303,320,329,320,29,321,31,321,32,321,61,321,98,321,113,321,117,321,125,321,137,321,178,321,185,321,186,321,201,321,203,321,223,321,225,321,234,321,255,321,272,321,274,321,275,321,288,321,289,321,302,321,303,321,329,321,330,321,331,321,342,321,343,321,346,321,348,321,350,321,351,321,352,321,353,321,354,321,355,321,32,322,99,322,127,322,128,322,129,322,130,322,137,322,148,322,186,322,220,322,222,322,227,322,231,322,233,322,235,322,236,322,275,322,287,322,303,322,328,322,329,322,330,322,331,322,332,322,339,322,344,322,348,322,352,322,355,322,356,322,32,323,49,323,99,323,127,323,130,323,137,323,167,323,186,323,198,323,226,323,229,323,232,323,234,323,235,323,236,323,274,323,294,323,303,323,326,323,329,323,330,323,331,323,335,323,336,323,345,323,346,323,356,323,359,323,360,323,366,323,367,323,368,323,99,324,124,324,126,324,129,324,130,324,186,324,201,324,221,324,223,324,225,324,232,324,234,324,235,324,236,324,247,324,258,324,274,324,276,324,302,324,303,324,326,324,327,324,328,324,329,324,330,324,331,324,333,324,340,324,342,324,343,324,351,324,358,324,359,324,360,324,361,324,366,324,367,324,368,324,369,324,370,324,86,325,99,325,186,325,198,325,223,325,225,325,228,325,229,325,235,325,236,325,275,325,276,325,295,325,303,325,327,325,328,325,333,325,340,325,342,325,344,325,345,325,348,325,349,325,352,325,357,325,359,325,360,325,361,325,362,325,363,325,364,325,368,325,369,325,370,325,371,325,32,326,99,326,137,326,186,326,198,326,201,326,229,326,235,326,236,326,259,326,275,326,276,326,303,326,330,326,338,326,339,326,340,326,341,326,342,326,344,326,345,326,346,326,347,326,348,326,349,326,350,326,351,326,352,326,353,326,357,326,358,326,359,326,362,326,363,326,364,326,365,326,366,326,369,326,370,326,371,326,373,326,31,327,32,327,33,327,47,327,49,327,67,327,133,327,137,327,186,327,198,327,201,327,224,327,225,327,227,327,228,327,233,327,236,327,248,327,257,327,258,327,259,327,260,327,261,327,274,327,275,327,276,327,287,327,302,327,303,327,327,327,328,327,329,327,334,327,337,327,338,327,339,327,340,327,342,327,343,327,349,327,350,327,354,327,355,327,356,327,357,327,358,327,359,327,361,327,362,327,363,327,364,327,365,327,366,327,371,327,14,328,29,328,30,328,32,328,33,328,34,328,35,328,36,328,38,328,45,328,49,328,65,328,67,328,135,328,150,328,151,328,155,328,157,328,162,328,184,328,185,328,198,328,200,328,201,328,202,328,217,328,219,328,221,328,222,328,223,328,224,328,225,328,227,328,228,328,234,328,236,328,248,328,258,328,259,328,260,328,261,328,262,328,264,328,265,328,268,328,270,328,271,328,273,328,274,328,275,328,276,328,288,328,302,328,303,328,330,328,336,328,337,328,338,328,339,328,340,328,357,328,358,328,359,328,364,328,365,328,366,328,368,328,13,329,30,329,64,329,65,329,69,329,100,329,110,329,122,329,132,329,134,329,135,329,136,329,160,329,172,329,174,329,176,329,201,329,219,329,220,329,221,329,222,329,224,329,225,329,226,329,227,329,232,329,234,329,235,329,236,329,258,329,259,329,287,329,288,329,289,329,290,329,291,329,295,329,302,329,303,329,329,329,331,329,333,329,334,329,335,329,336,329,337,329,359,329,361,329,365,329,366,329,367,329,13,330,29,330,30,330,91,330,227,330,232,330,235,330,236,330,253,330,257,330,258,330,325,330,326,330,328,330,329,330,331,330,332,330,333,330,334,330,335,330,360,330,361,330,362,330,363,330,364,330,365,330,366,330,367,330,368,330,369,330,13,331,29,331,30,331,91,331,95,331,225,331,235,331,236,331,258,331,326,331,328,331,329,331,330,331,331,331,332,331,333,331,334,331,335,331,361,331,362,331,363,331,366,331,369,331,370,331,100,332,122,332,225,332,229,332,233,332,234,332,235,332,236,332,258,332,259,332,328,332,330,332,331,332,332,332,333,332,334,332,362,332,363,332,364,332,366,332,368,332,370,332,28,333,29,333,90,333,100,333,122,333,225,333,229,333,234,333,235,333,236,333,258,333,259,333,325,333,327,333,328,333,329,333,363,333,364,333,366,333,368,333,369,333,370,333,371,333,28,334,29,334,100,334,225,334,229,334,235,334,236,334,254,334,258,334,259,334,317,334,318,334,319,334,320,334,321,334,325,334,327,334,328,334,330,334,333,334,363,334,364,334,367,334,370,334,371,334,27,335,28,335,29,335,100,335,122,335,225,335,227,335,229,335,233,335,236,335,258,335,259,335,319,335,320,335,321,335,324,335,326,335,327,335,330,335,331,335,364,335,365,335,366,335,371,335,372,335,26,336,27,336,28,336,29,336,100,336,110,336,122,336,225,336,234,336,236,336,251,336,258,336,315,336,316,336,318,336,320,336,324,336,325,336,326,336,327,336,328,336,329,336,330,336,364,336,365,336,370,336,371,336,28,337,29,337,30,337,31,337,33,337,34,337,35,337,36,337,42,337,43,337,86,337,87,337,100,337,110,337,121,337,161,337,164,337,165,337,166,337,167,337,168,337,169,337,170,337,171,337,172,337,173,337,174,337,175,337,176,337,234,337,235,337,236,337,258,337,259,337,319,337,320,337,321,337,324,337,325,337,327,337,328,337,329,337,364,337,366,337,370,337,371,337,372,337,376,337,377,337,378,337,29,338,31,338,32,338,43,338,63,338,66,338,67,338,69,338,71,338,73,338,74,338,76,338,81,338,84,338,85,338,86,338,100,338,110,338,163,338,165,338,167,338,176,338,198,338,201,338,202,338,203,338,204,338,205,338,206,338,207,338,208,338,236,338,259,338,287,338,289,338,290,338,291,338,292,338,293,338,294,338,295,338,296,338,297,338,298,338,299,338,300,338,301,338,303,338,317,338,318,338,320,338,324,338,327,338,328,338,329,338,330,338,331,338,332,338,364,338,365,338,370,338,371,338,375,338,376,338,377,338,378,338,380,338,13,339,69,339,71,339,73,339,85,339,100,339,122,339,176,339,198,339,200,339,202,339,203,339,206,339,207,339,208,339,209,339,210,339,226,339,235,339,236,339,259,339,287,339,288,339,291,339,292,339,294,339,296,339,297,339,300,339,301,339,302,339,303,339,316,339,317,339,318,339,319,339,320,339,324,339,325,339,327,339,328,339,329,339,330,339,331,339,332,339,364,339,366,339,367,339,371,339,372,339,375,339,376,339,377,339,380,339,43,340,67,340,69,340,110,340,121,340,177,340,208,340,209,340,210,340,236,340,287,340,294,340,296,340,300,340,302,340,303,340,325,340,326,340,327,340,328,340,329,340,330,340,331,340,332,340,364,340,365,340,371,340,375,340,376,340,377,340,380,340,43,341,110,341,160,341,210,341,211,341,225,341,226,341,231,341,235,341,236,341,254,341,258,341,294,341,295,341,300,341,302,341,303,341,324,341,325,341,327,341,328,341,330,341,331,341,332,341,360,341,363,341,365,341,369,341,370,341,371,341,375,341,376,341,378,341,380,341,36,342,41,342,42,342,43,342,100,342,110,342,122,342,198,342,210,342,226,342,227,342,228,342,234,342,236,342,250,342,257,342,258,342,259,342,296,342,301,342,302,342,303,342,325,342,326,342,328,342,329,342,330,342,331,342,333,342,362,342,363,342,375,342,377,342,378,342,379,342,30,343,31,343,32,343,33,343,34,343,36,343,38,343,39,343,41,343,42,343,94,343,100,343,122,343,176,343,198,343,210,343,225,343,226,343,227,343,229,343,234,343,235,343,236,343,250,343,258,343,259,343,294,343,296,343,299,343,300,343,301,343,302,343,303,343,326,343,327,343,328,343,331,343,332,343,333,343,334,343,359,343,362,343,369,343,29,344,76,344,77,344,82,344,100,344,110,344,176,344,198,344,209,344,210,344,225,344,226,344,227,344,228,344,234,344,235,344,236,344,287,344,292,344,294,344,296,344,299,344,302,344,303,344,326,344,327,344,328,344,330,344,331,344,332,344,333,344,334,344,335,344,359,344,360,344,362,344,363,344,367,344,369,344,14,345,29,345,73,345,86,345,100,345,110,345,121,345,168,345,176,345,209,345,210,345,225,345,227,345,228,345,235,345,257,345,258,345,259,345,288,345,297,345,300,345,303,345,327,345,328,345,331,345,333,345,334,345,335,345,336,345,359,345,360,345,361,345,367,345,368,345,369,345,14,346,27,346,100,346,121,346,122,346,177,346,210,346,212,346,216,346,217,346,218,346,219,346,220,346,221,346,222,346,223,346,224,346,225,346,227,346,228,346,234,346,235,346,258,346,259,346,294,346,299,346,301,346,303,346,328,346,329,346,330,346,332,346,333,346,335,346,336,346,337,346,338,346,357,346,358,346,359,346,360,346,367,346,368,346,369,346,14,347,29,347,74,347,100,347,125,347,126,347,132,347,133,347,134,347,198,347,210,347,211,347,212,347,213,347,214,347,215,347,216,347,217,347,218,347,219,347,220,347,221,347,222,347,224,347,226,347,235,347,259,347,288,347,294,347,295,347,296,347,299,347,302,347,303,347,328,347,329,347,335,347,337,347,338,347,339,347,340,347,355,347,356,347,357,347,358,347,363,347,366,347,367,347,368,347,100,348,118,348,130,348,137,348,177,348,210,348,211,348,212,348,213,348,214,348,216,348,218,348,234,348,258,348,259,348,288,348,289,348,293,348,294,348,295,348,296,348,297,348,299,348,300,348,302,348,303,348,330,348,334,348,335,348,336,348,337,348,340,348,341,348,342,348,343,348,344,348,350,348,352,348,353,348,354,348,355,348,356,348,365,348,366,348,367,348,11,349,30,349,75,349,100,349,110,349,130,349,137,349,176,349,216,349,218,349,233,349,235,349,258,349,259,349,287,349,292,349,295,349,296,349,302,349,303,349,325,349,331,349,334,349,335,349,336,349,337,349,338,349,339,349,341,349,342,349,343,349,344,349,345,349,346,349,353,349,364,349,365,349,29,350,99,350,100,350,124,350,131,350,132,350,137,350,158,350,232,350,234,350,247,350,259,350,287,350,290,350,294,350,296,350,302,350,303,350,323,350,324,350,325,350,326,350,332,350,333,350,334,350,335,350,339,350,341,350,342,350,344,350,345,350,346,350,349,350,351,350,362,350,363,350,364,350,14,351,29,351,75,351,128,351,132,351,137,351,198,351,200,351,202,351,231,351,232,351,233,351,235,351,249,351,259,351,285,351,295,351,299,351,301,351,303,351,322,351,325,351,326,351,327,351,328,351,333,351,334,351,335,351,336,351,338,351,339,351,340,351,342,351,349,351,350,351,359,351,362,351,363,351,368,351,28,352,29,352,64,352,75,352,99,352,120,352,128,352,137,352,158,352,201,352,202,352,231,352,232,352,233,352,234,352,249,352,250,352,251,352,258,352,295,352,296,352,301,352,324,352,327,352,328,352,329,352,336,352,337,352,338,352,339,352,340,352,341,352,342,352,353,352,357,352,358,352,359,352,360,352,361,352,368,352,28,353,29,353,66,353,75,353,98,353,120,353,129,353,137,353,202,353,203,353,205,353,229,353,231,353,232,353,250,353,251,353,259,353,286,353,288,353,290,353,296,353,299,353,301,353,302,353,325,353,327,353,328,353,329,353,338,353,339,353,340,353,341,353,343,353,347,353,352,353,353,353,356,353,357,353,358,353,359,353,365,353,366,353,367,353,368,353,369,353,371,353,19,354,23,354,25,354,27,354,28,354,29,354,75,354,96,354,118,354,120,354,129,354,137,354,160,354,176,354,202,354,203,354,205,354,206,354,209,354,214,354,216,354,228,354,229,354,230,354,251,354,259,354,289,354,291,354,292,354,293,354,295,354,299,354,300,354,326,354,341,354,342,354,343,354,344,354,345,354,346,354,348,354,349,354,350,354,351,354,353,354,354,354,355,354,363,354,366,354,367,354,371,354,17,355,18,355,19,355,20,355,21,355,22,355,24,355,25,355,26,355,28,355,29,355,75,355,96,355,137,355,158,355,161,355,163,355,176,355,204,355,205,355,206,355,207,355,210,355,211,355,212,355,213,355,214,355,215,355,216,355,217,355,218,355,219,355,221,355,222,355,223,355,224,355,226,355,227,355,232,355,255,355,257,355,291,355,293,355,295,355,296,355,298,355,299,355,326,355,343,355,345,355,346,355,347,355,348,355,349,355,363,355,364,355,365,355,367,355,368,355,369,355,67,356,69,356,73,356,75,356,95,356,116,356,117,356,118,356,120,356,123,356,130,356,205,356,206,356,208,356,209,356,210,356,211,356,212,356,214,356,215,356,216,356,218,356,219,356,220,356,221,356,222,356,223,356,224,356,225,356,226,356,227,356,228,356,229,356,230,356,231,356,289,356,292,356,296,356,298,356,299,356,365,356,366,356,367,356,341,357,342,357,344,357,345,357,346,357,347,357,348,357,349,357,342,358,343,358,344,358,345,358,346,358,347,358,348,358,349,358,343,359,344,359,345,359,347,359,348,359,349,359,343,360,346,360,348,360,345,361,346,361,347,361,348,361}
listreddesert3 = {219,19,223,19,223,20,225,33,222,34,223,34,225,34,194,35,220,35,224,35,205,36,222,37,225,37,222,38,196,39,224,39,225,39,204,40,208,40,223,40,224,40,193,42,224,42,213,44,222,44,122,45,213,45,201,46,202,46,208,46,178,47,179,47,191,47,192,47,198,47,201,47,205,47,208,47,203,48,222,48,191,49,203,49,212,49,128,50,191,50,197,50,198,50,203,50,219,50,193,51,194,51,199,51,206,51,190,52,192,52,193,52,198,52,208,52,210,52,211,52,191,53,193,53,199,53,202,53,207,53,209,53,213,53,216,53,188,54,193,54,197,54,200,54,207,54,208,54,219,54,220,54,183,55,192,55,196,55,197,55,210,55,223,55,228,55,229,55,296,55,133,56,190,56,191,56,192,56,205,56,210,56,211,56,213,56,215,56,148,57,193,57,199,57,210,57,211,57,219,57,220,57,297,57,129,58,146,58,202,58,227,58,293,58,297,58,144,59,188,59,204,59,218,59,223,59,227,59,228,59,296,59,298,59,299,59,185,60,187,60,191,60,209,60,214,60,215,60,217,60,299,60,301,60,175,61,181,61,190,61,200,61,201,61,202,61,203,61,205,61,211,61,217,61,218,61,226,61,240,61,290,61,292,61,296,61,298,61,301,61,208,62,209,62,221,62,256,62,290,62,292,62,295,62,296,62,297,62,298,62,300,62,176,63,183,63,189,63,191,63,193,63,202,63,203,63,209,63,218,63,230,63,232,63,289,63,290,63,291,63,292,63,295,63,298,63,299,63,137,64,142,64,193,64,195,64,208,64,211,64,215,64,217,64,227,64,260,64,289,64,290,64,291,64,295,64,297,64,298,64,299,64,300,64,301,64,302,64,303,64,122,65,181,65,187,65,205,65,213,65,214,65,221,65,290,65,292,65,294,65,295,65,296,65,297,65,298,65,301,65,302,65,143,66,182,66,183,66,194,66,196,66,224,66,229,66,289,66,291,66,292,66,296,66,298,66,300,66,301,66,302,66,303,66,304,66,133,67,142,67,143,67,144,67,191,67,196,67,202,67,206,67,231,67,290,67,291,67,293,67,294,67,295,67,296,67,299,67,300,67,302,67,303,67,305,67,307,67,135,68,141,68,143,68,158,68,189,68,191,68,229,68,232,68,233,68,267,68,268,68,269,68,291,68,293,68,294,68,295,68,297,68,298,68,302,68,303,68,304,68,305,68,306,68,308,68,126,69,160,69,161,69,177,69,178,69,180,69,181,69,200,69,205,69,214,69,220,69,226,69,236,69,237,69,290,69,291,69,293,69,294,69,295,69,299,69,300,69,301,69,302,69,304,69,306,69,308,69,139,70,142,70,145,70,152,70,156,70,170,70,171,70,174,70,180,70,191,70,192,70,216,70,219,70,222,70,237,70,293,70,294,70,298,70,299,70,300,70,301,70,302,70,304,70,305,70,306,70,309,70,130,71,133,71,137,71,138,71,139,71,140,71,142,71,143,71,159,71,164,71,170,71,180,71,192,71,194,71,215,71,230,71,233,71,237,71,238,71,239,71,291,71,292,71,294,71,295,71,303,71,304,71,305,71,307,71,309,71,310,71,140,72,171,72,205,72,206,72,230,72,238,72,239,72,240,72,246,72,279,72,290,72,291,72,295,72,296,72,299,72,300,72,303,72,305,72,306,72,308,72,126,73,133,73,134,73,144,73,163,73,226,73,244,73,294,73,295,73,298,73,302,73,304,73,305,73,306,73,307,73,308,73,309,73,103,74,135,74,140,74,168,74,238,74,243,74,254,74,276,74,278,74,300,74,301,74,302,74,303,74,304,74,305,74,306,74,307,74,308,74,309,74,312,74,104,75,120,75,122,75,127,75,132,75,133,75,140,75,157,75,174,75,202,75,230,75,243,75,275,75,295,75,297,75,298,75,299,75,300,75,301,75,303,75,306,75,307,75,308,75,311,75,128,76,138,76,151,76,180,76,185,76,190,76,201,76,210,76,211,76,217,76,230,76,235,76,238,76,239,76,244,76,254,76,286,76,294,76,300,76,301,76,302,76,303,76,304,76,305,76,306,76,308,76,309,76,311,76,313,76,123,77,124,77,128,77,151,77,153,77,157,77,160,77,201,77,236,77,240,77,295,77,297,77,299,77,301,77,304,77,305,77,307,77,309,77,310,77,311,77,107,78,125,78,126,78,131,78,133,78,135,78,151,78,157,78,196,78,214,78,227,78,260,78,270,78,272,78,273,78,295,78,296,78,297,78,300,78,303,78,304,78,306,78,307,78,310,78,111,79,124,79,150,79,151,79,154,79,155,79,201,79,215,79,229,79,242,79,253,79,257,79,261,79,266,79,274,79,299,79,300,79,302,79,303,79,305,79,307,79,309,79,315,79,316,79,114,80,131,80,149,80,168,80,198,80,230,80,241,80,251,80,252,80,253,80,256,80,267,80,268,80,274,80,302,80,304,80,305,80,306,80,307,80,309,80,314,80,111,81,125,81,162,81,190,81,244,81,249,81,262,81,266,81,272,81,279,81,292,81,301,81,302,81,303,81,304,81,132,82,181,82,192,82,212,82,213,82,214,82,243,82,244,82,246,82,264,82,302,82,303,82,304,82,306,82,307,82,311,82,125,83,152,83,165,83,168,83,171,83,180,83,187,83,188,83,203,83,207,83,241,83,242,83,265,83,267,83,269,83,270,83,273,83,275,83,286,83,302,83,303,83,307,83,309,83,114,84,117,84,119,84,120,84,124,84,143,84,152,84,156,84,241,84,253,84,258,84,266,84,267,84,268,84,282,84,303,84,307,84,112,85,113,85,117,85,146,85,192,85,248,85,250,85,268,85,269,85,270,85,275,85,282,85,284,85,304,85,306,85,307,85,112,86,115,86,116,86,125,86,179,86,209,86,225,86,247,86,250,86,251,86,273,86,275,86,280,86,281,86,283,86,286,86,304,86,305,86,117,87,119,87,196,87,210,87,224,87,245,87,248,87,260,87,273,87,274,87,284,87,302,87,305,87,116,88,119,88,120,88,184,88,208,88,215,88,248,88,275,88,276,88,278,88,279,88,286,88,303,88,215,89,248,89,253,89,262,89,271,89,272,89,277,89,278,89,281,89,115,90,118,90,119,90,120,90,158,90,168,90,169,90,170,90,175,90,176,90,185,90,197,90,205,90,235,90,241,90,244,90,256,90,134,91,142,91,175,91,188,91,209,91,234,91,255,91,256,91,259,91,266,91,279,91,280,91,285,91,108,92,117,92,119,92,130,92,142,92,149,92,155,92,162,92,188,92,203,92,243,92,247,92,265,92,274,92,275,92,278,92,296,92,138,93,140,93,168,93,177,93,231,93,252,93,253,93,263,93,264,93,268,93,277,93,278,93,279,93,280,93,283,93,130,94,131,94,132,94,137,94,178,94,190,94,237,94,243,94,258,94,261,94,276,94,280,94,281,94,115,95,118,95,137,95,185,95,214,95,223,95,265,95,277,95,279,95,281,95,287,95,117,96,181,96,185,96,198,96,202,96,205,96,214,96,240,96,258,96,264,96,278,96,284,96,285,96,157,97,170,97,178,97,197,97,198,97,215,97,240,97,253,97,257,97,259,97,270,97,278,97,281,97,283,97,138,98,144,98,153,98,162,98,171,98,172,98,181,98,193,98,200,98,206,98,218,98,219,98,260,98,272,98,282,98,283,98,286,98,289,98,143,99,145,99,183,99,187,99,188,99,237,99,260,99,269,99,272,99,280,99,285,99,287,99,288,99,290,99,114,100,127,100,143,100,163,100,167,100,178,100,186,100,193,100,201,100,212,100,219,100,222,100,224,100,236,100,241,100,242,100,282,100,284,100,290,100,291,100,116,101,171,101,175,101,186,101,188,101,194,101,204,101,206,101,208,101,209,101,212,101,236,101,242,101,251,101,274,101,282,101,291,101,168,102,171,102,173,102,174,102,189,102,191,102,194,102,195,102,205,102,208,102,212,102,214,102,218,102,226,102,233,102,235,102,243,102,265,102,267,102,275,102,282,102,285,102,163,103,164,103,167,103,169,103,170,103,172,103,183,103,204,103,210,103,218,103,221,103,241,103,254,103,255,103,260,103,269,103,270,103,285,103,289,103,143,104,163,104,164,104,165,104,167,104,169,104,172,104,174,104,180,104,181,104,183,104,184,104,213,104,230,104,236,104,248,104,272,104,273,104,275,104,276,104,128,105,143,105,144,105,165,105,171,105,223,105,229,105,235,105,236,105,242,105,245,105,269,105,273,105,275,105,277,105,127,106,128,106,151,106,162,106,163,106,171,106,227,106,267,106,268,106,277,106,285,106,141,107,158,107,168,107,231,107,233,107,234,107,264,107,267,107,117,108,148,108,155,108,165,108,171,108,172,108,173,108,225,108,230,108,235,108,240,108,241,108,246,108,271,108,274,108,275,108,123,109,129,109,130,109,169,109,239,109,240,109,254,109,270,109,275,109,137,110,153,110,163,110,164,110,165,110,166,110,280,110,281,110,128,111,149,111,158,111,159,111,232,111,272,111,119,112,120,112,122,112,133,112,144,112,145,112,191,112,230,112,231,112,232,112,262,112,275,112,276,112,209,113,232,113,252,113,259,113,275,113,127,114,145,114,147,114,150,114,159,114,160,114,211,114,235,114,252,114,259,114,267,114,269,114,272,114,274,114,279,114,280,114,115,115,153,115,158,115,160,115,234,115,265,115,110,116,116,116,117,116,160,116,235,116,242,116,117,117,139,117,143,117,145,117,157,117,159,117,218,117,220,117,221,117,242,117,250,117,255,117,265,117,271,117,280,117,283,117,115,118,116,118,126,118,149,118,151,118,154,118,236,118,239,118,255,118,272,118,274,118,282,118,284,118,119,119,145,119,153,119,238,119,261,119,270,119,272,119,274,119,280,119,281,119,282,119,107,120,124,120,225,120,226,120,227,120,230,120,239,120,242,120,243,120,273,120,284,120,108,121,115,121,116,121,123,121,127,121,133,121,226,121,227,121,240,121,251,121,254,121,267,121,275,121,276,121,277,121,285,121,286,121,113,122,114,122,122,122,144,122,228,122,241,122,244,122,245,122,246,122,278,122,279,122,280,122,103,123,105,123,137,123,138,123,145,123,146,123,149,123,152,123,229,123,252,123,280,123,281,123,114,124,121,124,122,124,131,124,137,124,139,124,145,124,151,124,230,124,235,124,256,124,284,124,125,125,129,125,130,125,137,125,138,125,149,125,231,125,243,125,254,125,256,125,277,125,150,126,253,126,100,127,132,127,142,127,234,127,235,127,240,127,245,127,250,127,251,127,261,127,269,127,270,127,275,127,118,128,128,128,135,128,234,128,235,128,236,128,237,128,238,128,243,128,250,128,251,128,252,128,258,128,278,128,111,129,124,129,130,129,138,129,235,129,239,129,240,129,244,129,245,129,249,129,257,129,274,129,289,129,109,130,111,130,123,130,128,130,236,130,237,130,240,130,241,130,245,130,246,130,255,130,285,130,287,130,123,131,138,131,141,131,237,131,240,131,241,131,248,131,249,131,279,131,285,131,121,132,127,132,140,132,238,132,240,132,247,132,253,132,255,132,284,132,107,133,110,133,132,133,135,133,137,133,142,133,145,133,241,133,242,133,243,133,245,133,247,133,253,133,255,133,256,133,264,133,278,133,125,134,127,134,138,134,239,134,243,134,246,134,248,134,259,134,263,134,272,134,280,134,116,135,129,135,243,135,245,135,247,135,259,135,279,135,280,135,285,135,96,136,105,136,108,136,109,136,110,136,119,136,127,136,242,136,243,136,256,136,263,136,279,136,285,136,91,137,93,137,94,137,111,137,117,137,142,137,243,137,244,137,245,137,247,137,248,137,250,137,277,137,290,137,86,138,95,138,107,138,110,138,119,138,123,138,124,138,136,138,142,138,144,138,241,138,242,138,247,138,254,138,287,138,289,138,290,138,292,138,79,139,123,139,131,139,243,139,244,139,245,139,287,139,288,139,292,139,84,140,143,140,243,140,249,140,250,140,291,140,83,141,84,141,110,141,133,141,252,141,257,141,272,141,286,141,288,141,289,141,108,142,109,142,117,142,122,142,244,142,246,142,249,142,257,142,271,142,272,142,289,142,85,143,93,143,94,143,119,143,141,143,142,143,244,143,271,143,278,143,287,143,292,143,86,144,95,144,108,144,121,144,125,144,126,144,130,144,139,144,244,144,245,144,264,144,285,144,90,145,92,145,107,145,282,145,288,145,291,145,293,145,87,146,141,146,249,146,250,146,288,146,292,146,293,146,75,147,96,147,97,147,130,147,138,147,91,148,109,148,114,148,247,148,261,148,262,148,294,148,301,148,303,148,82,149,111,149,115,149,246,149,288,149,291,149,317,149,81,150,90,150,91,150,114,150,132,150,139,150,252,150,278,150,287,150,288,150,308,150,309,150,315,150,316,150,317,150,318,150,319,150,322,150,323,150,90,151,117,151,128,151,129,151,130,151,134,151,248,151,263,151,264,151,286,151,294,151,312,151,316,151,317,151,318,151,319,151,322,151,323,151,324,151,326,151,331,151,93,152,247,152,287,152,291,152,292,152,302,152,304,152,306,152,314,152,320,152,321,152,322,152,323,152,324,152,325,152,326,152,327,152,328,152,329,152,331,152,76,153,85,153,92,153,93,153,94,153,103,153,121,153,132,153,139,153,140,153,274,153,284,153,287,153,293,153,302,153,304,153,308,153,316,153,324,153,325,153,326,153,327,153,328,153,329,153,331,153,332,153,334,153,337,153,338,153,339,153,107,154,122,154,126,154,127,154,136,154,245,154,249,154,259,154,263,154,264,154,267,154,284,154,285,154,288,154,302,154,312,154,325,154,332,154,339,154,99,155,107,155,124,155,125,155,126,155,128,155,131,155,249,155,279,155,283,155,284,155,292,155,301,155,305,155,308,155,310,155,324,155,339,155,94,156,108,156,139,156,246,156,270,156,293,156,294,156,315,156,318,156,319,156,323,156,324,156,332,156,86,157,87,157,90,157,91,157,106,157,125,157,245,157,293,157,294,157,302,157,303,157,311,157,318,157,320,157,90,158,96,158,107,158,140,158,301,158,303,158,307,158,312,158,313,158,325,158,81,159,82,159,83,159,122,159,123,159,139,159,245,159,246,159,247,159,259,159,260,159,268,159,288,159,291,159,301,159,313,159,325,159,73,160,108,160,109,160,110,160,125,160,127,160,268,160,282,160,294,160,306,160,307,160,315,160,83,161,103,161,122,161,123,161,126,161,130,161,139,161,253,161,256,161,264,161,302,161,313,161,314,161,324,161,325,161,73,162,82,162,83,162,104,162,120,162,132,162,134,162,135,162,136,162,259,162,269,162,276,162,286,162,292,162,305,162,308,162,313,162,314,162,324,162,77,163,82,163,87,163,90,163,103,163,116,163,117,163,131,163,133,163,140,163,264,163,288,163,291,163,306,163,308,163,309,163,321,163,85,164,91,164,112,164,116,164,117,164,139,164,264,164,289,164,292,164,294,164,305,164,310,164,311,164,325,164,81,165,87,165,94,165,130,165,135,165,136,165,137,165,262,165,266,165,307,165,311,165,318,165,325,165,72,166,77,166,89,166,93,166,94,166,127,166,131,166,135,166,269,166,301,166,302,166,306,166,309,166,325,166,60,167,82,167,89,167,97,167,106,167,132,167,140,167,262,167,265,167,292,167,302,167,303,167,312,167,313,167,85,168,88,168,94,168,99,168,104,168,105,168,106,168,116,168,140,168,257,168,258,168,267,168,272,168,292,168,293,168,294,168,302,168,306,168,307,168,121,169,127,169,131,169,133,169,139,169,256,169,258,169,259,169,260,169,288,169,289,169,290,169,292,169,293,169,324,169,106,170,113,170,124,170,130,170,141,170,246,170,287,170,293,170,318,170,103,171,120,171,127,171,132,171,133,171,141,171,261,171,262,171,291,171,301,171,306,171,320,171,99,172,114,172,121,172,141,172,244,172,245,172,261,172,262,172,263,172,285,172,302,172,306,172,308,172,325,172,96,173,112,173,261,173,263,173,267,173,312,173,324,173,98,174,108,174,110,174,111,174,122,174,131,174,139,174,142,174,243,174,260,174,262,174,281,174,286,174,288,174,290,174,292,174,108,175,109,175,110,175,112,175,139,175,142,175,290,175,291,175,292,175,304,175,324,175,142,176,242,176,288,176,292,176,307,176,309,176,312,176,316,176,99,177,101,177,105,177,110,177,116,177,133,177,142,177,143,177,262,177,287,177,300,177,316,177,100,178,106,178,110,178,134,178,138,178,142,178,291,178,302,178,303,178,305,178,105,179,106,179,111,179,117,179,135,179,258,179,289,179,291,179,320,179,106,180,112,180,124,180,131,180,245,180,257,180,263,180,279,180,289,180,301,180,322,180,323,180,105,181,114,181,126,181,132,181,258,181,264,181,289,181,290,181,292,181,310,181,323,181,99,182,241,182,257,182,289,182,290,182,291,182,292,182,309,182,310,182,317,182,323,182,103,183,113,183,128,183,139,183,288,183,291,183,304,183,310,183,109,184,128,184,130,184,145,184,254,184,311,184,312,184,314,184,319,184,101,185,103,185,111,185,120,185,131,185,254,185,299,185,300,185,301,185,303,185,304,185,100,186,101,186,106,186,115,186,134,186,139,186,289,186,101,187,104,187,120,187,127,187,132,187,253,187,289,187,108,188,109,188,147,188,253,188,284,188,107,189,117,189,122,189,132,189,253,189,286,189,289,189,104,190,105,190,110,190,143,190,281,190,285,190,104,191,134,191,149,191,236,191,105,192,111,192,113,192,114,192,279,192,107,193,113,193,123,193,150,193,252,193,270,193,282,193,284,193,107,194,110,194,143,194,144,194,150,194,257,194,280,194,282,194,283,194,284,194,114,195,149,195,150,195,152,195,166,195,255,195,261,195,272,195,283,195,104,196,120,196,272,196,113,197,114,197,128,197,153,197,154,197,246,197,152,198,154,198,168,198,246,198,274,198,276,198,108,199,112,199,115,199,116,199,119,199,120,199,129,199,154,199,155,199,253,199,274,199,279,199,113,200,114,200,119,200,136,200,171,200,172,200,242,200,246,200,247,200,252,200,276,200,279,200,282,200,112,201,113,201,116,201,119,201,122,201,149,201,156,201,157,201,173,201,175,201,224,201,271,201,280,201,111,202,115,202,125,202,135,202,141,202,149,202,159,202,220,202,244,202,267,202,271,202,273,202,278,202,108,203,140,203,145,203,149,203,150,203,152,203,178,203,220,203,221,203,240,203,241,203,282,203,134,204,139,204,156,204,180,204,182,204,218,204,241,204,278,204,281,204,109,205,114,205,155,205,181,205,215,205,218,205,243,205,267,205,275,205,281,205,110,206,111,206,119,206,126,206,133,206,141,206,163,206,184,206,185,206,188,206,208,206,214,206,229,206,243,206,247,206,273,206,274,206,280,206,110,207,112,207,116,207,157,207,164,207,165,207,184,207,185,207,188,207,191,207,194,207,195,207,196,207,203,207,207,207,209,207,211,207,243,207,244,207,264,207,273,207,276,207,107,208,108,208,118,208,119,208,129,208,135,208,141,208,166,208,167,208,189,208,192,208,193,208,194,208,197,208,198,208,199,208,201,208,202,208,205,208,206,208,207,208,210,208,237,208,276,208,280,208,112,209,113,209,117,209,148,209,196,209,203,209,205,209,206,209,209,209,271,209,278,209,117,210,122,210,127,210,150,210,192,210,193,210,196,210,197,210,202,210,203,210,208,210,237,210,119,211,218,211,235,211,248,211,249,211,268,211,273,211,107,212,122,212,123,212,158,212,160,212,161,212,174,212,188,212,189,212,212,212,229,212,107,213,118,213,124,213,202,213,212,213,236,213,271,213,103,214,104,214,106,214,127,214,142,214,163,214,166,214,193,214,198,214,209,214,103,215,105,215,110,215,125,215,165,215,192,215,196,215,198,215,201,215,223,215,224,215,267,215,268,215,277,215,121,216,129,216,133,216,190,216,191,216,193,216,198,216,208,216,222,216,223,216,276,216,109,217,111,217,120,217,132,217,142,217,145,217,167,217,169,217,176,217,188,217,196,217,197,217,199,217,203,217,230,217,231,217,266,217,273,217,276,217,106,218,119,218,123,218,126,218,147,218,149,218,154,218,174,218,177,218,182,218,193,218,231,218,271,218,274,218,275,218,107,219,111,219,130,219,145,219,147,219,169,219,210,219,211,219,222,219,271,219,106,220,107,220,109,220,116,220,121,220,126,220,129,220,173,220,188,220,215,220,219,220,105,221,122,221,126,221,127,221,133,221,147,221,157,221,169,221,173,221,179,221,187,221,198,221,219,221,262,221,103,222,105,222,122,222,129,222,132,222,155,222,180,222,182,222,189,222,207,222,210,222,251,222,261,222,262,222,263,222,272,222,118,223,128,223,134,223,144,223,151,223,161,223,169,223,177,223,183,223,192,223,211,223,225,223,232,223,263,223,108,224,115,224,128,224,129,224,161,224,197,224,263,224,125,225,126,225,130,225,134,225,147,225,148,225,178,225,263,225,264,225,108,226,114,226,115,226,120,226,133,226,140,226,142,226,159,226,173,226,179,226,185,226,244,226,260,226,103,227,107,227,117,227,118,227,128,227,133,227,138,227,139,227,144,227,172,227,176,227,211,227,265,227,267,227,113,228,130,228,144,228,158,228,163,228,178,228,185,228,190,228,204,228,224,228,260,228,264,228,265,228,266,228,106,229,113,229,115,229,117,229,120,229,122,229,143,229,182,229,183,229,185,229,192,229,214,229,255,229,266,229,114,230,117,230,118,230,133,230,135,230,142,230,174,230,190,230,191,230,192,230,205,230,260,230,102,231,109,231,113,231,125,231,132,231,135,231,137,231,139,231,142,231,143,231,150,231,191,231,221,231,255,231,260,231,99,232,120,232,125,232,137,232,163,232,164,232,217,232,272,232,100,233,110,233,124,233,125,233,134,233,135,233,159,233,168,233,190,233,242,233,253,233,271,233,282,233,284,233,119,234,121,234,122,234,126,234,150,234,203,234,204,234,211,234,258,234,273,234,274,234,283,234,91,235,119,235,121,235,141,235,143,235,150,235,154,235,159,235,175,235,189,235,195,235,215,235,242,235,246,235,251,235,98,236,102,236,110,236,112,236,121,236,122,236,125,236,137,236,140,236,145,236,149,236,170,236,173,236,186,236,235,236,279,236,88,237,97,237,104,237,141,237,142,237,149,237,176,237,270,237,271,237,279,237,282,237,117,238,124,238,125,238,128,238,142,238,147,238,151,238,152,238,155,238,159,238,173,238,174,238,180,238,235,238,251,238,271,238,272,238,283,238,85,239,99,239,116,239,126,239,129,239,130,239,143,239,149,239,150,239,154,239,155,239,168,239,238,239,249,239,250,239,251,239,253,239,268,239,272,239,284,239,285,239,82,240,84,240,115,240,116,240,122,240,126,240,129,240,149,240,155,240,156,240,157,240,161,240,224,240,237,240,249,240,252,240,272,240,274,240,276,240,101,241,118,241,122,241,129,241,130,241,149,241,151,241,152,241,165,241,237,241,245,241,246,241,249,241,274,241,279,241,289,241,107,242,109,242,122,242,126,242,127,242,128,242,152,242,156,242,158,242,163,242,167,242,172,242,174,242,198,242,269,242,273,242,274,242,285,242,119,243,121,243,125,243,148,243,159,243,167,243,172,243,197,243,203,243,233,243,234,243,244,243,245,243,246,243,260,243,262,243,278,243,280,243,282,243,111,244,120,244,121,244,124,244,151,244,152,244,154,244,166,244,180,244,181,244,202,244,240,244,242,244,244,244,245,244,262,244,265,244,276,244,278,244,282,244,288,244,109,245,121,245,122,245,154,245,158,245,165,245,224,245,225,245,242,245,256,245,257,245,258,245,265,245,271,245,286,245,291,245,166,246,168,246,169,246,219,246,229,246,235,246,239,246,241,246,256,246,267,246,286,246,162,247,168,247,171,247,172,247,173,247,174,247,180,247,183,247,186,247,224,247,229,247,230,247,236,247,238,247,265,247,270,247,274,247,276,247,277,247,287,247,114,248,115,248,121,248,162,248,163,248,165,248,176,248,198,248,207,248,211,248,223,248,228,248,230,248,233,248,234,248,254,248,166,249,168,249,171,249,172,249,179,249,185,249,186,249,196,249,200,249,211,249,215,249,216,249,218,249,227,249,186,250,195,250,196,250,202,250,203,250,215,250,216,250,223,250,226,250,227,250,228,250,263,250,265,250,171,251,195,251,207,251,216,251,225,251,226,251,227,251,265,251,273,251,172,252,174,252,176,252,177,252,198,252,200,252,207,252,216,252,283,252,285,252,184,253,188,253,197,253,201,253,205,253,207,253,208,253,212,253,257,253,262,253,283,253,193,254,194,254,197,254,204,254,205,254,266,254,272,254,182,255,189,255,191,255,198,255,200,255,204,255,261,255,189,256,191,256,192,256,193,256,195,256,197,256,199,256,200,256,201,256,202,256,262,256,265,256,267,256,277,256,269,257,278,257,277,258,269,260,273,261,272,262,273,262,269,263,271,263,176,264,202,264,204,264,176,265,188,265,196,265,200,265,178,266,181,266,193,266,194,266,195,266,196,266,182,267,187,267,192,267,195,267,197,267,202,267,191,268,196,268,184,269,185,269,188,269,189,269,190,269,177,270,180,270,183,270,184,270,185,270,190,270,200,270,202,270,206,270,207,270,182,271,183,271,190,271,196,271,201,271,206,271,179,272,180,272,182,272,188,272,206,272,181,273,186,273,188,273,191,273,196,273,176,274,183,274,187,274,197,274,204,274,187,275,194,275,195,275,206,275,184,276,187,276,191,276,193,276,174,277,186,277,187,277,199,278,200,278,204,278,203,279,190,280,191,280,191,281,181,282,199,282,201,283,177,284,182,284,202,284,174,285,176,285,180,285,191,285,203,285,204,285,194,286,200,286,202,286,173,296,48,317,49,317,150,317,161,317,162,317,164,317,169,317,171,317,173,317,184,317,186,317,253,317,254,317,257,317,264,317,269,317,271,317,272,317,50,318,223,318,225,318,227,318,229,318,230,318,232,318,273,318,291,318,292,318,293,318,294,318,295,318,298,318,300,318,302,318,346,318,50,319,274,319,303,319,346,319,347,319,348,319,349,319,351,319,352,319,50,320,275,320,346,320,347,320,348,320,349,320,350,320,50,321,99,321,148,321,235,321,276,321,50,322,187,322,276,322,358,322,359,322,368,322,50,323,148,323,187,323,276,323,332,323,333,323,334,323,361,323,100,324,137,324,148,324,363,324,50,325,100,325,137,325,148,325,329,325,330,325,50,326,100,326,148,326,328,326,50,327,100,327,341,327,345,327,346,327,367,327,370,327,372,327,31,328,50,328,61,328,100,328,137,328,186,328,367,328,126,329,165,329,166,329,168,329,169,329,171,329,175,329,177,329,178,329,179,329,180,329,181,329,183,329,184,329,338,329,368,329,369,329,100,330,122,330,237,330,259,330,336,330,337,330,370,330,100,331,259,331,324,331,30,332,371,332,30,333,334,333,30,334,122,334,237,334,331,334,315,335,30,336,237,336,259,336,372,336,32,337,237,337,360,337,375,337,379,337,380,337,122,338,177,338,209,338,210,338,211,338,288,338,302,338,372,338,177,339,326,339,100,340,198,340,211,340,259,340,333,340,372,340,100,341,122,341,198,341,259,341,333,341,177,342,211,342,327,342,371,342,376,342,43,343,211,343,370,343,30,344,122,344,158,344,177,344,211,344,259,344,370,344,30,345,75,345,122,345,177,345,211,345,212,345,224,345,226,345,236,345,30,346,75,346,123,346,128,346,129,346,130,346,131,346,132,346,133,346,134,346,211,346,214,346,215,346,226,346,236,346,30,347,75,347,137,347,177,347,236,347,285,347,341,347,30,348,75,348,158,348,236,348,351,348,158,349,177,349,236,349,285,349,304,349,324,349,30,350,75,350,177,350,235,350,236,350,365,350,30,351,100,351,138,351,158,351,177,351,234,351,30,352,138,352,177,352,259,352,366,352,367,352,369,352,30,353,138,353,234,353,30,354,158,354,231,354,232,354,301,354,337,354,352,354,362,354,365,354,23,355,27,355,201,355,229,355,230,355,231,355,259,355,300,355,350,355,366,355,70,356,119,356,121,356,122,356,125,356,126,356,127,356,128,356,129,356,131,356,132,356,232,356,343,357}
listsand1 = {195,17,196,17,197,17,198,17,201,17,204,17,205,17,193,18,194,18,195,18,196,18,197,18,198,18,199,18,200,18,201,18,202,18,204,18,205,18,208,18,209,18,211,18,212,18,213,18,214,18,192,19,193,19,196,19,197,19,198,19,199,19,200,19,201,19,202,19,203,19,204,19,205,19,206,19,207,19,208,19,209,19,210,19,211,19,212,19,213,19,214,19,217,19,218,19,221,19,191,20,192,20,193,20,194,20,195,20,196,20,197,20,198,20,199,20,201,20,202,20,203,20,204,20,205,20,206,20,207,20,208,20,209,20,210,20,211,20,212,20,213,20,214,20,215,20,216,20,217,20,218,20,219,20,220,20,221,20,222,20,224,20,225,20,191,21,192,21,193,21,194,21,195,21,196,21,197,21,198,21,199,21,200,21,201,21,202,21,203,21,204,21,205,21,207,21,208,21,209,21,210,21,211,21,212,21,213,21,214,21,215,21,216,21,217,21,218,21,219,21,220,21,222,21,223,21,224,21,225,21,191,22,192,22,193,22,194,22,195,22,196,22,197,22,198,22,199,22,200,22,201,22,202,22,203,22,204,22,205,22,206,22,207,22,208,22,209,22,210,22,211,22,212,22,213,22,214,22,216,22,217,22,218,22,219,22,220,22,221,22,222,22,223,22,224,22,191,23,192,23,193,23,194,23,195,23,196,23,197,23,198,23,199,23,200,23,201,23,202,23,203,23,204,23,205,23,206,23,207,23,210,23,211,23,212,23,213,23,214,23,215,23,216,23,217,23,218,23,219,23,220,23,221,23,222,23,223,23,224,23,190,24,191,24,192,24,193,24,194,24,196,24,197,24,198,24,199,24,200,24,201,24,202,24,203,24,204,24,205,24,206,24,207,24,208,24,209,24,210,24,211,24,212,24,213,24,214,24,215,24,216,24,217,24,219,24,220,24,221,24,222,24,223,24,190,25,191,25,192,25,193,25,194,25,195,25,196,25,197,25,198,25,199,25,200,25,201,25,202,25,203,25,204,25,205,25,206,25,207,25,208,25,209,25,210,25,211,25,212,25,213,25,214,25,215,25,216,25,217,25,218,25,219,25,220,25,221,25,222,25,223,25,190,26,191,26,192,26,193,26,194,26,196,26,197,26,198,26,199,26,200,26,201,26,202,26,203,26,204,26,205,26,207,26,208,26,209,26,210,26,211,26,212,26,213,26,214,26,215,26,216,26,217,26,218,26,219,26,220,26,221,26,222,26,223,26,190,27,191,27,192,27,193,27,194,27,195,27,196,27,197,27,198,27,199,27,200,27,201,27,202,27,203,27,204,27,205,27,206,27,207,27,208,27,209,27,210,27,211,27,212,27,214,27,216,27,217,27,218,27,219,27,220,27,221,27,222,27,223,27,190,28,191,28,192,28,193,28,194,28,195,28,196,28,197,28,198,28,199,28,200,28,201,28,202,28,203,28,204,28,205,28,206,28,207,28,208,28,209,28,210,28,211,28,212,28,213,28,214,28,215,28,216,28,217,28,218,28,219,28,220,28,222,28,223,28,189,29,190,29,191,29,192,29,193,29,194,29,195,29,196,29,197,29,198,29,199,29,200,29,201,29,202,29,203,29,204,29,205,29,206,29,207,29,208,29,209,29,210,29,211,29,213,29,214,29,215,29,216,29,217,29,218,29,219,29,220,29,221,29,222,29,189,30,190,30,191,30,192,30,193,30,194,30,195,30,196,30,197,30,198,30,199,30,200,30,201,30,202,30,203,30,204,30,205,30,206,30,207,30,208,30,209,30,210,30,211,30,212,30,214,30,215,30,216,30,217,30,218,30,219,30,220,30,221,30,222,30,189,31,190,31,191,31,192,31,193,31,194,31,195,31,196,31,199,31,200,31,201,31,202,31,203,31,204,31,207,31,208,31,209,31,210,31,211,31,212,31,213,31,214,31,215,31,216,31,217,31,218,31,219,31,220,31,221,31,189,32,190,32,191,32,192,32,193,32,194,32,195,32,196,32,197,32,198,32,199,32,200,32,201,32,202,32,203,32,207,32,208,32,210,32,211,32,212,32,213,32,214,32,215,32,216,32,217,32,218,32,219,32,220,32,221,32,188,33,189,33,190,33,191,33,192,33,193,33,196,33,197,33,198,33,199,33,200,33,201,33,202,33,203,33,204,33,207,33,208,33,210,33,211,33,213,33,214,33,215,33,216,33,217,33,219,33,220,33,221,33,188,34,189,34,190,34,191,34,192,34,193,34,197,34,198,34,202,34,203,34,204,34,205,34,206,34,207,34,208,34,209,34,211,34,214,34,215,34,216,34,217,34,218,34,219,34,220,34,221,34,188,35,189,35,190,35,191,35,193,35,197,35,198,35,199,35,200,35,206,35,207,35,208,35,210,35,211,35,212,35,213,35,216,35,217,35,218,35,219,35,221,35,187,36,188,36,189,36,190,36,191,36,193,36,194,36,195,36,196,36,198,36,199,36,200,36,210,36,212,36,213,36,215,36,217,36,218,36,219,36,221,36,187,37,188,37,189,37,190,37,191,37,192,37,193,37,194,37,195,37,203,37,204,37,209,37,210,37,211,37,212,37,213,37,215,37,220,37,187,38,188,38,189,38,190,38,191,38,192,38,194,38,197,38,198,38,200,38,201,38,203,38,204,38,205,38,206,38,210,38,211,38,215,38,186,39,187,39,188,39,189,39,190,39,191,39,192,39,197,39,198,39,200,39,201,39,205,39,206,39,210,39,211,39,212,39,213,39,214,39,216,39,217,39,218,39,219,39,220,39,186,40,187,40,188,40,189,40,190,40,191,40,192,40,200,40,202,40,203,40,210,40,211,40,212,40,213,40,216,40,217,40,218,40,219,40,220,40,186,41,187,41,188,41,189,41,190,41,191,41,192,41,198,41,201,41,202,41,203,41,205,41,212,41,215,41,216,41,219,41,220,41,186,42,187,42,188,42,189,42,190,42,191,42,192,42,199,42,207,42,208,42,209,42,214,42,215,42,117,43,118,43,185,43,186,43,187,43,188,43,189,43,191,43,194,43,195,43,207,43,208,43,209,43,215,43,218,43,116,44,117,44,118,44,119,44,185,44,186,44,187,44,188,44,189,44,190,44,191,44,195,44,196,44,201,44,203,44,207,44,209,44,218,44,221,44,115,45,116,45,117,45,118,45,119,45,120,45,186,45,187,45,188,45,189,45,190,45,191,45,192,45,196,45,197,45,198,45,200,45,206,45,210,45,218,45,113,46,114,46,115,46,116,46,117,46,118,46,119,46,120,46,121,46,184,46,186,46,187,46,189,46,190,46,191,46,192,46,200,46,203,46,204,46,209,46,210,46,212,46,112,47,113,47,114,47,115,47,116,47,117,47,118,47,119,47,120,47,121,47,181,47,182,47,183,47,185,47,186,47,187,47,188,47,189,47,199,47,203,47,209,47,210,47,213,47,215,47,216,47,110,48,111,48,112,48,113,48,114,48,115,48,116,48,117,48,118,48,119,48,120,48,121,48,122,48,123,48,124,48,177,48,178,48,179,48,180,48,181,48,182,48,184,48,185,48,187,48,188,48,189,48,190,48,202,48,209,48,210,48,214,48,215,48,220,48,109,49,110,49,111,49,112,49,113,49,114,49,115,49,116,49,117,49,118,49,119,49,120,49,121,49,122,49,123,49,124,49,173,49,174,49,175,49,176,49,177,49,178,49,179,49,180,49,181,49,188,49,189,49,190,49,195,49,201,49,204,49,209,49,217,49,220,49,108,50,109,50,110,50,111,50,112,50,113,50,114,50,115,50,116,50,117,50,118,50,119,50,120,50,121,50,122,50,123,50,169,50,170,50,171,50,172,50,173,50,174,50,175,50,176,50,177,50,179,50,180,50,184,50,188,50,189,50,201,50,204,50,209,50,215,50,220,50,221,50,107,51,108,51,109,51,110,51,111,51,112,51,113,51,114,51,116,51,117,51,118,51,119,51,120,51,121,51,122,51,123,51,124,51,128,51,166,51,167,51,168,51,169,51,170,51,171,51,172,51,173,51,174,51,175,51,176,51,177,51,178,51,179,51,180,51,181,51,182,51,183,51,189,51,196,51,201,51,202,51,209,51,215,51,220,51,221,51,106,52,107,52,108,52,109,52,110,52,111,52,112,52,113,52,114,52,115,52,116,52,117,52,118,52,119,52,120,52,121,52,122,52,123,52,124,52,125,52,126,52,128,52,129,52,163,52,164,52,165,52,166,52,167,52,168,52,169,52,170,52,171,52,172,52,173,52,175,52,176,52,177,52,178,52,179,52,180,52,181,52,187,52,189,52,196,52,204,52,215,52,217,52,218,52,219,52,221,52,104,53,105,53,106,53,107,53,108,53,109,53,110,53,111,53,112,53,113,53,114,53,115,53,116,53,117,53,118,53,119,53,120,53,121,53,122,53,123,53,124,53,125,53,126,53,160,53,161,53,162,53,163,53,164,53,165,53,166,53,167,53,168,53,169,53,170,53,171,53,172,53,173,53,174,53,175,53,176,53,177,53,178,53,179,53,180,53,181,53,182,53,183,53,184,53,187,53,188,53,218,53,221,53,103,54,104,54,105,54,106,54,107,54,108,54,109,54,110,54,111,54,112,54,113,54,114,54,115,54,116,54,117,54,118,54,119,54,120,54,121,54,122,54,123,54,124,54,125,54,126,54,127,54,129,54,157,54,158,54,159,54,160,54,161,54,162,54,163,54,164,54,165,54,166,54,167,54,168,54,169,54,170,54,171,54,172,54,173,54,174,54,175,54,176,54,177,54,178,54,179,54,180,54,181,54,182,54,183,54,187,54,221,54,102,55,103,55,104,55,105,55,106,55,107,55,108,55,109,55,110,55,111,55,112,55,113,55,114,55,115,55,116,55,117,55,118,55,119,55,120,55,121,55,122,55,123,55,124,55,125,55,126,55,127,55,128,55,129,55,155,55,156,55,157,55,158,55,159,55,160,55,161,55,162,55,163,55,164,55,165,55,166,55,167,55,168,55,169,55,170,55,171,55,172,55,173,55,174,55,175,55,176,55,177,55,178,55,179,55,180,55,181,55,189,55,190,55,206,55,207,55,213,55,221,55,222,55,294,55,101,56,102,56,103,56,104,56,105,56,106,56,107,56,108,56,109,56,110,56,111,56,112,56,113,56,116,56,117,56,118,56,119,56,120,56,121,56,122,56,123,56,124,56,125,56,127,56,130,56,131,56,152,56,153,56,154,56,155,56,156,56,157,56,158,56,159,56,160,56,161,56,162,56,163,56,164,56,165,56,166,56,167,56,168,56,169,56,170,56,171,56,172,56,173,56,175,56,176,56,177,56,178,56,179,56,180,56,181,56,184,56,200,56,207,56,219,56,220,56,221,56,222,56,292,56,293,56,294,56,100,57,101,57,102,57,103,57,104,57,105,57,106,57,107,57,108,57,109,57,110,57,111,57,112,57,113,57,114,57,115,57,116,57,117,57,118,57,119,57,120,57,121,57,122,57,123,57,124,57,125,57,126,57,127,57,150,57,151,57,152,57,153,57,154,57,155,57,156,57,157,57,158,57,159,57,160,57,161,57,162,57,163,57,164,57,165,57,166,57,167,57,168,57,169,57,170,57,171,57,173,57,175,57,176,57,177,57,178,57,182,57,183,57,184,57,186,57,187,57,188,57,197,57,201,57,203,57,204,57,290,57,291,57,292,57,99,58,100,58,101,58,102,58,103,58,104,58,105,58,106,58,107,58,108,58,109,58,110,58,112,58,113,58,114,58,115,58,116,58,117,58,118,58,119,58,120,58,121,58,122,58,123,58,124,58,125,58,126,58,127,58,128,58,131,58,133,58,147,58,148,58,149,58,150,58,151,58,152,58,153,58,154,58,155,58,156,58,157,58,158,58,159,58,160,58,161,58,162,58,163,58,164,58,165,58,166,58,167,58,168,58,169,58,170,58,171,58,172,58,173,58,174,58,175,58,176,58,177,58,178,58,179,58,185,58,187,58,188,58,189,58,190,58,191,58,195,58,196,58,197,58,198,58,204,58,205,58,206,58,209,58,215,58,216,58,217,58,221,58,288,58,289,58,290,58,291,58,98,59,99,59,100,59,101,59,102,59,103,59,104,59,105,59,106,59,107,59,108,59,109,59,110,59,111,59,112,59,113,59,114,59,115,59,116,59,117,59,118,59,119,59,120,59,121,59,123,59,124,59,125,59,127,59,131,59,137,59,147,59,148,59,149,59,150,59,151,59,152,59,153,59,154,59,155,59,156,59,157,59,158,59,159,59,160,59,161,59,162,59,163,59,164,59,165,59,166,59,167,59,168,59,169,59,170,59,171,59,172,59,176,59,179,59,180,59,181,59,185,59,186,59,189,59,190,59,191,59,192,59,193,59,194,59,195,59,196,59,197,59,206,59,209,59,210,59,211,59,215,59,220,59,221,59,222,59,287,59,288,59,289,59,290,59,97,60,98,60,99,60,100,60,101,60,102,60,103,60,104,60,105,60,106,60,107,60,108,60,109,60,110,60,112,60,113,60,114,60,115,60,116,60,117,60,118,60,119,60,120,60,121,60,122,60,123,60,124,60,125,60,129,60,130,60,131,60,132,60,137,60,144,60,145,60,146,60,147,60,148,60,149,60,150,60,151,60,152,60,153,60,154,60,155,60,156,60,157,60,158,60,159,60,160,60,161,60,162,60,163,60,164,60,165,60,166,60,168,60,169,60,170,60,171,60,175,60,176,60,177,60,180,60,183,60,184,60,220,60,221,60,285,60,286,60,287,60,288,60,289,60,96,61,98,61,99,61,100,61,101,61,102,61,103,61,104,61,105,61,106,61,107,61,108,61,109,61,110,61,111,61,112,61,113,61,114,61,115,61,116,61,117,61,118,61,121,61,122,61,123,61,124,61,125,61,128,61,137,61,146,61,147,61,148,61,149,61,150,61,151,61,152,61,153,61,154,61,155,61,156,61,157,61,158,61,159,61,160,61,161,61,162,61,163,61,164,61,165,61,166,61,167,61,168,61,169,61,170,61,171,61,172,61,173,61,177,61,183,61,184,61,221,61,247,61,248,61,283,61,284,61,285,61,286,61,287,61,288,61,95,62,98,62,99,62,100,62,101,62,102,62,103,62,104,62,105,62,106,62,107,62,108,62,109,62,110,62,111,62,112,62,113,62,114,62,115,62,116,62,117,62,119,62,120,62,121,62,122,62,123,62,126,62,128,62,132,62,135,62,142,62,143,62,144,62,145,62,146,62,147,62,148,62,149,62,150,62,151,62,152,62,153,62,154,62,155,62,156,62,157,62,158,62,159,62,160,62,161,62,162,62,163,62,164,62,165,62,166,62,170,62,171,62,173,62,174,62,175,62,176,62,177,62,178,62,184,62,185,62,186,62,195,62,196,62,197,62,201,62,227,62,228,62,233,62,237,62,241,62,242,62,245,62,246,62,250,62,253,62,282,62,283,62,284,62,285,62,286,62,287,62,94,63,95,63,96,63,97,63,98,63,99,63,100,63,101,63,102,63,103,63,104,63,105,63,106,63,107,63,108,63,109,63,110,63,111,63,112,63,113,63,114,63,115,63,116,63,117,63,118,63,122,63,123,63,124,63,128,63,132,63,133,63,146,63,147,63,148,63,149,63,150,63,151,63,152,63,153,63,154,63,155,63,156,63,157,63,158,63,159,63,160,63,161,63,162,63,163,63,164,63,165,63,166,63,167,63,175,63,181,63,182,63,185,63,186,63,187,63,194,63,195,63,196,63,197,63,206,63,237,63,238,63,239,63,241,63,242,63,246,63,247,63,249,63,251,63,252,63,253,63,280,63,281,63,282,63,283,63,284,63,285,63,286,63,287,63,93,64,94,64,95,64,96,64,97,64,98,64,99,64,100,64,101,64,102,64,103,64,104,64,105,64,106,64,107,64,108,64,109,64,110,64,111,64,112,64,113,64,114,64,115,64,116,64,117,64,119,64,123,64,124,64,126,64,132,64,133,64,134,64,144,64,147,64,148,64,149,64,150,64,151,64,152,64,153,64,154,64,155,64,156,64,157,64,158,64,159,64,160,64,161,64,162,64,164,64,166,64,167,64,168,64,169,64,170,64,179,64,180,64,181,64,182,64,185,64,186,64,189,64,190,64,191,64,192,64,199,64,200,64,201,64,206,64,207,64,229,64,233,64,241,64,242,64,244,64,245,64,246,64,247,64,249,64,250,64,251,64,252,64,253,64,254,64,255,64,257,64,258,64,278,64,279,64,280,64,281,64,282,64,283,64,284,64,285,64,286,64,94,65,95,65,96,65,97,65,98,65,99,65,100,65,101,65,102,65,103,65,104,65,105,65,106,65,107,65,108,65,109,65,110,65,111,65,112,65,113,65,115,65,117,65,118,65,120,65,121,65,123,65,135,65,144,65,148,65,149,65,150,65,152,65,153,65,154,65,155,65,156,65,157,65,158,65,159,65,162,65,166,65,167,65,169,65,170,65,174,65,175,65,176,65,177,65,178,65,179,65,180,65,185,65,189,65,190,65,191,65,192,65,198,65,200,65,201,65,203,65,206,65,207,65,208,65,211,65,212,65,218,65,219,65,220,65,236,65,237,65,238,65,241,65,242,65,243,65,244,65,245,65,246,65,247,65,248,65,250,65,251,65,254,65,255,65,256,65,257,65,258,65,277,65,278,65,279,65,280,65,281,65,282,65,283,65,284,65,285,65,286,65,95,66,96,66,97,66,98,66,99,66,100,66,101,66,102,66,103,66,104,66,105,66,106,66,107,66,108,66,109,66,110,66,111,66,112,66,115,66,117,66,118,66,123,66,135,66,136,66,146,66,147,66,148,66,149,66,150,66,151,66,152,66,153,66,154,66,155,66,158,66,159,66,160,66,161,66,163,66,164,66,165,66,168,66,169,66,178,66,179,66,180,66,193,66,198,66,201,66,204,66,205,66,206,66,210,66,211,66,212,66,215,66,218,66,220,66,233,66,236,66,239,66,241,66,242,66,243,66,244,66,246,66,248,66,252,66,253,66,254,66,255,66,256,66,257,66,259,66,260,66,261,66,275,66,276,66,277,66,278,66,279,66,280,66,281,66,282,66,283,66,284,66,286,66,95,67,96,67,97,67,98,67,99,67,100,67,101,67,102,67,103,67,104,67,105,67,106,67,107,67,108,67,109,67,110,67,111,67,112,67,113,67,114,67,115,67,117,67,118,67,120,67,121,67,124,67,126,67,127,67,131,67,138,67,147,67,148,67,149,67,150,67,151,67,153,67,154,67,155,67,157,67,158,67,159,67,160,67,161,67,162,67,163,67,168,67,169,67,170,67,171,67,172,67,175,67,176,67,177,67,178,67,179,67,180,67,184,67,195,67,201,67,204,67,205,67,212,67,215,67,217,67,218,67,233,67,235,67,242,67,243,67,244,67,245,67,246,67,247,67,248,67,251,67,252,67,253,67,254,67,255,67,256,67,257,67,258,67,259,67,260,67,261,67,262,67,263,67,264,67,274,67,275,67,276,67,277,67,278,67,279,67,280,67,281,67,282,67,283,67,284,67,97,68,98,68,99,68,100,68,101,68,102,68,103,68,104,68,105,68,106,68,107,68,108,68,109,68,110,68,112,68,115,68,117,68,118,68,120,68,121,68,127,68,128,68,146,68,147,68,148,68,149,68,150,68,153,68,156,68,162,68,166,68,167,68,168,68,169,68,170,68,171,68,172,68,173,68,174,68,175,68,176,68,183,68,184,68,185,68,194,68,209,68,212,68,215,68,216,68,236,68,237,68,238,68,239,68,242,68,244,68,245,68,246,68,247,68,248,68,251,68,252,68,253,68,255,68,256,68,257,68,260,68,261,68,262,68,263,68,264,68,272,68,273,68,274,68,275,68,276,68,277,68,278,68,279,68,280,68,282,68,283,68,284,68,286,68,98,69,99,69,100,69,101,69,102,69,103,69,104,69,105,69,106,69,107,69,108,69,109,69,112,69,115,69,116,69,117,69,118,69,133,69,134,69,146,69,147,69,148,69,149,69,152,69,153,69,154,69,157,69,158,69,162,69,163,69,164,69,165,69,166,69,168,69,169,69,170,69,171,69,172,69,175,69,176,69,184,69,185,69,186,69,194,69,202,69,203,69,204,69,212,69,215,69,230,69,231,69,242,69,244,69,245,69,246,69,247,69,250,69,251,69,253,69,254,69,255,69,256,69,257,69,258,69,259,69,260,69,261,69,262,69,264,69,267,69,268,69,269,69,271,69,272,69,273,69,274,69,275,69,276,69,277,69,278,69,279,69,280,69,283,69,284,69,99,70,100,70,101,70,102,70,103,70,104,70,105,70,106,70,107,70,108,70,109,70,111,70,119,70,120,70,122,70,124,70,130,70,147,70,148,70,149,70,150,70,153,70,154,70,161,70,162,70,163,70,164,70,167,70,169,70,184,70,185,70,186,70,187,70,188,70,198,70,202,70,203,70,230,70,231,70,248,70,249,70,250,70,251,70,252,70,253,70,254,70,255,70,256,70,257,70,258,70,259,70,260,70,261,70,262,70,263,70,264,70,265,70,266,70,267,70,268,70,269,70,271,70,272,70,273,70,274,70,275,70,276,70,278,70,279,70,280,70,284,70,101,71,102,71,103,71,104,71,105,71,106,71,107,71,108,71,109,71,110,71,119,71,122,71,123,71,153,71,154,71,155,71,156,71,157,71,161,71,162,71,169,71,184,71,185,71,186,71,187,71,190,71,198,71,201,71,202,71,217,71,218,71,227,71,234,71,241,71,243,71,245,71,251,71,252,71,253,71,255,71,257,71,258,71,259,71,260,71,261,71,262,71,266,71,267,71,268,71,270,71,271,71,272,71,273,71,274,71,275,71,276,71,277,71,282,71,283,71,284,71,290,71,102,72,103,72,104,72,105,72,106,72,107,72,108,72,109,72,114,72,115,72,116,72,122,72,123,72,127,72,128,72,142,72,145,72,146,72,148,72,149,72,154,72,156,72,157,72,158,72,159,72,160,72,161,72,162,72,169,72,174,72,175,72,178,72,189,72,196,72,197,72,201,72,202,72,203,72,210,72,211,72,212,72,218,72,219,72,224,72,225,72,226,72,227,72,228,72,229,72,234,72,244,72,247,72,248,72,252,72,253,72,254,72,256,72,257,72,259,72,260,72,261,72,262,72,263,72,264,72,265,72,266,72,267,72,268,72,269,72,270,72,271,72,272,72,273,72,274,72,275,72,276,72,277,72,281,72,282,72,103,73,104,73,105,73,107,73,108,73,110,73,111,73,112,73,114,73,116,73,117,73,118,73,121,73,139,73,141,73,142,73,145,73,146,73,147,73,148,73,149,73,150,73,151,73,152,73,153,73,154,73,155,73,157,73,158,73,159,73,160,73,161,73,165,73,167,73,180,73,184,73,185,73,186,73,196,73,197,73,200,73,201,73,204,73,207,73,208,73,209,73,210,73,211,73,213,73,215,73,223,73,224,73,229,73,245,73,246,73,247,73,250,73,251,73,257,73,258,73,263,73,264,73,265,73,266,73,267,73,268,73,269,73,270,73,271,73,272,73,273,73,274,73,281,73,105,74,107,74,108,74,109,74,110,74,111,74,113,74,114,74,116,74,117,74,118,74,125,74,142,74,147,74,148,74,149,74,150,74,151,74,153,74,160,74,161,74,162,74,165,74,171,74,185,74,188,74,189,74,193,74,194,74,197,74,198,74,200,74,201,74,203,74,204,74,207,74,208,74,209,74,210,74,221,74,222,74,223,74,224,74,233,74,234,74,235,74,236,74,257,74,258,74,260,74,261,74,268,74,269,74,270,74,271,74,273,74,280,74,281,74,283,74,287,74,288,74,106,75,107,75,108,75,109,75,110,75,111,75,113,75,114,75,118,75,119,75,125,75,126,75,142,75,143,75,145,75,147,75,151,75,152,75,153,75,161,75,162,75,171,75,172,75,178,75,181,75,182,75,183,75,188,75,193,75,194,75,195,75,196,75,203,75,204,75,206,75,208,75,209,75,213,75,220,75,221,75,222,75,223,75,224,75,233,75,234,75,235,75,249,75,252,75,253,75,256,75,257,75,259,75,260,75,268,75,269,75,271,75,272,75,281,75,283,75,284,75,286,75,289,75,290,75,112,76,115,76,119,76,122,76,126,76,133,76,137,76,140,76,141,76,142,76,145,76,146,76,147,76,148,76,149,76,150,76,152,76,153,76,158,76,169,76,176,76,177,76,183,76,187,76,188,76,192,76,193,76,194,76,195,76,203,76,204,76,206,76,207,76,209,76,212,76,213,76,215,76,220,76,221,76,222,76,223,76,224,76,226,76,233,76,241,76,251,76,257,76,261,76,267,76,268,76,269,76,270,76,271,76,272,76,273,76,274,76,275,76,280,76,281,76,282,76,287,76,292,76,112,77,113,77,114,77,116,77,119,77,120,77,122,77,126,77,131,77,132,77,137,77,138,77,142,77,145,77,150,77,162,77,163,77,168,77,169,77,178,77,179,77,180,77,181,77,183,77,191,77,192,77,193,77,195,77,199,77,206,77,212,77,218,77,219,77,226,77,227,77,228,77,229,77,230,77,241,77,245,77,254,77,255,77,256,77,266,77,267,77,268,77,274,77,275,77,276,77,277,77,279,77,280,77,281,77,286,77,288,77,291,77,112,78,116,78,117,78,121,78,122,78,132,78,137,78,142,78,146,78,148,78,153,78,162,78,164,78,169,78,170,78,172,78,178,78,179,78,180,78,182,78,187,78,189,78,199,78,200,78,204,78,205,78,206,78,210,78,211,78,217,78,218,78,219,78,221,78,222,78,223,78,224,78,231,78,238,78,245,78,256,78,257,78,258,78,263,78,275,78,279,78,285,78,288,78,121,79,134,79,135,79,136,79,137,79,138,79,139,79,142,79,143,79,144,79,145,79,146,79,147,79,148,79,166,79,167,79,169,79,170,79,176,79,179,79,181,79,186,79,187,79,188,79,189,79,191,79,194,79,195,79,196,79,203,79,204,79,205,79,217,79,218,79,219,79,223,79,227,79,231,79,234,79,238,79,244,79,262,79,263,79,264,79,279,79,291,79,297,79,112,80,122,80,126,80,132,80,133,80,134,80,137,80,138,80,139,80,140,80,141,80,142,80,146,80,147,80,157,80,166,80,167,80,169,80,170,80,171,80,176,80,181,80,184,80,185,80,186,80,187,80,188,80,195,80,196,80,204,80,205,80,211,80,214,80,216,80,217,80,218,80,219,80,227,80,235,80,236,80,237,80,238,80,239,80,243,80,247,80,262,80,263,80,270,80,291,80,293,80,294,80,295,80,298,80,110,81,116,81,122,81,127,81,131,81,133,81,146,81,151,81,155,81,156,81,158,81,159,81,166,81,169,81,170,81,173,81,176,81,177,81,178,81,183,81,184,81,185,81,195,81,196,81,197,81,200,81,201,81,204,81,205,81,207,81,209,81,210,81,211,81,214,81,215,81,218,81,221,81,223,81,227,81,235,81,236,81,269,81,270,81,294,81,295,81,110,82,116,82,127,82,131,82,133,82,136,82,137,82,139,82,140,82,142,82,143,82,146,82,147,82,155,82,158,82,159,82,160,82,162,82,163,82,164,82,166,82,167,82,173,82,177,82,179,82,180,82,183,82,184,82,185,82,194,82,195,82,200,82,201,82,206,82,207,82,208,82,209,82,210,82,215,82,217,82,218,82,221,82,227,82,228,82,233,82,234,82,251,82,267,82,294,82,295,82,300,82,113,83,115,83,116,83,128,83,129,83,132,83,133,83,135,83,136,83,147,83,148,83,154,83,155,83,158,83,159,83,167,83,172,83,174,83,182,83,183,83,193,83,194,83,197,83,198,83,199,83,200,83,201,83,204,83,205,83,206,83,208,83,209,83,213,83,214,83,215,83,216,83,220,83,221,83,224,83,225,83,226,83,227,83,228,83,232,83,233,83,234,83,235,83,236,83,240,83,244,83,247,83,248,83,251,83,288,83,292,83,295,83,296,83,128,84,129,84,134,84,135,84,138,84,141,84,144,84,145,84,150,84,153,84,154,84,161,84,164,84,165,84,166,84,167,84,176,84,177,84,180,84,182,84,183,84,184,84,193,84,194,84,195,84,197,84,198,84,199,84,201,84,205,84,206,84,208,84,212,84,213,84,214,84,215,84,216,84,220,84,221,84,222,84,223,84,224,84,225,84,226,84,227,84,230,84,235,84,236,84,239,84,243,84,244,84,248,84,251,84,254,84,255,84,256,84,284,84,285,84,292,84,297,84,298,84,128,85,129,85,130,85,131,85,132,85,135,85,136,85,137,85,140,85,141,85,142,85,149,85,150,85,151,85,153,85,157,85,162,85,163,85,164,85,165,85,166,85,167,85,170,85,171,85,173,85,176,85,177,85,182,85,188,85,189,85,194,85,195,85,197,85,198,85,199,85,204,85,206,85,207,85,208,85,209,85,210,85,214,85,218,85,219,85,220,85,222,85,223,85,225,85,226,85,229,85,230,85,233,85,235,85,239,85,255,85,256,85,298,85,128,86,137,86,138,86,139,86,140,86,141,86,142,86,148,86,150,86,153,86,156,86,157,86,162,86,163,86,164,86,167,86,170,86,171,86,172,86,173,86,177,86,194,86,195,86,196,86,197,86,198,86,199,86,203,86,204,86,217,86,218,86,219,86,220,86,226,86,229,86,230,86,231,86,232,86,233,86,236,86,242,86,297,86,123,87,124,87,125,87,126,87,127,87,128,87,133,87,134,87,137,87,138,87,139,87,140,87,144,87,145,87,153,87,155,87,156,87,157,87,158,87,159,87,160,87,164,87,169,87,172,87,173,87,185,87,186,87,190,87,192,87,193,87,198,87,201,87,202,87,203,87,214,87,216,87,217,87,218,87,219,87,220,87,222,87,223,87,226,87,227,87,228,87,229,87,230,87,231,87,235,87,236,87,241,87,242,87,246,87,249,87,296,87,297,87,300,87,125,88,126,88,128,88,129,88,132,88,135,88,136,88,137,88,138,88,139,88,144,88,145,88,146,88,147,88,150,88,151,88,154,88,155,88,157,88,158,88,159,88,160,88,161,88,164,88,165,88,169,88,173,88,176,88,177,88,178,88,180,88,181,88,185,88,186,88,187,88,188,88,189,88,190,88,197,88,198,88,199,88,200,88,201,88,202,88,203,88,204,88,205,88,206,88,213,88,219,88,222,88,223,88,225,88,226,88,227,88,228,88,230,88,231,88,234,88,241,88,246,88,260,88,282,88,293,88,296,88,297,88,298,88,300,88,127,89,129,89,131,89,134,89,137,89,138,89,142,89,144,89,145,89,146,89,147,89,149,89,150,89,154,89,155,89,159,89,160,89,165,89,169,89,172,89,173,89,178,89,181,89,182,89,189,89,190,89,191,89,192,89,193,89,194,89,195,89,196,89,197,89,204,89,211,89,212,89,216,89,224,89,225,89,226,89,227,89,228,89,229,89,230,89,233,89,234,89,239,89,246,89,247,89,254,89,261,89,283,89,285,89,296,89,297,89,299,89,300,89,123,90,124,90,125,90,127,90,133,90,137,90,144,90,147,90,148,90,154,90,155,90,160,90,161,90,163,90,164,90,165,90,167,90,172,90,173,90,179,90,181,90,183,90,184,90,191,90,192,90,193,90,194,90,196,90,203,90,207,90,208,90,211,90,212,90,214,90,219,90,221,90,222,90,223,90,224,90,225,90,226,90,227,90,232,90,237,90,238,90,239,90,240,90,246,90,247,90,296,90,299,90,300,90,122,91,124,91,127,91,130,91,131,91,132,91,133,91,137,91,139,91,143,91,147,91,148,91,151,91,158,91,159,91,160,91,161,91,163,91,164,91,172,91,184,91,191,91,194,91,195,91,196,91,199,91,201,91,202,91,207,91,210,91,211,91,213,91,214,91,219,91,221,91,222,91,223,91,224,91,226,91,227,91,230,91,231,91,236,91,237,91,238,91,239,91,251,91,262,91,298,91,299,91,122,92,127,92,129,92,132,92,133,92,136,92,137,92,145,92,146,92,147,92,153,92,157,92,158,92,160,92,169,92,180,92,181,92,194,92,195,92,198,92,201,92,208,92,213,92,214,92,217,92,218,92,219,92,220,92,221,92,223,92,224,92,225,92,226,92,227,92,228,92,229,92,230,92,234,92,236,92,237,92,245,92,255,92,256,92,259,92,260,92,297,92,298,92,107,93,108,93,120,93,125,93,128,93,129,93,133,93,134,93,136,93,143,93,144,93,145,93,146,93,147,93,148,93,151,93,153,93,157,93,158,93,159,93,160,93,164,93,165,93,169,93,170,93,171,93,172,93,180,93,184,93,188,93,189,93,192,93,193,93,194,93,202,93,203,93,204,93,205,93,207,93,214,93,217,93,218,93,219,93,220,93,221,93,222,93,223,93,224,93,225,93,226,93,227,93,228,93,229,93,236,93,244,93,248,93,249,93,250,93,255,93,256,93,259,93,285,93,292,93,297,93,106,94,107,94,108,94,119,94,120,94,121,94,123,94,128,94,133,94,134,94,135,94,136,94,146,94,151,94,153,94,157,94,159,94,160,94,162,94,163,94,164,94,172,94,173,94,174,94,175,94,179,94,180,94,182,94,188,94,198,94,199,94,200,94,204,94,211,94,217,94,218,94,219,94,220,94,221,94,222,94,226,94,227,94,229,94,231,94,232,94,235,94,241,94,244,94,255,94,264,94,292,94,295,94,105,95,107,95,108,95,112,95,125,95,128,95,129,95,130,95,134,95,135,95,136,95,138,95,141,95,142,95,144,95,145,95,146,95,148,95,150,95,151,95,152,95,153,95,154,95,155,95,156,95,157,95,159,95,160,95,162,95,163,95,164,95,172,95,174,95,175,95,178,95,179,95,182,95,183,95,189,95,190,95,194,95,198,95,199,95,208,95,213,95,218,95,220,95,221,95,225,95,226,95,227,95,235,95,244,95,247,95,292,95,295,95,105,96,106,96,107,96,108,96,109,96,110,96,111,96,112,96,113,96,114,96,115,96,116,96,119,96,127,96,130,96,134,96,135,96,139,96,144,96,145,96,146,96,149,96,150,96,151,96,152,96,153,96,154,96,155,96,156,96,157,96,162,96,167,96,171,96,172,96,174,96,175,96,179,96,180,96,187,96,189,96,190,96,191,96,194,96,195,96,210,96,213,96,216,96,220,96,225,96,229,96,250,96,268,96,292,96,104,97,105,97,106,97,108,97,109,97,110,97,111,97,112,97,113,97,114,97,115,97,116,97,119,97,122,97,127,97,130,97,133,97,134,97,135,97,136,97,138,97,139,97,142,97,143,97,144,97,145,97,146,97,147,97,148,97,149,97,150,97,151,97,154,97,155,97,172,97,173,97,174,97,179,97,180,97,186,97,190,97,194,97,195,97,210,97,220,97,221,97,223,97,224,97,225,97,229,97,233,97,234,97,251,97,267,97,287,97,289,97,290,97,291,97,104,98,105,98,106,98,107,98,110,98,111,98,112,98,113,98,114,98,115,98,116,98,117,98,124,98,126,98,127,98,128,98,133,98,136,98,142,98,145,98,149,98,150,98,158,98,159,98,165,98,179,98,189,98,190,98,203,98,207,98,208,98,215,98,217,98,220,98,221,98,223,98,224,98,225,98,226,98,229,98,230,98,231,98,232,98,233,98,234,98,235,98,245,98,246,98,248,98,249,98,250,98,262,98,263,98,266,98,267,98,268,98,291,98,292,98,103,99,104,99,105,99,106,99,107,99,108,99,109,99,110,99,112,99,114,99,115,99,116,99,117,99,123,99,126,99,127,99,128,99,129,99,130,99,136,99,137,99,149,99,150,99,153,99,158,99,159,99,161,99,168,99,169,99,178,99,179,99,180,99,184,99,185,99,203,99,207,99,208,99,214,99,217,99,220,99,223,99,226,99,227,99,229,99,232,99,244,99,245,99,247,99,248,99,250,99,252,99,262,99,263,99,267,99,271,99,103,100,104,100,105,100,106,100,107,100,108,100,109,100,111,100,112,100,117,100,118,100,119,100,126,100,129,100,134,100,136,100,139,100,140,100,152,100,158,100,169,100,183,100,184,100,185,100,189,100,190,100,191,100,197,100,198,100,217,100,220,100,226,100,245,100,247,100,250,100,253,100,256,100,268,100,269,100,102,101,103,101,104,101,105,101,106,101,107,101,108,101,109,101,110,101,111,101,112,101,113,101,117,101,118,101,119,101,126,101,127,101,134,101,139,101,140,101,147,101,148,101,149,101,152,101,154,101,157,101,158,101,165,101,183,101,184,101,185,101,189,101,218,101,220,101,246,101,247,101,248,101,249,101,253,101,256,101,102,102,103,102,104,102,105,102,106,102,107,102,108,102,109,102,110,102,112,102,114,102,117,102,121,102,123,102,132,102,133,102,134,102,138,102,139,102,146,102,147,102,148,102,149,102,153,102,157,102,164,102,165,102,178,102,183,102,184,102,185,102,223,102,229,102,246,102,247,102,248,102,251,102,252,102,255,102,288,102,101,103,102,103,103,103,104,103,105,103,106,103,107,103,108,103,109,103,110,103,111,103,112,103,114,103,123,103,129,103,130,103,131,103,132,103,134,103,135,103,139,103,146,103,147,103,148,103,151,103,152,103,156,103,178,103,214,103,223,103,227,103,228,103,234,103,238,103,244,103,245,103,246,103,262,103,263,103,287,103,100,104,101,104,102,104,103,104,104,104,105,104,106,104,107,104,108,104,109,104,111,104,112,104,116,104,117,104,120,104,126,104,127,104,129,104,130,104,135,104,137,104,141,104,142,104,145,104,146,104,147,104,150,104,151,104,152,104,155,104,161,104,162,104,218,104,219,104,223,104,226,104,227,104,234,104,237,104,238,104,239,104,243,104,252,104,253,104,256,104,257,104,261,104,262,104,263,104,267,104,286,104,287,104,100,105,101,105,102,105,103,105,104,105,105,105,106,105,107,105,108,105,109,105,110,105,113,105,116,105,117,105,120,105,123,105,124,105,125,105,129,105,130,105,132,105,134,105,137,105,141,105,146,105,149,105,150,105,154,105,166,105,167,105,239,105,249,105,253,105,256,105,261,105,265,105,266,105,267,105,270,105,286,105,287,105,99,106,100,106,101,106,102,106,103,106,104,106,105,106,106,106,107,106,108,106,109,106,112,106,113,106,115,106,123,106,132,106,134,106,136,106,139,106,146,106,147,106,154,106,161,106,165,106,170,106,253,106,254,106,255,106,265,106,272,106,98,107,99,107,100,107,101,107,102,107,103,107,104,107,105,107,106,107,107,107,108,107,109,107,110,107,112,107,113,107,114,107,115,107,116,107,117,107,119,107,130,107,134,107,136,107,137,107,138,107,144,107,145,107,147,107,149,107,150,107,154,107,162,107,164,107,165,107,169,107,223,107,224,107,228,107,229,107,230,107,247,107,250,107,252,107,253,107,254,107,255,107,257,107,258,107,259,107,269,107,276,107,277,107,98,108,99,108,100,108,101,108,102,108,103,108,104,108,105,108,106,108,107,108,108,108,109,108,110,108,111,108,112,108,113,108,115,108,116,108,118,108,124,108,132,108,134,108,135,108,136,108,138,108,142,108,145,108,146,108,162,108,169,108,229,108,231,108,248,108,249,108,250,108,252,108,253,108,254,108,255,108,257,108,258,108,265,108,97,109,98,109,99,109,100,109,101,109,102,109,103,109,104,109,105,109,106,109,107,109,110,109,111,109,114,109,117,109,118,109,119,109,120,109,121,109,124,109,125,109,131,109,132,109,134,109,140,109,141,109,142,109,143,109,146,109,149,109,150,109,151,109,152,109,154,109,155,109,156,109,160,109,231,109,237,109,245,109,246,109,247,109,248,109,265,109,278,109,97,110,98,110,99,110,100,110,101,110,102,110,103,110,104,110,105,110,106,110,107,110,113,110,114,110,116,110,117,110,119,110,120,110,121,110,124,110,125,110,126,110,131,110,132,110,134,110,140,110,143,110,144,110,152,110,154,110,160,110,231,110,236,110,237,110,238,110,244,110,247,110,248,110,249,110,251,110,252,110,253,110,254,110,263,110,273,110,97,111,98,111,99,111,100,111,101,111,102,111,103,111,104,111,105,111,106,111,107,111,108,111,113,111,115,111,116,111,117,111,121,111,124,111,130,111,131,111,132,111,138,111,139,111,140,111,143,111,150,111,151,111,152,111,156,111,163,111,164,111,233,111,236,111,237,111,245,111,246,111,247,111,248,111,250,111,251,111,252,111,253,111,254,111,258,111,263,111,264,111,273,111,96,112,97,112,98,112,99,112,100,112,101,112,102,112,103,112,104,112,105,112,106,112,107,112,108,112,109,112,110,112,112,112,116,112,127,112,130,112,131,112,135,112,138,112,139,112,140,112,142,112,150,112,151,112,152,112,156,112,163,112,242,112,245,112,246,112,248,112,251,112,253,112,258,112,259,112,260,112,264,112,265,112,278,112,96,113,97,113,98,113,99,113,100,113,101,113,102,113,103,113,104,113,105,113,106,113,116,113,117,113,118,113,126,113,127,113,128,113,129,113,134,113,137,113,138,113,139,113,140,113,148,113,157,113,158,113,162,113,236,113,239,113,240,113,241,113,242,113,248,113,254,113,255,113,257,113,261,113,271,113,95,114,96,114,97,114,98,114,99,114,100,114,101,114,102,114,103,114,105,114,106,114,107,114,108,114,109,114,110,114,113,114,114,114,117,114,120,114,121,114,122,114,123,114,124,114,129,114,131,114,136,114,137,114,138,114,139,114,143,114,144,114,148,114,151,114,156,114,157,114,236,114,242,114,243,114,247,114,254,114,255,114,257,114,261,114,262,114,263,114,264,114,271,114,95,115,96,115,97,115,98,115,99,115,100,115,101,115,105,115,106,115,107,115,108,115,109,115,111,115,112,115,113,115,114,115,121,115,123,115,124,115,129,115,130,115,131,115,134,115,135,115,136,115,137,115,138,115,148,115,154,115,156,115,236,115,241,115,242,115,243,115,244,115,246,115,247,115,249,115,254,115,255,115,260,115,263,115,280,115,281,115,94,116,95,116,96,116,97,116,98,116,99,116,100,116,101,116,102,116,103,116,104,116,105,116,106,116,108,116,109,116,113,116,114,116,115,116,124,116,128,116,129,116,136,116,137,116,142,116,148,116,149,116,245,116,246,116,248,116,253,116,254,116,263,116,269,116,272,116,273,116,275,116,280,116,281,116,94,117,95,117,96,117,97,117,98,117,99,117,100,117,101,117,102,117,103,117,104,117,105,117,106,117,109,117,110,117,113,117,114,117,115,117,118,117,119,117,123,117,128,117,129,117,130,117,136,117,137,117,142,117,152,117,238,117,248,117,93,118,94,118,95,118,96,118,97,118,98,118,99,118,100,118,101,118,102,118,103,118,104,118,106,118,107,118,109,118,112,118,118,118,119,118,129,118,130,118,132,118,135,118,136,118,137,118,142,118,155,118,242,118,247,118,263,118,264,118,277,118,93,119,94,119,95,119,96,119,97,119,98,119,99,119,100,119,101,119,102,119,103,119,104,119,109,119,112,119,116,119,117,119,123,119,125,119,129,119,130,119,134,119,135,119,139,119,142,119,149,119,246,119,260,119,277,119,92,120,93,120,94,120,95,120,96,120,99,120,100,120,101,120,102,120,103,120,106,120,108,120,109,120,110,120,112,120,116,120,117,120,118,120,122,120,127,120,129,120,130,120,135,120,245,120,246,120,247,120,250,120,252,120,262,120,268,120,269,120,271,120,282,120,283,120,92,121,93,121,94,121,95,121,96,121,97,121,98,121,99,121,100,121,101,121,102,121,103,121,105,121,106,121,109,121,110,121,114,121,117,121,118,121,125,121,129,121,130,121,241,121,242,121,243,121,247,121,248,121,262,121,263,121,268,121,269,121,270,121,281,121,282,121,92,122,93,122,94,122,95,122,96,122,97,122,98,122,99,122,101,122,102,122,103,122,106,122,108,122,111,122,117,122,118,122,125,122,132,122,135,122,136,122,140,122,141,122,147,122,148,122,247,122,258,122,259,122,261,122,262,122,272,122,285,122,92,123,93,123,94,123,95,123,96,123,97,123,98,123,99,123,100,123,102,123,107,123,111,123,117,123,123,123,128,123,131,123,132,123,134,123,135,123,141,123,147,123,244,123,245,123,246,123,257,123,258,123,261,123,264,123,266,123,271,123,272,123,276,123,282,123,91,124,92,124,93,124,94,124,95,124,96,124,97,124,98,124,99,124,100,124,102,124,106,124,110,124,119,124,126,124,127,124,128,124,129,124,135,124,141,124,244,124,245,124,246,124,250,124,251,124,252,124,254,124,258,124,266,124,267,124,270,124,271,124,276,124,286,124,91,125,92,125,93,125,94,125,95,125,96,125,97,125,98,125,99,125,100,125,101,125,102,125,103,125,105,125,106,125,107,125,108,125,110,125,112,125,116,125,127,125,128,125,134,125,135,125,140,125,146,125,250,125,251,125,252,125,260,125,261,125,267,125,273,125,274,125,276,125,282,125,90,126,91,126,92,126,93,126,94,126,95,126,96,126,97,126,98,126,99,126,100,126,101,126,103,126,104,126,105,126,108,126,109,126,110,126,112,126,116,126,118,126,119,126,121,126,122,126,130,126,134,126,139,126,140,126,250,126,251,126,260,126,263,126,271,126,272,126,273,126,274,126,282,126,283,126,89,127,90,127,91,127,92,127,93,127,94,127,95,127,96,127,97,127,98,127,102,127,103,127,104,127,105,127,108,127,111,127,112,127,114,127,121,127,122,127,127,127,139,127,140,127,255,127,259,127,262,127,263,127,272,127,273,127,277,127,278,127,282,127,283,127,284,127,89,128,90,128,91,128,92,128,93,128,94,128,95,128,96,128,99,128,100,128,102,128,103,128,111,128,112,128,113,128,114,128,115,128,116,128,120,128,126,128,127,128,132,128,143,128,255,128,259,128,262,128,263,128,264,128,266,128,267,128,271,128,272,128,273,128,88,129,89,129,90,129,91,129,92,129,93,129,94,129,95,129,96,129,97,129,100,129,101,129,108,129,109,129,115,129,116,129,117,129,119,129,120,129,126,129,127,129,136,129,250,129,259,129,260,129,265,129,266,129,271,129,277,129,280,129,281,129,285,129,87,130,88,130,89,130,90,130,91,130,92,130,93,130,94,130,95,130,96,130,97,130,99,130,101,130,104,130,105,130,110,130,115,130,126,130,131,130,132,130,136,130,142,130,143,130,144,130,248,130,250,130,251,130,253,130,259,130,264,130,265,130,270,130,271,130,277,130,281,130,84,131,85,131,86,131,87,131,88,131,89,131,90,131,91,131,92,131,93,131,94,131,95,131,96,131,101,131,107,131,108,131,110,131,114,131,115,131,116,131,117,131,118,131,125,131,126,131,131,131,134,131,135,131,142,131,143,131,144,131,250,131,251,131,253,131,254,131,258,131,263,131,265,131,268,131,269,131,270,131,281,131,286,131,73,132,74,132,75,132,76,132,77,132,78,132,79,132,80,132,81,132,82,132,83,132,84,132,85,132,86,132,87,132,88,132,89,132,90,132,91,132,92,132,93,132,94,132,95,132,96,132,97,132,103,132,106,132,107,132,108,132,109,132,110,132,116,132,117,132,118,132,129,132,138,132,143,132,249,132,250,132,257,132,258,132,259,132,262,132,263,132,274,132,281,132,282,132,285,132,286,132,65,133,66,133,67,133,68,133,69,133,70,133,71,133,72,133,73,133,74,133,75,133,76,133,77,133,78,133,79,133,80,133,81,133,82,133,83,133,84,133,85,133,86,133,87,133,88,133,89,133,90,133,91,133,92,133,93,133,95,133,96,133,97,133,99,133,100,133,101,133,102,133,108,133,109,133,116,133,117,133,118,133,122,133,123,133,129,133,130,133,249,133,250,133,251,133,257,133,258,133,259,133,260,133,262,133,266,133,267,133,268,133,273,133,274,133,275,133,276,133,281,133,282,133,283,133,59,134,61,134,62,134,63,134,64,134,65,134,66,134,67,134,68,134,69,134,70,134,71,134,72,134,73,134,74,134,75,134,76,134,77,134,78,134,79,134,80,134,81,134,82,134,83,134,84,134,85,134,86,134,87,134,89,134,90,134,91,134,95,134,96,134,97,134,98,134,100,134,102,134,104,134,106,134,109,134,112,134,113,134,114,134,116,134,117,134,119,134,120,134,132,134,134,134,139,134,144,134,145,134,250,134,251,134,253,134,261,134,262,134,270,134,271,134,283,134,284,134,58,135,59,135,60,135,61,135,62,135,63,135,64,135,65,135,66,135,67,135,68,135,69,135,70,135,71,135,72,135,73,135,74,135,75,135,76,135,77,135,78,135,79,135,80,135,81,135,82,135,83,135,84,135,85,135,86,135,88,135,89,135,90,135,91,135,92,135,93,135,98,135,99,135,100,135,102,135,104,135,112,135,113,135,114,135,115,135,118,135,122,135,127,135,128,135,132,135,133,135,134,135,140,135,144,135,251,135,252,135,261,135,262,135,265,135,266,135,286,135,287,135,58,136,59,136,60,136,61,136,62,136,63,136,64,136,65,136,66,136,67,136,68,136,69,136,70,136,71,136,72,136,73,136,74,136,75,136,76,136,77,136,78,136,79,136,80,136,81,136,84,136,85,136,86,136,89,136,90,136,98,136,99,136,101,136,102,136,104,136,112,136,113,136,121,136,122,136,132,136,133,136,140,136,265,136,266,136,275,136,276,136,286,136,287,136,58,137,59,137,60,137,61,137,62,137,63,137,64,137,65,137,66,137,67,137,68,137,69,137,70,137,71,137,72,137,73,137,75,137,76,137,77,137,81,137,84,137,85,137,98,137,100,137,101,137,102,137,105,137,106,137,108,137,109,137,113,137,115,137,128,137,129,137,130,137,136,137,137,137,143,137,251,137,252,137,253,137,257,137,258,137,259,137,270,137,271,137,273,137,275,137,58,138,59,138,60,138,61,138,62,138,63,138,64,138,65,138,66,138,67,138,68,138,69,138,70,138,71,138,72,138,73,138,75,138,76,138,77,138,82,138,83,138,84,138,91,138,92,138,97,138,98,138,99,138,100,138,104,138,106,138,108,138,109,138,113,138,127,138,128,138,143,138,252,138,253,138,256,138,267,138,270,138,272,138,273,138,278,138,279,138,280,138,57,139,58,139,59,139,61,139,62,139,63,139,64,139,65,139,66,139,67,139,68,139,69,139,70,139,73,139,75,139,76,139,77,139,78,139,83,139,89,139,91,139,92,139,94,139,98,139,100,139,101,139,103,139,104,139,105,139,107,139,108,139,109,139,115,139,121,139,252,139,253,139,254,139,255,139,256,139,265,139,270,139,280,139,284,139,285,139,57,140,58,140,59,140,60,140,61,140,62,140,63,140,64,140,65,140,66,140,67,140,68,140,69,140,70,140,71,140,72,140,75,140,77,140,78,140,80,140,86,140,87,140,88,140,89,140,98,140,99,140,103,140,107,140,116,140,120,140,129,140,134,140,253,140,258,140,262,140,263,140,264,140,271,140,273,140,274,140,276,140,279,140,280,140,283,140,284,140,285,140,57,141,58,141,59,141,60,141,61,141,62,141,63,141,64,141,65,141,66,141,67,141,68,141,69,141,70,141,71,141,72,141,73,141,74,141,75,141,77,141,79,141,80,141,81,141,89,141,95,141,98,141,100,141,103,141,112,141,120,141,124,141,127,141,128,141,129,141,140,141,141,141,142,141,253,141,254,141,255,141,262,141,264,141,265,141,267,141,278,141,279,141,57,142,58,142,59,142,60,142,61,142,62,142,63,142,64,142,65,142,66,142,67,142,68,142,69,142,70,142,71,142,72,142,73,142,74,142,77,142,79,142,81,142,82,142,94,142,97,142,98,142,100,142,103,142,105,142,106,142,107,142,112,142,124,142,129,142,131,142,248,142,253,142,254,142,265,142,267,142,268,142,270,142,274,142,275,142,277,142,56,143,57,143,58,143,59,143,60,143,61,143,62,143,63,143,64,143,65,143,66,143,67,143,68,143,69,143,70,143,71,143,72,143,73,143,74,143,75,143,77,143,78,143,79,143,80,143,81,143,82,143,83,143,87,143,88,143,90,143,97,143,100,143,101,143,103,143,105,143,106,143,107,143,115,143,123,143,124,143,127,143,128,143,132,143,247,143,251,143,252,143,253,143,254,143,261,143,265,143,269,143,272,143,274,143,279,143,280,143,56,144,57,144,58,144,59,144,60,144,61,144,62,144,63,144,64,144,65,144,66,144,67,144,68,144,69,144,70,144,71,144,72,144,73,144,81,144,82,144,83,144,90,144,97,144,98,144,99,144,100,144,105,144,110,144,111,144,116,144,117,144,120,144,124,144,135,144,136,144,140,144,249,144,250,144,253,144,254,144,255,144,261,144,262,144,269,144,274,144,275,144,276,144,280,144,283,144,284,144,289,144,290,144,56,145,57,145,58,145,59,145,60,145,61,145,62,145,63,145,64,145,65,145,66,145,67,145,68,145,69,145,70,145,72,145,73,145,75,145,76,145,81,145,82,145,96,145,97,145,99,145,100,145,102,145,109,145,110,145,112,145,120,145,121,145,123,145,124,145,127,145,253,145,254,145,255,145,261,145,271,145,272,145,275,145,277,145,278,145,280,145,56,146,57,146,58,146,59,146,61,146,62,146,63,146,64,146,65,146,66,146,67,146,68,146,69,146,70,146,72,146,73,146,75,146,77,146,78,146,79,146,81,146,82,146,84,146,85,146,86,146,91,146,92,146,95,146,96,146,97,146,98,146,100,146,101,146,103,146,108,146,109,146,110,146,112,146,120,146,126,146,127,146,128,146,129,146,254,146,255,146,256,146,259,146,260,146,267,146,271,146,272,146,277,146,278,146,280,146,287,146,56,147,57,147,58,147,59,147,60,147,61,147,62,147,63,147,64,147,65,147,66,147,67,147,68,147,69,147,70,147,72,147,73,147,77,147,78,147,84,147,85,147,86,147,87,147,92,147,93,147,99,147,103,147,107,147,108,147,110,147,111,147,112,147,113,147,122,147,123,147,124,147,127,147,128,147,134,147,249,147,250,147,251,147,254,147,255,147,256,147,263,147,264,147,267,147,272,147,277,147,278,147,280,147,283,147,284,147,285,147,286,147,287,147,290,147,56,148,57,148,58,148,59,148,60,148,61,148,62,148,63,148,64,148,65,148,66,148,67,148,68,148,69,148,70,148,71,148,72,148,73,148,76,148,77,148,85,148,86,148,87,148,93,148,97,148,107,148,122,148,138,148,139,148,249,148,250,148,253,148,254,148,255,148,256,148,272,148,273,148,276,148,277,148,281,148,283,148,284,148,292,148,56,149,57,149,58,149,59,149,60,149,61,149,62,149,63,149,64,149,65,149,66,149,67,149,68,149,69,149,70,149,71,149,72,149,73,149,76,149,85,149,86,149,87,149,88,149,92,149,93,149,96,149,99,149,100,149,104,149,105,149,107,149,119,149,120,149,121,149,130,149,139,149,248,149,249,149,255,149,256,149,271,149,272,149,273,149,275,149,282,149,283,149,292,149,56,150,57,150,58,150,59,150,60,150,61,150,62,150,63,150,64,150,65,150,66,150,67,150,68,150,69,150,70,150,71,150,72,150,73,150,76,150,77,150,78,150,87,150,88,150,89,150,92,150,96,150,99,150,101,150,103,150,104,150,107,150,108,150,110,150,118,150,249,150,250,150,255,150,256,150,258,150,259,150,262,150,265,150,269,150,270,150,271,150,272,150,274,150,275,150,56,151,57,151,58,151,59,151,60,151,61,151,62,151,63,151,64,151,65,151,66,151,67,151,68,151,69,151,70,151,71,151,72,151,73,151,78,151,86,151,87,151,91,151,96,151,97,151,98,151,99,151,101,151,103,151,105,151,116,151,124,151,125,151,131,151,256,151,257,151,258,151,259,151,262,151,270,151,271,151,274,151,288,151,289,151,303,151,304,151,307,151,57,152,58,152,59,152,60,152,61,152,62,152,63,152,64,152,65,152,66,152,67,152,68,152,69,152,70,152,71,152,72,152,79,152,80,152,82,152,99,152,102,152,103,152,116,152,124,152,125,152,129,152,130,152,131,152,137,152,250,152,251,152,254,152,255,152,256,152,257,152,258,152,262,152,266,152,271,152,272,152,280,152,282,152,284,152,290,152,311,152,56,153,57,153,58,153,59,153,60,153,61,153,62,153,63,153,64,153,65,153,66,153,67,153,68,153,69,153,70,153,71,153,72,153,74,153,75,153,80,153,81,153,82,153,83,153,96,153,99,153,100,153,104,153,106,153,109,153,116,153,117,153,124,153,128,153,129,153,250,153,251,153,255,153,256,153,265,153,267,153,268,153,269,153,271,153,277,153,279,153,280,153,281,153,282,153,290,153,312,153,313,153,318,153,319,153,56,154,57,154,58,154,59,154,60,154,61,154,62,154,63,154,64,154,65,154,66,154,67,154,68,154,69,154,71,154,72,154,73,154,74,154,75,154,76,154,77,154,78,154,79,154,83,154,84,154,93,154,98,154,99,154,101,154,109,154,112,154,114,154,119,154,130,154,137,154,250,154,251,154,252,154,253,154,254,154,255,154,256,154,262,154,275,154,278,154,314,154,315,154,320,154,321,154,322,154,323,154,56,155,57,155,58,155,59,155,60,155,61,155,62,155,63,155,64,155,65,155,66,155,67,155,68,155,69,155,70,155,71,155,73,155,74,155,78,155,81,155,84,155,87,155,88,155,92,155,93,155,98,155,101,155,102,155,103,155,104,155,110,155,117,155,119,155,120,155,130,155,134,155,251,155,252,155,254,155,256,155,281,155,288,155,289,155,290,155,314,155,320,155,321,155,322,155,323,155,56,156,57,156,58,156,59,156,60,156,61,156,62,156,63,156,64,156,65,156,66,156,67,156,68,156,69,156,71,156,72,156,73,156,74,156,75,156,79,156,80,156,87,156,88,156,98,156,103,156,104,156,105,156,118,156,126,156,130,156,133,156,134,156,135,156,251,156,252,156,253,156,254,156,256,156,258,156,264,156,265,156,268,156,275,156,276,156,277,156,278,156,279,156,280,156,281,156,321,156,56,157,57,157,58,157,59,157,60,157,61,157,62,157,63,157,64,157,65,157,66,157,67,157,68,157,69,157,70,157,71,157,72,157,73,157,79,157,80,157,83,157,84,157,97,157,98,157,100,157,101,157,102,157,103,157,104,157,105,157,111,157,112,157,113,157,126,157,130,157,131,157,132,157,133,157,134,157,250,157,251,157,252,157,253,157,254,157,255,157,256,157,257,157,258,157,268,157,269,157,280,157,282,157,308,157,313,157,56,158,57,158,58,158,59,158,60,158,61,158,62,158,63,158,64,158,65,158,66,158,67,158,68,158,69,158,70,158,71,158,72,158,73,158,80,158,84,158,97,158,98,158,99,158,100,158,102,158,103,158,104,158,105,158,111,158,126,158,132,158,133,158,134,158,248,158,249,158,250,158,251,158,252,158,253,158,254,158,256,158,257,158,262,158,278,158,279,158,282,158,316,158,322,158,323,158,56,159,57,159,58,159,59,159,60,159,61,159,62,159,63,159,64,159,65,159,66,159,67,159,68,159,69,159,70,159,71,159,72,159,74,159,75,159,86,159,87,159,91,159,92,159,93,159,94,159,95,159,98,159,99,159,102,159,103,159,105,159,112,159,113,159,114,159,115,159,116,159,127,159,128,159,129,159,130,159,248,159,249,159,250,159,252,159,253,159,254,159,262,159,265,159,270,159,271,159,275,159,276,159,286,159,292,159,293,159,319,159,322,159,323,159,56,160,57,160,58,160,59,160,60,160,61,160,62,160,63,160,64,160,65,160,66,160,67,160,68,160,69,160,70,160,71,160,72,160,74,160,75,160,82,160,90,160,91,160,95,160,99,160,104,160,112,160,116,160,136,160,138,160,248,160,250,160,251,160,252,160,255,160,256,160,258,160,259,160,260,160,275,160,278,160,284,160,285,160,286,160,289,160,290,160,321,160,322,160,56,161,57,161,58,161,59,161,60,161,61,161,62,161,63,161,64,161,65,161,66,161,67,161,68,161,69,161,70,161,71,161,72,161,74,161,75,161,76,161,84,161,85,161,90,161,91,161,95,161,96,161,97,161,100,161,104,161,105,161,106,161,110,161,111,161,117,161,118,161,119,161,127,161,128,161,138,161,249,161,250,161,251,161,252,161,258,161,259,161,268,161,274,161,275,161,276,161,281,161,288,161,290,161,56,162,57,162,58,162,59,162,60,162,61,162,62,162,63,162,64,162,65,162,66,162,67,162,68,162,69,162,70,162,71,162,72,162,75,162,76,162,85,162,86,162,93,162,94,162,97,162,98,162,100,162,108,162,109,162,113,162,114,162,115,162,127,162,128,162,138,162,249,162,250,162,251,162,252,162,253,162,254,162,255,162,258,162,261,162,271,162,274,162,316,162,322,162,56,163,57,163,58,163,59,163,60,163,61,163,62,163,63,163,64,163,65,163,66,163,68,163,70,163,71,163,72,163,76,163,78,163,79,163,80,163,96,163,98,163,99,163,100,163,102,163,108,163,110,163,115,163,122,163,123,163,126,163,134,163,248,163,249,163,250,163,251,163,252,163,256,163,257,163,261,163,267,163,271,163,277,163,278,163,280,163,281,163,303,163,316,163,319,163,56,164,57,164,58,164,59,164,60,164,61,164,62,164,63,164,64,164,65,164,66,164,67,164,70,164,71,164,72,164,73,164,76,164,78,164,83,164,96,164,97,164,99,164,100,164,106,164,107,164,110,164,121,164,123,164,124,164,125,164,126,164,132,164,133,164,134,164,248,164,249,164,250,164,252,164,253,164,254,164,255,164,256,164,257,164,268,164,271,164,279,164,280,164,281,164,284,164,285,164,314,164,315,164,317,164,318,164,319,164,56,165,57,165,58,165,59,165,60,165,61,165,62,165,63,165,64,165,65,165,66,165,67,165,68,165,69,165,70,165,76,165,77,165,83,165,84,165,98,165,99,165,100,165,101,165,102,165,103,165,104,165,111,165,113,165,122,165,123,165,128,165,129,165,132,165,248,165,249,165,251,165,254,165,255,165,256,165,257,165,258,165,259,165,271,165,276,165,277,165,278,165,281,165,284,165,287,165,291,165,292,165,308,165,320,165,56,166,57,166,59,166,60,166,61,166,62,166,64,166,65,166,66,166,67,166,68,166,69,166,83,166,98,166,102,166,103,166,107,166,111,166,116,166,117,166,129,166,132,166,247,166,248,166,249,166,251,166,252,166,254,166,255,166,256,166,257,166,258,166,259,166,264,166,276,166,277,166,287,166,308,166,320,166,321,166,83,167,90,167,91,167,95,167,96,167,102,167,111,167,116,167,126,167,129,167,134,167,137,167,247,167,248,167,249,167,250,167,251,167,253,167,254,167,255,167,256,167,278,167,285,167,308,167,321,167,322,167,323,167,91,168,95,168,96,168,97,168,103,168,119,168,120,168,122,168,123,168,125,168,126,168,127,168,134,168,136,168,137,168,248,168,250,168,251,168,252,168,253,168,254,168,256,168,262,168,263,168,273,168,276,168,277,168,278,168,279,168,280,168,283,168,284,168,285,168,320,168,321,168,95,169,96,169,97,169,101,169,102,169,103,169,104,169,105,169,111,169,119,169,120,169,122,169,124,169,125,169,128,169,129,169,248,169,249,169,250,169,251,169,253,169,255,169,264,169,268,169,271,169,276,169,277,169,282,169,283,169,284,169,310,169,320,169,321,169,104,170,105,170,125,170,128,170,129,170,135,170,136,170,247,170,248,170,252,170,253,170,259,170,264,170,275,170,276,170,277,170,282,170,283,170,284,170,311,170,313,170,314,170,315,170,323,170,104,171,105,171,106,171,110,171,129,171,130,171,247,171,248,171,251,171,253,171,254,171,259,171,264,171,266,171,270,171,274,171,281,171,289,171,313,171,101,172,102,172,103,172,105,172,106,172,108,172,110,172,129,172,130,172,133,172,134,172,135,172,136,172,137,172,247,172,248,172,250,172,251,172,254,172,256,172,266,172,270,172,272,172,273,172,274,172,281,172,283,172,318,172,319,172,101,173,102,173,103,173,105,173,106,173,116,173,117,173,120,173,129,173,133,173,134,173,137,173,140,173,246,173,247,173,248,173,250,173,253,173,254,173,255,173,256,173,257,173,270,173,273,173,275,173,276,173,278,173,283,173,285,173,287,173,289,173,315,173,319,173,322,173,101,174,105,174,106,174,115,174,116,174,119,174,120,174,123,174,124,174,126,174,129,174,246,174,247,174,252,174,253,174,254,174,255,174,267,174,268,174,269,174,274,174,275,174,283,174,285,174,287,174,308,174,310,174,311,174,312,174,317,174,320,174,321,174,322,174,96,175,97,175,101,175,105,175,106,175,113,175,114,175,116,175,118,175,119,175,123,175,128,175,129,175,135,175,136,175,137,175,245,175,247,175,248,175,249,175,252,175,253,175,255,175,267,175,268,175,269,175,274,175,275,175,279,175,280,175,281,175,282,175,287,175,314,175,317,175,320,175,321,175,322,175,96,176,97,176,102,176,103,176,106,176,107,176,111,176,132,176,140,176,245,176,247,176,249,176,250,176,251,176,252,176,255,176,261,176,265,176,267,176,268,176,269,176,272,176,273,176,274,176,275,176,276,176,277,176,278,176,279,176,280,176,282,176,284,176,285,176,303,176,313,176,314,176,102,177,103,177,119,177,139,177,243,177,244,177,245,177,250,177,251,177,252,177,253,177,255,177,260,177,261,177,264,177,265,177,271,177,272,177,273,177,275,177,278,177,280,177,281,177,282,177,285,177,317,177,92,178,96,178,98,178,103,178,113,178,114,178,115,178,119,178,124,178,131,178,244,178,249,178,250,178,261,178,262,178,263,178,264,178,267,178,268,178,269,178,270,178,274,178,275,178,277,178,278,178,280,178,281,178,283,178,288,178,309,178,317,178,93,179,100,179,103,179,127,179,130,179,131,179,132,179,137,179,243,179,244,179,245,179,247,179,248,179,249,179,254,179,256,179,261,179,262,179,263,179,267,179,268,179,270,179,272,179,277,179,278,179,288,179,313,179,93,180,94,180,95,180,96,180,99,180,100,180,103,180,104,180,105,180,115,180,117,180,125,180,136,180,137,180,138,180,243,180,244,180,248,180,249,180,250,180,251,180,252,180,254,180,256,180,262,180,271,180,272,180,273,180,283,180,306,180,307,180,308,180,311,180,314,180,315,180,318,180,90,181,91,181,94,181,95,181,104,181,111,181,115,181,121,181,122,181,124,181,125,181,127,181,130,181,135,181,138,181,243,181,244,181,247,181,248,181,249,181,252,181,253,181,268,181,269,181,272,181,273,181,276,181,301,181,315,181,316,181,318,181,320,181,87,182,89,182,90,182,91,182,93,182,95,182,96,182,110,182,120,182,127,182,131,182,141,182,243,182,250,182,252,182,255,182,259,182,260,182,261,182,262,182,263,182,264,182,266,182,267,182,268,182,269,182,270,182,271,182,272,182,273,182,275,182,285,182,321,182,88,183,89,183,90,183,92,183,93,183,94,183,95,183,102,183,115,183,127,183,134,183,137,183,141,183,142,183,242,183,243,183,244,183,245,183,249,183,250,183,255,183,256,183,259,183,260,183,261,183,264,183,265,183,266,183,267,183,268,183,270,183,271,183,274,183,275,183,277,183,282,183,286,183,88,184,89,184,90,184,93,184,94,184,95,184,96,184,100,184,104,184,106,184,107,184,121,184,133,184,134,184,135,184,137,184,138,184,139,184,140,184,241,184,243,184,244,184,245,184,248,184,249,184,259,184,260,184,264,184,267,184,268,184,269,184,270,184,271,184,272,184,273,184,274,184,275,184,277,184,279,184,282,184,286,184,88,185,89,185,90,185,94,185,95,185,96,185,100,185,104,185,105,185,106,185,107,185,114,185,125,185,129,185,133,185,134,185,137,185,138,185,240,185,241,185,246,185,249,185,250,185,251,185,252,185,259,185,260,185,267,185,268,185,269,185,270,185,272,185,273,185,274,185,275,185,277,185,278,185,279,185,280,185,285,185,286,185,88,186,90,186,91,186,92,186,93,186,94,186,97,186,103,186,108,186,109,186,110,186,129,186,133,186,143,186,144,186,240,186,241,186,245,186,246,186,249,186,250,186,251,186,261,186,262,186,263,186,264,186,265,186,267,186,268,186,269,186,271,186,272,186,273,186,284,186,285,186,88,187,89,187,91,187,92,187,93,187,95,187,97,187,99,187,107,187,113,187,138,187,141,187,142,187,143,187,144,187,240,187,244,187,250,187,257,187,260,187,261,187,262,187,263,187,264,187,265,187,266,187,267,187,268,187,269,187,270,187,271,187,272,187,275,187,276,187,282,187,89,188,90,188,91,188,92,188,93,188,94,188,95,188,96,188,97,188,98,188,100,188,101,188,102,188,105,188,107,188,114,188,139,188,142,188,143,188,239,188,240,188,242,188,243,188,245,188,246,188,248,188,250,188,255,188,256,188,259,188,260,188,261,188,262,188,263,188,264,188,265,188,266,188,267,188,271,188,272,188,274,188,275,188,277,188,280,188,281,188,282,188,90,189,91,189,92,189,93,189,94,189,95,189,98,189,99,189,101,189,113,189,116,189,121,189,134,189,137,189,145,189,146,189,238,189,239,189,242,189,245,189,249,189,250,189,259,189,260,189,261,189,265,189,266,189,268,189,269,189,270,189,272,189,275,189,276,189,280,189,93,190,94,190,95,190,96,190,97,190,98,190,99,190,100,190,108,190,112,190,117,190,121,190,123,190,127,190,130,190,131,190,133,190,134,190,142,190,145,190,146,190,147,190,240,190,242,190,248,190,249,190,250,190,256,190,259,190,264,190,265,190,266,190,269,190,270,190,275,190,276,190,279,190,90,191,91,191,92,191,93,191,94,191,95,191,96,191,97,191,98,191,107,191,108,191,112,191,126,191,130,191,131,191,132,191,141,191,142,191,143,191,145,191,146,191,147,191,238,191,242,191,244,191,248,191,249,191,250,191,253,191,256,191,259,191,263,191,264,191,265,191,268,191,269,191,270,191,273,191,274,191,280,191,285,191,90,192,91,192,92,192,93,192,94,192,95,192,96,192,97,192,99,192,129,192,130,192,131,192,132,192,140,192,145,192,146,192,236,192,237,192,242,192,243,192,245,192,248,192,253,192,258,192,259,192,261,192,262,192,263,192,264,192,265,192,266,192,267,192,268,192,269,192,270,192,272,192,273,192,275,192,276,192,277,192,285,192,91,193,92,193,93,193,94,193,95,193,96,193,97,193,99,193,102,193,109,193,112,193,125,193,126,193,127,193,129,193,133,193,140,193,145,193,235,193,240,193,242,193,243,193,244,193,247,193,261,193,262,193,264,193,265,193,266,193,269,193,272,193,276,193,277,193,92,194,93,194,94,194,95,194,96,194,99,194,101,194,105,194,108,194,111,194,112,194,127,194,132,194,133,194,138,194,142,194,145,194,146,194,147,194,148,194,235,194,240,194,253,194,259,194,264,194,265,194,266,194,269,194,271,194,274,194,276,194,277,194,91,195,93,195,95,195,96,195,97,195,99,195,100,195,108,195,111,195,124,195,127,195,132,195,133,195,138,195,141,195,145,195,147,195,151,195,234,195,237,195,238,195,239,195,240,195,248,195,249,195,253,195,265,195,267,195,269,195,270,195,271,195,274,195,276,195,91,196,92,196,93,196,94,196,95,196,97,196,98,196,99,196,100,196,101,196,109,196,115,196,123,196,127,196,130,196,135,196,136,196,144,196,149,196,150,196,232,196,233,196,236,196,238,196,243,196,248,196,249,196,252,196,260,196,261,196,262,196,279,196,92,197,93,197,96,197,97,197,98,197,99,197,100,197,101,197,103,197,109,197,110,197,117,197,122,197,123,197,124,197,129,197,134,197,135,197,142,197,144,197,149,197,150,197,232,197,233,197,236,197,237,197,240,197,241,197,247,197,248,197,249,197,252,197,258,197,260,197,263,197,268,197,92,198,93,198,94,198,96,198,97,198,98,198,99,198,100,198,109,198,110,198,144,198,145,198,230,198,231,198,236,198,244,198,247,198,248,198,261,198,263,198,264,198,265,198,267,198,92,199,93,199,94,199,95,199,96,199,97,199,98,199,99,199,100,199,101,199,109,199,110,199,111,199,123,199,124,199,126,199,127,199,133,199,134,199,137,199,138,199,139,199,150,199,229,199,232,199,233,199,236,199,237,199,242,199,243,199,259,199,261,199,264,199,265,199,266,199,92,200,93,200,94,200,97,200,98,200,99,200,100,200,104,200,110,200,111,200,127,200,128,200,133,200,134,200,139,200,146,200,147,200,150,200,151,200,152,200,229,200,230,200,233,200,235,200,241,200,258,200,259,200,264,200,269,200,93,201,94,201,95,201,98,201,99,201,100,201,101,201,102,201,103,201,105,201,121,201,127,201,131,201,132,201,138,201,139,201,144,201,146,201,147,201,150,201,151,201,152,201,154,201,226,201,227,201,233,201,236,201,237,201,241,201,245,201,246,201,254,201,255,201,259,201,260,201,265,201,93,202,94,202,95,202,96,202,98,202,99,202,100,202,101,202,102,202,113,202,114,202,120,202,123,202,124,202,127,202,128,202,129,202,130,202,131,202,132,202,138,202,139,202,143,202,154,202,225,202,226,202,227,202,228,202,230,202,232,202,233,202,234,202,236,202,238,202,239,202,240,202,242,202,245,202,246,202,252,202,254,202,260,202,265,202,266,202,94,203,95,203,96,203,97,203,98,203,99,203,111,203,113,203,114,203,117,203,122,203,127,203,128,203,129,203,130,203,142,203,143,203,154,203,157,203,223,203,224,203,225,203,228,203,232,203,233,203,236,203,237,203,238,203,242,203,246,203,265,203,266,203,268,203,269,203,276,203,94,204,95,204,96,204,97,204,98,204,113,204,114,204,117,204,122,204,123,204,124,204,125,204,126,204,131,204,136,204,142,204,143,204,151,204,152,204,153,204,157,204,158,204,159,204,222,204,223,204,226,204,227,204,228,204,233,204,234,204,237,204,238,204,242,204,253,204,254,204,259,204,260,204,264,204,265,204,266,204,267,204,276,204,95,205,96,205,97,205,98,205,99,205,100,205,112,205,113,205,117,205,121,205,124,205,125,205,130,205,137,205,149,205,150,205,151,205,152,205,153,205,154,205,157,205,158,205,222,205,223,205,224,205,225,205,228,205,230,205,231,205,232,205,234,205,236,205,237,205,238,205,239,205,248,205,252,205,253,205,256,205,257,205,259,205,260,205,263,205,264,205,270,205,95,206,96,206,97,206,98,206,99,206,102,206,112,206,113,206,117,206,121,206,130,206,134,206,135,206,139,206,142,206,144,206,146,206,147,206,148,206,149,206,150,206,151,206,158,206,217,206,218,206,220,206,221,206,222,206,223,206,225,206,228,206,230,206,231,206,232,206,233,206,234,206,235,206,236,206,237,206,238,206,251,206,254,206,255,206,257,206,258,206,262,206,263,206,264,206,265,206,268,206,269,206,271,206,95,207,96,207,97,207,99,207,100,207,113,207,114,207,127,207,139,207,140,207,146,207,147,207,148,207,161,207,162,207,215,207,216,207,217,207,218,207,219,207,221,207,222,207,226,207,229,207,233,207,236,207,237,207,241,207,246,207,251,207,254,207,255,207,261,207,262,207,96,208,97,208,98,208,99,208,100,208,113,208,114,208,115,208,121,208,124,208,126,208,133,208,157,208,158,208,160,208,161,208,215,208,217,208,218,208,219,208,220,208,222,208,226,208,227,208,233,208,235,208,236,208,246,208,247,208,248,208,250,208,251,208,261,208,265,208,266,208,267,208,268,208,269,208,270,208,96,209,97,209,98,209,99,209,100,209,101,209,102,209,106,209,107,209,108,209,115,209,116,209,121,209,125,209,128,209,132,209,133,209,134,209,145,209,154,209,160,209,161,209,211,209,212,209,213,209,214,209,216,209,217,209,218,209,221,209,224,209,225,209,226,209,227,209,229,209,230,209,231,209,232,209,233,209,239,209,240,209,243,209,248,209,251,209,254,209,255,209,264,209,265,209,267,209,270,209,97,210,98,210,99,210,102,210,106,210,107,210,108,210,116,210,119,210,124,210,125,210,132,210,133,210,135,210,137,210,138,210,141,210,142,210,143,210,144,210,145,210,152,210,153,210,154,210,155,210,157,210,160,210,163,210,164,210,166,210,167,210,205,210,211,210,213,210,214,210,215,210,217,210,218,210,219,210,220,210,221,210,222,210,223,210,224,210,225,210,226,210,228,210,232,210,236,210,240,210,244,210,248,210,250,210,251,210,259,210,264,210,267,210,275,210,97,211,98,211,99,211,100,211,101,211,106,211,107,211,108,211,116,211,124,211,128,211,129,211,130,211,131,211,132,211,137,211,145,211,148,211,153,211,163,211,164,211,165,211,166,211,202,211,214,211,216,211,219,211,220,211,221,211,224,211,225,211,228,211,232,211,236,211,237,211,251,211,252,211,253,211,266,211,275,211,97,212,98,212,99,212,100,212,101,212,106,212,108,212,109,212,117,212,120,212,126,212,130,212,131,212,137,212,139,212,140,212,142,212,143,212,146,212,147,212,148,212,154,212,169,212,201,212,205,212,206,212,208,212,210,212,214,212,215,212,216,212,219,212,220,212,221,212,222,212,223,212,224,212,226,212,227,212,230,212,231,212,232,212,242,212,244,212,245,212,250,212,251,212,262,212,263,212,266,212,267,212,268,212,275,212,98,213,100,213,101,213,108,213,134,213,136,213,137,213,145,213,146,213,169,213,206,213,207,213,208,213,209,213,215,213,216,213,217,213,218,213,219,213,220,213,222,213,223,213,224,213,225,213,226,213,231,213,232,213,233,213,240,213,242,213,243,213,244,213,248,213,249,213,250,213,252,213,253,213,254,213,261,213,262,213,273,213,274,213,98,214,100,214,101,214,102,214,107,214,108,214,129,214,130,214,131,214,136,214,143,214,144,214,145,214,146,214,151,214,157,214,158,214,160,214,161,214,168,214,169,214,173,214,174,214,207,214,208,214,210,214,211,214,215,214,216,214,217,214,218,214,219,214,220,214,221,214,222,214,223,214,226,214,231,214,232,214,233,214,239,214,240,214,242,214,243,214,244,214,247,214,248,214,249,214,250,214,252,214,253,214,254,214,260,214,261,214,262,214,263,214,264,214,265,214,273,214,274,214,98,215,100,215,102,215,107,215,108,215,118,215,119,215,129,215,130,215,131,215,132,215,136,215,139,215,140,215,141,215,142,215,143,215,144,215,146,215,148,215,157,215,158,215,160,215,161,215,166,215,167,215,175,215,176,215,178,215,179,215,207,215,208,215,209,215,210,215,211,215,212,215,213,215,214,215,215,215,217,215,218,215,219,215,220,215,221,215,228,215,232,215,235,215,239,215,246,215,247,215,252,215,255,215,256,215,260,215,262,215,263,215,264,215,98,216,107,216,126,216,137,216,138,216,139,216,140,216,141,216,142,216,149,216,154,216,160,216,161,216,164,216,165,216,166,216,167,216,172,216,175,216,176,216,177,216,178,216,179,216,180,216,207,216,211,216,212,216,221,216,228,216,232,216,238,216,239,216,240,216,241,216,242,216,246,216,247,216,248,216,250,216,252,216,253,216,255,216,272,216,102,217,105,217,106,217,107,217,108,217,122,217,125,217,126,217,139,217,140,217,143,217,152,217,153,217,161,217,162,217,163,217,164,217,179,217,184,217,185,217,186,217,187,217,190,217,198,217,200,217,201,217,206,217,207,217,209,217,210,217,211,217,212,217,214,217,215,217,216,217,217,217,224,217,241,217,244,217,245,217,246,217,247,217,248,217,252,217,253,217,257,217,258,217,259,217,261,217,263,217,264,217,270,217,271,217,99,218,101,218,102,218,103,218,104,218,105,218,125,218,133,218,134,218,136,218,142,218,143,218,144,218,163,218,164,218,178,218,179,218,183,218,184,218,185,218,186,218,190,218,191,218,194,218,195,218,197,218,198,218,199,218,200,218,201,218,202,218,203,218,205,218,207,218,208,218,209,218,210,218,215,218,216,218,217,218,218,218,220,218,223,218,224,218,236,218,238,218,244,218,247,218,250,218,251,218,253,218,256,218,257,218,259,218,261,218,262,218,99,219,100,219,101,219,102,219,103,219,104,219,114,219,115,219,133,219,134,219,135,219,136,219,140,219,142,219,143,219,163,219,172,219,175,219,178,219,179,219,183,219,185,219,186,219,190,219,191,219,194,219,197,219,198,219,200,219,201,219,202,219,205,219,206,219,207,219,208,219,209,219,217,219,220,219,228,219,234,219,235,219,237,219,238,219,239,219,240,219,241,219,242,219,243,219,244,219,246,219,249,219,250,219,251,219,256,219,257,219,269,219,98,220,99,220,100,220,101,220,102,220,103,220,104,220,114,220,124,220,134,220,135,220,136,220,139,220,140,220,146,220,150,220,151,220,159,220,163,220,164,220,165,220,166,220,167,220,168,220,175,220,180,220,181,220,182,220,185,220,191,220,196,220,197,220,202,220,205,220,206,220,209,220,214,220,227,220,228,220,229,220,234,220,237,220,241,220,242,220,243,220,245,220,249,220,252,220,256,220,257,220,259,220,260,220,261,220,262,220,267,220,268,220,269,220,97,221,98,221,99,221,100,221,101,221,102,221,103,221,123,221,124,221,138,221,139,221,140,221,141,221,149,221,150,221,151,221,162,221,163,221,164,221,168,221,174,221,184,221,185,221,189,221,190,221,191,221,192,221,193,221,196,221,200,221,201,221,202,221,205,221,209,221,212,221,213,221,214,221,221,221,222,221,223,221,224,221,225,221,227,221,228,221,229,221,232,221,236,221,237,221,238,221,239,221,240,221,241,221,244,221,245,221,246,221,255,221,256,221,257,221,259,221,260,221,267,221,268,221,269,221,96,222,97,222,98,222,99,222,100,222,101,222,102,222,117,222,125,222,128,222,137,222,148,222,150,222,151,222,153,222,158,222,162,222,163,222,173,222,174,222,179,222,184,222,185,222,193,222,196,222,200,222,205,222,212,222,213,222,214,222,216,222,221,222,222,222,223,222,227,222,228,222,229,222,231,222,234,222,235,222,237,222,239,222,243,222,244,222,248,222,249,222,253,222,254,222,255,222,256,222,265,222,95,223,96,223,97,223,98,223,99,223,100,223,101,223,102,223,125,223,126,223,136,223,137,223,138,223,139,223,147,223,148,223,153,223,156,223,157,223,179,223,180,223,184,223,188,223,195,223,199,223,200,223,203,223,204,223,206,223,207,223,212,223,213,223,214,223,216,223,221,223,222,223,223,223,227,223,234,223,237,223,240,223,241,223,242,223,243,223,244,223,247,223,248,223,249,223,250,223,252,223,253,223,256,223,257,223,265,223,94,224,95,224,96,224,97,224,98,224,99,224,100,224,101,224,106,224,107,224,110,224,126,224,136,224,138,224,153,224,156,224,157,224,164,224,167,224,175,224,176,224,180,224,181,224,189,224,194,224,199,224,200,224,204,224,207,224,211,224,212,224,213,224,214,224,215,224,219,224,220,224,226,224,227,224,234,224,235,224,237,224,240,224,243,224,244,224,246,224,247,224,249,224,251,224,252,224,253,224,255,224,261,224,262,224,265,224,266,224,94,225,95,225,96,225,97,225,98,225,99,225,100,225,104,225,111,225,117,225,118,225,128,225,143,225,156,225,166,225,167,225,171,225,188,225,189,225,192,225,193,225,194,225,199,225,200,225,201,225,203,225,204,225,208,225,209,225,211,225,212,225,213,225,214,225,215,225,218,225,219,225,220,225,224,225,225,225,226,225,227,225,231,225,232,225,233,225,234,225,235,225,236,225,237,225,242,225,243,225,247,225,252,225,255,225,256,225,261,225,262,225,265,225,93,226,94,226,95,226,96,226,97,226,98,226,99,226,111,226,128,226,129,226,136,226,137,226,138,226,141,226,143,226,148,226,150,226,161,226,162,226,163,226,166,226,167,226,168,226,169,226,171,226,182,226,183,226,188,226,193,226,194,226,198,226,200,226,201,226,202,226,203,226,205,226,207,226,208,226,209,226,210,226,211,226,212,226,214,226,215,226,219,226,220,226,224,226,226,226,227,226,231,226,232,226,233,226,234,226,236,226,237,226,241,226,242,226,246,226,247,226,251,226,252,226,254,226,255,226,256,226,266,226,92,227,93,227,94,227,95,227,96,227,97,227,98,227,129,227,130,227,134,227,135,227,141,227,146,227,157,227,158,227,167,227,168,227,169,227,170,227,178,227,181,227,182,227,186,227,193,227,198,227,199,227,202,227,206,227,207,227,208,227,218,227,219,227,220,227,221,227,222,227,223,227,228,227,229,227,230,227,231,227,233,227,236,227,237,227,238,227,241,227,242,227,246,227,247,227,249,227,250,227,251,227,254,227,92,228,93,228,94,228,95,228,96,228,97,228,98,228,99,228,100,228,101,228,105,228,108,228,109,228,111,228,148,228,149,228,152,228,153,228,156,228,157,228,160,228,168,228,173,228,179,228,180,228,181,228,194,228,207,228,208,228,209,228,216,228,217,228,218,228,221,228,222,228,223,228,230,228,231,228,232,228,237,228,238,228,241,228,242,228,245,228,249,228,253,228,254,228,257,228,258,228,262,228,277,228,90,229,91,229,92,229,93,229,94,229,95,229,96,229,98,229,101,229,105,229,109,229,112,229,132,229,152,229,156,229,157,229,166,229,178,229,179,229,180,229,188,229,194,229,197,229,200,229,201,229,208,229,217,229,218,229,219,229,220,229,221,229,222,229,224,229,225,229,229,229,230,229,231,229,239,229,240,229,242,229,243,229,244,229,245,229,246,229,248,229,249,229,261,229,262,229,277,229,278,229,90,230,91,230,92,230,93,230,94,230,95,230,100,230,101,230,103,230,104,230,107,230,145,230,147,230,149,230,153,230,154,230,169,230,172,230,175,230,176,230,178,230,179,230,184,230,194,230,195,230,196,230,197,230,199,230,200,230,203,230,204,230,207,230,215,230,216,230,217,230,218,230,219,230,220,230,221,230,224,230,225,230,227,230,228,230,229,230,230,230,231,230,234,230,239,230,240,230,244,230,246,230,248,230,249,230,250,230,251,230,261,230,277,230,89,231,90,231,91,231,92,231,93,231,94,231,95,231,147,231,148,231,158,231,159,231,160,231,167,231,168,231,169,231,170,231,172,231,183,231,193,231,194,231,195,231,199,231,203,231,204,231,205,231,206,231,214,231,215,231,218,231,219,231,225,231,226,231,227,231,228,231,229,231,230,231,231,231,232,231,233,231,234,231,241,231,242,231,243,231,246,231,248,231,249,231,251,231,257,231,276,231,277,231,88,232,89,232,90,232,91,232,92,232,93,232,94,232,95,232,96,232,104,232,105,232,107,232,111,232,112,232,117,232,154,232,155,232,161,232,166,232,167,232,172,232,173,232,175,232,178,232,183,232,188,232,189,232,195,232,198,232,199,232,200,232,201,232,202,232,204,232,205,232,210,232,211,232,213,232,214,232,215,232,216,232,219,232,221,232,222,232,226,232,231,232,232,232,233,232,234,232,235,232,236,232,239,232,243,232,246,232,247,232,249,232,254,232,257,232,87,233,88,233,89,233,90,233,91,233,92,233,108,233,112,233,114,233,138,233,157,233,166,233,170,233,174,233,175,233,183,233,184,233,185,233,186,233,187,233,188,233,189,233,192,233,193,233,194,233,197,233,198,233,199,233,209,233,210,233,213,233,214,233,215,233,218,233,219,233,220,233,225,233,226,233,229,233,230,233,231,233,232,233,235,233,239,233,241,233,245,233,246,233,249,233,250,233,254,233,87,234,88,234,89,234,90,234,106,234,112,234,124,234,138,234,148,234,160,234,166,234,174,234,175,234,183,234,184,234,185,234,186,234,188,234,191,234,192,234,193,234,194,234,197,234,198,234,202,234,207,234,214,234,217,234,218,234,219,234,226,234,227,234,228,234,229,234,230,234,231,234,232,234,234,234,235,234,236,234,237,234,239,234,244,234,245,234,248,234,249,234,254,234,86,235,87,235,88,235,89,235,97,235,98,235,101,235,104,235,105,235,117,235,124,235,138,235,139,235,156,235,169,235,172,235,173,235,177,235,178,235,180,235,181,235,182,235,188,235,190,235,191,235,192,235,193,235,197,235,198,235,202,235,206,235,209,235,212,235,216,235,217,235,225,235,226,235,227,235,228,235,229,235,230,235,234,235,239,235,243,235,244,235,248,235,249,235,85,236,86,236,87,236,88,236,101,236,114,236,151,236,155,236,156,236,157,236,164,236,165,236,168,236,169,236,172,236,177,236,178,236,179,236,180,236,183,236,184,236,188,236,190,236,193,236,197,236,198,236,199,236,200,236,207,236,209,236,215,236,216,236,217,236,220,236,224,236,225,236,227,236,229,236,230,236,232,236,233,236,234,236,239,236,240,236,248,236,249,236,269,236,274,236,275,236,84,237,85,237,86,237,101,237,103,237,109,237,110,237,111,237,116,237,117,237,122,237,146,237,155,237,156,237,161,237,162,237,164,237,165,237,169,237,171,237,172,237,178,237,179,237,180,237,184,237,192,237,195,237,196,237,197,237,198,237,201,237,202,237,203,237,207,237,208,237,209,237,210,237,214,237,215,237,217,237,220,237,222,237,223,237,229,237,230,237,231,237,238,237,239,237,242,237,250,237,273,237,274,237,275,237,276,237,277,237,83,238,84,238,85,238,110,238,157,238,162,238,164,238,184,238,185,238,186,238,187,238,192,238,195,238,196,238,197,238,201,238,202,238,203,238,208,238,209,238,210,238,211,238,214,238,215,238,216,238,222,238,223,238,225,238,227,238,228,238,230,238,233,238,237,238,238,238,242,238,245,238,276,238,282,238,82,239,83,239,105,239,109,239,111,239,112,239,113,239,114,239,117,239,167,239,170,239,179,239,182,239,184,239,185,239,189,239,190,239,195,239,196,239,205,239,207,239,208,239,211,239,214,239,216,239,221,239,222,239,225,239,227,239,228,239,241,239,245,239,102,240,105,240,107,240,111,240,112,240,113,240,148,240,177,240,178,240,180,240,181,240,182,240,184,240,185,240,189,240,190,240,191,240,192,240,195,240,196,240,197,240,200,240,201,240,202,240,204,240,207,240,208,240,210,240,211,240,212,240,213,240,216,240,221,240,227,240,228,240,230,240,240,240,282,240,283,240,102,241,103,241,105,241,107,241,112,241,113,241,116,241,123,241,158,241,162,241,163,241,176,241,177,241,180,241,181,241,184,241,185,241,187,241,188,241,189,241,190,241,191,241,192,241,194,241,195,241,196,241,199,241,200,241,201,241,202,241,203,241,204,241,205,241,206,241,207,241,208,241,213,241,220,241,227,241,228,241,231,241,232,241,234,241,235,241,236,241,240,241,248,241,267,241,283,241,284,241,287,241,288,241,125,242,154,242,161,242,171,242,176,242,177,242,180,242,181,242,184,242,187,242,190,242,194,242,196,242,201,242,202,242,204,242,205,242,206,242,207,242,208,242,209,242,212,242,213,242,215,242,222,242,225,242,226,242,227,242,234,242,267,242,275,242,283,242,284,242,288,242,107,243,110,243,112,243,115,243,117,243,157,243,161,243,175,243,176,243,177,243,183,243,186,243,187,243,188,243,192,243,193,243,198,243,199,243,204,243,205,243,206,243,207,243,209,243,212,243,213,243,214,243,218,243,221,243,222,243,223,243,224,243,225,243,228,243,229,243,232,243,265,243,269,243,270,243,286,243,107,244,156,244,161,244,174,244,182,244,185,244,186,244,187,244,188,244,192,244,193,244,198,244,200,244,201,244,205,244,211,244,212,244,216,244,217,244,218,244,231,244,271,244,284,244,285,244,286,244,107,245,114,245,115,245,159,245,160,245,164,245,180,245,182,245,185,245,186,245,190,245,192,245,193,245,196,245,197,245,198,245,200,245,201,245,204,245,205,245,210,245,211,245,212,245,216,245,217,245,220,245,221,245,222,245,226,245,227,245,228,245,233,245,264,245,275,245,276,245,280,245,284,245,109,246,110,246,117,246,118,246,119,246,175,246,177,246,178,246,180,246,181,246,182,246,183,246,185,246,189,246,190,246,196,246,199,246,201,246,203,246,204,246,210,246,211,246,220,246,221,246,222,246,226,246,227,246,228,246,275,246,276,246,284,246,109,247,110,247,117,247,118,247,119,247,165,247,166,247,175,247,178,247,188,247,189,247,190,247,197,247,199,247,200,247,201,247,202,247,203,247,207,247,209,247,210,247,214,247,221,247,227,247,256,247,278,247,284,247,285,247,182,248,184,248,188,248,189,248,190,248,201,248,204,248,213,248,214,248,220,248,225,248,256,248,111,249,183,249,184,249,188,249,189,249,194,249,198,249,206,249,207,249,214,249,220,249,221,249,225,249,253,249,254,249,272,249,273,249,274,249,278,249,281,249,283,249,111,250,170,250,176,250,183,250,189,250,194,250,198,250,220,250,254,250,272,250,275,250,278,250,283,250,284,250,112,251,113,251,115,251,181,251,182,251,183,251,194,251,197,251,198,251,205,251,208,251,218,251,112,252,113,252,180,252,190,252,191,252,196,252,204,252,205,252,218,252,219,252,256,252,257,252,258,252,269,252,278,252,186,253,189,253,199,253,210,253,218,253,259,253,260,253,272,253,273,253,274,253,278,253,199,254,210,254,213,254,260,254,264,254,274,257,271,258,173,262,269,262,173,263,174,263,176,263,177,263,173,264,184,264,185,264,186,264,187,264,206,264,173,265,195,265,204,265,176,266,179,266,192,266,200,266,201,266,202,266,205,266,176,267,177,267,183,267,200,267,204,267,176,268,177,268,181,268,190,268,176,269,181,269,182,269,195,269,196,269,200,269,187,271,203,271,205,271,184,272,189,272,199,272,202,272,203,272,185,273,189,273,195,273,189,274,191,274,192,274,174,275,175,275,180,275,181,275,182,275,189,275,190,275,191,275,198,275,199,275,180,276,198,276,199,276,200,276,204,276,176,277,180,277,183,277,195,277,200,277,176,278,178,278,179,278,183,278,191,278,192,278,197,278,175,279,176,279,179,279,184,279,187,279,197,279,175,280,181,280,184,280,197,280,204,280,175,281,176,281,186,281,187,281,197,281,198,281,203,281,204,281,175,282,176,282,179,282,183,282,187,282,188,282,194,282,195,282,196,282,197,282,203,282,175,283,176,283,188,283,193,283,194,283,203,283,175,284,184,284,185,284,188,284,192,284,193,284,175,285,195,285,199,285,200,285,175,286,174,288,174,289,173,292,173,293,172,294,172,295,172,296,172,297,172,298,351,316,353,316,149,317,34,318,36,318,37,318,38,318,40,318,62,318,149,318,160,318,199,318,34,319,35,319,36,319,37,319,38,319,39,319,40,319,41,319,42,319,43,319,62,319,75,319,83,319,85,319,86,319,87,319,88,319,89,319,91,319,92,319,93,319,118,319,149,319,151,319,152,319,153,319,154,319,155,319,156,319,157,319,158,319,160,319,161,319,162,319,163,319,164,319,166,319,169,319,173,319,174,319,199,319,214,319,265,319,21,320,23,320,25,320,35,320,36,320,37,320,38,320,39,320,40,320,41,320,42,320,43,320,45,320,48,320,62,320,64,320,68,320,70,320,72,320,73,320,74,320,75,320,77,320,78,320,79,320,80,320,81,320,82,320,83,320,85,320,86,320,87,320,88,320,89,320,90,320,91,320,92,320,93,320,94,320,95,320,97,320,118,320,119,320,121,320,122,320,132,320,135,320,149,320,151,320,152,320,153,320,154,320,155,320,156,320,157,320,158,320,160,320,161,320,162,320,163,320,164,320,166,320,172,320,173,320,175,320,199,320,208,320,209,320,210,320,211,320,212,320,213,320,214,320,215,320,216,320,217,320,255,320,260,320,263,320,264,320,265,320,266,320,20,321,21,321,22,321,35,321,37,321,38,321,39,321,40,321,41,321,42,321,43,321,44,321,46,321,48,321,62,321,63,321,69,321,70,321,72,321,73,321,74,321,75,321,76,321,77,321,79,321,80,321,81,321,82,321,83,321,84,321,85,321,86,321,87,321,88,321,89,321,90,321,91,321,92,321,93,321,94,321,95,321,96,321,97,321,114,321,115,321,118,321,120,321,123,321,133,321,134,321,135,321,149,321,150,321,151,321,152,321,153,321,154,321,155,321,156,321,157,321,158,321,159,321,160,321,161,321,162,321,163,321,164,321,165,321,166,321,167,321,169,321,170,321,172,321,173,321,174,321,177,321,199,321,206,321,207,321,208,321,209,321,210,321,211,321,212,321,213,321,214,321,215,321,216,321,217,321,218,321,219,321,221,321,230,321,254,321,257,321,258,321,261,321,264,321,265,321,266,321,269,321,19,322,20,322,21,322,22,322,23,322,34,322,35,322,36,322,37,322,38,322,39,322,40,322,41,322,42,322,44,322,45,322,47,322,48,322,62,322,69,322,70,322,71,322,72,322,73,322,74,322,75,322,76,322,77,322,78,322,79,322,80,322,82,322,83,322,85,322,86,322,87,322,88,322,89,322,90,322,91,322,92,322,93,322,94,322,95,322,96,322,97,322,112,322,113,322,114,322,115,322,116,322,117,322,118,322,120,322,133,322,134,322,135,322,136,322,149,322,150,322,151,322,152,322,153,322,155,322,156,322,157,322,158,322,159,322,160,322,161,322,162,322,164,322,165,322,169,322,170,322,171,322,172,322,176,322,199,322,204,322,206,322,207,322,208,322,209,322,210,322,211,322,212,322,213,322,214,322,216,322,217,322,218,322,219,322,221,322,248,322,251,322,255,322,260,322,264,322,265,322,268,322,291,322,294,322,295,322,296,322,299,322,300,322,350,322,354,322,18,323,19,323,20,323,21,323,22,323,23,323,24,323,35,323,36,323,37,323,38,323,39,323,40,323,41,323,42,323,43,323,44,323,45,323,46,323,47,323,62,323,63,323,69,323,70,323,72,323,73,323,74,323,75,323,76,323,77,323,78,323,79,323,80,323,81,323,82,323,83,323,84,323,85,323,86,323,88,323,89,323,90,323,91,323,92,323,93,323,94,323,95,323,96,323,97,323,111,323,112,323,113,323,114,323,115,323,116,323,117,323,118,323,119,323,120,323,124,323,125,323,133,323,134,323,135,323,149,323,150,323,151,323,152,323,153,323,154,323,155,323,156,323,157,323,158,323,159,323,160,323,161,323,162,323,163,323,164,323,166,323,170,323,171,323,172,323,173,323,174,323,175,323,176,323,199,323,204,323,205,323,206,323,207,323,208,323,209,323,210,323,211,323,212,323,213,323,214,323,216,323,218,323,219,323,246,323,247,323,248,323,250,323,251,323,253,323,260,323,261,323,262,323,264,323,265,323,266,323,267,323,286,323,289,323,290,323,293,323,295,323,296,323,297,323,298,323,300,323,344,323,347,323,350,323,353,323,17,324,18,324,19,324,20,324,21,324,22,324,23,324,24,324,25,324,30,324,31,324,34,324,35,324,36,324,37,324,38,324,39,324,40,324,42,324,43,324,44,324,45,324,48,324,62,324,63,324,69,324,70,324,72,324,73,324,74,324,76,324,77,324,78,324,79,324,80,324,81,324,82,324,83,324,84,324,86,324,88,324,89,324,90,324,91,324,92,324,93,324,94,324,95,324,96,324,97,324,98,324,110,324,111,324,112,324,113,324,114,324,115,324,116,324,117,324,118,324,119,324,120,324,121,324,125,324,131,324,133,324,134,324,135,324,149,324,151,324,152,324,153,324,154,324,155,324,156,324,157,324,158,324,159,324,160,324,161,324,162,324,163,324,166,324,167,324,168,324,170,324,171,324,174,324,175,324,176,324,199,324,203,324,204,324,205,324,207,324,208,324,210,324,211,324,212,324,213,324,214,324,216,324,217,324,218,324,219,324,246,324,248,324,250,324,251,324,255,324,260,324,264,324,266,324,268,324,271,324,288,324,289,324,293,324,296,324,298,324,299,324,300,324,347,324,348,324,349,324,353,324,354,324,355,324,356,324,16,325,17,325,18,325,19,325,20,325,21,325,22,325,23,325,24,325,25,325,26,325,27,325,28,325,29,325,30,325,34,325,35,325,36,325,37,325,38,325,39,325,40,325,41,325,42,325,43,325,44,325,45,325,46,325,62,325,69,325,70,325,71,325,72,325,73,325,74,325,77,325,78,325,79,325,81,325,82,325,83,325,84,325,87,325,88,325,89,325,91,325,92,325,93,325,94,325,95,325,96,325,97,325,112,325,113,325,114,325,115,325,116,325,117,325,118,325,119,325,120,325,121,325,122,325,124,325,127,325,128,325,133,325,134,325,135,325,136,325,149,325,151,325,152,325,153,325,154,325,155,325,156,325,157,325,158,325,159,325,160,325,161,325,162,325,163,325,164,325,166,325,167,325,168,325,169,325,170,325,171,325,172,325,173,325,174,325,175,325,176,325,177,325,178,325,179,325,199,325,202,325,205,325,207,325,208,325,209,325,210,325,211,325,212,325,213,325,215,325,216,325,217,325,219,325,222,325,249,325,250,325,251,325,257,325,260,325,263,325,265,325,286,325,289,325,290,325,291,325,297,325,298,325,299,325,300,325,301,325,334,325,338,325,353,325,354,325,355,325,15,326,16,326,17,326,18,326,19,326,20,326,21,326,22,326,23,326,24,326,25,326,26,326,27,326,28,326,29,326,35,326,36,326,37,326,38,326,39,326,40,326,41,326,42,326,43,326,62,326,68,326,69,326,70,326,71,326,72,326,73,326,74,326,76,326,77,326,78,326,79,326,80,326,81,326,82,326,84,326,85,326,87,326,89,326,91,326,92,326,93,326,95,326,96,326,97,326,98,326,112,326,113,326,114,326,115,326,116,326,117,326,118,326,119,326,120,326,121,326,122,326,123,326,127,326,128,326,132,326,134,326,135,326,136,326,149,326,151,326,152,326,153,326,154,326,155,326,156,326,157,326,158,326,159,326,160,326,162,326,163,326,164,326,165,326,166,326,167,326,168,326,169,326,170,326,171,326,172,326,173,326,174,326,176,326,177,326,178,326,179,326,184,326,199,326,203,326,205,326,206,326,212,326,213,326,218,326,219,326,220,326,222,326,234,326,246,326,250,326,260,326,262,326,266,326,286,326,289,326,290,326,294,326,297,326,298,326,299,326,300,326,327,326,335,326,14,327,15,327,16,327,17,327,18,327,19,327,20,327,21,327,22,327,23,327,24,327,25,327,26,327,27,327,28,327,34,327,36,327,37,327,38,327,39,327,40,327,42,327,43,327,44,327,46,327,62,327,69,327,70,327,71,327,72,327,73,327,74,327,75,327,76,327,77,327,78,327,79,327,80,327,81,327,82,327,83,327,84,327,85,327,86,327,87,327,89,327,90,327,92,327,93,327,96,327,112,327,113,327,114,327,115,327,116,327,117,327,118,327,119,327,120,327,121,327,122,327,123,327,124,327,125,327,126,327,127,327,128,327,130,327,132,327,136,327,149,327,153,327,154,327,157,327,158,327,159,327,160,327,161,327,162,327,163,327,164,327,165,327,166,327,167,327,168,327,169,327,170,327,171,327,172,327,173,327,174,327,176,327,177,327,179,327,183,327,199,327,202,327,203,327,205,327,206,327,209,327,212,327,215,327,216,327,217,327,220,327,246,327,249,327,250,327,251,327,253,327,255,327,285,327,286,327,288,327,289,327,290,327,298,327,299,327,300,327,335,327,351,327,16,328,17,328,18,328,19,328,20,328,21,328,22,328,23,328,24,328,25,328,26,328,40,328,62,328,69,328,70,328,71,328,72,328,73,328,74,328,76,328,77,328,78,328,79,328,81,328,83,328,85,328,86,328,87,328,89,328,90,328,110,328,112,328,113,328,114,328,115,328,116,328,117,328,118,328,119,328,120,328,121,328,122,328,124,328,125,328,126,328,127,328,128,328,129,328,130,328,132,328,133,328,149,328,164,328,166,328,172,328,173,328,174,328,175,328,176,328,178,328,179,328,180,328,199,328,218,328,246,328,247,328,251,328,286,328,290,328,293,328,327,328,331,328,352,328,353,328,354,328,361,328,362,328,15,329,16,329,17,329,18,329,19,329,20,329,21,329,22,329,23,329,24,329,25,329,62,329,71,329,74,329,77,329,79,329,81,329,85,329,86,329,88,329,89,329,96,329,112,329,113,329,114,329,115,329,116,329,117,329,118,329,119,329,120,329,199,329,246,329,247,329,250,329,251,329,286,329,332,329,352,329,353,329,354,329,355,329,356,329,357,329,358,329,12,330,15,330,16,330,17,330,18,330,19,330,20,330,21,330,22,330,23,330,24,330,25,330,26,330,86,330,87,330,88,330,89,330,97,330,99,330,112,330,113,330,114,330,115,330,116,330,117,330,118,330,119,330,120,330,223,330,224,330,233,330,246,330,247,330,250,330,251,330,354,330,355,330,356,330,357,330,359,330,12,331,15,331,16,331,17,331,18,331,19,331,20,331,21,331,22,331,23,331,24,331,25,331,26,331,27,331,87,331,88,331,89,331,94,331,111,331,112,331,113,331,114,331,115,331,116,331,117,331,118,331,119,331,120,331,121,331,224,331,231,331,246,331,247,331,248,331,250,331,251,331,325,331,356,331,360,331,12,332,15,332,16,332,17,332,18,332,19,332,20,332,21,332,22,332,23,332,24,332,25,332,26,332,27,332,87,332,88,332,89,332,94,332,99,332,111,332,112,332,113,332,114,332,115,332,116,332,117,332,118,332,119,332,120,332,121,332,224,332,231,332,246,332,248,332,250,332,255,332,324,332,357,332,361,332,12,333,15,333,16,333,17,333,18,333,19,333,20,333,21,333,22,333,23,333,24,333,25,333,26,333,27,333,87,333,88,333,89,333,98,333,99,333,111,333,112,333,113,333,114,333,115,333,116,333,117,333,118,333,119,333,120,333,121,333,246,333,247,333,250,333,323,333,324,333,358,333,362,333,12,334,14,334,15,334,16,334,17,334,18,334,19,334,20,334,21,334,22,334,23,334,24,334,25,334,26,334,87,334,88,334,89,334,98,334,111,334,112,334,113,334,114,334,115,334,116,334,117,334,118,334,119,334,120,334,121,334,246,334,247,334,250,334,253,334,316,334,322,334,323,334,359,334,362,334,12,335,14,335,16,335,17,335,18,335,19,335,20,335,21,335,22,335,24,335,25,335,26,335,87,335,88,335,97,335,112,335,113,335,114,335,115,335,116,335,117,335,118,335,119,335,120,335,121,335,224,335,232,335,250,335,252,335,253,335,317,335,318,335,322,335,323,335,360,335,363,335,12,336,15,336,16,336,18,336,19,336,20,336,21,336,22,336,23,336,24,336,25,336,87,336,93,336,98,336,111,336,112,336,113,336,114,336,115,336,116,336,117,336,118,336,119,336,120,336,121,336,224,336,232,336,246,336,247,336,252,336,322,336,323,336,360,336,363,336,12,337,15,337,16,337,17,337,18,337,19,337,20,337,21,337,22,337,23,337,24,337,25,337,91,337,94,337,97,337,111,337,112,337,113,337,114,337,115,337,116,337,117,337,118,337,224,337,233,337,246,337,248,337,252,337,315,337,317,337,322,337,323,337,363,337,12,338,15,338,16,338,17,338,19,338,20,338,21,338,23,338,24,338,25,338,27,338,37,338,38,338,40,338,41,338,62,338,90,338,91,338,94,338,97,338,111,338,112,338,114,338,115,338,116,338,117,338,118,338,119,338,120,338,121,338,159,338,199,338,224,338,228,338,246,338,256,338,257,338,285,338,321,338,323,338,361,338,362,338,363,338,12,339,16,339,17,339,19,339,21,339,23,339,24,339,25,339,26,339,27,339,30,339,31,339,38,339,40,339,41,339,62,339,66,339,68,339,70,339,72,339,74,339,75,339,77,339,79,339,88,339,89,339,91,339,111,339,112,339,114,339,115,339,116,339,117,339,118,339,119,339,120,339,121,339,159,339,160,339,164,339,168,339,169,339,170,339,172,339,173,339,174,339,175,339,199,339,224,339,227,339,246,339,248,339,286,339,322,339,323,339,361,339,363,339,12,340,16,340,17,340,19,340,20,340,21,340,24,340,25,340,26,340,27,340,31,340,38,340,39,340,40,340,41,340,42,340,62,340,63,340,66,340,68,340,70,340,71,340,73,340,74,340,75,340,76,340,77,340,79,340,81,340,84,340,88,340,89,340,91,340,111,340,112,340,113,340,114,340,115,340,116,340,117,340,119,340,120,340,159,340,161,340,162,340,163,340,164,340,165,340,168,340,169,340,174,340,199,340,204,340,205,340,224,340,228,340,246,340,247,340,248,340,286,340,290,340,322,340,323,340,324,340,361,340,362,340,12,341,14,341,16,341,17,341,19,341,20,341,24,341,25,341,26,341,31,341,37,341,38,341,40,341,41,341,62,341,63,341,64,341,65,341,68,341,71,341,72,341,73,341,74,341,75,341,77,341,78,341,80,341,81,341,84,341,86,341,89,341,91,341,95,341,96,341,112,341,113,341,115,341,117,341,119,341,120,341,121,341,159,341,161,341,163,341,164,341,166,341,167,341,168,341,169,341,170,341,172,341,174,341,199,341,202,341,203,341,204,341,205,341,207,341,224,341,229,341,246,341,249,341,253,341,286,341,323,341,361,341,362,341,367,341,12,342,14,342,16,342,17,342,18,342,19,342,21,342,24,342,25,342,26,342,33,342,38,342,62,342,63,342,65,342,66,342,68,342,69,342,70,342,71,342,72,342,74,342,75,342,76,342,77,342,78,342,80,342,82,342,83,342,84,342,88,342,89,342,91,342,92,342,98,342,99,342,111,342,112,342,113,342,115,342,116,342,117,342,120,342,121,342,159,342,161,342,163,342,164,342,165,342,167,342,168,342,169,342,172,342,174,342,199,342,201,342,202,342,203,342,204,342,224,342,246,342,247,342,248,342,286,342,298,342,323,342,324,342,360,342,361,342,364,342,365,342,366,342,367,342,12,343,13,343,16,343,17,343,18,343,19,343,20,343,21,343,23,343,24,343,26,343,62,343,63,343,64,343,65,343,66,343,67,343,68,343,70,343,71,343,72,343,74,343,75,343,76,343,77,343,78,343,79,343,80,343,81,343,82,343,83,343,84,343,86,343,89,343,90,343,91,343,92,343,111,343,112,343,113,343,115,343,116,343,120,343,121,343,159,343,160,343,161,343,162,343,163,343,164,343,165,343,166,343,169,343,170,343,171,343,172,343,174,343,199,343,200,343,202,343,203,343,224,343,246,343,247,343,248,343,286,343,288,343,324,343,364,343,365,343,366,343,12,344,13,344,15,344,16,344,18,344,19,344,20,344,21,344,26,344,62,344,63,344,64,344,65,344,66,344,67,344,68,344,69,344,70,344,71,344,72,344,74,344,75,344,79,344,86,344,91,344,92,344,93,344,98,344,111,344,112,344,113,344,114,344,115,344,116,344,118,344,159,344,160,344,161,344,162,344,163,344,165,344,168,344,169,344,170,344,171,344,172,344,173,344,174,344,175,344,199,344,202,344,203,344,204,344,205,344,206,344,224,344,246,344,247,344,255,344,286,344,293,344,298,344,324,344,325,344,12,345,13,345,15,345,16,345,17,345,18,345,20,345,21,345,24,345,25,345,26,345,27,345,28,345,62,345,63,345,64,345,65,345,66,345,67,345,68,345,69,345,70,345,71,345,72,345,87,345,91,345,96,345,97,345,98,345,111,345,112,345,113,345,114,345,116,345,117,345,159,345,162,345,163,345,164,345,165,345,166,345,169,345,170,345,172,345,173,345,174,345,199,345,200,345,201,345,202,345,203,345,246,345,247,345,248,345,249,345,255,345,286,345,293,345,298,345,325,345,365,345,12,346,13,346,15,346,16,346,17,346,18,346,19,346,24,346,25,346,26,346,28,346,62,346,63,346,67,346,68,346,69,346,70,346,71,346,72,346,73,346,74,346,87,346,89,346,90,346,91,346,97,346,112,346,113,346,114,346,116,346,159,346,160,346,162,346,163,346,164,346,166,346,167,346,168,346,169,346,170,346,171,346,172,346,173,346,174,346,175,346,199,346,203,346,204,346,205,346,206,346,246,346,250,346,252,346,255,346,256,346,286,346,290,346,291,346,293,346,325,346,326,346,12,347,13,347,15,347,16,347,17,347,18,347,19,347,21,347,23,347,24,347,25,347,26,347,62,347,63,347,64,347,66,347,67,347,68,347,69,347,70,347,71,347,72,347,73,347,87,347,88,347,89,347,90,347,91,347,92,347,110,347,112,347,113,347,114,347,115,347,116,347,119,347,120,347,123,347,159,347,161,347,162,347,166,347,167,347,174,347,175,347,199,347,203,347,204,347,205,347,206,347,228,347,230,347,246,347,247,347,251,347,253,347,254,347,255,347,256,347,286,347,289,347,293,347,325,347,327,347,334,347,361,347,362,347,12,348,14,348,15,348,16,348,17,348,18,348,19,348,20,348,22,348,23,348,24,348,25,348,26,348,27,348,62,348,63,348,64,348,66,348,67,348,68,348,69,348,70,348,71,348,72,348,87,348,89,348,91,348,92,348,111,348,112,348,113,348,114,348,115,348,117,348,119,348,120,348,121,348,123,348,124,348,125,348,135,348,159,348,162,348,163,348,164,348,167,348,171,348,173,348,174,348,175,348,199,348,201,348,203,348,204,348,206,348,208,348,209,348,221,348,225,348,232,348,246,348,247,348,250,348,251,348,253,348,254,348,255,348,286,348,325,348,328,348,333,348,363,348,12,349,14,349,15,349,16,349,17,349,18,349,19,349,20,349,21,349,22,349,23,349,24,349,25,349,26,349,27,349,62,349,63,349,66,349,68,349,70,349,71,349,72,349,73,349,74,349,87,349,88,349,89,349,91,349,92,349,96,349,99,349,111,349,112,349,115,349,116,349,119,349,120,349,121,349,122,349,125,349,136,349,159,349,160,349,162,349,163,349,169,349,172,349,173,349,174,349,199,349,200,349,204,349,208,349,209,349,219,349,220,349,223,349,225,349,228,349,229,349,246,349,250,349,251,349,252,349,253,349,254,349,255,349,256,349,286,349,326,349,329,349,359,349,12,350,13,350,15,350,16,350,17,350,18,350,19,350,20,350,21,350,22,350,23,350,24,350,26,350,27,350,63,350,66,350,68,350,70,350,71,350,72,350,73,350,87,350,88,350,89,350,91,350,92,350,93,350,97,350,114,350,115,350,116,350,117,350,118,350,119,350,120,350,121,350,122,350,123,350,125,350,129,350,136,350,159,350,163,350,166,350,170,350,171,350,172,350,174,350,175,350,199,350,204,350,209,350,213,350,216,350,219,350,221,350,222,350,223,350,225,350,228,350,229,350,231,350,246,350,251,350,252,350,253,350,254,350,255,350,256,350,258,350,286,350,327,350,328,350,330,350,331,350,340,350,353,350,356,350,359,350,361,350,12,351,15,351,16,351,17,351,18,351,19,351,20,351,21,351,22,351,23,351,25,351,26,351,27,351,62,351,66,351,68,351,69,351,70,351,71,351,72,351,73,351,74,351,87,351,88,351,92,351,96,351,97,351,111,351,112,351,113,351,114,351,115,351,116,351,117,351,118,351,119,351,121,351,122,351,123,351,125,351,130,351,159,351,162,351,164,351,165,351,167,351,168,351,169,351,170,351,172,351,173,351,174,351,175,351,199,351,205,351,208,351,209,351,213,351,221,351,222,351,224,351,225,351,226,351,227,351,228,351,246,351,247,351,251,351,252,351,253,351,254,351,255,351,256,351,286,351,288,351,291,351,300,351,329,351,332,351,352,351,355,351,356,351,14,352,17,352,18,352,19,352,20,352,21,352,22,352,23,352,24,352,26,352,27,352,62,352,68,352,69,352,70,352,71,352,72,352,73,352,74,352,87,352,88,352,91,352,92,352,93,352,96,352,98,352,111,352,112,352,113,352,114,352,117,352,118,352,119,352,121,352,122,352,123,352,125,352,126,352,127,352,133,352,159,352,164,352,165,352,166,352,167,352,168,352,169,352,170,352,171,352,172,352,173,352,174,352,175,352,199,352,206,352,207,352,209,352,210,352,219,352,222,352,224,352,225,352,227,352,247,352,248,352,253,352,254,352,255,352,256,352,257,352,286,352,322,352,330,352,331,352,332,352,333,352,334,352,349,352,350,352,18,353,19,353,20,353,22,353,23,353,26,353,63,353,64,353,67,353,68,353,69,353,70,353,71,353,72,353,73,353,74,353,87,353,88,353,89,353,90,353,92,353,93,353,94,353,95,353,96,353,112,353,113,353,115,353,116,353,117,353,118,353,119,353,121,353,122,353,123,353,124,353,125,353,126,353,127,353,130,353,159,353,166,353,167,353,169,353,171,353,172,353,173,353,200,353,206,353,210,353,218,353,224,353,225,353,227,353,248,353,249,353,252,353,253,353,254,353,257,353,287,353,323,353,335,353,336,353,348,353,15,354,16,354,20,354,64,354,65,354,67,354,68,354,69,354,70,354,71,354,72,354,73,354,87,354,88,354,89,354,90,354,91,354,93,354,95,354,113,354,114,354,116,354,119,354,122,354,123,354,124,354,130,354,132,354,159,354,167,354,168,354,173,354,174,354,175,354,201,354,218,354,249,354,250,354,254,354,257,354,288,354,324,354,339,354,340,354,65,355,66,355,67,355,69,355,70,355,72,355,74,355,87,355,88,355,89,355,90,355,91,355,93,355,94,355,114,355,115,355,116,355,117,355,118,355,119,355,120,355,121,355,122,355,123,355,124,355,125,355,126,355,127,355,128,355,129,355,130,355,131,355,132,355,133,355,134,355,135,355,136,355,159,355,172,355,202,355,250,355,251,355,289,355,292,355,66,356,87,356,88,356,90,356,91,356,203,356,290,356,342,360}
listsand2 = {199,17,200,17,202,17,203,17,206,17,207,17,208,17,209,17,212,17,192,18,203,18,206,18,207,18,217,18,194,19,195,19,216,19,220,19,206,21,221,21,215,22,225,22,208,23,195,24,218,24,224,25,195,26,206,26,224,26,213,27,215,27,221,28,223,29,213,30,198,31,205,31,206,31,222,31,223,31,204,32,205,32,206,32,194,33,195,33,205,33,206,33,209,33,212,33,218,33,196,34,199,34,200,34,210,34,201,35,202,35,204,35,205,35,209,35,203,36,207,36,211,36,214,36,216,36,220,36,197,37,206,37,207,37,214,37,221,37,193,38,209,38,213,38,214,38,216,38,218,38,219,38,193,39,194,39,199,39,203,39,204,39,208,39,209,39,215,39,194,40,197,40,199,40,201,40,206,40,209,40,221,40,199,41,206,41,209,41,211,41,214,41,217,41,218,41,221,41,198,42,201,42,204,42,206,42,199,43,201,43,214,43,216,43,217,43,219,43,221,43,120,44,192,44,206,44,208,44,215,44,219,44,220,44,185,45,195,45,201,45,202,45,209,45,215,45,220,45,221,45,122,46,188,46,199,46,213,46,215,46,122,47,123,47,180,47,184,47,190,47,195,47,200,47,206,47,214,47,220,47,221,47,183,48,186,48,197,48,198,48,199,48,200,48,201,48,204,48,211,48,213,48,216,48,219,48,125,49,172,49,182,49,184,49,187,49,198,49,199,49,210,49,214,49,215,49,216,49,218,49,124,50,125,50,178,50,183,50,185,50,186,50,195,50,210,50,213,50,214,50,216,50,115,51,125,51,129,51,200,51,203,51,204,51,207,51,208,51,213,51,214,51,127,52,174,52,182,52,185,52,186,52,195,52,205,52,206,52,207,52,216,52,220,52,127,53,128,53,129,53,185,53,186,53,190,53,195,53,200,53,210,53,128,54,130,54,131,54,185,54,186,54,194,54,209,54,210,54,213,54,130,55,131,55,186,55,188,55,191,55,194,55,212,55,220,55,295,55,114,56,128,56,129,56,132,56,134,56,174,56,182,56,194,56,195,56,199,56,201,56,208,56,291,56,296,56,128,57,130,57,131,57,132,57,133,57,134,57,135,57,172,57,174,57,180,57,200,57,202,57,208,57,209,57,215,57,216,57,217,57,245,57,111,58,134,58,135,58,136,58,137,58,182,58,192,58,194,58,203,58,207,58,210,58,220,58,230,58,126,59,128,59,132,59,133,59,134,59,145,59,146,59,175,59,177,59,183,59,184,59,200,59,201,59,205,59,207,59,214,59,286,59,111,60,128,60,133,60,134,60,135,60,136,60,138,60,167,60,172,60,174,60,179,60,181,60,211,60,247,60,248,60,251,60,252,60,290,60,97,61,131,61,135,61,136,61,138,61,145,61,174,61,185,61,220,61,231,61,242,61,243,61,244,61,246,61,249,61,289,61,302,61,96,62,97,62,125,62,127,62,129,62,131,62,138,62,167,62,169,62,194,62,200,62,229,62,230,62,232,62,234,62,236,62,238,62,239,62,240,62,243,62,247,62,248,62,249,62,251,62,252,62,127,63,131,63,138,63,140,63,143,63,144,63,145,63,170,63,171,63,173,63,174,63,178,63,188,63,192,63,198,63,201,63,205,63,227,63,228,63,229,63,235,63,236,63,244,63,245,63,248,63,250,63,254,63,255,63,256,63,120,64,121,64,131,64,135,64,139,64,140,64,143,64,145,64,163,64,165,64,175,64,177,64,178,64,183,64,196,64,197,64,203,64,228,64,238,64,239,64,248,64,256,64,287,64,119,65,124,65,128,65,130,65,133,65,134,65,136,65,143,65,145,65,147,65,151,65,160,65,161,65,163,65,165,65,184,65,188,65,193,65,194,65,204,65,210,65,215,65,233,65,239,65,240,65,249,65,253,65,259,65,260,65,261,65,276,65,121,66,124,66,128,66,145,66,156,66,173,66,174,66,175,66,181,66,184,66,190,66,191,66,197,66,216,66,217,66,219,66,221,66,232,66,234,66,235,66,237,66,238,66,240,66,245,66,247,66,249,66,250,66,258,66,262,66,285,66,116,67,122,67,125,67,139,67,146,67,156,67,181,67,187,67,194,67,198,67,213,67,216,67,232,67,238,67,241,67,249,67,250,67,273,67,286,67,287,67,96,68,119,68,122,68,126,68,129,68,130,68,132,68,133,68,139,68,140,68,145,68,161,68,165,68,182,68,193,68,201,68,202,68,207,68,208,68,213,68,243,68,249,68,250,68,254,68,258,68,259,68,265,68,281,68,285,68,119,69,122,69,123,69,124,69,127,69,129,69,132,69,135,69,137,69,140,69,141,69,142,69,145,69,150,69,151,69,182,69,183,69,195,69,196,69,209,69,211,69,216,69,229,69,239,69,243,69,248,69,249,69,252,69,263,69,265,69,266,69,270,69,286,69,289,69,113,70,115,70,116,70,118,70,123,70,129,70,134,70,141,70,155,70,160,70,165,70,168,70,175,70,176,70,182,70,183,70,195,70,196,70,204,70,209,70,212,70,215,70,218,70,223,70,224,70,227,70,228,70,240,70,242,70,243,70,246,70,247,70,270,70,277,70,283,70,285,70,287,70,289,70,100,71,112,71,113,71,117,71,118,71,120,71,124,71,125,71,127,71,128,71,148,71,149,71,150,71,163,71,168,71,172,71,173,71,175,71,176,71,181,71,183,71,188,71,197,71,205,71,209,71,216,71,221,71,222,71,228,71,240,71,242,71,244,71,246,71,248,71,250,71,254,71,256,71,263,71,265,71,269,71,278,71,279,71,280,71,281,71,285,71,289,71,101,72,110,72,113,72,117,72,118,72,121,72,131,72,132,72,136,72,139,72,144,72,167,72,170,72,176,72,177,72,179,72,181,72,186,72,188,72,195,72,200,72,204,72,209,72,215,72,222,72,223,72,243,72,251,72,255,72,258,72,280,72,283,72,284,72,285,72,288,72,109,73,113,73,115,73,119,73,130,73,131,73,132,73,136,73,137,73,138,73,140,73,162,73,166,73,170,73,173,73,174,73,175,73,176,73,194,73,198,73,205,73,212,73,225,73,228,73,233,73,234,73,236,73,248,73,253,73,254,73,259,73,260,73,262,73,275,73,276,73,280,73,291,73,121,74,130,74,131,74,141,74,156,74,163,74,166,74,167,74,170,74,172,74,173,74,176,74,179,74,180,74,181,74,182,74,186,74,187,74,196,74,199,74,206,74,211,74,213,74,229,74,232,74,248,74,256,74,259,74,264,74,265,74,267,74,272,74,282,74,284,74,285,74,291,74,112,75,117,75,137,75,156,75,160,75,165,75,166,75,167,75,173,75,176,75,177,75,179,75,185,75,192,75,197,75,199,75,207,75,214,75,215,75,216,75,217,75,232,75,237,75,242,75,250,75,254,75,255,75,258,75,264,75,267,75,273,75,277,75,278,75,279,75,280,75,282,75,285,75,287,75,288,75,108,76,111,76,113,76,114,76,120,76,132,76,159,76,162,76,163,76,170,76,171,76,172,76,173,76,174,76,175,76,178,76,181,76,182,76,184,76,202,76,208,76,227,76,231,76,232,76,240,76,242,76,250,76,252,76,256,76,258,76,259,76,260,76,262,76,266,76,276,76,277,76,278,76,279,76,283,76,284,76,289,76,290,76,291,76,109,77,110,77,117,77,118,77,121,77,125,77,130,77,161,77,164,77,166,77,167,77,170,77,171,77,175,77,190,77,203,77,205,77,207,77,208,77,209,77,211,77,213,77,215,77,223,77,231,77,253,77,258,77,261,77,262,77,269,77,273,77,282,77,283,77,287,77,289,77,290,77,292,77,111,78,118,78,119,78,128,78,129,78,134,78,147,78,152,78,154,78,159,78,161,78,163,78,166,78,167,78,171,78,173,78,175,78,181,78,186,78,191,78,192,78,202,78,203,78,212,78,229,78,230,78,244,78,247,78,255,78,262,78,264,78,276,78,278,78,280,78,281,78,286,78,290,78,293,78,116,79,118,79,119,79,120,79,122,79,128,79,132,79,133,79,152,79,162,79,165,79,171,79,172,79,178,79,180,79,182,79,184,79,190,79,192,79,197,79,199,79,210,79,213,79,214,79,220,79,222,79,224,79,235,79,237,79,239,79,247,79,248,79,256,79,269,79,285,79,286,79,287,79,290,79,109,80,116,80,119,80,120,80,121,80,127,80,156,80,158,80,159,80,160,80,163,80,177,80,178,80,179,80,180,80,191,80,197,80,200,80,206,80,208,80,209,80,210,80,212,80,220,80,223,80,234,80,240,80,244,80,245,80,264,80,265,80,269,80,282,80,290,80,297,80,109,81,112,81,113,81,115,81,120,81,123,81,126,81,138,81,140,81,149,81,150,81,152,81,157,81,160,81,163,81,164,81,165,81,167,81,171,81,181,81,182,81,186,81,193,81,206,81,212,81,213,81,216,81,217,81,222,81,226,81,234,81,237,81,238,81,242,81,243,81,250,81,252,81,267,81,268,81,277,81,287,81,288,81,293,81,296,81,298,81,299,81,113,82,114,82,121,82,123,82,138,82,144,82,161,82,169,82,170,82,172,82,186,82,193,82,205,82,222,82,225,82,230,82,236,82,241,82,250,82,252,82,277,82,278,82,288,82,289,82,299,82,111,83,114,83,122,83,123,83,134,83,141,83,144,83,156,83,160,83,161,83,162,83,163,83,173,83,184,83,185,83,186,83,189,83,192,83,217,83,230,83,238,83,239,83,243,83,245,83,246,83,250,83,252,83,276,83,279,83,284,83,289,83,294,83,300,83,115,84,122,84,126,84,127,84,146,84,151,84,155,84,158,84,159,84,162,84,163,84,171,84,172,84,173,84,174,84,178,84,179,84,187,84,189,84,190,84,192,84,202,84,204,84,207,84,210,84,217,84,219,84,231,84,233,84,237,84,240,84,249,84,257,84,279,84,287,84,290,84,291,84,293,84,295,84,296,84,299,84,300,84,301,84,302,84,116,85,139,85,154,85,161,85,168,85,169,85,172,85,174,85,183,85,187,85,190,85,193,85,196,85,203,85,205,85,212,85,213,85,216,85,217,85,221,85,227,85,237,85,238,85,243,85,244,85,245,85,257,85,289,85,290,85,295,85,296,85,297,85,302,85,123,86,144,86,145,86,147,86,149,86,151,86,158,86,165,86,183,86,185,86,186,86,202,86,205,86,208,86,212,86,214,86,224,86,241,86,255,86,256,86,258,86,277,86,278,86,289,86,290,86,296,86,298,86,303,86,120,87,147,87,148,87,151,87,152,87,154,87,161,87,167,87,170,87,171,87,183,87,188,87,189,87,191,87,197,87,199,87,200,87,204,87,206,87,207,87,209,87,212,87,225,87,232,87,239,87,250,87,258,87,277,87,282,87,287,87,289,87,290,87,292,87,293,87,303,87,117,88,118,88,121,88,122,88,124,88,143,88,148,88,152,88,153,88,156,88,182,88,196,88,207,88,211,88,212,88,217,88,218,88,229,88,235,88,238,88,239,88,240,88,242,88,247,88,249,88,250,88,273,88,283,88,287,88,288,88,291,88,292,88,299,88,301,88,117,89,119,89,135,89,136,89,139,89,151,89,156,89,163,89,164,89,167,89,177,89,179,89,180,89,183,89,185,89,187,89,198,89,203,89,205,89,206,89,207,89,213,89,222,89,240,89,275,89,284,89,292,89,293,89,295,89,298,89,126,90,134,90,138,90,150,90,153,90,159,90,171,90,177,90,178,90,182,90,189,90,190,90,195,90,199,90,204,90,206,90,228,90,231,90,251,90,253,90,276,90,277,90,285,90,293,90,295,90,297,90,136,91,138,91,144,91,145,91,150,91,153,91,154,91,162,91,165,91,170,91,171,91,177,91,179,91,180,91,182,91,183,91,190,91,203,91,208,91,212,91,218,91,220,91,225,91,228,91,240,91,241,91,252,91,257,91,260,91,287,91,291,91,293,91,297,91,107,92,131,92,134,92,135,92,138,92,159,92,161,92,170,92,174,92,177,92,178,92,196,92,197,92,202,92,205,92,207,92,209,92,231,92,242,92,244,92,257,92,258,92,281,92,283,92,291,92,292,92,299,92,132,93,152,93,161,93,166,93,173,93,174,93,179,93,182,93,185,93,186,93,187,93,191,93,195,93,198,93,211,93,215,93,216,93,233,93,234,93,291,93,298,93,139,94,140,94,141,94,148,94,156,94,161,94,165,94,171,94,185,94,186,94,187,94,191,94,192,94,193,94,197,94,207,94,209,94,212,94,223,94,224,94,225,94,228,94,236,94,240,94,246,94,247,94,248,94,250,94,254,94,259,94,263,94,283,94,284,94,285,94,290,94,291,94,293,94,294,94,296,94,106,95,109,95,111,95,114,95,119,95,124,95,140,95,147,95,173,95,180,95,187,95,195,95,196,95,197,95,200,95,211,95,212,95,217,95,228,95,229,95,234,95,240,95,243,95,246,95,248,95,252,95,253,95,262,95,263,95,283,95,286,95,294,95,118,96,131,96,138,96,142,96,143,96,159,96,166,96,169,96,178,96,186,96,193,96,196,96,199,96,211,96,212,96,221,96,224,96,227,96,228,96,230,96,234,96,239,96,247,96,251,96,252,96,253,96,255,96,256,96,257,96,261,96,294,96,295,96,107,97,120,97,140,97,141,97,152,97,153,97,159,97,162,97,191,97,193,97,196,97,204,97,211,97,212,97,216,97,217,97,228,97,230,97,236,97,238,97,241,97,245,97,246,97,250,97,261,97,262,97,263,97,266,97,268,97,288,97,108,98,109,98,129,98,130,98,134,98,137,98,140,98,141,98,146,98,148,98,151,98,152,98,154,98,166,98,168,98,169,98,175,98,178,98,180,98,185,98,209,98,213,98,214,98,216,98,227,98,241,98,243,98,244,98,252,98,253,98,254,98,264,98,281,98,290,98,111,99,113,99,134,99,139,99,140,99,152,99,154,99,160,99,165,99,175,99,181,99,189,99,190,99,202,99,209,99,213,99,221,99,224,99,228,99,231,99,249,99,261,99,266,99,268,99,281,99,291,99,110,100,113,100,116,100,130,100,131,100,135,100,137,100,149,100,159,100,170,100,202,100,203,100,210,100,225,100,229,100,232,100,243,100,244,100,246,100,248,100,252,100,254,100,255,100,257,100,261,100,263,100,264,100,114,101,124,101,125,101,128,101,129,101,130,101,133,101,135,101,137,101,146,101,150,101,151,101,164,101,168,101,172,101,182,101,190,101,191,101,192,101,202,101,210,101,217,101,219,101,224,101,229,101,237,101,238,101,240,101,245,101,250,101,257,101,260,101,270,101,288,101,111,102,113,102,115,102,124,102,129,102,140,102,150,102,154,102,163,102,177,102,186,102,220,102,224,102,231,102,232,102,240,102,241,102,242,102,244,102,245,102,249,102,258,102,259,102,272,102,273,102,289,102,127,103,128,103,138,103,142,103,153,103,157,103,166,103,176,103,177,103,179,103,213,103,219,103,226,103,239,103,251,103,252,103,258,103,261,103,264,103,267,103,272,103,286,103,110,104,123,104,124,104,128,104,132,104,134,104,136,104,149,104,156,104,166,104,178,104,228,104,240,104,241,104,244,104,245,104,246,104,247,104,249,104,251,104,264,104,126,105,127,105,131,105,133,105,135,105,136,105,140,105,147,105,152,105,153,105,155,105,161,105,168,105,174,105,226,105,234,105,241,105,243,105,250,105,252,105,257,105,259,105,260,105,285,105,110,106,120,106,122,106,124,106,130,106,133,106,135,106,140,106,150,106,155,106,160,106,164,106,166,106,167,106,168,106,169,106,228,106,229,106,230,106,234,106,239,106,243,106,244,106,250,106,258,106,259,106,260,106,263,106,264,106,270,106,111,107,122,107,128,107,131,107,132,107,135,107,139,107,146,107,148,107,155,107,156,107,170,107,171,107,222,107,225,107,240,107,241,107,243,107,246,107,251,107,260,107,265,107,268,107,119,108,121,108,128,108,129,108,131,108,133,108,137,108,140,108,143,108,147,108,150,108,228,108,234,108,236,108,237,108,243,108,256,108,259,108,266,108,268,108,269,108,277,108,109,109,113,109,116,109,126,109,133,109,135,109,136,109,157,109,161,109,236,109,242,109,249,109,252,109,255,109,258,109,261,109,262,109,264,109,266,109,267,109,276,109,111,110,112,110,123,110,133,110,135,110,136,110,139,110,141,110,149,110,150,110,156,110,161,110,243,110,245,110,246,110,258,110,259,110,262,110,264,110,267,110,274,110,278,110,279,110,109,111,112,111,120,111,125,111,126,111,127,111,129,111,133,111,134,111,135,111,142,111,161,111,230,111,238,111,249,111,255,111,256,111,257,111,260,111,265,111,267,111,274,111,111,112,115,112,121,112,129,112,146,112,147,112,164,112,233,112,236,112,237,112,254,112,257,112,263,112,270,112,107,113,109,113,110,113,112,113,119,113,121,113,133,113,136,113,141,113,145,113,146,113,151,113,152,113,156,113,237,113,243,113,247,113,251,113,256,113,258,113,262,113,265,113,268,113,104,114,116,114,118,114,130,114,132,114,141,114,154,114,158,114,237,114,240,114,244,114,245,114,250,114,256,114,258,114,102,115,103,115,104,115,110,115,120,115,128,115,132,115,133,115,139,115,144,115,147,115,149,115,151,115,237,115,248,115,261,115,262,115,264,115,270,115,272,115,273,115,275,115,279,115,118,116,119,116,123,116,156,116,237,116,238,116,240,116,249,116,255,116,259,116,260,116,261,116,262,116,264,116,266,116,270,116,107,117,120,117,121,117,124,117,125,117,135,117,141,117,149,117,155,117,156,117,249,117,258,117,259,117,263,117,269,117,273,117,274,117,275,117,278,117,120,118,121,118,131,118,139,118,143,118,150,118,156,118,248,118,251,118,252,118,257,118,267,118,278,118,106,119,114,119,115,119,120,119,121,119,126,119,136,119,140,119,143,119,144,119,148,119,154,119,242,119,247,119,253,119,257,119,264,119,266,119,267,119,268,119,276,119,98,120,104,120,113,120,114,120,120,120,126,120,136,120,144,120,148,120,149,120,152,120,241,120,251,120,260,120,263,120,264,120,267,120,270,120,274,120,279,120,280,120,281,120,104,121,113,121,119,121,126,121,135,121,136,121,138,121,140,121,143,121,144,121,244,121,249,121,252,121,261,121,264,121,271,121,273,121,274,121,283,121,100,122,105,122,107,122,109,122,123,122,124,122,126,122,129,122,130,122,131,122,134,122,137,122,139,122,146,122,150,122,151,122,257,122,260,122,267,122,268,122,271,122,276,122,281,122,282,122,101,123,122,123,124,123,125,123,126,123,129,123,130,123,133,123,148,123,150,123,243,123,255,123,259,123,263,123,265,123,267,123,274,123,275,123,101,124,103,124,116,124,117,124,120,124,134,124,143,124,144,124,253,124,255,124,257,124,259,124,261,124,272,124,277,124,282,124,283,124,104,125,113,125,115,125,117,125,119,125,122,125,123,125,126,125,133,125,141,125,249,125,258,125,262,125,263,125,272,125,275,125,278,125,279,125,280,125,283,125,102,126,113,126,114,126,117,126,123,126,127,126,133,126,138,126,249,126,259,126,262,126,267,126,276,126,277,126,278,126,279,126,99,127,113,127,115,127,118,127,120,127,123,127,125,127,126,127,138,127,246,127,260,127,264,127,266,127,271,127,274,127,101,128,108,128,109,128,123,128,260,128,265,128,277,128,281,128,282,128,288,128,99,129,114,129,132,129,133,129,140,129,141,129,147,129,264,129,272,129,279,129,288,129,98,130,108,130,116,130,117,130,121,130,122,130,125,130,135,130,141,130,147,130,254,130,260,130,263,130,266,130,268,130,272,130,280,130,81,131,83,131,97,131,98,131,100,131,112,131,124,131,145,131,252,131,257,131,259,131,264,131,266,131,272,131,273,131,275,131,276,131,277,131,280,131,282,131,100,132,112,132,125,132,126,132,128,132,131,132,134,132,142,132,251,132,266,132,270,132,271,132,272,132,273,132,275,132,276,132,277,132,280,132,94,133,98,133,112,133,124,133,125,133,126,133,139,133,143,133,261,133,263,133,265,133,270,133,271,133,280,133,284,133,285,133,60,134,92,134,105,134,118,134,123,134,129,134,130,134,131,134,140,134,249,134,252,134,254,134,255,134,266,134,269,134,274,134,282,134,87,135,94,135,106,135,111,135,119,135,123,135,131,135,136,135,141,135,253,135,267,135,270,135,276,135,278,135,88,136,100,136,106,136,107,136,114,136,115,136,116,136,134,136,135,136,136,136,144,136,251,136,252,136,259,136,264,136,270,136,271,136,272,136,273,136,274,136,277,136,282,136,78,137,80,137,82,137,89,137,107,137,116,137,118,137,121,137,122,137,123,137,125,137,126,137,131,137,260,137,264,137,267,137,276,137,282,137,57,138,81,138,85,138,90,138,101,138,105,138,112,138,115,138,118,138,121,138,125,138,126,138,130,138,246,138,250,138,257,138,258,138,262,138,271,138,277,138,281,138,284,138,60,139,71,139,72,139,88,139,99,139,110,139,116,139,120,139,137,139,249,139,250,139,257,139,258,139,260,139,263,139,264,139,266,139,267,139,269,139,271,139,272,139,276,139,277,139,278,139,281,139,283,139,286,139,76,140,81,140,93,140,101,140,108,140,109,140,115,140,117,140,121,140,124,140,130,140,140,140,141,140,255,140,257,140,259,140,265,140,266,140,269,140,270,140,275,140,277,140,278,140,78,141,88,141,113,141,114,141,118,141,119,141,125,141,126,141,135,141,259,141,263,141,266,141,268,141,269,141,274,141,277,141,280,141,281,141,282,141,76,142,78,142,83,142,89,142,113,142,115,142,121,142,123,142,125,142,127,142,128,142,130,142,140,142,141,142,242,142,252,142,255,142,261,142,266,142,269,142,278,142,281,142,282,142,76,143,89,143,111,143,113,143,116,143,129,143,131,143,255,143,258,143,262,143,264,143,266,143,267,143,268,143,270,143,273,143,277,143,283,143,284,143,285,143,288,143,77,144,89,144,91,144,102,144,106,144,123,144,127,144,141,144,267,144,272,144,273,144,281,144,282,144,288,144,291,144,83,145,84,145,85,145,86,145,88,145,95,145,101,145,103,145,111,145,115,145,118,145,119,145,126,145,128,145,140,145,247,145,249,145,252,145,257,145,258,145,259,145,260,145,267,145,274,145,281,145,283,145,284,145,287,145,290,145,60,146,71,146,74,146,76,146,94,146,99,146,107,146,111,146,113,146,114,146,118,146,119,146,133,146,134,146,136,146,258,146,261,146,266,146,268,146,274,146,275,146,279,146,281,146,286,146,290,146,71,147,76,147,83,147,91,147,109,147,118,147,133,147,135,147,136,147,260,147,265,147,266,147,268,147,276,147,279,147,281,147,282,147,291,147,78,148,80,148,92,148,103,148,105,148,106,148,117,148,121,148,126,148,133,148,134,148,248,148,252,148,257,148,263,148,264,148,267,148,271,148,278,148,282,148,285,148,286,148,290,148,291,148,77,149,78,149,81,149,89,149,95,149,106,149,108,149,116,149,126,149,127,149,133,149,140,149,244,149,251,149,253,149,264,149,266,149,270,149,274,149,276,149,277,149,278,149,284,149,293,149,86,150,105,150,106,150,109,150,112,150,113,150,119,150,121,150,123,150,135,150,248,150,251,150,260,150,261,150,266,150,268,150,273,150,276,150,277,150,282,150,303,150,306,150,307,150,77,151,79,151,84,151,88,151,104,151,122,151,123,151,135,151,137,151,249,151,250,151,251,151,253,151,254,151,255,151,261,151,266,151,267,151,268,151,272,151,282,151,284,151,290,151,306,151,56,152,81,152,83,152,86,152,91,152,96,152,100,152,104,152,105,152,106,152,115,152,128,152,135,152,253,152,259,152,265,152,268,152,269,152,270,152,277,152,281,152,283,152,285,152,289,152,310,152,312,152,78,153,79,153,84,153,87,153,112,153,118,153,119,153,120,153,125,153,130,153,131,153,137,153,245,153,249,153,254,153,260,153,262,153,263,153,266,153,272,153,276,153,283,153,286,153,320,153,85,154,94,154,102,154,104,154,111,154,113,154,116,154,117,154,118,154,120,154,125,154,129,154,139,154,248,154,270,154,271,154,277,154,279,154,281,154,282,154,286,154,289,154,293,154,303,154,306,154,307,154,313,154,316,154,318,154,319,154,324,154,75,155,79,155,80,155,85,155,89,155,91,155,94,155,100,155,106,155,109,155,118,155,245,155,248,155,250,155,253,155,257,155,258,155,264,155,265,155,271,155,275,155,276,155,280,155,282,155,316,155,70,156,76,156,77,156,78,156,81,156,83,156,89,156,91,156,110,156,113,156,114,156,117,156,119,156,120,156,123,156,131,156,132,156,250,156,257,156,266,156,267,156,269,156,271,156,272,156,274,156,287,156,288,156,289,156,290,156,291,156,313,156,314,156,74,157,75,157,77,157,78,157,88,157,89,157,99,157,110,157,116,157,117,157,118,157,119,157,120,157,122,157,127,157,129,157,139,157,259,157,267,157,272,157,275,157,276,157,278,157,279,157,283,157,286,157,287,157,290,157,291,157,314,157,77,158,85,158,89,158,94,158,95,158,108,158,109,158,110,158,112,158,120,158,125,158,127,158,129,158,258,158,265,158,266,158,267,158,272,158,273,158,274,158,277,158,280,158,283,158,290,158,308,158,309,158,315,158,317,158,73,159,76,159,77,159,79,159,80,159,84,159,96,159,104,159,108,159,109,159,121,159,124,159,126,159,131,159,132,159,133,159,263,159,264,159,266,159,273,159,274,159,277,159,279,159,282,159,285,159,290,159,305,159,310,159,316,159,320,159,321,159,85,160,86,160,87,160,89,160,98,160,102,160,103,160,105,160,115,160,124,160,137,160,249,160,257,160,262,160,263,160,270,160,279,160,312,160,316,160,317,160,318,160,73,161,82,161,86,161,109,161,112,161,113,161,114,161,124,161,136,161,257,161,260,161,267,161,272,161,273,161,278,161,280,161,284,161,285,161,289,161,291,161,309,161,311,161,315,161,316,161,317,161,321,161,322,161,77,162,78,162,79,162,80,162,84,162,87,162,88,162,90,162,101,162,102,162,105,162,110,162,116,162,117,162,119,162,123,162,124,162,125,162,126,162,139,162,256,162,257,162,260,162,266,162,267,162,273,162,275,162,281,162,282,162,284,162,288,162,303,162,315,162,317,162,67,163,94,163,95,163,109,163,113,163,114,163,124,163,125,163,135,163,138,163,139,163,258,163,266,163,273,163,274,163,282,163,284,163,290,163,311,163,312,163,314,163,315,163,317,163,318,163,322,163,77,164,79,164,80,164,114,164,115,164,122,164,131,164,135,164,260,164,261,164,269,164,272,164,277,164,278,164,283,164,286,164,290,164,291,164,303,164,307,164,312,164,313,164,320,164,323,164,71,165,78,165,88,165,89,165,95,165,105,165,107,165,110,165,112,165,114,165,260,165,264,165,265,165,275,165,279,165,280,165,285,165,290,165,304,165,315,165,316,165,317,165,321,165,58,166,70,166,80,166,88,166,97,166,106,166,108,166,122,166,133,166,137,166,138,166,271,166,278,166,281,166,289,166,290,166,292,166,315,166,317,166,319,166,322,166,323,166,57,167,98,167,112,167,120,167,122,167,127,167,133,167,135,167,136,167,138,167,139,167,257,167,264,167,270,167,271,167,276,167,277,167,279,167,280,167,281,167,286,167,287,167,314,167,315,167,318,167,319,167,320,167,90,168,98,168,112,168,118,168,128,168,133,168,249,168,264,168,269,168,270,168,271,168,274,168,282,168,286,168,287,168,291,168,308,168,310,168,314,168,316,168,319,168,98,169,100,169,107,169,109,169,117,169,118,169,123,169,130,169,136,169,137,169,247,169,261,169,263,169,265,169,275,169,279,169,286,169,291,169,306,169,309,169,311,169,314,169,315,169,103,170,110,170,116,170,126,170,138,170,258,170,260,170,265,170,268,170,271,170,273,170,274,170,279,170,280,170,286,170,291,170,304,170,306,170,310,170,312,170,108,171,111,171,117,171,135,171,136,171,252,171,258,171,260,171,265,171,272,171,273,171,275,171,276,171,279,171,282,171,284,171,302,171,303,171,315,171,323,171,104,172,107,172,111,172,117,172,124,172,127,172,258,172,259,172,275,172,276,172,278,172,287,172,288,172,289,172,317,172,320,172,107,173,109,173,110,173,115,173,118,173,121,173,123,173,127,173,128,173,130,173,265,173,268,173,269,173,274,173,277,173,280,173,281,173,282,173,284,173,288,173,309,173,310,173,317,173,318,173,320,173,321,173,323,173,96,174,97,174,102,174,114,174,118,174,125,174,128,174,134,174,137,174,140,174,245,174,265,174,266,174,270,174,276,174,277,174,280,174,282,174,284,174,306,174,316,174,319,174,323,174,98,175,102,175,111,175,115,175,124,175,125,175,132,175,134,175,273,175,276,175,277,175,278,175,309,175,310,175,318,175,319,175,98,176,105,176,108,176,109,176,113,176,114,176,117,176,118,176,126,176,127,176,128,176,129,176,135,176,141,176,243,176,256,176,258,176,260,176,264,176,271,176,281,176,290,176,302,176,315,176,317,176,319,176,95,177,96,177,104,177,106,177,107,177,108,177,109,177,113,177,123,177,125,177,129,177,130,177,132,177,140,177,256,177,258,177,263,177,268,177,269,177,270,177,274,177,276,177,277,177,279,177,302,177,303,177,310,177,311,177,313,177,318,177,319,177,320,177,88,178,93,178,94,178,95,178,97,178,102,178,108,178,123,178,125,178,129,178,130,178,132,178,272,178,276,178,285,178,308,178,310,178,312,178,313,178,320,178,88,179,89,179,90,179,92,179,94,179,97,179,104,179,107,179,113,179,114,179,115,179,119,179,121,179,124,179,125,179,129,179,133,179,136,179,138,179,264,179,265,179,266,179,269,179,276,179,279,179,283,179,286,179,287,179,302,179,308,179,309,179,310,179,317,179,87,180,90,180,116,180,118,180,126,180,127,180,135,180,246,180,265,180,276,180,277,180,286,180,310,180,313,180,317,180,96,181,98,181,99,181,103,181,112,181,113,181,116,181,120,181,131,181,134,181,141,181,254,181,262,181,271,181,274,181,275,181,280,181,281,181,302,181,319,181,88,182,92,182,94,182,97,182,98,182,109,182,111,182,112,182,116,182,117,182,240,182,242,182,254,182,256,182,274,182,276,182,281,182,286,182,312,182,315,182,316,182,320,182,322,182,87,183,91,183,96,183,97,183,98,183,99,183,107,183,110,183,112,183,120,183,131,183,133,183,140,183,239,183,262,183,269,183,273,183,280,183,281,183,283,183,285,183,313,183,314,183,318,183,321,183,91,184,92,184,99,184,102,184,114,184,115,184,141,184,255,184,262,184,280,184,281,184,283,184,284,184,285,184,303,184,304,184,91,185,93,185,97,185,98,185,108,185,110,185,126,185,128,185,136,185,139,185,262,185,263,185,264,185,265,185,271,185,276,185,282,185,284,185,89,186,95,186,98,186,104,186,107,186,126,186,128,186,132,186,136,186,138,186,142,186,252,186,257,186,258,186,274,186,275,186,277,186,279,186,280,186,282,186,286,186,90,187,94,187,96,187,98,187,100,187,105,187,106,187,108,187,109,187,110,187,114,187,122,187,123,187,126,187,129,187,130,187,131,187,133,187,134,187,135,187,136,187,139,187,245,187,246,187,254,187,255,187,256,187,258,187,277,187,281,187,283,187,99,188,106,188,113,188,115,188,116,188,125,188,131,188,137,188,138,188,140,188,257,188,268,188,269,188,270,188,273,188,89,189,96,189,97,189,102,189,106,189,111,189,114,189,115,189,120,189,123,189,124,189,125,189,127,189,130,189,133,189,142,189,251,189,255,189,256,189,257,189,258,189,262,189,267,189,271,189,273,189,277,189,282,189,89,190,90,190,91,190,92,190,102,190,106,190,107,190,113,190,116,190,118,190,120,190,125,190,132,190,135,190,137,190,238,190,258,190,260,190,263,190,267,190,268,190,271,190,277,190,278,190,280,190,282,190,288,190,99,191,101,191,102,191,106,191,109,191,116,191,120,191,121,191,123,191,129,191,137,191,138,191,140,191,254,191,255,191,262,191,266,191,267,191,271,191,272,191,275,191,278,191,279,191,286,191,98,192,101,192,102,192,103,192,108,192,109,192,116,192,118,192,119,192,125,192,126,192,128,192,137,192,138,192,139,192,147,192,244,192,252,192,254,192,256,192,274,192,281,192,286,192,90,193,98,193,100,193,101,193,103,193,105,193,108,193,116,193,119,193,124,193,128,193,130,193,134,193,135,193,136,193,137,193,138,193,139,193,146,193,248,193,255,193,256,193,258,193,259,193,263,193,267,193,271,193,273,193,275,193,91,194,97,194,100,194,103,194,109,194,116,194,119,194,124,194,125,194,129,194,135,194,140,194,141,194,149,194,234,194,248,194,249,194,254,194,258,194,260,194,263,194,267,194,268,194,272,194,273,194,275,194,92,195,109,195,115,195,125,195,128,195,136,195,137,195,142,195,146,195,233,195,254,195,258,195,264,195,268,195,273,195,275,195,277,195,278,195,281,195,96,196,102,196,103,196,105,196,108,196,119,196,124,196,126,196,137,196,142,196,245,196,251,196,253,196,254,196,256,196,257,196,258,196,263,196,264,196,265,196,274,196,275,196,278,196,281,196,282,196,94,197,102,197,112,197,115,197,118,197,121,197,130,197,132,197,133,197,136,197,143,197,145,197,230,197,244,197,251,197,259,197,261,197,262,197,269,197,277,197,95,198,101,198,102,198,103,198,105,198,106,198,111,198,115,198,118,198,121,198,122,198,123,198,125,198,127,198,128,198,129,198,131,198,138,198,142,198,150,198,249,198,251,198,252,198,256,198,258,198,260,198,262,198,266,198,268,198,102,199,113,199,121,199,125,199,128,199,143,199,144,199,151,199,255,199,256,199,257,199,258,199,263,199,267,199,268,199,269,199,270,199,273,199,275,199,95,200,96,200,101,200,105,200,124,200,129,200,130,200,138,200,141,200,144,200,149,200,153,200,154,200,228,200,234,200,244,200,254,200,255,200,257,200,261,200,263,200,265,200,266,200,268,200,270,200,277,200,280,200,106,201,114,201,120,201,124,201,125,201,128,201,133,201,140,201,143,201,145,201,247,201,248,201,257,201,258,201,261,201,268,201,269,201,270,201,278,201,281,201,97,202,103,202,105,202,106,202,118,202,119,202,121,202,142,202,146,202,155,202,229,202,251,202,253,202,255,202,256,202,258,202,259,202,264,202,275,202,276,202,281,202,102,203,103,203,105,203,118,203,121,203,123,203,124,203,125,203,126,203,136,203,144,203,158,203,243,203,245,203,247,203,254,203,255,203,259,203,260,203,262,203,264,203,275,203,99,204,103,204,119,204,121,204,129,204,130,204,133,204,137,204,144,204,150,204,221,204,225,204,239,204,243,204,245,204,246,204,247,204,248,204,251,204,252,204,261,204,263,204,268,204,272,204,273,204,101,205,122,205,123,205,131,205,134,205,135,205,136,205,140,205,141,205,159,205,242,205,245,205,246,205,247,205,250,205,254,205,258,205,261,205,262,205,265,205,266,205,269,205,276,205,100,206,103,206,106,206,107,206,108,206,120,206,122,206,131,206,132,206,138,206,140,206,143,206,145,206,154,206,159,206,187,206,219,206,250,206,252,206,256,206,259,206,260,206,270,206,98,207,101,207,103,207,104,207,106,207,121,207,122,207,128,207,133,207,138,207,142,207,158,207,163,207,214,207,247,207,248,207,257,207,258,207,260,207,263,207,267,207,268,207,269,207,270,207,271,207,101,208,103,208,104,208,120,208,125,208,127,208,134,208,139,208,145,208,146,208,147,208,159,208,165,208,216,208,223,208,234,208,240,208,245,208,253,208,254,208,255,208,260,208,103,209,109,209,120,209,124,209,126,209,129,209,137,209,138,209,142,209,144,209,146,209,150,209,151,209,153,209,155,209,157,209,159,209,166,209,210,209,234,209,235,209,236,209,242,209,245,209,246,209,247,209,249,209,250,209,252,209,253,209,259,209,260,209,266,209,268,209,269,209,273,209,276,209,100,210,101,210,105,210,109,210,115,210,120,210,121,210,128,210,129,210,134,210,136,210,139,210,140,210,156,210,161,210,165,210,206,210,241,210,249,210,252,210,253,210,254,210,256,210,257,210,263,210,266,210,272,210,276,210,102,211,103,211,104,211,109,211,115,211,117,211,133,211,136,211,138,211,139,211,140,211,141,211,143,211,146,211,151,211,154,211,160,211,167,211,169,211,209,211,210,211,231,211,244,211,254,211,256,211,257,211,259,211,262,211,263,211,105,212,121,212,125,212,127,212,132,212,136,212,138,212,144,212,149,212,150,212,153,212,155,212,162,212,163,212,170,212,171,212,203,212,207,212,228,212,233,212,237,212,240,212,241,212,243,212,249,212,255,212,256,212,257,212,260,212,264,212,269,212,99,213,102,213,105,213,109,213,120,213,125,213,126,213,130,213,133,213,135,213,139,213,140,213,141,213,142,213,143,213,144,213,148,213,151,213,154,213,161,213,173,213,174,213,199,213,200,213,203,213,204,213,205,213,211,213,214,213,227,213,230,213,239,213,251,213,255,213,258,213,264,213,265,213,267,213,268,213,269,213,272,213,275,213,126,214,128,214,132,214,133,214,135,214,137,214,140,214,141,214,152,214,156,214,167,214,171,214,175,214,203,214,204,214,205,214,225,214,228,214,246,214,255,214,266,214,267,214,269,214,99,215,106,215,112,215,135,215,145,215,149,215,151,215,152,215,154,215,159,215,171,215,172,215,173,215,174,215,202,215,216,215,222,215,227,215,231,215,233,215,234,215,237,215,243,215,250,215,253,215,254,215,257,215,261,215,270,215,272,215,273,215,99,216,100,216,102,216,105,216,108,216,109,216,110,216,125,216,127,216,135,216,136,216,153,216,156,216,171,216,182,216,184,216,206,216,210,216,215,216,217,216,224,216,229,216,235,216,245,216,249,216,254,216,256,216,260,216,261,216,262,216,264,216,270,216,271,216,99,217,103,217,104,217,124,217,129,217,130,217,134,217,136,217,137,217,138,217,141,217,148,217,154,217,156,217,157,217,158,217,165,217,171,217,175,217,180,217,182,217,208,217,221,217,225,217,232,217,235,217,236,217,238,217,239,217,240,217,250,217,251,217,254,217,256,217,260,217,262,217,100,218,122,218,129,218,139,218,152,218,157,218,158,218,212,218,213,218,219,218,228,218,232,218,233,218,234,218,235,218,241,218,246,218,248,218,252,218,255,218,258,218,263,218,269,218,270,218,98,219,125,219,132,219,139,219,141,219,144,219,146,219,149,219,150,219,158,219,162,219,164,219,166,219,168,219,176,219,177,219,180,219,184,219,203,219,215,219,221,219,223,219,233,219,236,219,260,219,261,219,262,219,113,220,115,220,122,220,125,220,131,220,141,220,143,220,149,220,158,220,162,220,171,220,172,220,179,220,183,220,186,220,190,220,194,220,217,220,220,220,221,220,223,220,225,220,226,220,233,220,235,220,244,220,248,220,254,220,255,220,258,220,263,220,270,220,114,221,116,221,131,221,134,221,135,221,137,221,145,221,158,221,159,221,167,221,180,221,183,221,186,221,194,221,235,221,242,221,247,221,250,221,251,221,254,221,266,221,130,222,138,222,139,222,140,222,142,222,143,222,145,222,149,222,152,222,157,222,167,222,170,222,178,222,201,222,203,222,204,222,209,222,230,222,233,222,238,222,241,222,246,222,247,222,252,222,257,222,259,222,140,223,146,223,154,223,155,223,160,223,168,223,170,223,172,223,174,223,175,223,176,223,181,223,189,223,194,223,196,223,198,223,202,223,205,223,208,223,215,223,220,223,228,223,230,223,231,223,233,223,235,223,236,223,238,223,239,223,254,223,255,223,266,223,111,224,112,224,118,224,125,224,135,224,139,224,140,224,160,224,165,224,166,224,171,224,179,224,182,224,183,224,188,224,190,224,191,224,195,224,198,224,201,224,203,224,208,224,209,224,210,224,216,224,218,224,221,224,222,224,236,224,238,224,239,224,242,224,245,224,248,224,250,224,254,224,257,224,259,224,103,225,105,225,110,225,112,225,132,225,133,225,136,225,138,225,142,225,144,225,150,225,152,225,157,225,160,225,163,225,164,225,165,225,169,225,170,225,175,225,176,225,182,225,183,225,195,225,198,225,210,225,228,225,240,225,248,225,249,225,250,225,253,225,254,225,259,225,260,225,266,225,100,226,102,226,112,226,131,226,135,226,144,226,146,226,147,226,151,226,170,226,172,226,187,226,190,226,192,226,195,226,196,226,199,226,204,226,206,226,213,226,218,226,223,226,230,226,240,226,243,226,250,226,257,226,262,226,100,227,115,227,147,227,148,227,149,227,153,227,154,227,161,227,173,227,179,227,180,227,184,227,190,227,191,227,192,227,194,227,196,227,201,227,209,227,213,227,214,227,217,227,226,227,232,227,234,227,243,227,244,227,248,227,253,227,255,227,257,227,116,228,117,228,132,228,141,228,145,228,146,228,155,228,159,228,161,228,167,228,170,228,174,228,176,228,177,228,184,228,188,228,193,228,196,228,199,228,205,228,212,228,213,228,226,228,229,228,233,228,235,228,239,228,240,228,244,228,248,228,250,228,251,228,278,228,102,229,103,229,104,229,107,229,108,229,111,229,131,229,139,229,145,229,149,229,153,229,155,229,158,229,159,229,160,229,161,229,162,229,164,229,165,229,169,229,170,229,172,229,173,229,175,229,176,229,186,229,189,229,190,229,203,229,204,229,207,229,209,229,210,229,215,229,216,229,223,229,226,229,227,229,232,229,234,229,235,229,238,229,247,229,252,229,276,229,279,229,280,229,99,230,102,230,105,230,112,230,115,230,116,230,121,230,132,230,137,230,141,230,144,230,146,230,155,230,158,230,161,230,162,230,164,230,165,230,166,230,167,230,168,230,170,230,171,230,173,230,177,230,185,230,186,230,188,230,193,230,198,230,210,230,226,230,232,230,233,230,235,230,238,230,242,230,243,230,245,230,247,230,257,230,262,230,276,230,280,230,101,231,107,231,116,231,119,231,121,231,141,231,145,231,152,231,153,231,154,231,155,231,162,231,164,231,165,231,166,231,171,231,173,231,178,231,184,231,186,231,196,231,197,231,198,231,200,231,207,231,208,231,209,231,210,231,235,231,236,231,237,231,250,231,252,231,253,231,254,231,258,231,261,231,282,231,97,232,103,232,115,232,142,232,143,232,149,232,156,232,158,232,159,232,160,232,170,232,171,232,174,232,179,232,182,232,185,232,186,232,192,232,193,232,203,232,220,232,223,232,225,232,227,232,228,232,229,232,230,232,237,232,241,232,242,232,245,232,248,232,251,232,253,232,258,232,282,232,93,233,95,233,96,233,98,233,99,233,102,233,103,233,106,233,118,233,119,233,137,233,139,233,141,233,147,233,153,233,155,233,156,233,165,233,171,233,176,233,179,233,180,233,191,233,195,233,202,233,204,233,207,233,211,233,216,233,221,233,222,233,236,233,237,233,238,233,247,233,248,233,255,233,257,233,97,234,98,234,99,234,101,234,103,234,107,234,108,234,110,234,111,234,117,234,120,234,125,234,139,234,145,234,147,234,149,234,159,234,164,234,165,234,169,234,170,234,176,234,180,234,181,234,199,234,201,234,213,234,221,234,223,234,225,234,238,234,240,234,241,234,243,234,250,234,96,235,99,235,103,235,111,235,112,235,113,235,114,235,120,235,123,235,125,235,128,235,140,235,148,235,151,235,157,235,164,235,166,235,174,235,176,235,179,235,183,235,185,235,187,235,194,235,196,235,199,235,201,235,207,235,211,235,213,235,214,235,220,235,221,235,223,235,224,235,231,235,232,235,235,235,237,235,238,235,240,235,250,235,97,236,103,236,104,236,113,236,117,236,148,236,152,236,153,236,154,236,160,236,161,236,163,236,181,236,191,236,194,236,196,236,202,236,206,236,208,236,212,236,214,236,218,236,221,236,223,236,226,236,228,236,238,236,247,236,251,236,98,237,99,237,102,237,113,237,121,237,127,237,131,237,148,237,151,237,153,237,154,237,157,237,160,237,168,237,177,237,181,237,188,237,193,237,194,237,199,237,204,237,212,237,213,237,219,237,221,237,237,237,243,237,247,237,248,237,249,237,272,237,278,237,99,238,100,238,102,238,103,238,104,238,109,238,115,238,116,238,122,238,127,238,153,238,158,238,161,238,165,238,177,238,178,238,188,238,189,238,190,238,198,238,204,238,207,238,212,238,213,238,217,238,219,238,221,238,224,238,226,238,229,238,231,238,232,238,236,238,275,238,277,238,279,238,280,238,281,238,106,239,108,239,110,239,118,239,124,239,146,239,147,239,160,239,169,239,171,239,174,239,175,239,178,239,181,239,183,239,186,239,193,239,194,239,197,239,202,239,204,239,206,239,209,239,219,239,223,239,226,239,230,239,231,239,232,239,233,239,234,239,240,239,242,239,273,239,276,239,279,239,280,239,281,239,282,239,283,239,101,240,104,240,108,240,109,240,114,240,117,240,118,240,120,240,147,240,159,240,166,240,167,240,169,240,170,240,176,240,188,240,193,240,194,240,203,240,209,240,217,240,218,240,219,240,220,240,226,240,229,240,231,240,232,240,236,240,241,240,266,240,284,240,287,240,104,241,111,241,114,241,120,241,128,241,148,241,153,241,159,241,186,241,197,241,209,241,212,241,216,241,221,241,225,241,226,241,229,241,239,241,241,241,242,241,266,241,271,241,282,241,105,242,112,242,113,242,114,242,117,242,120,242,124,242,153,242,162,242,165,242,178,242,183,242,185,242,186,242,188,242,191,242,193,242,199,242,220,242,221,242,224,242,228,242,232,242,235,242,236,242,239,242,240,242,242,242,266,242,272,242,287,242,289,242,104,243,105,243,109,243,113,243,114,243,122,243,160,243,162,243,163,243,166,243,178,243,182,243,189,243,190,243,191,243,200,243,201,243,210,243,215,243,230,243,231,243,237,243,264,243,268,243,271,243,272,243,277,243,284,243,285,243,112,244,113,244,115,244,157,244,158,244,163,244,164,244,168,244,173,244,183,244,184,244,189,244,190,244,196,244,210,244,214,244,223,244,224,244,232,244,236,244,237,244,261,244,263,244,264,244,270,244,272,244,273,244,275,244,277,244,283,244,287,244,106,245,116,245,156,245,163,245,167,245,168,245,170,245,173,245,174,245,177,245,178,245,181,245,183,245,187,245,191,245,199,245,203,245,207,245,215,245,223,245,231,245,234,245,241,245,263,245,273,245,277,245,279,245,283,245,285,245,108,246,114,246,115,246,120,246,170,246,171,246,173,246,191,246,192,246,197,246,200,246,212,246,215,246,233,246,257,246,264,246,274,246,277,246,278,246,279,246,285,246,289,246,108,247,112,247,115,247,116,247,161,247,177,247,182,247,184,247,191,247,194,247,195,247,196,247,204,247,205,247,206,247,222,247,225,247,226,247,228,247,257,247,258,247,259,247,279,247,280,247,109,248,110,248,111,248,120,248,172,248,175,248,179,248,191,248,195,248,196,248,197,248,202,248,205,248,209,248,253,248,257,248,258,248,259,248,278,248,279,248,280,248,281,248,286,248,287,248,113,249,116,249,117,249,174,249,181,249,182,249,195,249,201,249,204,249,205,249,213,249,219,249,224,249,282,249,110,250,167,250,169,250,181,250,187,250,188,250,197,250,206,250,214,250,221,250,253,250,267,250,271,250,274,250,276,250,281,250,282,250,114,251,170,251,179,251,180,251,193,251,196,251,209,251,210,251,219,251,258,251,259,251,272,251,274,251,277,251,278,251,284,251,114,252,175,252,183,252,184,252,187,252,189,252,193,252,194,252,197,252,203,252,208,252,209,252,259,252,268,252,272,252,274,252,277,252,279,252,187,253,190,253,196,253,217,253,261,253,263,253,264,253,266,253,271,253,275,253,279,253,183,254,186,254,189,254,202,254,203,254,259,254,263,254,265,254,275,254,282,254,196,255,203,255,273,255,274,255,275,255,277,255,280,255,263,256,273,256,274,256,273,257,264,258,268,258,270,258,273,258,265,259,267,259,270,259,271,259,272,259,266,260,174,262,268,262,270,262,175,263,181,263,182,263,174,264,205,264,207,264,174,265,179,265,185,265,186,265,190,265,191,265,194,265,202,265,203,265,205,265,190,266,199,266,204,266,180,267,184,267,188,267,203,267,180,268,182,268,188,268,189,268,195,268,200,268,207,269,175,270,176,270,181,270,182,270,187,270,196,270,205,270,174,271,177,271,178,271,184,271,177,272,178,272,185,272,187,272,195,272,200,272,205,272,177,273,179,273,184,273,190,273,193,273,200,273,174,274,180,274,182,274,190,274,193,274,194,274,198,274,199,274,205,274,185,275,192,275,193,275,202,275,204,275,205,275,175,276,185,276,202,276,175,277,179,277,181,277,182,277,190,277,191,277,192,277,196,277,197,277,201,277,202,277,204,277,175,278,177,278,182,278,186,278,187,278,188,278,195,278,196,278,201,278,177,279,178,279,180,279,181,279,186,279,188,279,196,279,198,279,204,279,205,279,183,280,189,280,193,280,196,280,201,280,202,280,203,280,181,281,182,281,183,281,184,281,185,281,189,281,192,281,193,281,194,281,199,281,202,281,177,282,178,282,186,282,190,282,191,282,192,282,202,282,204,282,178,283,180,283,186,283,190,283,191,283,196,283,204,283,176,284,178,284,179,284,180,284,183,284,186,284,190,284,191,284,199,284,200,284,201,284,184,285,188,285,189,285,192,285,193,285,194,285,196,285,198,285,174,287,175,287,173,289,173,290,173,291,173,294,171,296,348,316,349,316,350,316,352,316,28,317,34,317,348,317,349,317,350,317,351,317,352,317,23,318,26,318,27,318,28,318,29,318,30,318,31,318,32,318,33,318,35,318,39,318,41,318,42,318,43,318,44,318,47,318,48,318,67,318,69,318,70,318,71,318,72,318,73,318,74,318,75,318,76,318,77,318,78,318,81,318,82,318,151,318,152,318,153,318,154,318,155,318,156,318,157,318,158,318,159,318,161,318,162,318,163,318,164,318,165,318,166,318,167,318,170,318,171,318,172,318,175,318,176,318,179,318,181,318,183,318,184,318,185,318,263,318,352,318,353,318,22,319,23,319,24,319,25,319,26,319,27,319,28,319,29,319,31,319,32,319,44,319,45,319,46,319,47,319,63,319,64,319,65,319,66,319,67,319,68,319,69,319,70,319,71,319,72,319,73,319,74,319,76,319,77,319,78,319,79,319,80,319,81,319,82,319,84,319,90,319,94,319,117,319,119,319,120,319,121,319,122,319,123,319,124,319,125,319,127,319,129,319,132,319,134,319,148,319,150,319,159,319,165,319,167,319,168,319,170,319,171,319,172,319,175,319,176,319,177,319,178,319,180,319,181,319,182,319,183,319,184,319,185,319,198,319,206,319,208,319,209,319,210,319,211,319,212,319,213,319,215,319,216,319,217,319,222,319,252,319,256,319,257,319,259,319,260,319,261,319,262,319,263,319,264,319,266,319,267,319,268,319,22,320,24,320,26,320,27,320,28,320,29,320,30,320,33,320,34,320,44,320,46,320,47,320,63,320,65,320,66,320,67,320,69,320,71,320,76,320,84,320,96,320,114,320,115,320,116,320,117,320,120,320,123,320,124,320,125,320,126,320,127,320,129,320,130,320,131,320,133,320,134,320,136,320,150,320,159,320,165,320,167,320,168,320,169,320,170,320,171,320,174,320,176,320,177,320,178,320,179,320,180,320,182,320,183,320,184,320,185,320,198,320,203,320,204,320,205,320,206,320,207,320,218,320,219,320,220,320,221,320,224,320,226,320,250,320,251,320,256,320,257,320,258,320,259,320,261,320,262,320,267,320,268,320,269,320,270,320,271,320,273,320,293,320,294,320,295,320,297,320,298,320,299,320,300,320,301,320,23,321,24,321,25,321,26,321,27,321,28,321,30,321,33,321,34,321,36,321,45,321,47,321,49,321,64,321,65,321,66,321,67,321,68,321,71,321,78,321,116,321,119,321,121,321,122,321,124,321,126,321,127,321,128,321,129,321,130,321,131,321,132,321,136,321,168,321,171,321,175,321,176,321,179,321,180,321,181,321,182,321,183,321,184,321,198,321,200,321,202,321,204,321,205,321,220,321,222,321,224,321,226,321,227,321,228,321,229,321,231,321,232,321,233,321,248,321,249,321,250,321,251,321,252,321,253,321,256,321,259,321,260,321,262,321,263,321,267,321,268,321,270,321,271,321,273,321,290,321,291,321,292,321,293,321,294,321,295,321,296,321,297,321,298,321,299,321,300,321,301,321,327,321,328,321,344,321,345,321,347,321,349,321,24,322,25,322,26,322,27,322,28,322,29,322,30,322,31,322,33,322,43,322,46,322,49,322,63,322,64,322,65,322,66,322,67,322,68,322,81,322,84,322,98,322,119,322,121,322,122,322,123,322,124,322,125,322,126,322,131,322,132,322,154,322,163,322,166,322,167,322,168,322,173,322,174,322,175,322,177,322,178,322,179,322,180,322,181,322,182,322,183,322,184,322,185,322,198,322,200,322,201,322,202,322,203,322,205,322,215,322,223,322,224,322,225,322,226,322,228,322,229,322,230,322,232,322,234,322,247,322,249,322,250,322,252,322,253,322,254,322,256,322,257,322,258,322,259,322,261,322,262,322,263,322,266,322,267,322,269,322,270,322,271,322,272,322,273,322,274,322,288,322,289,322,290,322,292,322,293,322,297,322,298,322,301,322,302,322,326,322,327,322,338,322,340,322,341,322,342,322,343,322,345,322,346,322,347,322,349,322,351,322,353,322,357,322,369,322,25,323,26,323,27,323,28,323,29,323,30,323,31,323,33,323,34,323,48,323,64,323,65,323,66,323,67,323,68,323,71,323,87,323,98,323,110,323,121,323,122,323,123,323,126,323,128,323,129,323,131,323,132,323,136,323,165,323,168,323,169,323,177,323,178,323,179,323,180,323,181,323,182,323,183,323,184,323,185,323,200,323,201,323,202,323,203,323,215,323,217,323,220,323,221,323,222,323,223,323,224,323,225,323,227,323,228,323,230,323,231,323,233,323,249,323,252,323,254,323,255,323,256,323,257,323,258,323,259,323,263,323,268,323,269,323,270,323,271,323,272,323,273,323,275,323,287,323,288,323,291,323,292,323,299,323,301,323,302,323,325,323,327,323,328,323,337,323,338,323,339,323,340,323,341,323,342,323,343,323,348,323,349,323,351,323,352,323,354,323,355,323,357,323,358,323,369,323,370,323,371,323,26,324,27,324,28,324,29,324,32,324,33,324,41,324,46,324,47,324,49,324,64,324,65,324,66,324,67,324,68,324,71,324,75,324,85,324,87,324,122,324,123,324,127,324,128,324,132,324,136,324,150,324,164,324,165,324,169,324,172,324,173,324,177,324,178,324,179,324,180,324,181,324,182,324,183,324,184,324,185,324,198,324,200,324,202,324,206,324,209,324,215,324,220,324,222,324,224,324,226,324,227,324,228,324,229,324,230,324,231,324,233,324,249,324,252,324,253,324,254,324,256,324,257,324,259,324,261,324,262,324,263,324,265,324,267,324,269,324,270,324,272,324,273,324,275,324,285,324,286,324,287,324,290,324,291,324,292,324,294,324,295,324,297,324,301,324,325,324,332,324,334,324,335,324,336,324,337,324,338,324,339,324,341,324,344,324,345,324,346,324,350,324,352,324,357,324,371,324,372,324,31,325,32,325,33,325,47,325,48,325,49,325,63,325,64,325,65,325,66,325,67,325,68,325,75,325,76,325,80,325,85,325,90,325,98,325,110,325,123,325,125,325,126,325,129,325,130,325,131,325,132,325,150,325,165,325,180,325,181,325,182,325,183,325,184,325,185,325,200,325,201,325,203,325,204,325,206,325,214,325,218,325,220,325,221,325,224,325,226,325,227,325,230,325,231,325,232,325,233,325,234,325,246,325,247,325,248,325,252,325,253,325,254,325,255,325,256,325,258,325,259,325,261,325,262,325,264,325,266,325,267,325,268,325,269,325,270,325,271,325,272,325,273,325,274,325,287,325,288,325,292,325,293,325,294,325,296,325,302,325,326,325,331,325,332,325,335,325,336,325,337,325,339,325,341,325,343,325,346,325,347,325,350,325,351,325,356,325,358,325,372,325,373,325,30,326,31,326,33,326,34,326,44,326,45,326,46,326,47,326,48,326,49,326,63,326,64,326,65,326,66,326,67,326,75,326,83,326,86,326,88,326,90,326,94,326,110,326,124,326,125,326,126,326,129,326,130,326,131,326,133,326,150,326,161,326,175,326,180,326,181,326,182,326,183,326,185,326,200,326,202,326,204,326,207,326,208,326,209,326,210,326,211,326,214,326,215,326,216,326,217,326,221,326,223,326,224,326,225,326,226,326,227,326,228,326,230,326,231,326,232,326,233,326,247,326,248,326,249,326,251,326,252,326,253,326,254,326,255,326,256,326,257,326,258,326,261,326,263,326,264,326,265,326,267,326,268,326,269,326,270,326,271,326,272,326,273,326,274,326,285,326,287,326,288,326,291,326,292,326,293,326,295,326,296,326,301,326,302,326,329,326,331,326,332,326,333,326,334,326,336,326,337,326,343,326,354,326,355,326,356,326,360,326,361,326,372,326,29,327,30,327,35,327,41,327,45,327,48,327,63,327,64,327,65,327,66,327,68,327,88,327,91,327,94,327,95,327,97,327,98,327,99,327,110,327,129,327,131,327,134,327,135,327,150,327,151,327,152,327,155,327,156,327,175,327,178,327,180,327,181,327,182,327,184,327,185,327,200,327,204,327,207,327,208,327,210,327,211,327,213,327,214,327,218,327,219,327,221,327,222,327,223,327,226,327,229,327,230,327,231,327,232,327,234,327,235,327,247,327,252,327,254,327,256,327,262,327,263,327,264,327,265,327,266,327,267,327,268,327,269,327,270,327,271,327,272,327,273,327,291,327,292,327,293,327,294,327,295,327,296,327,297,327,301,327,330,327,331,327,332,327,333,327,336,327,344,327,352,327,353,327,360,327,15,328,27,328,28,328,37,328,39,328,41,328,42,328,43,328,44,328,46,328,47,328,48,328,63,328,64,328,66,328,68,328,75,328,80,328,82,328,84,328,88,328,91,328,92,328,93,328,94,328,95,328,96,328,97,328,98,328,99,328,123,328,131,328,134,328,136,328,152,328,153,328,154,328,156,328,158,328,159,328,160,328,161,328,163,328,165,328,167,328,168,328,169,328,170,328,171,328,177,328,181,328,182,328,183,328,203,328,204,328,205,328,206,328,207,328,208,328,209,328,210,328,211,328,212,328,213,328,214,328,215,328,216,328,220,328,226,328,229,328,230,328,231,328,232,328,233,328,235,328,249,328,250,328,252,328,253,328,254,328,255,328,256,328,257,328,263,328,266,328,267,328,269,328,272,328,285,328,289,328,291,328,292,328,294,328,295,328,296,328,297,328,298,328,299,328,300,328,301,328,328,328,329,328,332,328,333,328,334,328,335,328,355,328,356,328,360,328,363,328,14,329,26,329,27,329,28,329,29,329,63,329,66,329,67,329,68,329,70,329,72,329,73,329,75,329,76,329,78,329,80,329,82,329,83,329,84,329,87,329,90,329,91,329,92,329,93,329,94,329,95,329,97,329,98,329,99,329,121,329,127,329,128,329,129,329,130,329,131,329,133,329,200,329,202,329,203,329,204,329,205,329,206,329,207,329,208,329,209,329,210,329,211,329,212,329,213,329,214,329,215,329,216,329,217,329,218,329,223,329,228,329,229,329,230,329,231,329,233,329,248,329,249,329,252,329,253,329,254,329,255,329,256,329,257,329,285,329,292,329,293,329,294,329,296,329,297,329,298,329,299,329,300,329,301,329,326,329,327,329,328,329,330,329,360,329,362,329,363,329,364,329,14,330,27,330,28,330,90,330,92,330,93,330,94,330,95,330,96,330,98,330,121,330,225,330,226,330,228,330,229,330,230,330,231,330,234,330,248,330,249,330,252,330,254,330,255,330,256,330,327,330,330,330,14,331,28,331,90,331,92,331,93,331,96,331,97,331,98,331,99,331,226,331,227,331,228,331,229,331,230,331,232,331,233,331,234,331,249,331,252,331,253,331,254,331,255,331,256,331,257,331,327,331,364,331,365,331,367,331,368,331,13,332,14,332,28,332,29,332,90,332,91,332,92,332,93,332,95,332,96,332,97,332,98,332,226,332,227,332,228,332,230,332,232,332,247,332,249,332,251,332,252,332,253,332,254,332,256,332,257,332,325,332,326,332,327,332,329,332,365,332,367,332,369,332,13,333,14,333,91,333,92,333,93,333,94,333,95,333,96,333,97,333,224,333,226,333,227,333,228,333,230,333,231,333,232,333,233,333,248,333,249,333,251,333,252,333,253,333,254,333,255,333,256,333,257,333,326,333,330,333,331,333,365,333,367,333,13,334,27,334,90,334,91,334,92,334,93,334,94,334,95,334,96,334,97,334,99,334,224,334,226,334,227,334,228,334,230,334,231,334,232,334,233,334,234,334,248,334,249,334,251,334,252,334,255,334,256,334,257,334,324,334,326,334,329,334,365,334,366,334,368,334,369,334,13,335,15,335,23,335,89,335,90,335,91,335,92,335,93,335,94,335,95,335,96,335,98,335,99,335,226,335,228,335,230,335,231,335,234,335,235,335,246,335,247,335,248,335,249,335,251,335,254,335,255,335,256,335,257,335,316,335,325,335,328,335,329,335,367,335,368,335,369,335,370,335,13,336,14,336,17,336,88,336,89,336,90,336,91,336,92,336,94,336,95,336,96,336,97,336,99,336,226,336,227,336,228,336,229,336,230,336,231,336,233,336,235,336,248,336,249,336,250,336,253,336,254,336,255,336,256,336,257,336,317,336,319,336,321,336,366,336,367,336,368,336,369,336,13,337,14,337,26,337,27,337,37,337,38,337,39,337,40,337,41,337,88,337,89,337,90,337,92,337,93,337,95,337,96,337,98,337,99,337,119,337,120,337,159,337,225,337,226,337,227,337,228,337,229,337,230,337,231,337,232,337,247,337,249,337,250,337,251,337,253,337,254,337,255,337,256,337,257,337,316,337,318,337,326,337,330,337,365,337,367,337,368,337,369,337,13,338,14,338,18,338,22,338,26,338,28,338,30,338,33,338,34,338,35,338,36,338,39,338,42,338,64,338,65,338,68,338,70,338,72,338,75,338,77,338,78,338,79,338,80,338,82,338,83,338,87,338,88,338,89,338,92,338,93,338,95,338,96,338,98,338,99,338,113,338,160,338,161,338,162,338,164,338,166,338,168,338,169,338,170,338,171,338,172,338,173,338,174,338,175,338,225,338,226,338,227,338,229,338,230,338,231,338,232,338,233,338,234,338,235,338,247,338,248,338,249,338,250,338,251,338,252,338,253,338,254,338,255,338,258,338,286,338,315,338,316,338,319,338,325,338,326,338,366,338,367,338,368,338,369,338,379,338,14,339,15,339,18,339,20,339,22,339,28,339,29,339,32,339,33,339,34,339,35,339,36,339,37,339,39,339,42,339,43,339,63,339,64,339,65,339,67,339,76,339,78,339,80,339,81,339,82,339,83,339,84,339,86,339,87,339,90,339,92,339,93,339,94,339,95,339,96,339,97,339,98,339,99,339,113,339,161,339,162,339,163,339,165,339,166,339,167,339,171,339,201,339,204,339,205,339,225,339,228,339,229,339,230,339,231,339,232,339,233,339,234,339,247,339,249,339,250,339,251,339,252,339,253,339,254,339,255,339,256,339,257,339,258,339,285,339,289,339,290,339,293,339,295,339,298,339,299,339,321,339,365,339,368,339,369,339,370,339,378,339,379,339,13,340,14,340,15,340,18,340,22,340,23,340,28,340,29,340,30,340,32,340,33,340,34,340,35,340,36,340,37,340,64,340,65,340,72,340,78,340,80,340,82,340,83,340,85,340,86,340,87,340,90,340,92,340,93,340,94,340,95,340,96,340,97,340,98,340,99,340,118,340,160,340,166,340,167,340,170,340,171,340,172,340,173,340,175,340,176,340,200,340,201,340,202,340,203,340,206,340,207,340,225,340,226,340,227,340,229,340,230,340,231,340,232,340,233,340,234,340,235,340,249,340,250,340,251,340,252,340,253,340,254,340,255,340,256,340,257,340,258,340,285,340,288,340,289,340,291,340,292,340,293,340,295,340,297,340,298,340,299,340,301,340,363,340,366,340,367,340,368,340,369,340,370,340,378,340,379,340,13,341,15,341,18,341,21,341,22,341,23,341,27,341,28,341,29,341,30,341,32,341,33,341,34,341,35,341,36,341,39,341,42,341,66,341,67,341,69,341,70,341,76,341,79,341,82,341,83,341,85,341,87,341,88,341,90,341,92,341,93,341,94,341,97,341,98,341,99,341,114,341,116,341,118,341,162,341,165,341,171,341,173,341,175,341,176,341,200,341,201,341,206,341,208,341,209,341,227,341,228,341,230,341,232,341,233,341,234,341,247,341,248,341,250,341,251,341,252,341,255,341,256,341,257,341,285,341,287,341,288,341,289,341,290,341,291,341,292,341,293,341,296,341,297,341,298,341,299,341,301,341,326,341,329,341,364,341,366,341,368,341,377,341,379,341,13,342,15,342,20,342,22,342,23,342,27,342,28,342,29,342,30,342,31,342,32,342,34,342,35,342,37,342,39,342,40,342,64,342,67,342,73,342,79,342,81,342,85,342,86,342,87,342,90,342,93,342,94,342,95,342,96,342,97,342,114,342,118,342,119,342,160,342,162,342,166,342,170,342,171,342,173,342,175,342,176,342,200,342,205,342,206,342,207,342,208,342,209,342,225,342,229,342,230,342,231,342,232,342,233,342,235,342,249,342,251,342,252,342,253,342,254,342,255,342,256,342,285,342,287,342,288,342,289,342,290,342,291,342,292,342,293,342,294,342,295,342,297,342,299,342,300,342,332,342,368,342,369,342,370,342,14,343,15,343,22,343,25,343,27,343,28,343,29,343,35,343,37,343,40,343,69,343,73,343,85,343,87,343,88,343,93,343,95,343,96,343,97,343,98,343,99,343,114,343,117,343,118,343,119,343,167,343,168,343,173,343,175,343,201,343,204,343,205,343,206,343,207,343,208,343,209,343,228,343,230,343,231,343,232,343,233,343,249,343,251,343,252,343,253,343,254,343,255,343,256,343,257,343,285,343,287,343,289,343,290,343,291,343,292,343,293,343,295,343,297,343,298,343,325,343,329,343,330,343,360,343,361,343,363,343,367,343,368,343,14,344,17,344,22,344,23,344,24,344,25,344,27,344,28,344,73,344,78,344,80,344,81,344,83,344,84,344,85,344,87,344,88,344,89,344,90,344,94,344,95,344,96,344,97,344,99,344,117,344,119,344,120,344,121,344,164,344,166,344,167,344,200,344,201,344,207,344,208,344,229,344,230,344,231,344,232,344,233,344,248,344,249,344,250,344,251,344,252,344,253,344,254,344,256,344,257,344,258,344,285,344,288,344,289,344,290,344,291,344,295,344,297,344,300,344,301,344,329,344,361,344,364,344,365,344,366,344,368,344,19,345,22,345,23,345,74,345,88,345,89,345,90,345,92,345,93,345,94,345,95,345,99,345,115,345,118,345,119,345,120,345,160,345,161,345,167,345,171,345,175,345,204,345,205,345,206,345,207,345,208,345,229,345,230,345,231,345,232,345,233,345,234,345,250,345,251,345,252,345,253,345,254,345,256,345,285,345,287,345,289,345,290,345,291,345,292,345,294,345,295,345,296,345,299,345,301,345,302,345,326,345,329,345,330,345,332,345,362,345,363,345,364,345,366,345,20,346,21,346,22,346,23,346,29,346,64,346,65,346,66,346,88,346,92,346,93,346,94,346,95,346,96,346,98,346,99,346,110,346,115,346,117,346,118,346,119,346,120,346,161,346,165,346,176,346,198,346,200,346,201,346,202,346,207,346,208,346,209,346,229,346,230,346,231,346,232,346,233,346,247,346,248,346,249,346,251,346,253,346,254,346,257,346,285,346,287,346,288,346,289,346,292,346,295,346,296,346,297,346,298,346,300,346,302,346,327,346,331,346,334,346,361,346,362,346,363,346,364,346,365,346,366,346,20,347,22,347,27,347,28,347,65,347,93,347,94,347,95,347,96,347,97,347,98,347,99,347,117,347,118,347,121,347,122,347,124,347,127,347,128,347,129,347,130,347,131,347,135,347,136,347,160,347,163,347,164,347,165,347,168,347,169,347,170,347,171,347,172,347,173,347,176,347,200,347,201,347,202,347,207,347,208,347,209,347,223,347,225,347,227,347,229,347,231,347,232,347,233,347,234,347,248,347,249,347,250,347,252,347,257,347,258,347,287,347,290,347,291,347,292,347,297,347,298,347,300,347,301,347,330,347,331,347,332,347,333,347,336,347,359,347,360,347,364,347,365,347,13,348,21,348,28,348,29,348,65,348,73,348,74,348,88,348,90,348,93,348,94,348,95,348,96,348,97,348,98,348,99,348,116,348,122,348,126,348,127,348,128,348,129,348,131,348,132,348,133,348,134,348,136,348,160,348,161,348,165,348,166,348,168,348,169,348,170,348,172,348,176,348,198,348,200,348,202,348,205,348,207,348,215,348,217,348,219,348,220,348,222,348,223,348,224,348,226,348,227,348,228,348,229,348,230,348,231,348,233,348,235,348,248,348,249,348,252,348,256,348,257,348,285,348,287,348,290,348,291,348,292,348,298,348,301,348,329,348,331,348,332,348,338,348,339,348,357,348,358,348,359,348,360,348,361,348,362,348,364,348,13,349,28,349,29,349,64,349,65,349,67,349,69,349,90,349,93,349,94,349,95,349,97,349,98,349,113,349,114,349,117,349,118,349,123,349,124,349,126,349,127,349,128,349,129,349,131,349,132,349,133,349,134,349,135,349,161,349,164,349,165,349,166,349,167,349,168,349,170,349,171,349,175,349,198,349,201,349,202,349,203,349,205,349,206,349,207,349,210,349,211,349,212,349,213,349,214,349,215,349,217,349,221,349,222,349,224,349,226,349,227,349,230,349,231,349,232,349,234,349,247,349,248,349,249,349,257,349,288,349,289,349,290,349,291,349,293,349,294,349,297,349,298,349,299,349,300,349,301,349,330,349,332,349,333,349,340,349,347,349,348,349,349,349,350,349,351,349,352,349,354,349,355,349,356,349,357,349,358,349,360,349,361,349,362,349,363,349,14,350,25,350,28,350,62,350,64,350,65,350,67,350,69,350,74,350,90,350,94,350,95,350,96,350,98,350,112,350,113,350,126,350,127,350,128,350,130,350,133,350,134,350,135,350,160,350,161,350,162,350,164,350,165,350,167,350,168,350,169,350,173,350,176,350,198,350,200,350,201,350,202,350,203,350,205,350,206,350,207,350,208,350,210,350,211,350,212,350,214,350,215,350,217,350,218,350,220,350,224,350,226,350,227,350,230,350,233,350,248,350,249,350,250,350,257,350,285,350,288,350,289,350,291,350,292,350,293,350,295,350,297,350,298,350,299,350,300,350,301,350,336,350,337,350,338,350,343,350,347,350,348,350,350,350,352,350,354,350,355,350,357,350,358,350,360,350,13,351,24,351,28,351,63,351,64,351,65,351,67,351,89,351,90,351,91,351,93,351,94,351,95,351,98,351,99,351,120,351,124,351,126,351,127,351,129,351,131,351,133,351,134,351,135,351,136,351,160,351,161,351,163,351,166,351,171,351,176,351,201,351,203,351,204,351,206,351,207,351,210,351,211,351,212,351,214,351,215,351,216,351,217,351,218,351,219,351,220,351,223,351,229,351,230,351,248,351,250,351,257,351,258,351,287,351,289,351,290,351,292,351,293,351,294,351,296,351,297,351,298,351,302,351,323,351,324,351,337,351,341,351,343,351,344,351,345,351,346,351,347,351,348,351,351,351,353,351,354,351,357,351,358,351,360,351,361,351,13,352,15,352,16,352,25,352,63,352,65,352,66,352,67,352,89,352,90,352,94,352,95,352,97,352,115,352,116,352,124,352,129,352,130,352,131,352,132,352,134,352,135,352,136,352,160,352,161,352,162,352,163,352,176,352,200,352,203,352,204,352,205,352,208,352,211,352,212,352,213,352,214,352,215,352,216,352,217,352,218,352,220,352,221,352,223,352,226,352,228,352,229,352,230,352,252,352,287,352,288,352,289,352,290,352,291,352,292,352,293,352,294,352,297,352,298,352,299,352,300,352,302,352,323,352,325,352,326,352,335,352,343,352,344,352,345,352,346,352,347,352,348,352,351,352,352,352,354,352,355,352,356,352,14,353,15,353,16,353,17,353,21,353,24,353,25,353,27,353,65,353,91,353,97,353,114,353,128,353,131,353,132,353,133,353,134,353,135,353,136,353,160,353,161,353,162,353,163,353,164,353,165,353,168,353,170,353,174,353,175,353,176,353,201,353,204,353,207,353,208,353,209,353,211,353,212,353,213,353,214,353,215,353,216,353,217,353,219,353,220,353,221,353,222,353,223,353,226,353,228,353,230,353,255,353,256,353,258,353,289,353,291,353,292,353,293,353,294,353,295,353,297,353,298,353,300,353,324,353,326,353,337,353,342,353,344,353,345,353,346,353,349,353,350,353,351,353,354,353,355,353,370,353,17,354,18,354,21,354,22,354,24,354,26,354,66,354,74,354,92,354,94,354,97,354,115,354,117,354,121,354,125,354,126,354,127,354,128,354,131,354,133,354,134,354,135,354,136,354,161,354,162,354,163,354,164,354,165,354,166,354,169,354,170,354,171,354,172,354,204,354,207,354,208,354,210,354,211,354,212,354,213,354,215,354,217,354,219,354,220,354,221,354,222,354,223,354,224,354,225,354,226,354,227,354,252,354,253,354,255,354,256,354,258,354,287,354,290,354,294,354,296,354,297,354,298,354,325,354,327,354,338,354,347,354,368,354,369,354,370,354,16,355,68,355,71,355,73,355,92,355,95,355,160,355,162,355,164,355,165,355,166,355,167,355,168,355,169,355,170,355,171,355,173,355,174,355,175,355,203,355,208,355,209,355,220,355,225,355,228,355,252,355,253,355,254,355,256,355,258,355,290,355,294,355,297,355,341,355,342,355,344,355,68,356,71,356,72,356,74,356,89,356,92,356,93,356,94,356,115,356,204,356,207,356,213,356,217,356,291,356,293,356,294,356,295,356,297,356,342,359,346,359,344,360,345,360,347,360,349,360}
listsand3 = {213,17,222,35,298,57,231,58,237,58,139,59,247,59,291,59,187,64,304,64,186,65,199,65,207,66,265,67,239,73,149,79,153,79,200,79,178,82,184,85,254,90,119,93,245,93,241,95,175,97,269,101,158,102,256,102,235,103,235,104,122,115,248,122,151,123,247,123,245,125,127,130,123,136,93,142,136,145,131,149,254,149,95,150,96,154,260,158,326,160,111,164,89,178,119,180,101,183,145,186,138,196,105,197,121,213,143,216,113,219,197,221,163,223,276,228,281,229,142,233,283,233,268,236,215,247,252,249,277,250,267,258,175,265,179,267,194,268,202,271,285,323,285,325,287,328,198,329,331,337,198,345,110,348,288,355}
a=1;
while(a<#listdirt1) do
  x=listdirt1[a+0];
  y=listdirt1[a+1];
  table.insert(tiles,{name="dirt-1",position={posx+x+xoffset,posy+y+yoffset}} );
  a=a+2;
end
a=1;
while(a<#listdirt2) do
  x=listdirt2[a+0];
  y=listdirt2[a+1];
  table.insert(tiles,{name="dirt-2",position={posx+x+xoffset,posy+y+yoffset}} );
  a=a+2;
end
a=1;
while(a<#listdirt3) do
  x=listdirt3[a+0];
  y=listdirt3[a+1];
  table.insert(tiles,{name="dirt-3",position={posx+x+xoffset,posy+y+yoffset}} );
  a=a+2;
end
a=1;
while(a<#listdirt4) do
  x=listdirt4[a+0];
  y=listdirt4[a+1];
  table.insert(tiles,{name="dirt-4",position={posx+x+xoffset,posy+y+yoffset}} );
  a=a+2;
end
a=1;
while(a<#listdirt5) do
  x=listdirt5[a+0];
  y=listdirt5[a+1];
  table.insert(tiles,{name="dirt-5",position={posx+x+xoffset,posy+y+yoffset}} );
  a=a+2;
end
a=1;
while(a<#listdirt6) do
  x=listdirt6[a+0];
  y=listdirt6[a+1];
  table.insert(tiles,{name="dirt-6",position={posx+x+xoffset,posy+y+yoffset}} );
  a=a+2;
end
a=1;
while(a<#listdirt7) do
  x=listdirt7[a+0];
  y=listdirt7[a+1];
  table.insert(tiles,{name="dirt-7",position={posx+x+xoffset,posy+y+yoffset}} );
  a=a+2;
end
a=1;
while(a<#listdrydirt) do
  x=listdrydirt[a+0];
  y=listdrydirt[a+1];
  table.insert(tiles,{name="dry-dirt",position={posx+x+xoffset,posy+y+yoffset}} );
  a=a+2;
end
a=1;
while(a<#listgrass1) do
  x=listgrass1[a+0];
  y=listgrass1[a+1];
  table.insert(tiles,{name="grass-1",position={posx+x+xoffset,posy+y+yoffset}} );
  a=a+2;
end
a=1;
while(a<#listgrass2) do
  x=listgrass2[a+0];
  y=listgrass2[a+1];
  table.insert(tiles,{name="grass-2",position={posx+x+xoffset,posy+y+yoffset}} );
  a=a+2;
end
a=1;
while(a<#listgrass3) do
  x=listgrass3[a+0];
  y=listgrass3[a+1];
  table.insert(tiles,{name="grass-3",position={posx+x+xoffset,posy+y+yoffset}} );
  a=a+2;
end
a=1;
while(a<#listgrass4) do
  x=listgrass4[a+0];
  y=listgrass4[a+1];
  table.insert(tiles,{name="grass-4",position={posx+x+xoffset,posy+y+yoffset}} );
  a=a+2;
end
a=1;
while(a<#listlabdark1) do
  x=listlabdark1[a+0];
  y=listlabdark1[a+1];
  table.insert(tiles,{name="lab-dark-1",position={posx+x+xoffset,posy+y+yoffset}} );
  a=a+2;
end
a=1;
while(a<#listlabdark2) do
  x=listlabdark2[a+0];
  y=listlabdark2[a+1];
  table.insert(tiles,{name="lab-dark-2",position={posx+x+xoffset,posy+y+yoffset}} );
  a=a+2;
end
a=1;
while(a<#listlabwhite) do
  x=listlabwhite[a+0];
  y=listlabwhite[a+1];
  table.insert(tiles,{name="lab-white",position={posx+x+xoffset,posy+y+yoffset}} );
  a=a+2;
end
a=1;
while(a<#listreddesert1) do
  x=listreddesert1[a+0];
  y=listreddesert1[a+1];
  table.insert(tiles,{name="red-desert-1",position={posx+x+xoffset,posy+y+yoffset}} );
  a=a+2;
end
a=1;
while(a<#listreddesert2) do
  x=listreddesert2[a+0];
  y=listreddesert2[a+1];
  table.insert(tiles,{name="red-desert-2",position={posx+x+xoffset,posy+y+yoffset}} );
  a=a+2;
end
a=1;
while(a<#listreddesert3) do
  x=listreddesert3[a+0];
  y=listreddesert3[a+1];
  table.insert(tiles,{name="red-desert-3",position={posx+x+xoffset,posy+y+yoffset}} );
  a=a+2;
end
a=1;
while(a<#listsand1) do
  x=listsand1[a+0];
  y=listsand1[a+1];
  table.insert(tiles,{name="sand-1",position={posx+x+xoffset,posy+y+yoffset}} );
  a=a+2;
end
a=1;
while(a<#listsand2) do
  x=listsand2[a+0];
  y=listsand2[a+1];
  table.insert(tiles,{name="sand-2",position={posx+x+xoffset,posy+y+yoffset}} );
  a=a+2;
end
a=1;
while(a<#listsand3) do
  x=listsand3[a+0];
  y=listsand3[a+1];
  table.insert(tiles,{name="sand-3",position={posx+x+xoffset,posy+y+yoffset}} );
  a=a+2;
end

  game.surfaces[surface].set_tiles(tiles,true);
end -- DrawFactorioGear

-- END ===========================================================
return ovsandbox
